@@ -9,21 +9,14 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Popularity Type."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC.AccountingSystem.Client.Types.BaseAccountingType import BaseAccountingType
 
-__RCSID__ = "$Id$"
-
 
 class Popularity(BaseAccountingType):
     """Popularity as extension of BaseAccountingType."""
 
     def __init__(self):
-
-        super(Popularity, self).__init__()
+        super().__init__()
 
         self.definitionKeyFields = [
             ("DataType", "VARCHAR(64)"),
