@@ -9,18 +9,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_AS_Client_Type_DataStorage."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 
-__RCSID__ = "$Id$"
-
 dummyResults = {}
 
 
-class DummyReturn(object):
+class DummyReturn:
     def __init__(self, *args, **kwargs):
         pass
 
