@@ -123,7 +123,7 @@ class DataStoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "LFN space usage grouped by %s" % reportRequest["grouping"],
+            "title": f"LFN space usage grouped by {reportRequest['grouping']}",
             "starttime": startTime,
             "endtime": endTime,
             "span": span,
@@ -227,7 +227,7 @@ class DataStoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Number of LFNs by %s" % reportRequest["grouping"],
+            "title": f"Number of LFNs by {reportRequest['grouping']}",
             "starttime": startTime,
             "endtime": endTime,
             "span": span,
@@ -328,7 +328,7 @@ class DataStoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "PFN space usage by %s" % reportRequest["grouping"],
+            "title": f"PFN space usage by {reportRequest['grouping']}",
             "starttime": startTime,
             "endtime": endTime,
             "span": span,
@@ -428,7 +428,7 @@ class DataStoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Number of PFNs by %s" % reportRequest["grouping"],
+            "title": f"Number of PFNs by {reportRequest['grouping']}",
             "starttime": startTime,
             "endtime": endTime,
             "span": span,
