@@ -13,17 +13,11 @@
 JobStepPlotter.__bases__:
   DIRAC.AccountingSystem.private.Plotters.BaseReporter.BaseReporter
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK
 from DIRAC.AccountingSystem.private.Plotters.BaseReporter import BaseReporter
 
 from LHCbDIRAC.AccountingSystem.Client.Types.JobStep import JobStep
 
-__RCSID__ = "$Id$"
-
 
 class JobStepPlotter(BaseReporter):
     """JobStepPlotter as an extension of BaseReporter."""
@@ -37,7 +31,6 @@ class JobStepPlotter(BaseReporter):
     _reportCPUEfficiencyName = "CPU efficiency"
 
     def _reportCPUEfficiency(self, reportRequest):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s), SUM(%s)",
@@ -89,9 +82,8 @@ class JobStepPlotter(BaseReporter):
         return S_OK({"data": dataDict, "granularity": granularity})
 
     def _plotCPUEfficiency(self, reportRequest, plotInfo, filename):
-
         metadata = {
-            "title": "CPU efficiency by %s" % reportRequest["grouping"],
+            "title": f"CPU efficiency by {reportRequest['grouping']}",
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
             "span": plotInfo["granularity"],
@@ -105,14 +97,12 @@ class JobStepPlotter(BaseReporter):
     _reportCPUUsageName = "CPU time"
 
     def _reportCPUUsage(self, reportRequest):
-
         field = "CPUTime"
         unit = "time"
 
         return self.__reportNormPlot(reportRequest, field, unit)
 
     def _plotCPUUsage(self, reportRequest, plotInfo, filename):
-
         title = "CPU usage"
 
         return self.__plotNormPlot(reportRequest, plotInfo, filename, title)
@@ -123,11 +113,9 @@ class JobStepPlotter(BaseReporter):
     _reportPieCPUTimeName = "Pie plot of CPU time"
 
     def _reportPieCPUTime(self, reportRequest):
-
         return self.__reportPiePlot(reportRequest, "CPUTime")
 
     def _plotPieCPUTime(self, reportRequest, plotInfo, filename):
-
         title = "CPU time"
         label = "CPUTime"
 
@@ -139,14 +127,12 @@ class JobStepPlotter(BaseReporter):
     _reportCumulativeCPUTimeName = "Cumulative CPU time"
 
     def _reportCumulativeCPUTime(self, reportRequest):
-
         field = "CPUTime"
         unit = "time"
 
         return self.__reportCumulativePlot(reportRequest, field, unit)
 
     def _plotCumulativeCPUTime(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative CPU time"
 
         return self.__plotCumulative(reportRequest, plotInfo, filename, title)
@@ -157,14 +143,12 @@ class JobStepPlotter(BaseReporter):
     _reportNormCPUTimeName = "NormCPU time"
 
     def _reportNormCPUTime(self, reportRequest):
-
         field = "NormCPUTime"
         unit = "time"
 
         return self.__reportNormPlot(reportRequest, field, unit)
 
     def _plotNormCPUTime(self, reportRequest, plotInfo, filename):
-
         title = "Normalized CPU"
 
         return self.__plotNormPlot(reportRequest, plotInfo, filename, title)
@@ -175,14 +159,12 @@ class JobStepPlotter(BaseReporter):
     _reportCumulativeNormCPUTimeName = "Cumulative normalized CPU time"
 
     def _reportCumulativeNormCPUTime(self, reportRequest):
-
         field = "NormCPUTime"
         unit = "time"
 
         return self.__reportCumulativePlot(reportRequest, field, unit)
 
     def _plotCumulativeNormCPUTime(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative Normalized CPU time"
 
         return self.__plotCumulative(reportRequest, plotInfo, filename, title)
@@ -193,11 +175,9 @@ class JobStepPlotter(BaseReporter):
     _reportPieNormCPUTimeName = "Pie plot of NormCPU time"
 
     def _reportPieNormCPUTime(self, reportRequest):
-
         return self.__reportPiePlot(reportRequest, "NormCPUTime")
 
     def _plotPieNormCPUTime(self, reportRequest, plotInfo, filename):
-
         title = "Average Normalized CPU time"
         label = "NormCPUTime"
 
@@ -209,14 +189,12 @@ class JobStepPlotter(BaseReporter):
     _reportInputDataName = "Input Data"
 
     def _reportInputData(self, reportRequest):
-
         field = "InputData"
         unit = "files"
 
         return self.__reportNormPlot(reportRequest, field, unit)
 
     def _plotInputData(self, reportRequest, plotInfo, filename):
-
         title = "Input data"
 
         return self.__plotNormPlot(reportRequest, plotInfo, filename, title)
@@ -227,14 +205,12 @@ class JobStepPlotter(BaseReporter):
     _reportCumulativeInputDataName = "Cumulative Input Data"
 
     def _reportCumulativeInputData(self, reportRequest):
-
         field = "InputData"
         unit = "files"
 
         return self.__reportCumulativePlot(reportRequest, field, unit)
 
     def _plotCumulativeInputData(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative Input Data"
 
         return self.__plotCumulative(reportRequest, plotInfo, filename, title)
@@ -245,11 +221,9 @@ class JobStepPlotter(BaseReporter):
     _reportPieInputDataName = "Pie plot of Input Data"
 
     def _reportPieInputData(self, reportRequest):
-
         return self.__reportPiePlot(reportRequest, "InputData")
 
     def _plotPieInputData(self, reportRequest, plotInfo, filename):
-
         title = "Pie plot of Input data"
         label = "InputData"
 
@@ -261,14 +235,12 @@ class JobStepPlotter(BaseReporter):
     _reportOutputDataName = "Output Data"
 
     def _reportOutputData(self, reportRequest):
-
         field = "OutputData"
         units = "files"
 
         return self.__reportNormPlot(reportRequest, field, units)
 
     def _plotOutputData(self, reportRequest, plotInfo, filename):
-
         title = "Output data"
 
         return self.__plotNormPlot(reportRequest, plotInfo, filename, title)
@@ -279,14 +251,12 @@ class JobStepPlotter(BaseReporter):
     _reportCumulativeOutputDataName = "Cumulative OutputData"
 
     def _reportCumulativeOutputData(self, reportRequest):
-
         field = "OutputData"
         unit = "files"
 
         return self.__reportCumulativePlot(reportRequest, field, unit)
 
     def _plotCumulativeOutputData(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative Output Data"
 
         return self.__plotCumulative(reportRequest, plotInfo, filename, title)
@@ -297,11 +267,9 @@ class JobStepPlotter(BaseReporter):
     _reportPieOutputDataName = "Pie plot of Output Data"
 
     def _reportPieOutputData(self, reportRequest):
-
         return self.__reportPiePlot(reportRequest, "OutputData")
 
     def _plotPieOutputData(self, reportRequest, plotInfo, filename):
-
         title = "Pie plot of  Output data"
         label = "OutputData"
 
@@ -316,7 +284,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportNumberOfField(reportRequest, "InputEvents")
 
     def _plotInputEvents(self, reportRequest, plotInfo, filename):
-
         title = "InputEvents"
         label = "Input Events"
 
@@ -331,7 +298,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportCumulativeNumberOfField(reportRequest, "InputEvents")
 
     def _plotCumulativeInputEvents(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative Input Events "
         label = "Input Events"
 
@@ -346,7 +312,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportPiePlot(reportRequest, "InputEvents")
 
     def _plotPieInputEvents(self, reportRequest, plotInfo, filename):
-
         title = "Pie plot of Input Events"
         label = "InputEvents"
 
@@ -361,7 +326,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportNumberOfField(reportRequest, "OutputEvents")
 
     def _plotOutputEvents(self, reportRequest, plotInfo, filename):
-
         title = "OutputEvents"
         label = "Output Events"
 
@@ -376,7 +340,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportCumulativeNumberOfField(reportRequest, "OutputEvents")
 
     def _plotCumulativeOutputEvents(self, reportRequest, plotInfo, filename):
-
         title = "Cumulative Output Events "
         label = "Output Events"
 
@@ -391,7 +354,6 @@ class JobStepPlotter(BaseReporter):
         return self.__reportPiePlot(reportRequest, "OutputEvents")
 
     def _plotPieOutputEvents(self, reportRequest, plotInfo, filename):
-
         title = "Pie plot of Output Events"
         label = "OutputEvents"
 
@@ -434,7 +396,6 @@ class JobStepPlotter(BaseReporter):
     # HELPER methods
 
     def __reportNormPlot(self, reportRequest, field, unit):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s)",
@@ -468,9 +429,8 @@ class JobStepPlotter(BaseReporter):
         )
 
     def __plotNormPlot(self, reportRequest, plotInfo, filename, title):
-
         metadata = {
-            "title": "%s by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title} by {reportRequest['grouping']}",
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
             "span": plotInfo["granularity"],
@@ -507,7 +467,7 @@ class JobStepPlotter(BaseReporter):
 
     def __plotPie(self, reportRequest, plotInfo, filename, title, label):
         metadata = {
-            "title": "%s by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title} by {reportRequest['grouping']}",
             "ylabel": label,
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
@@ -515,7 +475,6 @@ class JobStepPlotter(BaseReporter):
         return self._generatePiePlot(filename, plotInfo["data"], metadata)
 
     def __reportCumulativePlot(self, reportRequest, field, unit):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s)",
@@ -548,9 +507,8 @@ class JobStepPlotter(BaseReporter):
         )
 
     def __plotCumulative(self, reportRequest, plotInfo, filename, title):
-
         metadata = {
-            "title": "%s by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title} by {reportRequest['grouping']}",
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
             "span": plotInfo["granularity"],
@@ -561,7 +519,6 @@ class JobStepPlotter(BaseReporter):
         return self._generateCumulativePlot(filename, plotInfo["graphDataDict"], metadata)
 
     def __reportNumberOfField(self, reportRequest, field):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s)",
@@ -595,14 +552,13 @@ class JobStepPlotter(BaseReporter):
         )
 
     def __plotNumberOfField(self, reportRequest, plotInfo, filename, title, label):
-
         startEpoch = reportRequest["startTime"]
         endEpoch = reportRequest["endTime"]
         granularity = plotInfo["granularity"]
         dataDict = plotInfo["data"]
 
         metadata = {
-            "title": "%s  by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title}  by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -614,7 +570,6 @@ class JobStepPlotter(BaseReporter):
         return self._generateStackedLinePlot(filename, dataDict, metadata)
 
     def __reportCumulativeNumberOfField(self, reportRequest, field):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s)",
@@ -644,14 +599,13 @@ class JobStepPlotter(BaseReporter):
         return S_OK({"data": dataDict, "granularity": granularity})
 
     def __plotCumulativeNumberOfField(self, reportRequest, plotInfo, filename, title, label):
-
         startEpoch = reportRequest["startTime"]
         endEpoch = reportRequest["endTime"]
         granularity = plotInfo["granularity"]
         dataDict = plotInfo["data"]
 
         metadata = {
-            "title": "%s  by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title}  by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -692,9 +646,8 @@ class JobStepPlotter(BaseReporter):
 
     # FIXME: smells like unused
     def __plotAverageNumberOfField(self, reportRequest, plotInfo, filename, title, label):
-
         metadata = {
-            "title": "%s by %s" % (title, reportRequest["grouping"]),
+            "title": f"{title} by {reportRequest['grouping']}",
             "ylabel": label,
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
@@ -702,7 +655,6 @@ class JobStepPlotter(BaseReporter):
         return self._generatePiePlot(filename, plotInfo["data"], metadata)
 
     def __report2D(self, reportRequest, field1, field2):
-
         selectField = self._getSelectStringForGrouping(reportRequest["groupingFields"])
         selectFields = (
             selectField + ", %s, %s, SUM(%s), SUM(%s)",
@@ -730,9 +682,8 @@ class JobStepPlotter(BaseReporter):
         return S_OK({"data": dataDict, "granularity": granularity})
 
     def __plot2D(self, reportRequest, plotInfo, filename, label):
-
         metadata = {
-            "title": "Jobs by %s" % reportRequest["grouping"],
+            "title": f"Jobs by {reportRequest['grouping']}",
             "starttime": reportRequest["startTime"],
             "endtime": reportRequest["endTime"],
             "span": plotInfo["granularity"],
