@@ -13,17 +13,11 @@
 PopularityPlotter.__bases__:
   DIRAC.AccountingSystem.private.Plotters.BaseReporter.BaseReporter
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK
 from DIRAC.AccountingSystem.private.Plotters.BaseReporter import BaseReporter
 
 from LHCbDIRAC.AccountingSystem.Client.Types.Popularity import Popularity
 
-__RCSID__ = "$Id$"
-
 # FIXME: refactor _reportMethods
 # FIXME: refactor _plotMethods
 
@@ -132,7 +126,7 @@ class PopularityPlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Data Usage grouped by %s" % reportRequest["grouping"],
+            "title": f"Data Usage grouped by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -240,7 +234,7 @@ class PopularityPlotter(BaseReporter):
         granularity = plotInfo["granularity"]
 
         metadata = {
-            "title": "Normalized Data Usage grouped by %s" % reportRequest["grouping"],
+            "title": f"Normalized Data Usage grouped by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
