@@ -13,17 +13,11 @@
 StoragePlotter.__bases__:
   DIRAC.AccountingSystem.private.Plotters.BaseReporter.BaseReporter
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK, S_ERROR
 from DIRAC.AccountingSystem.private.Plotters.BaseReporter import BaseReporter
 
 from LHCbDIRAC.AccountingSystem.Client.Types.Storage import Storage
 
-__RCSID__ = "$Id$"
-
 # FIXME: refactor _reportMethods
 # FIXME: refactor _plotMethods
 
@@ -136,7 +130,7 @@ class StoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "LFN space usage by %s" % reportRequest["grouping"],
+            "title": f"LFN space usage by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -248,7 +242,7 @@ class StoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Number of LFNs by %s" % reportRequest["grouping"],
+            "title": f"Number of LFNs by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -358,7 +352,7 @@ class StoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "PFN space usage by %s" % reportRequest["grouping"],
+            "title": f"PFN space usage by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -475,7 +469,7 @@ class StoragePlotter(BaseReporter):
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Number of PFNs by %s" % reportRequest["grouping"],
+            "title": f"Number of PFNs by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -491,21 +485,19 @@ class StoragePlotter(BaseReporter):
     _reportPFNvsLFNFileMultiplicityName = "PFN/LFN file ratio"
 
     def _reportPFNvsLFNFileMultiplicity(self, reportRequest):
-
         logicalField = "LogicalFiles"
         physicalField = "PhysicalFiles"
 
         return self._multiplicityReport(reportRequest, logicalField, physicalField)
 
     def _plotPFNvsLFNFileMultiplicity(self, reportRequest, plotInfo, filename):
-
         startEpoch = reportRequest["startTime"]
         endEpoch = reportRequest["endTime"]
         granularity = plotInfo["granularity"]
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Ratio of PFN/LFN files by %s" % reportRequest["grouping"],
+            "title": f"Ratio of PFN/LFN files by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -521,21 +513,19 @@ class StoragePlotter(BaseReporter):
     _reportPFNvsLFNSizeMultiplicityName = "PFN/LFN size ratio"
 
     def _reportPFNvsLFNSizeMultiplicity(self, reportRequest):
-
         logicalField = "LogicalSize"
         physicalField = "PhysicalSize"
 
         return self._multiplicityReport(reportRequest, logicalField, physicalField)
 
     def _plotPFNvsLFNSizeMultiplicity(self, reportRequest, plotInfo, filename):
-
         startEpoch = reportRequest["startTime"]
         endEpoch = reportRequest["endTime"]
         granularity = plotInfo["granularity"]
         dataDict = plotInfo["graphDataDict"]
 
         metadata = {
-            "title": "Ratio of PFN/LFN space used by %s" % reportRequest["grouping"],
+            "title": f"Ratio of PFN/LFN space used by {reportRequest['grouping']}",
             "starttime": startEpoch,
             "endtime": endEpoch,
             "span": granularity,
@@ -549,7 +539,6 @@ class StoragePlotter(BaseReporter):
     # helper methods
 
     def _multiplicityReport(self, reportRequest, logicalField, physicalField):
-
         # Step 1 get the total LFNs for each bucket
         selectFields = (
             "%s, %s, %s, SUM(%s)/SUM(%s)",
