@@ -27,7 +27,7 @@ import operator
 
 from decimal import Decimal
 
-import mock
+from unittest import mock
 
 from PIL import Image
 from functools import reduce
@@ -69,7 +69,7 @@ class DataStoragePlotterTestCase(unittest.TestCase):
                 continue
 
         # And then makes its own mock
-        class MockDataStorage(object):
+        class MockDataStorage:
             # pylint: disable=missing-docstring,no-init
             definitionKeyFields = (
                 "DataType",
