@@ -23,7 +23,7 @@ IMPORTANT: the test MUST be pylint compliant !
 import unittest
 from decimal import Decimal
 
-import mock
+from unittest import mock
 
 
 class StoragePlotterTestCase(unittest.TestCase):
@@ -44,7 +44,7 @@ class StoragePlotterTestCase(unittest.TestCase):
                 continue
 
         # And then makes its own mock
-        class MockStorage(object):
+        class MockStorage:
             # pylint: disable=missing-docstring,no-init
             definitionKeyFields = ("StorageElement", "Directory")
 
