@@ -11,7 +11,6 @@
 """BKQuery is a class that decodes BK paths, queries the BK at a high level."""
 import os
 import sys
-import six
 from fnmatch import fnmatch
 from DIRAC import gLogger
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
@@ -78,11 +77,11 @@ def parseRuns(bkQuery, runs):
     :param runs: a string, an int, or a list,dict,tuple of run numbers
     :type runs: string or int/long, iterable
     """
-    if isinstance(runs, six.string_types):
+    if isinstance(runs, str):
         runs = runs.split(",")
     elif isinstance(runs, (dict, tuple)):
         runs = list(runs)
-    elif isinstance(runs, six.integer_types):
+    elif isinstance(runs, int):
         runs = [str(runs)]
     if len(runs) > 1:
         runList = []
@@ -106,7 +105,7 @@ def parseRuns(bkQuery, runs):
     if "RunNumber" not in bkQuery:
         try:
             if runs[0] and runs[1] and int(runs[0]) > int(runs[1]):
-                gLogger.error("Warning: End run should be larger than start run: %d, %d" % (int(runs[0]), int(runs[1])))
+                gLogger.error(f"Warning: End run should be larger than start run: {runs[0]}, {runs[1]}")
                 raise BadRunRange
             if runs[0].isdigit():
                 bkQuery["StartRun"] = int(runs[0])
@@ -144,7 +143,7 @@ class BKQuery:
             bkQueryDict = bkQuery.getQueryDict().copy()
         elif isinstance(bkQuery, dict):
             bkQueryDict = bkQuery.copy()
-        elif isinstance(bkQuery, six.string_types):
+        elif isinstance(bkQuery, str):
             bkPath = bkQuery
         bkQueryDict = self.buildBKQuery(
             bkPath=bkPath,
@@ -175,9 +174,8 @@ class BKQuery:
         fileTypes = fileTypes if fileTypes is not None else []
 
         gLogger.verbose(
-            "BKQUERY.buildBKQuery: Path %s, Dict %s, \
-      Prods %s, Runs %s, FileTypes %s, EventTypes %s, Visible %s"
-            % (bkPath, str(bkQueryDict), str(prods), str(runs), str(fileTypes), str(eventTypes), visible)
+            f"BKQUERY.buildBKQuery: Path {bkPath}, Dict {bkQueryDict}, Prods {prods}, "
+            f"Runs {runs}, FileTypes {fileTypes}, EventTypes {eventTypes}, Visible {visible}"
         )
         self.__bkQueryDict = {}
         if not bkPath and not prods and not bkQueryDict and not runs:
@@ -219,7 +217,7 @@ class BKQuery:
                 elif url[0] == "runs":
                     bkFields = ("Runs", "ProcessingPass", "EventType", "FileType")
                 elif url[0] not in ("sim", "daq", "cond"):
-                    gLogger.error("Invalid BK path:%s" % bkPath)
+                    gLogger.error(f"Invalid BK path:{bkPath}")
                     return self.__bkQueryDict
                 bkPath = url[1]
             if bkPath[0] != "/":
@@ -270,7 +268,7 @@ class BKQuery:
                         if len(eventTypeList) == 1:
                             eventTypeList = eventTypeList[0]
                         bpath = eventTypeList
-                        gLogger.verbose("buildBKQuery. Event types %s" % eventTypeList)
+                        gLogger.verbose(f"buildBKQuery. Event types {eventTypeList}")
                 # Set the BK dictionary item
                 if bpath != "":
                     bkQuery[bkFields[i]] = bpath
@@ -283,7 +281,7 @@ class BKQuery:
                 if i == len(bkFields):
                     break
 
-            gLogger.verbose("buildBKQuery. Query dict %s" % str(bkQuery))
+            gLogger.verbose(f"buildBKQuery. Query dict {str(bkQuery)}")
             # Set default event type to real data
             if bkQuery.get("ConfigName") != "MC" and not bkQuery.get("EventType"):
                 bkQuery["EventType"] = "90000000"
@@ -322,7 +320,7 @@ class BKQuery:
 
         # Remove all "ALL"'s in the dict, if any
         for i in self.__bkQueryDict:
-            if isinstance(bkQuery[i], six.string_types) and bkQuery[i] == "ALL":
+            if isinstance(bkQuery[i], str) and bkQuery[i] == "ALL":
                 bkQuery.pop(i)
 
         # If there is only one production, make it faster with a single value rather than a list
@@ -367,7 +365,7 @@ class BKQuery:
         # There are two items in the dictionary: ConditionDescription and Simulation/DataTaking-Conditions
         eventType = self.__bkQueryDict.get("EventType", "ALL")
         if self.__bkQueryDict.get("ConfigName") == "MC" or (
-            isinstance(eventType, six.string_types) and eventType.upper() != "ALL" and eventType[0] != "9"
+            isinstance(eventType, str) and eventType.upper() != "ALL" and eventType[0] != "9"
         ):
             conditionsKey = "SimulationConditions"
         else:
@@ -381,7 +379,7 @@ class BKQuery:
 
     def setDQFlag(self, dqFlag="OK"):
         """Sets the data quality."""
-        if isinstance(dqFlag, six.string_types):
+        if isinstance(dqFlag, str):
             dqFlag = dqFlag.upper()
         elif isinstance(dqFlag, list):
             dqFlag = [dq.upper() for dq in dqFlag]
@@ -402,7 +400,7 @@ class BKQuery:
     def setEventType(self, eventTypes=None):
         """Sets the event type."""
         if eventTypes:
-            if isinstance(eventTypes, six.string_types):
+            if isinstance(eventTypes, str):
                 eventTypes = eventTypes.split(",")
             elif not isinstance(eventTypes, list):
                 eventTypes = [eventTypes]
@@ -418,7 +416,7 @@ class BKQuery:
 
     def setVisible(self, visible=None):
         """Sets the visibility flag."""
-        if visible is True or (isinstance(visible, six.string_types) and visible[0].lower() == "y"):
+        if visible is True or (isinstance(visible, str) and visible[0].lower() == "y"):
             visible = "Yes"
         if visible is False:
             visible = "No"
@@ -500,7 +498,7 @@ class BKQuery:
 
     def __fileType(self, fileType=None, returnList=False):
         """return the file types taking into account the expected file types."""
-        gLogger.verbose("BKQuery.__fileType: %s, fileType: %s" % (self, fileType))
+        gLogger.verbose(f"BKQuery.__fileType: {self}, fileType: {fileType}")
         if not fileType:
             return []
         self.__getAllBKFileTypes()
@@ -512,7 +510,7 @@ class BKQuery:
         if fileTypes[0].lower() == "all":
             allRequested = True
             bkTypes = self.getBKFileTypes()
-            gLogger.verbose("BKQuery.__fileType: bkTypes %s" % str(bkTypes))
+            gLogger.verbose(f"BKQuery.__fileType: bkTypes {str(bkTypes)}")
             if bkTypes:
                 fileTypes = list(set(bkTypes) - self.__exceptFileTypes)
             else:
@@ -538,8 +536,7 @@ class BKQuery:
         # Remove __exceptFileTypes only if not explicitly required
         # print "Obtained", fileTypes, expandedTypes
         gLogger.verbose(
-            "BKQuery.__fileType: requested %s, expanded %s, except %s"
-            % (allRequested, expandedTypes, self.__exceptFileTypes)
+            f"BKQuery.__fileType: requested {allRequested}, expanded {expandedTypes}, except {self.__alreadyWarned}"
         )
         if expandedTypes - self.__bkFileTypes and not self.__alreadyWarned:
             self.__alreadyWarned = True
@@ -549,7 +546,7 @@ class BKQuery:
             )
         if allRequested or not expandedTypes & self.__exceptFileTypes:
             expandedTypes -= self.__exceptFileTypes
-        gLogger.verbose("BKQuery.__fileType: result %s" % sorted(expandedTypes))
+        gLogger.verbose(f"BKQuery.__fileType: result {sorted(expandedTypes)}")
         if len(expandedTypes) == 1 and not returnList:
             return list(expandedTypes)[0]
         return list(expandedTypes)
@@ -557,7 +554,7 @@ class BKQuery:
     def __getAllBKFileTypes(self):
         """Returns the file types from the bookkeeping database."""
         if not self.__bkFileTypes:
-            self.__bkFileTypes = set([self.__fakeAllDST])
+            self.__bkFileTypes = {self.__fakeAllDST}
             warned = False
             while True:
                 res = self.__bkClient.getAvailableFileTypes()
@@ -599,7 +596,7 @@ class BKQuery:
         lfns = []
         lfnSize = 0
         if not res["OK"]:
-            gLogger.error("Error from BK for %s:" % self.__bkQueryDict, res["Message"])
+            gLogger.error(f"Error from BK for {self.__bkQueryDict}:", res["Message"])
         else:
             lfns = set(res["Value"])
             exceptFiles = list(self.__exceptFileTypes)
@@ -609,12 +606,12 @@ class BKQuery:
                     lfnsExcept = set(res["Value"]) & lfns
                 else:
                     gLogger.error(
-                        "***** ERROR ***** Error in getting dataset from BK for %s files:" % exceptFiles, res["Message"]
+                        f"***** ERROR ***** Error in getting dataset from BK for {exceptFiles} files:", res["Message"]
                     )
                     lfnsExcept = set()
                 if lfnsExcept:
                     gLogger.warn(
-                        "***** WARNING ***** Found %d files in BK query that will be excluded!" % len(lfnsExcept)
+                        f"***** WARNING ***** Found {len(lfnsExcept)} files in BK query that will be excluded!"
                     )
                     gLogger.verbose("Exclusion file types", str(exceptFiles))
                     gLogger.warn("                    If creating a transformation, set '--FileType ALL'")
@@ -633,7 +630,7 @@ class BKQuery:
                     if res["OK"] and isinstance(res["Value"], list) and res["Value"][0]:
                         lfnSize -= res["Value"][0]
 
-                lfnSize /= 1000000000000.0
+                lfnSize /= 1e12  # 1 Tera
             else:
                 lfnSize = 0.0
         return {"LFNs": list(lfns), "LFNSize": lfnSize}
@@ -719,19 +716,19 @@ class BKQuery:
             lfnSize = lfnsAndSize["LFNSize"]
 
         if not lfns:
-            gLogger.verbose("No files found for BK query %s" % str(self.__bkQueryDict))
+            gLogger.verbose("No files found for BK query", self.__bkQueryDict)
         else:
             lfns.sort()
 
             # Only for printing
             if printOutput:
-                gLogger.notice("\n%d files (%.1f TB) in directories:" % (len(lfns), lfnSize))
+                gLogger.notice(f"\n{len(lfns)} files ({lfnSize:.1f} TB) in directories:")
                 dirs = {}
                 for lfn in lfns:
                     directory = os.path.join(os.path.dirname(lfn), "")
                     dirs[directory] = dirs.setdefault(directory, 0) + 1
                 for directory in sorted(dirs):
-                    gLogger.notice("%s %s files" % (directory, dirs[directory]))
+                    gLogger.notice(f"{directory} {dirs[directory]} files")
                 if printSEUsage:
                     rpc = StorageUsageClient()
                     totalUsage = {}
@@ -745,9 +742,9 @@ class BKQuery:
                     ses = sorted(totalUsage)
                     totalUsage["Total"] = totalSize
                     ses.append("Total")
-                    gLogger.notice("\n%s %s" % ("SE".ljust(20), "Size (TB)"))
+                    gLogger.notice(f"\n{'SE'.ljust(20)} Size (TB)")
                     for se in ses:
-                        gLogger.notice("%s %s" % (se.ljust(20), ("%.1f" % (totalUsage[se] / 1000000000000.0))))
+                        gLogger.notice(f"{se.ljust(20)} {totalUsage[se] / 1000000000000.0:.1f}")
         return lfns
 
     def getDirs(self, printOutput=False, visible=None):
@@ -765,7 +762,7 @@ class BKQuery:
         """Returns the status of a given transformation."""
         res = TransformationClient().getTransformation(prod, extraParams=False)
         if not res["OK"]:
-            gLogger.error("Could not get information", "on production %d" % prod)
+            gLogger.error("Could not get information", f"on production {prod}")
             return None
         return res["Value"]["Status"]
 
@@ -801,12 +798,12 @@ class BKQuery:
                 return []
             if self.getProcessingPass().replace("/", "") != "Real Data":
                 fileTypes = self.getFileTypeList()
-                prodList = set(
+                prodList = {
                     prod
                     for prods in res["Value"]["Records"]
                     for prod in prods
                     if self.__getProdStatus(prod) != "Deleted"
-                )
+                }
                 # print '\n', self.__bkQueryDict, res['Value']['Records'], '\nVisible:', visible, prodList
                 pList = set()
                 if fileTypes:
@@ -818,10 +815,10 @@ class BKQuery:
                 if not pList:
                     pList = prodList
             else:
-                runList = sorted([-run for r in res["Value"]["Records"] for run in r])
+                runList = sorted(-run for r in res["Value"]["Records"] for run in r)
                 startRun = int(self.__bkQueryDict.get("StartRun", 0))
                 endRun = int(self.__bkQueryDict.get("EndRun", sys.maxsize))
-                pList = set(run for run in runList if run >= startRun and run <= endRun)
+                pList = {run for run in runList if run >= startRun and run <= endRun}
             fullList.update(pList)
         return sorted(fullList)
 
@@ -903,12 +900,12 @@ class BKQuery:
         res = self.__bkClient.getProcessingPass(queryDict, initialPP)
         if not res["OK"]:
             if "Empty Directory" not in res["Message"]:
-                gLogger.error("ERROR getting processing passes for %s" % queryDict, res["Message"])
+                gLogger.error(f"ERROR getting processing passes for {queryDict}", res["Message"])
             return {}
         ppRecords = res["Value"][0]
         if "Name" in ppRecords["ParameterNames"]:
             ind = ppRecords["ParameterNames"].index("Name")
-            passes = sorted([os.path.join(initialPP, rec[ind]) for rec in ppRecords["Records"]])
+            passes = sorted(os.path.join(initialPP, rec[ind]) for rec in ppRecords["Records"])
         else:
             passes = []
         evtRecords = res["Value"][1]
