@@ -23,11 +23,12 @@ Whatever:
   }
 """
 import tempfile
-import six
 
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Core.Base.Client import Client, createClient
-from DIRAC.Core.DISET.TransferClient import TransferClient
+from DIRAC.Core.Tornado.Client.ClientSelector import TransferClientSelector as TransferClient
+from DIRAC.Core.Utilities.Decorators import deprecated
+from DIRAC.Core.Utilities.JEncode import strToIntDict
 
 from LHCbDIRAC.BookkeepingSystem.Client import JEncoder
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import ProductionRequestClient
@@ -38,15 +39,13 @@ from LHCbDIRAC.TransformationSystem.Client.TransformationClient import Transform
 class BookkeepingClient(Client):
     """This class expose the methods of the Bookkeeping Service."""
 
-    def __init__(self, url=None, **kwargs):
+    def __init__(self, **kwargs):
         """c'tor.
 
         :param str url: can specify a specific URL
         """
-        super(BookkeepingClient, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.setServer("Bookkeeping/BookkeepingManager")
-        if url:
-            self.setServer(url)
         self.timeout = 3600
         self.log = gLogger.getSubLogger("BookkeepingClient")
 
@@ -75,14 +74,14 @@ class BookkeepingClient(Client):
         """
         in_dict = dict(in_dict)
         bkk = TransferClient("Bookkeeping/BookkeepingManager")
+        in_dict["MethodName"] = "getFilesWithMetadata"
         params = JEncoder.dumps(in_dict)
-        file_name = tempfile.NamedTemporaryFile()
-        retVal = bkk.receiveFile(file_name.name, params)
-        if not retVal["OK"]:
-            return retVal
-        value = JEncoder.load(open(file_name.name))
-        file_name.close()
-        return S_OK(value)
+        with tempfile.NamedTemporaryFile() as file_name:
+            retVal = bkk.receiveFile(file_name.name, params)
+            if not retVal["OK"]:
+                return retVal
+            value = JEncoder.load(open(file_name.name))
+        return value
 
     #############################################################################
     def bulkJobInfo(self, in_dict):
@@ -96,7 +95,7 @@ class BookkeepingClient(Client):
         :return: job meta data
         """
         conditions = {}
-        if isinstance(in_dict, six.string_types):
+        if isinstance(in_dict, str):
             conditions["lfn"] = in_dict.split(";")
         elif isinstance(in_dict, list):
             conditions["lfn"] = in_dict
@@ -112,7 +111,7 @@ class BookkeepingClient(Client):
         :param list lfns: list of LFNs or an LFN
         :param str flag: data quality flag: OK, UNCHECKED, etc.
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
 
         return self._getRPC().setFileDataQuality(lfns, flag)
@@ -127,13 +126,17 @@ class BookkeepingClient(Client):
 
         :returns: It returns the ancestors of a file with metadata or a list of files
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
 
         return self._getRPC().getFileAncestors(lfns, depth, replica)
 
     #############################################################################
+    @deprecated("Use getFileDescendents")
     def getFileDescendants(self, lfns, depth=0, production=0, checkreplica=False):
+        return self.getFileDescendents(lfns, depth, production, checkreplica)
+
+    def getFileDescendents(self, lfns, depth=0, production=0, checkreplica=False):
         """Retrieve the file descendants.
 
         :param list lfns: list of LFNs
@@ -141,10 +144,10 @@ class BookkeepingClient(Client):
         :param bool replica: take into account the replica flag.
         :return: descendants of a file or a list of files.
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
 
-        return self._getRPC().getFileDescendants(lfns, depth, production, checkreplica)
+        return self._getRPC().getFileDescendents(lfns, depth, production, checkreplica)
 
     #############################################################################
     def addFiles(self, lfns):
@@ -152,7 +155,7 @@ class BookkeepingClient(Client):
 
         :param list lfns: list of LFNs
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().addFiles(lfns)
 
@@ -162,7 +165,7 @@ class BookkeepingClient(Client):
 
         :param list lfns: list of lfns
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().removeFiles(lfns)
 
@@ -173,21 +176,10 @@ class BookkeepingClient(Client):
         :param list lfns: list of LFNs
         :return: file metadata
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().getFileMetadata(lfns)
 
-    #############################################################################
-    def getFileMetaDataForWeb(self, lfns):
-        """This method only used by the web portal. It is same as getFileMetadata.
-
-        :param list lfns: list of LFNs
-        :return: file metadata
-        """
-        if isinstance(lfns, six.string_types):
-            lfns = lfns.split(";")
-        return self._getRPC().getFileMetaDataForWeb(lfns)
-
     #############################################################################
     def exists(self, lfns):
         """It used to check the existence of a list of files in the Bookkeeping
@@ -196,7 +188,7 @@ class BookkeepingClient(Client):
         :param list lfns: list of LFNs
         :return: a dictionary with the lfns {'lfn':True/False}
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().exists(lfns)
 
@@ -244,7 +236,7 @@ class BookkeepingClient(Client):
         try:
             return self._getRPC().getRunInformations(int(runnb))
         except (ValueError, TypeError) as e:
-            return S_ERROR("Invalid run number: %s" % repr(e))
+            return S_ERROR(f"Invalid run number: {repr(e)}")
 
     #############################################################################
     def getRunFilesDataQuality(self, runs):
@@ -253,9 +245,9 @@ class BookkeepingClient(Client):
         :param list runs: list of run numbers.
         :return: run or file data quality
         """
-        if isinstance(runs, six.string_types):
+        if isinstance(runs, str):
             runs = runs.split(";")
-        elif isinstance(runs, six.integer_types):
+        elif isinstance(runs, int):
             runs = [runs]
         return self._getRPC().getRunFilesDataQuality(runs)
 
@@ -265,7 +257,7 @@ class BookkeepingClient(Client):
 
         :paran list lfns: an lfn or list of lfns
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().setFilesInvisible(lfns)
 
@@ -275,7 +267,7 @@ class BookkeepingClient(Client):
 
         :param list lfns: an lfn or list of lfns
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().setFilesVisible(lfns)
 
@@ -286,7 +278,7 @@ class BookkeepingClient(Client):
         :param list lfns: list of lfns
         :return: file type version
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().getFileTypeVersion(lfns)
 
@@ -297,7 +289,7 @@ class BookkeepingClient(Client):
         :param list lfns: list of lfns
         :return: directory metadata
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.split(";")
         return self._getRPC().getDirectoryMetadata(lfns)
 
@@ -333,7 +325,7 @@ class BookkeepingClient(Client):
         :param list diracjobids: list of dirac job ids.
         :return: input/output file(s) for a given dirac job
         """
-        if isinstance(diracjobids, six.integer_types):
+        if isinstance(diracjobids, int):
             diracjobids = [diracjobids]
         return self._getRPC().getJobInputOutputFiles(diracjobids)
 
@@ -342,7 +334,7 @@ class BookkeepingClient(Client):
 
         :param list runnumbers: list of run numbers.
         """
-        if isinstance(runnumbers, six.integer_types):
+        if isinstance(runnumbers, int):
             runnumbers = [runnumbers]
         return self._getRPC().fixRunLuminosity(runnumbers)
 
@@ -359,13 +351,11 @@ class BookkeepingClient(Client):
         bkk = TransferClient("Bookkeeping/BookkeepingManager")
         in_dict["MethodName"] = "getFiles"
         params = JEncoder.dumps(in_dict)
-        file_name = tempfile.NamedTemporaryFile()
-        retVal = bkk.receiveFile(file_name.name, params)
-        if not retVal["OK"]:
-            return retVal
-        value = JEncoder.load(open(file_name.name))
-        file_name.close()
-        return value
+        with tempfile.NamedTemporaryFile() as file_name:
+            retVal = bkk.receiveFile(file_name.name, params)
+            if not retVal["OK"]:
+                return retVal
+            return JEncoder.load(open(file_name.name))
 
     def getRunStatus(self, runs):
         """For retrieving the run status.
@@ -374,13 +364,16 @@ class BookkeepingClient(Client):
         :return: run status (finished, or not finished)
         """
         runnumbers = []
-        if isinstance(runs, six.string_types):
+        if isinstance(runs, str):
             runnumbers = [int(run) for run in runs.split(";")]
-        elif isinstance(runs, six.integer_types):
+        elif isinstance(runs, int):
             runnumbers += [runs]
         else:
             runnumbers = runs
-        return self._getRPC().getRunStatus(runnumbers)
+        retVal = self._getRPC().getRunStatus(runnumbers)
+        if retVal["OK"]:
+            retVal["Value"]["Successful"] = strToIntDict(retVal["Value"]["Successful"])
+        return retVal
 
     def getProcessingPass(self, in_dict, path=None):
         """This method is used to recursively browse the processing pass.
@@ -437,14 +430,14 @@ class BookkeepingClient(Client):
             return res
         steps = res["Value"]  # this is an ordered list
         if not steps:
-            self.log.error("Production %s does not have recorded steps" % prodID)
+            self.log.error(f"Production {prodID} does not have recorded steps")
             return S_ERROR("No recorded steps")
         # now we check if the first in the list had DDDB and CondDB defined, or not
         # if not, we get the steps of all the previous productions
         if steps[0][4] == steps[0][5] == "fromPreviousStep":
             # if we are here it is because in the current production none of the steps contain DB tags
             self.log.info(
-                "DB tags are not set: they will be retrieved from the parent production(s)", "(prod: %s)" % prodID
+                "DB tags are not set: they will be retrieved from the parent production(s)", f"(prod: {prodID})"
             )
             numberOfSteps = len(steps)
             # Now finding the previous productions
@@ -500,7 +493,7 @@ class BookkeepingClient(Client):
         # Start by getting the RequestID
         res = TransformationClient().getTransformation(prodID, True)
         if not res["OK"]:
-            self.log.error("Could not retrieve parameters for production", "%d: %s" % (prodID, res["Message"]))
+            self.log.error(f"Could not retrieve parameters for production", f"{prodID}: {res['Message']}")
             return res
         parameters = res["Value"]
 
@@ -516,7 +509,7 @@ class BookkeepingClient(Client):
 
         res = ProductionRequestClient().getProductionList(int(reqID))
         if not res["OK"]:
-            self.log.error("Could not retrieve productions list for request", "%d:%s" % (int(reqID), res["Message"]))
+            self.log.error("Could not retrieve productions list for request", f"{reqID}: {res['Message']}")
             return res
         ancestorProdIDs = res["Value"]
 
