@@ -15,17 +15,16 @@ import time
 from DIRAC import gLogger, S_OK, S_ERROR
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 
-from LHCbDIRAC.BookkeepingSystem.Client.BaseESManager import BaseESManager
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 from LHCbDIRAC.BookkeepingSystem.Client import objects
-from LHCbDIRAC.BookkeepingSystem.Client.Help import Help
+from LHCbDIRAC.BookkeepingSystem.Client.Help import helpConfig, helpProcessing, helpEventType
 
 INTERNAL_PATH_SEPARATOR = "/"
 
 #############################################################################
 
 
-class LHCbBookkeepingManager(BaseESManager):
+class LHCbBookkeepingManager:
     """creates the virtual file system."""
 
     __bookkeepingFolderProperties = [
@@ -74,15 +73,10 @@ class LHCbBookkeepingManager(BaseESManager):
     __bookkeepingQueryTypes = ["adv", "std"]
 
     #############################################################################
-    def __init__(self, url=None, web=False, welcome=True):
+    def __init__(self):
         """initialize the values."""
-        BaseESManager.__init__(self)
-        self._BaseESManager___fileSeparator = INTERNAL_PATH_SEPARATOR
-        # self.__pathSeparator = INTERNAL_PATH_SEPARATOR
-        self.db_ = BookkeepingClient(url)
-        if not web:
-            self.fileCatalog = FileCatalog()
-        self.helper_ = Help()
+        self.db_ = BookkeepingClient()
+        self.fileCatalog = FileCatalog()
 
         self.__entityCache = {"/": (objects.Entity({"name": "/", "fullpath": "/", "expandable": True}), 0)}
         self.parameter_ = self.__bookkeepingParameters[0]
@@ -92,18 +86,14 @@ class LHCbBookkeepingManager(BaseESManager):
 
         self.treeLevels_ = -1
         self.advancedQuery_ = False
-        if welcome:
-            print("WELCOME")
-            print("For more information use the 'help' command! ")
         self.dataQualities_ = {}
 
         retVal = self.db_.getAvailableFileTypes()
         if not retVal["OK"]:
-            gLogger.error(retVal)
+            gLogger.error(retVal["Message"])
         else:
             self.__filetypes = [i[0] for i in retVal["Value"]["Records"]]
 
-    #############################################################################
     def setFileTypes(self, fileTypeList=list()):
         """it sets the file types.
 
@@ -118,36 +108,20 @@ class LHCbBookkeepingManager(BaseESManager):
             else:
                 self.__filetypes = [i[0] for i in retVal["Value"]["Records"]]
 
-    #############################################################################
-    def _updateTreeLevels(self, level):
-        """tree level update."""
-        self.treeLevels_ = level
-
-    #############################################################################
-    @staticmethod
-    def setVerbose(value):
-        """information printed."""
-        objects.VERBOSE = value
-
     #############################################################################
     def setAdvancedQueries(self, value):
         """advanced queries."""
         self.advancedQuery_ = value
 
-    #############################################################################
-    def _getTreeLevels(self):
-        """level of the current tree."""
-        return self.treeLevels_
-
     #############################################################################
     def help(self):
         """help information."""
         if self.parameter_ == self.__bookkeepingParameters[0]:
-            self.helper_.helpConfig(self._getTreeLevels())
+            helpConfig(self.treeLevels_)
         elif self.parameter_ == self.__bookkeepingParameters[1]:
-            self.helper_.helpEventType(self._getTreeLevels())
+            helpEventType(self.treeLevels_)
         elif self.parameter_ == self.__bookkeepingParameters[2]:
-            self.helper_.helpProcessing(self._getTreeLevels())
+            helpProcessing(self.treeLevels_)
 
     #############################################################################
     def getPossibleParameters(self):
@@ -184,17 +158,10 @@ class LHCbBookkeepingManager(BaseESManager):
         else:
             gLogger.error("Wrong Parameter!")
 
-    #############################################################################
-    def getLogicalFiles(self):
-        """lfn."""
-        return self.files_
-
     #############################################################################
     def getFilesPFN(self):
         """pfn."""
-        lfns = self.files_
-        res = self.fileCatalog.getReplicas(lfns)
-        return res
+        return self.fileCatalog.getReplicas(self.files_)
 
     #############################################################################
     def list(self, path="/", selectionDict=None, sortDict=None, startItem=0, maxitems=0):
@@ -232,7 +199,7 @@ class LHCbBookkeepingManager(BaseESManager):
             level, procpass = self.__getLevel(
                 path=tmpPath, visited=[], level=0, start=False, end=False, processingpath="", startlevel=3
             )
-        self._updateTreeLevels(level)
+        self.treeLevels_ = level
         return level, processedPath, procpass
 
     #############################################################################
@@ -368,8 +335,6 @@ class LHCbBookkeepingManager(BaseESManager):
         """level all."""
         if self.advancedQuery_:
             return self._getEntityFromPath(path, "ALL", levels, description)
-        else:
-            return None
 
     @staticmethod
     def __createPath(processedPath, name):
@@ -417,7 +382,7 @@ class LHCbBookkeepingManager(BaseESManager):
         gLogger.debug("-----------------------------------------------------------")
         gLogger.debug("Selected parameters:")
         gLogger.debug("-----------------------------------------------------------")
-        gLogger.debug("Configuration Name      | %s " % (processedPath[0]))
+        gLogger.debug(f"Configuration Name      | {processedPath[0]} ")
 
         gLogger.debug("Available Config Versions:")
         return in_dict
@@ -1453,8 +1418,7 @@ class LHCbBookkeepingManager(BaseESManager):
         If invalid path returns null
         """
         path = path.strip(INTERNAL_PATH_SEPARATOR + " ")
-        paths = path.split(self.getPathSeparator())
-        return paths
+        return path.split(INTERNAL_PATH_SEPARATOR)
 
     #############################################################################
     def _cacheIt(self, entityList):
@@ -1752,7 +1716,7 @@ class LHCbBookkeepingManager(BaseESManager):
         return self.db_.getFileAncestors(files, depth)
 
     #############################################################################
-    def getLogfile(self, filename):
+    def getFileCreationLog(self, filename):
         """log file."""
         return self.db_.getFileCreationLog(filename)
 
@@ -1850,7 +1814,7 @@ class LHCbBookkeepingManager(BaseESManager):
 
         if optionsFile:
             # Write options file if requested
-            with open(optionsFile, "wt") as fd:
+            with open(optionsFile, "w") as fd:
                 fd.write(string)
 
         # Always return the string
@@ -1861,14 +1825,14 @@ class LHCbBookkeepingManager(BaseESManager):
         """it adds the metadata information about the dataset creation."""
         string = ""
         if dataset:
-            string += "\n%s Extra information about the data processing phases:\n" % (self.comment)
+            string += f"\n{self.comment} Extra information about the data processing phases:\n"
             retVal = self.db_.getStepsMetadata(dataset)
             if retVal["OK"]:
                 for ppass, record in retVal["Value"]["Records"].items():
                     ppass = dataset.get("ProcessingPass", ppass)
-                    string += "\n%s Processing Pass: '%s' \n\n" % (self.comment, ppass)
+                    string += f"\n{self.comment} Processing Pass: '{ppass}' \n\n"
                     for i in record:
-                        string += "%s %s : %s \n" % (self.comment, i[0], i[1])
+                        string += f"{self.comment} {i[0]} : {i[1]} \n"
         return string
 
     #############################################################################
@@ -1879,10 +1843,10 @@ class LHCbBookkeepingManager(BaseESManager):
         string += "\nfrom GaudiConf import IOHelper\n"
         for fileFormat, lfns in filesandformats.items():
             if fileFormat:
-                string += "IOHelper('%s').inputFiles([\n" % fileFormat
+                string += f"IOHelper('{fileFormat}').inputFiles([\n"
             else:
                 string += "IOHelper().inputFiles([\n"
-            string += "\n".join("'LFN:%s'," % lfn for lfn in lfns)
+            string += "\n".join(f"'LFN:{lfn}'," for lfn in lfns)
             string += "\n], clear=True)\n"
 
         return string
@@ -1956,7 +1920,7 @@ class LHCbBookkeepingManager(BaseESManager):
                 info[1] += stat
                 size = metadata.get("FileSize")
                 if size is not None:
-                    info[2] += int(size) / 1000000000.0
+                    info[2] += int(size) / 1e9
         return evtTypes
 
     #############################################################################
@@ -1996,7 +1960,7 @@ class LHCbBookkeepingManager(BaseESManager):
 
     def __getSelectedQualities(self):
         """data quality."""
-        return [flag for flag, val in self.dataQualities_.items() if val is True]
+        return [flag for flag, val in self.dataQualities_.items() if val]
 
     #############################################################################
     def getStepsMetadata(self, bkDict):
