@@ -14,7 +14,7 @@ import datetime
 
 from DIRAC import gLogger, S_OK, exit as diracExit
 from DIRAC.Core.Utilities.List import breakListIntoChunks
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 from LHCbDIRAC.DataManagementSystem.Client.DMScript import printDMResult, ProgressBar
@@ -74,10 +74,10 @@ def executeFileMetadata(dmScript):
     for lfn in lfnMetadata:
         lfnMetaDict = lfnMetadata[lfn]
         if full:
-            gLogger.notice("%s%s %s" % (sep, "FileName".ljust(lenItem), lfn))
+            gLogger.notice(f"{sep}{'FileName'.ljust(lenItem)} {lfn}")
             sep = "\n"
             for item in sorted(lfnMetaDict):
-                gLogger.notice("%s %s" % (item.ljust(lenItem), lfnMetaDict[item]))
+                gLogger.notice(f"{item.ljust(lenItem)} {lfnMetaDict[item]}")
         else:
             size = lfnMetaDict["FileSize"]
             guid = lfnMetaDict["GUID"]
@@ -187,7 +187,7 @@ def executeFilePath(dmScript):
         paths = {"Successful": {}, "Failed": []}
         chunkSize = 1000
         progressBar = ProgressBar(
-            len(lfnList), title="Getting %s from BK for %d files" % (groupBy, len(lfnList)), chunk=chunkSize
+            len(lfnList), title=f"Getting {groupBy} from BK for {len(lfnList)} files", chunk=chunkSize
         )
         for lfnChunk in breakListIntoChunks(lfnList, chunkSize):
             res = bkClient.getFileMetadata(lfnChunk)
@@ -195,14 +195,14 @@ def executeFilePath(dmScript):
             if res["OK"]:
                 for lfn, metadata in res["Value"]["Successful"].items():  # can be an iterator
                     group = metadata.get(groupBy)
-                    paths["Successful"].setdefault("%s %s" % (groupBy, group), set()).add(lfn)
+                    paths["Successful"].setdefault(f"{groupBy} {group}", set()).add(lfn)
                     lfnChunk.remove(lfn)
                 paths["Failed"].extend(lfnChunk)
         progressBar.endLoop()
         if summary:
             pathSummary = {"Successful": {}}
             for groupStr in paths["Successful"]:
-                pathSummary["Successful"][groupStr] = "%d files" % len(paths["Successful"][groupStr])
+                pathSummary["Successful"][groupStr] = f"{len(paths['Successful'][groupStr])} files"
             if paths["Failed"]:
                 pathSummary["Failed"] = len(paths["Failed"])
             res = S_OK(pathSummary)
@@ -226,7 +226,7 @@ def executeFilePath(dmScript):
 
         chunkSize = 2
         progressBar = ProgressBar(
-            len(directories), title="Getting metadata for %d directories" % len(directories), chunk=chunkSize
+            len(directories), title=f"Getting metadata for {len(directories)} directories", chunk=chunkSize
         )
         success = {}
         failed = set()
@@ -260,13 +260,13 @@ def executeFilePath(dmScript):
                 bkDict["Path"] = __buildPath(bkDict)
                 if groupBy in bkDict:
                     if groupBy != "Path":
-                        prStr = "%s %s" % (groupBy, bkDict[groupBy])
+                        prStr = f"{groupBy} {bkDict[groupBy]}"
                     else:
                         prStr = bkDict[groupBy]
                     paths["Successful"].setdefault(prStr, set()).update(directories[dirName])
                 elif groupBy:
-                    gLogger.notice("Invalid metadata item: %s" % groupBy)
-                    gLogger.notice("Available are: %s" % str(list(bkDict)))
+                    gLogger.notice(f"Invalid metadata item: {groupBy}")
+                    gLogger.notice(f"Available are: {str(list(bkDict))}")
                     diracExit(1)
                 else:
                     success[dirName] = bkDict["Path"]
@@ -283,9 +283,9 @@ def executeFilePath(dmScript):
                         inv = ""
                     pathSummary["Successful"][path] = "%d files%s" % (nfiles, inv)
                 if failed:
-                    pathSummary["Failed"] = dict(
-                        (path, "Directory not in BK (%d files)" % len(directories[path])) for path in failed
-                    )
+                    pathSummary["Failed"] = {
+                        path: f"Directory not in BK ({len(directories[path])} files)" for path in failed
+                    }
                 else:
                     pathSummary.pop("Failed")
                 res = S_OK(pathSummary)
@@ -296,8 +296,8 @@ def executeFilePath(dmScript):
 
     printDMResult(res, empty="None", script="dirac-bookkeeping-file-path")
     if printList:
-        gLogger.notice("\nList of %s values" % groupBy)
-        gLogger.notice(",".join(sorted([item.replace("%s " % groupBy, "") for item in res["Value"]["Successful"]])))
+        gLogger.notice(f"\nList of {groupBy} values")
+        gLogger.notice(",".join(sorted(item.replace(f"{groupBy} ", "") for item in res["Value"]["Successful"])))
 
 
 def _updateFileLumi(fileDict, retries=5):
@@ -337,7 +337,7 @@ def _updateDescendantsLumi(parentLumi, doIt=False, force=False):
         return None
     # Get descendants:
     error = False
-    res = bkClient.getFileDescendants(list(parentLumi), depth=1, checkreplica=False)
+    res = bkClient.getFileDescendents(list(parentLumi), depth=1, checkreplica=False)
     if not res["OK"]:
         gLogger.error("Error getting descendants", res["Message"])
         return True
@@ -394,7 +394,7 @@ def _updateRunLumi(run, evtType, fileInfo, doIt=False, force=False):
     info = res["Value"]
     runLumi = info["TotalLuminosity"]
     runEvts = dict(zip(info["Stream"], info["Number of events"]))[evtType]
-    filesLumi = sum([lumi for _lfn, _evts, lumi in fileInfo])
+    filesLumi = sum(lumi for _lfn, _evts, lumi in fileInfo)
     # Check luminosity
     error = False
     if not runEvts:
@@ -416,7 +416,7 @@ def _updateRunLumi(run, evtType, fileInfo, doIt=False, force=False):
         gLogger.notice("Run %d: %d RAW files are OK" % (run, len(fileInfo)))
 
     # Now update descendants
-    fileLumi = dict([(lfn, lumi) for lfn, _evts, lumi in fileInfo])
+    fileLumi = {lfn: lumi for lfn, _evts, lumi in fileInfo}
     result = _updateDescendantsLumi(fileLumi, doIt=doIt, force=force)
     return error or result
 
@@ -452,7 +452,7 @@ def executeFixLuminosity(dmScript):
 
     runChecked = False
     for evtType in evtTypes:
-        gLogger.notice("**** Event type %s" % evtType)
+        gLogger.notice(f"**** Event type {evtType}")
         bkQueryDict["EventType"] = evtType
         res = bkClient.getFilesWithMetadata(bkQueryDict)
         if not res["OK"]:
@@ -476,14 +476,12 @@ def executeFixLuminosity(dmScript):
                 str(run) for run in res["Value"]["Successful"] if res["Value"]["Successful"][run]["Finished"] != "Y"
             )
             if runNotFinished:
-                gLogger.notice(
-                    "Found %d runs that are not Finished: %s" % (len(runNotFinished), ",".join(runNotFinished))
-                )
+                gLogger.notice(f"Found {len(runNotFinished)} runs that are not Finished: {','.join(runNotFinished)}")
             runFinished = sorted(
                 run for run in res["Value"]["Successful"] if res["Value"]["Successful"][run]["Finished"] == "Y"
             )
             if runFinished:
-                gLogger.notice("Found %d runs that are Finished" % len(runFinished))
+                gLogger.notice(f"Found {len(runFinished)} runs that are Finished")
             else:
                 gLogger.notice("No Finished run found")
                 diracExit(0)
@@ -491,7 +489,7 @@ def executeFixLuminosity(dmScript):
             result = _updateRunLumi(run, int(evtType), runFiles[run], doIt=doIt, force=force)
             if doIt:
                 if result is not None:
-                    gLogger.notice("Update done %s" % ("with errors" if result else "successfully"))
+                    gLogger.notice(f"Update done {'with errors' if result else 'successfully'}")
 
 
 def executeFileAncestors(dmScript, level=1):
@@ -545,9 +543,9 @@ def executeFileAncestors(dmScript, level=1):
             else:
                 okResult = result["Value"]["WithMetadata"]
                 for lfn in okResult:
-                    fullResult["Value"].setdefault("Successful", {})[lfn] = dict(
-                        (desc, "Replica-%s" % meta["GotReplica"]) for desc, meta in okResult[lfn].items()
-                    )  # can be an iterator
+                    fullResult["Value"].setdefault("Successful", {})[lfn] = {
+                        desc: f"Replica-{meta['GotReplica']}" for desc, meta in okResult[lfn].items()
+                    }  # can be an iterator
             failed = result["Value"]["Failed"]
             if isinstance(failed, list):
                 failed = dict.fromkeys(failed, "Not found")
@@ -611,7 +609,7 @@ def executeFileDescendants(dmScript, level=1):
     fullResult = S_OK({})
     for lfnChunk in breakListIntoChunks(lfnList, 50):
         progressBar.loop()
-        result = bkClient.getFileDescendants(lfnChunk, depth=level, production=prod, checkreplica=checkreplica)
+        result = bkClient.getFileDescendents(lfnChunk, depth=level, production=prod, checkreplica=checkreplica)
         if result["OK"]:
             noDescendants = (
                 set(lfnChunk)
@@ -626,9 +624,9 @@ def executeFileDescendants(dmScript, level=1):
             else:
                 okResult = result["Value"]["WithMetadata"]
                 for lfn in okResult:
-                    fullResult["Value"].setdefault("Successful", {})[lfn] = dict(
-                        (desc, "Replica-%s" % meta["GotReplica"]) for desc, meta in okResult[lfn].items()
-                    )  # can be an iterator
+                    fullResult["Value"].setdefault("Successful", {})[lfn] = {
+                        desc: f"Replica-{meta['GotReplica']}" for desc, meta in okResult[lfn].items()
+                    }  # can be an iterator
             failed = result["Value"]["Failed"]
             if isinstance(failed, list):
                 failed = dict.fromkeys(failed, "Unknown error")
@@ -673,7 +671,7 @@ def executeGetFiles(dmScript, maxFiles=20):
     bkQuery = dmScript.getBKQuery()
     bkQueries = [bkQuery] if bkQuery else []
     if bkFile and os.path.exists(bkFile):
-        with open(bkFile, "rt") as fd:
+        with open(bkFile) as fd:
             bkQueries += [BKQuery(ll.strip().split()[0]) for ll in fd.readlines()]
 
     if not bkQueries:
@@ -713,14 +711,14 @@ def executeGetFiles(dmScript, maxFiles=20):
     # Now print out
     nFiles = len(fileDict)
     if output:
-        fd = open(output, "wt")
+        fd = open(output, "w")
         if not nMax:
             nMax = maxFiles
     else:
         if not nMax:
             nMax = nFiles
     gLogger.notice("%d files found" % nFiles, "(showing only first %d files):" % nMax if nFiles > nMax else ":")
-    outputStr = "%s %s %s %s %s" % (
+    outputStr = "{} {} {} {} {}".format(
         "FileName".ljust(100),
         "Size".ljust(10),
         "GUID".ljust(40),
@@ -735,7 +733,7 @@ def executeGetFiles(dmScript, maxFiles=20):
         guid = metadata["GUID"]
         hasReplica = metadata["GotReplica"]
         visible = metadata.get("VisibilityFlag", "?")
-        outputStr = "%s %s %s %s %s" % (
+        outputStr = "{} {} {} {} {}".format(
             lfn.ljust(100),
             str(size).ljust(10),
             guid.ljust(40),
@@ -750,7 +748,7 @@ def executeGetFiles(dmScript, maxFiles=20):
 
     if output:
         fd.close()
-        gLogger.notice("\nList of %d files saved in" % len(fileDict), output)
+        gLogger.notice(f"\nList of {len(fileDict)} files saved in", output)
 
     if optionsFile:
         # Use BK client method to write options file
@@ -762,8 +760,8 @@ def executeGetFiles(dmScript, maxFiles=20):
             dataset["fullpath"] = bkQueries[0].getPath()
         else:
             dataset = None
-        LHCB_BKKDBClient(welcome=False).writeJobOptions(fileDict, optionsFile=optionsFile, dataset=dataset)
-        gLogger.notice("\n%d files in options file %s" % (len(fileDict), optionsFile))
+        LHCB_BKKDBClient().writeJobOptions(fileDict, optionsFile=optionsFile, dataset=dataset)
+        gLogger.notice(f"\n{len(fileDict)} files in options file {optionsFile}")
 
 
 def executeFileSisters(dmScript, level=1):
@@ -830,7 +828,7 @@ def executeFileSisters(dmScript, level=1):
         for dirName in directories:
             prod = res["Value"]["Successful"].get(dirName, [{}])[0].get("Production")
             if not prod:
-                gLogger.error("Error: could not get production number for %s" % dirName)
+                gLogger.error(f"Error: could not get production number for {dirName}")
             else:
                 prodLfns.setdefault(prod, []).extend(directories[dirName])
     else:
@@ -865,7 +863,7 @@ def executeFileSisters(dmScript, level=1):
         ancestors = {}
         # More than one file in the input list may have the same ancestor(s), check if they are sisters/cousins
         for lfn, ancList in result["Value"]["Successful"].items():  # can be an iterator
-            sameAncestors = set(anc["FileName"] for anc in ancList) & set(ancestors)
+            sameAncestors = {anc["FileName"] for anc in ancList} & set(ancestors)
             skip = False
             if sameAncestors:
                 # Some of the input files share the same ancestor, are they sisters/cousins?
@@ -879,7 +877,7 @@ def executeFileSisters(dmScript, level=1):
                     ancestors.setdefault(anc["FileName"], []).append(lfn)
         # print ancestors
 
-        res = bkClient.getFileDescendants(list(ancestors), depth=999999, production=prod, checkreplica=checkreplica)
+        res = bkClient.getFileDescendents(list(ancestors), depth=999999, production=prod, checkreplica=checkreplica)
 
         fullResult["OK"] = res["OK"]
         if res["OK"]:
@@ -894,7 +892,7 @@ def executeFileSisters(dmScript, level=1):
                             resValue[resItem].setdefault(allLfns, {}).update(metadata)
                         else:
                             resValue[resItem].setdefault(allLfns, {}).update(
-                                {sister: "Replica-%s" % metadata["GotReplica"]}
+                                {sister: f"Replica-{metadata['GotReplica']}"}
                             )
                         found = True
                 for lfn in lfns:
@@ -969,9 +967,9 @@ def _getCollidingBunches(fills):
 
     :return: dictionary {fill:nbCollisingBunches}
     """
-    from six.moves.urllib.request import urlopen
-    from six.moves.urllib.error import HTTPError
     import json
+    from urllib.request import urlopen
+    from urllib.error import HTTPError
 
     result = {}
     for fill in fills:
@@ -981,7 +979,7 @@ def _getCollidingBunches(fills):
             result[fill] = int(fillInfo["nCollidingBunches"])
         except (KeyError, ValueError) as e:
             gLogger.exception("Exception getting info for fill", str(fill), lException=e)
-        except HTTPError as e:
+        except HTTPError:
             pass
     return result
 
@@ -1021,9 +1019,9 @@ def executeGetStats(dmScript):
         processingPass = bkQuery.getProcessingPass().replace("...", "*")
         if "*" in processingPass:
             depth = None if processingPass.endswith("/*") else 1
-            progressBar = ProgressBar(1, title="Getting list of processing passes (depth=%s)" % depth)
+            progressBar = ProgressBar(1, title=f"Getting list of processing passes (depth={depth})")
             processingPasses = getProcessingPasses(bkQuery, depth=depth)
-            progressBar.endLoop(message="obtained %d processing passes" % len(processingPasses))
+            progressBar.endLoop(message=f"obtained {len(processingPasses)} processing passes")
         else:
             processingPasses = [processingPass]
     else:
@@ -1046,13 +1044,13 @@ def executeGetStats(dmScript):
             bkQuery.setOption("Production", prod)
             gLogger.notice("For production %d, %s (query %s)" % (prod, prodName, bkQuery))
         elif lfns:
-            gLogger.notice("For %d LFNs:" % len(lfns))
+            gLogger.notice(f"For {len(lfns)} LFNs:")
         elif bkQuery:
             queryDict = bkQuery.getQueryDict()
             if len(processingPasses) > 1:
                 queryDict.pop("ProcessingPass", None)
                 gLogger.notice("For BK query:", queryDict)
-                gLogger.notice("   and %d processing passes :" % len(processingPasses), ", ".join(processingPasses))
+                gLogger.notice(f"   and {len(processingPasses)} processing passes :", ", ".join(processingPasses))
             else:
                 gLogger.notice("For BK query:", bkQuery)
 
@@ -1170,7 +1168,7 @@ def executeGetStats(dmScript):
                             runList[run][2] += metadata["FileSize"]
                             nbFiles += 1
                         except (KeyError, ValueError) as e:
-                            gLogger.exception("Exception for %s" % str(list(metadata)), lException=e)
+                            gLogger.exception(f"Exception for {str(list(metadata))}", lException=e)
                 progressBar.endLoop()
             if lfns:
                 gLogger.notice("Getting info from files...")
@@ -1195,7 +1193,7 @@ def executeGetStats(dmScript):
                                 runList[run][2] += metadata["FileSize"]
                                 nbFiles += 1
                             except (KeyError, ValueError) as e:
-                                gLogger.exception("Exception for %s" % lfn, str(list(metadata)), lException=e)
+                                gLogger.exception(f"Exception for {lfn}", str(list(metadata)), lException=e)
                     else:
                         gLogger.error("Error getting files metadata:", res["Message"])
                         continue
@@ -1218,26 +1216,26 @@ def executeGetStats(dmScript):
         for name, value in zip(paramNames, records):
             if name == "NbofFiles":
                 nfiles = value
-                gLogger.notice("%s: %s" % ("Nb of Files".ljust(tab), _intWithQuotes(value)))
+                gLogger.notice("Nb of Files".ljust(tab) + ": ", f"{_intWithQuotes(value)}")
             elif name == "NumberOfEvents":
                 nevts = value
-                gLogger.notice("%s: %s" % ("Nb of Events".ljust(tab), _intWithQuotes(value)))
+                gLogger.notice("Nb of Events".ljust(tab) + ": ", f"{_intWithQuotes(value)}")
             elif name == "FileSize":
                 size = value
-                sizePerEvt = "(%.1f kB per evt)" % (size / nevts / 1000.0) if nevts and nDatasets == 1 else ""
+                sizePerEvt = f"({size / nevts / 1000.0:.1f} kB per evt)" if nevts and nDatasets == 1 else ""
                 size, sizeUnit = scaleSize(size)
-                gLogger.notice("%s: %.3f %s %s" % ("Total size".ljust(tab), size, sizeUnit, sizePerEvt))
+                gLogger.notice("Total size".ljust(tab) + ": ", f"{size:.3f} {sizeUnit} {sizePerEvt}")
             elif name == "Luminosity":
                 lumi = value / nDatasets
                 lumi, lumiUnit = _scaleLumi(lumi)
                 lumiString = "Luminosity" if nDatasets == 1 else "Avg luminosity"
-                gLogger.notice("%s: %.3f %s" % (lumiString.ljust(tab), lumi, lumiUnit))
+                gLogger.notice(f"{lumiString.ljust(tab)}: {lumi:.3f} {lumiUnit}")
             elif name == "SizePerLumi":
                 # value *= nDatasets
-                gLogger.notice("%s: %.1f GB" % (("Size  per %s" % "/pb").ljust(tab), value * 1000000.0 / 1000000000.0))
+                gLogger.notice("Size per /pb".ljust(tab) + ": ", f"{value * 1e-3:.1f} GB")
         if lumi:
             filesPerLumi = nfiles / lumi
-            gLogger.notice("%s: %.1f" % (("Files per %s" % lumiUnit).ljust(tab), filesPerLumi))
+            gLogger.notice(f"Files per {lumiUnit}".ljust(tab) + ": ", f"{filesPerLumi:.1f}")
 
         if triggerRate:
             # Get information from the runs, but first get those that are Finished
@@ -1251,10 +1249,10 @@ def executeGetStats(dmScript):
             notFinished = set(runList) - set(runs)
             if notFinished:
                 gLogger.notice(
-                    "%d runs not Finished (ignored), %s runs Finished (used for trigger rate)"
-                    % (len(notFinished), str(len(runs) if runs else "no"))
+                    f"{len(notFinished)} runs not Finished (ignored), "
+                    f"{len(runs) if runs else 'no'} runs Finished (used for trigger rate)"
                 )
-                gLogger.notice("These runs are not Finished: %s" % ",".join(str(run) for run in sorted(notFinished)))
+                gLogger.notice("These runs are not Finished: ", ",".join(str(run) for run in sorted(notFinished)))
             if runs:
                 nevts = 0
                 size = 0
@@ -1278,27 +1276,27 @@ def executeGetStats(dmScript):
                         lumi = info["TotalLuminosity"]
                         if abs(lumi - runList[run][0] / nDatasets) > 1:
                             gLogger.notice(
-                                "Run and files luminosity mismatch (ignored): run %d, runLumi %d, filesLumi %d"
-                                % (run, lumi, int(runList[run][0] / nDatasets))
+                                "Run and files luminosity mismatch (ignored): ",
+                                f"run {run}, runLumi {lumi}, filesLumi {runList[run][0] / nDatasets}",
                             )
                         else:
                             totalLumi += lumi
                 if fullDuration:
                     triggerRate = nevts / fullDuration / 3600
-                    rate = "%.1f events/second" % triggerRate
+                    rate = f"{triggerRate:.1f} events/second"
                 else:
                     triggerRate = 0.0
                     rate = "Run duration not available"
                 totalLumi, lumiUnit = _scaleLumi(totalLumi)
-                gLogger.notice("%s: %.3f %s" % ("Total Luminosity".ljust(tab), totalLumi, lumiUnit))
-                gLogger.notice("%s: %.2f hours (%d runs)" % ("Run duration".ljust(tab), fullDuration, len(runs)))
-                gLogger.notice("%s: %s" % ("Trigger rate".ljust(tab), rate))
+                gLogger.notice(f"{'Total Luminosity'.ljust(tab)}: {totalLumi:.3f} {lumiUnit}")
+                gLogger.notice(f"{'Run duration'.ljust(tab)}: {fullDuration:.2f} hours ({len(runs)} runs)")
+                gLogger.notice(f"{'Trigger rate'.ljust(tab)}: {rate}")
                 rate = (
-                    ("%.1f MB/second" % (size / 1000000.0 / fullDuration / 3600.0))
+                    f"{size / 1000000.0 / fullDuration / 3600.0:.1f} MB/second"
                     if fullDuration
                     else "Run duration not available"
                 )
-                gLogger.notice("%s: %s" % ("Throughput".ljust(tab), rate))
+                gLogger.notice(f"{'Throughput'.ljust(tab)}: {rate}")
                 collBunches = 0.0
                 result = {}
                 # FIXME: if/when the online run DB is accessible to get the number of bunches this should be re-activated
@@ -1310,10 +1308,8 @@ def executeGetStats(dmScript):
                 #     collBunches += result[fill] * fillDuration[fill]
                 if fullDuration and collBunches:
                     collBunches /= fullDuration
-                    gLogger.notice("%s: %.1f on average" % ("Colliding bunches".ljust(tab), collBunches))
-                    gLogger.notice(
-                        "%s: %.2f events/s/bunch" % ("Trigger per bunch".ljust(tab), triggerRate / collBunches)
-                    )
+                    gLogger.notice(f"{'Colliding bunches'.ljust(tab)}: {collBunches:.1f} on average")
+                    gLogger.notice(f"{'Trigger per bunch'.ljust(tab)}: {triggerRate / collBunches:.2f} events/s/bunch")
                 if listFills:
                     gLogger.notice(
                         "List of fills: ",
@@ -1388,12 +1384,12 @@ def executeRunInfo(item):
         runGap = 100000000
         timeGap = 365
     if activity:
-        progressBar = ProgressBar(1, title="Getting run list for activity %s" % activity, step=20)
-        runsList = BKQuery("/LHCb/%s//Real Data//RAW" % activity).getBKRuns()
-        progressBar.endLoop(message="Obtained %d runs" % len(runsList))
+        progressBar = ProgressBar(1, title=f"Getting run list for activity {activity}", step=20)
+        runsList = BKQuery(f"/LHCb/{activity}//Real Data/RAW").getBKRuns()
+        progressBar.endLoop(message=f"Obtained {len(runsList)} runs")
         if runsDict:
             runsList = sorted(set(runsList) & set(runsDict["RunNumber"]))
-            gLogger.notice("Only %d runs in range %s" % (len(runsList), runRange))
+            gLogger.notice(f"Only {len(runsList)} runs in range {runRange}")
     elif not runsDict:
         Script.showHelp()
         diracExit(1)
@@ -1402,9 +1398,9 @@ def executeRunInfo(item):
         # Remove the fake run number
         runsList.remove(0)
         if len(runRange) < 30:
-            progressBar = ProgressBar(1, title="Getting runs for run range %s " % runRange, step=20)
+            progressBar = ProgressBar(1, title=f"Getting runs for run range {runRange} ", step=20)
         else:
-            progressBar = ProgressBar(1, title="Getting runs for %d runs " % len(runsList), step=20)
+            progressBar = ProgressBar(1, title=f"Getting runs for {len(runsList)} runs ", step=20)
         res = bkClient.getRunStatus(runsList)
         progressBar.endLoop()
         if not res["OK"]:
@@ -1415,20 +1411,20 @@ def executeRunInfo(item):
     if dqFlag:
         nruns = len(runsList)
         chunkSize = 10
-        progressBar = ProgressBar(len(runsList), title="Getting DQFlag for %d runs " % len(runsList), chunk=chunkSize)
+        progressBar = ProgressBar(len(runsList), title=f"Getting DQFlag for {len(runsList)} runs ", chunk=chunkSize)
         for runChunk in breakListIntoChunks(runsList, chunkSize):
             progressBar.loop()
             res = bkClient.getRunFilesDataQuality(runChunk)
             if not res["OK"]:
                 gLogger.fatal("Error getting DQFlag", res["Message"])
                 diracExit(1)
-            dq = dict((r, dq) for r, dq, s in res["Value"] if s == 90000000)
+            dq = {r: dq for r, dq, s in res["Value"] if s == 90000000}
             for run in runChunk:
                 if dq.get(run) not in dqFlag:
                     runsList.remove(run)
         progressBar.endLoop()
         if len(runsList) != nruns:
-            gLogger.notice("Only %d runs have DQ flag in %s" % (len(runsList), ",".join(dqFlag)))
+            gLogger.notice(f"Only {len(runsList)} runs have DQ flag in {','.join(dqFlag)}")
 
     runTime = {}
     if getRanges and force:
@@ -1437,7 +1433,7 @@ def executeRunInfo(item):
     else:
         counted = "files"
         runDict = {}
-        progressBar = ProgressBar(len(runsList), title="Getting %s for %d runs " % (item, len(runsList)), step=20)
+        progressBar = ProgressBar(len(runsList), title=f"Getting {item} for {len(runsList)} runs ", step=20)
         for run in sorted(runsList):
             progressBar.loop()
             res = bkClient.getRunInformations(run)
@@ -1507,13 +1503,13 @@ def executeRunInfo(item):
                 if lastRun != firstRun:
                     # This should be "disable=bad-string-format-type" but this
                     # isn't support in Python 2 versions of pylint
-                    rangeStr = "%d:%d" % (firstRun, lastRun)  # pylint: disable=E
+                    rangeStr = f"{firstRun}:{lastRun}"
                 else:
-                    rangeStr = "%d" % firstRun
+                    rangeStr = f"{firstRun}"
                 if lastRunDesc:
-                    rangeStr += " (%s)" % lastRunDesc
+                    rangeStr += f" ({lastRunDesc})"
                 if getRanges:
-                    rangesDict[rangeStr] = "%d %s" % (count, counted)
+                    rangesDict[rangeStr] = f"{count} {counted}"
                     # Initialize count of files
                     count = 0
                 else:
@@ -1531,12 +1527,12 @@ def executeRunInfo(item):
 
     if byRange:
         if item == "Ranges":
-            gLogger.notice("Total number of runs: %d" % len(runDict))
+            gLogger.notice(f"Total number of runs: {len(runDict)}")
         for rangeStr in sorted(rangesDict):
-            gLogger.notice("%s : %s" % (rangeStr, rangesDict[rangeStr]))
+            gLogger.notice(f"{rangeStr} : {rangesDict[rangeStr]}")
     else:
         for itemValue in sorted(itemDict):
-            gLogger.notice("%s :" % itemValue, ", ".join(itemDict[itemValue]))
+            gLogger.notice(f"{itemValue} :", ", ".join(itemDict[itemValue]))
 
 
 def _jobFromLfn(lfn):
@@ -1558,8 +1554,8 @@ def _getJobsEISFromAncestors(lfnList):
             jobDict.setdefault(job, lfn)
     lfnList = list(jobDict.values())
     # Get ancestors of these files
-    gLogger.verbose("\nGet EIS for %d jobs like %s" % (len(jobDict), str(list(jobDict.items())[0])))
-    gLogger.verbose("\t%d unique files" % len(set(lfnList)))
+    gLogger.verbose(f"\nGet EIS for {len(jobDict)} jobs like {str(list(jobDict.items())[0])}")
+    gLogger.verbose(f"\t{len(set(lfnList))} unique files")
     ancToCheck = set()
     ancestors = {}
     topFiles = 0
@@ -1615,7 +1611,7 @@ def _getEventInputStat(lfns):
     # These are the final LFNs, but we must get to the top ancestors to get it right
     # Let's do it job by job
     if jobLfns:
-        progressBar = ProgressBar(len(jobLfns), title="Getting ancestors for %d jobs" % len(jobLfns), chunk=1)
+        progressBar = ProgressBar(len(jobLfns), title=f"Getting ancestors for {len(jobLfns)} jobs", chunk=1)
         for lfns in jobLfns.values():
             progressBar.loop()
             res = _getJobsEISFromAncestors(lfns)
@@ -1740,9 +1736,7 @@ def executeRejectionStats(dmScript):
                     gLogger.fatal("Error getting ancestors EventStat", res["Message"])
                     diracExit(1)
             else:
-                progressBar = ProgressBar(
-                    len(lfns), title="Getting metadata for %d jobs" % len(jobLfns), chunk=chunkSize
-                )
+                progressBar = ProgressBar(len(lfns), title=f"Getting metadata for {len(jobLfns)} jobs", chunk=chunkSize)
                 for lfnChunk in breakListIntoChunks(jobLfns, chunkSize):
                     progressBar.loop()
                     res = bkClient.bulkJobInfo(lfnChunk)
@@ -1758,14 +1752,14 @@ def executeRejectionStats(dmScript):
                 progressBar.endLoop()
 
         eventInputStatByStream[stream] = sum(jobEventInputStat[_jobFromLfn(lfn)] for lfn in lfns)
-        jobs[stream] = set(_jobFromLfn(lfn) for lfn in lfns)
+        jobs[stream] = {_jobFromLfn(lfn) for lfn in lfns}
     # End of loop on streams
 
     tab = "\t" if byStream else ""
     eventInputStat = 0
     multiStream = len(fileTypes) > 1 and not byStream and len(jobs["all"]) == len(lfnsByStream["all"])
     if multiStream:
-        gLogger.notice("*** WARNING *** %d streams with as many jobs as files, rescaled input stat" % len(fileTypes))
+        gLogger.notice(f"*** WARNING *** {len(fileTypes)} streams with as many jobs as files, rescaled input stat")
         rescale = len(fileTypes)
     else:
         rescale = 1
@@ -1775,11 +1769,11 @@ def executeRejectionStats(dmScript):
         if prInput:
             eventInputStat = eventInputStatByStream[stream] / float(rescale)
         if len(fileTypes) > 1:
-            gLogger.notice("For %s stream%s:" % (stream, "" if byStream else "s"))
+            gLogger.notice(f"For {stream} stream{'' if byStream else 's'}:")
         gLogger.notice(tab + "Event stat: %d on %d files" % (eventStat, len(lfnsByStream[stream])))
         if prInput:
             gLogger.notice(
                 tab + "EventInputStat: %d" % eventInputStat,
-                ("from %d jobs" % len(jobs[stream])) if jobs[stream] != lfnsByStream[stream] else "",
+                f"from {len(jobs[stream])} jobs" if jobs[stream] != lfnsByStream[stream] else "",
             )
-        gLogger.notice(tab + "Retention: %.2f %%" % (100.0 * eventStat / eventInputStat))
+        gLogger.notice(tab + f"Retention: {100.0 * eventStat / eventInputStat:.2f} %")
