@@ -11,7 +11,7 @@
 """A mock of the BookkeepingClient, used for testing purposes."""
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
 
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 bkc_mock = MagicMock()
 bkc_mock.sendXMLBookkeepingReport.return_value = {"OK": True, "Value": ""}
@@ -72,7 +72,7 @@ bkc_mock.getFileMetadata.return_value = {
     "rpcStub": (("Bookkeeping/BookkeepingManager",)),
 }
 bkc_mock.getFileTypeVersion.return_value = {"OK": True, "Value": {"lfn1": "ROOT", "lfn2": "MDF"}}
-bkc_mock.getFileDescendants.return_value = {
+bkc_mock.getFileDescendents.return_value = {
     "OK": True,
     "Value": {
         "Failed": [],
@@ -88,11 +88,10 @@ bkc_mock.getFileDescendants.return_value = {
 }
 
 
-class BookkeepingClientFake(object):
+class BookkeepingClientFake:
     """a fake BookkeepingClient - replicating some of the methods"""
 
     def getAvailableSteps(self, stepID):
-
         if stepID == {"StepId": 123}:
             return {
                 "OK": True,
