@@ -57,29 +57,32 @@ the calling method is responsible for closing this connection once it is no
 longer needed.
 """
 # FIXME: use Connection Pooling
-# https://cx-oracle.readthedocs.io/en/latest/user_guide/connection_handling.html#connection-pooling
+# https://python-oracledb.readthedocs.io/en/latest/user_guide/connection_handling.html#connection-pooling
+# FIXME: tnsEntry is named dsn in python-oracledb
 
-from six.moves import queue as Queue
 import time
 import threading
-import six
+import queue
 
-import cx_Oracle
+import oracledb
+from oracledb import STRING as oracledb_STRING  # pylint: disable=no-name-in-module
+from oracledb import NUMBER as oracledb_NUMBER  # pylint: disable=no-name-in-module
 
 from DIRAC import gLogger
 from DIRAC import S_OK, S_ERROR
 
 
 gInstancesCount = 0
+gModeFixed = False
 
 maxConnectRetry = 100
 maxArraysize = 5000  # max allowed
 
 
-class OracleDB(object):
+class OracleDB:
     """Basic multithreaded DIRAC Oracle Client Class."""
 
-    def __init__(self, userName, password="", tnsEntry="", maxQueueSize=100):
+    def __init__(self, userName, password="", tnsEntry="", confDir="", mode="", maxQueueSize=100, **kwargs):
         """set Oracle connection parameters and try to connect."""
         global gInstancesCount
         gInstancesCount += 1
@@ -91,16 +94,20 @@ class OracleDB(object):
             self.logger = gLogger.getSubLogger("Oracle")
 
         # let the derived class decide what to do with if is not 1
-        self._threadsafe = cx_Oracle.threadsafety
-        self.logger.debug("thread_safe = %s" % self._threadsafe)
+        self._threadsafe = oracledb.threadsafety
+        self.logger.debug(f"thread_safe = {self._threadsafe}")
 
         self.__checkQueueSize(maxQueueSize)
 
-        self.__userName = str(userName)
-        self.__passwd = str(password)
-        self.__tnsName = str(tnsEntry)
+        self.__connect_kwargs = kwargs | dict(
+            user=userName,
+            password=password,
+            dsn=tnsEntry,
+            config_dir=confDir,
+        )
+        self.__mode = mode
         # Create the connection Queue to reuse connections
-        self.__connectionQueue = Queue.Queue(maxQueueSize)
+        self.__connectionQueue = queue.Queue(maxQueueSize)
         # Create the connection Semaphore to limit total number of open connection
         self.__connectionSemaphore = threading.Semaphore(maxQueueSize)
 
@@ -111,8 +118,8 @@ class OracleDB(object):
             raise RuntimeError("Can not connect, exiting...")
 
         self.logger.info("===================== Oracle =====================")
-        self.logger.info("User:           " + self.__userName)
-        self.logger.info("TNS:            " + self.__tnsName)
+        self.logger.info("User:           " + self.__connect_kwargs.get("user"))
+        self.logger.info("TNS:            " + self.__connect_kwargs.get("dsn"))
         self.logger.info("==================================================")
 
     def __del__(self):
@@ -123,8 +130,8 @@ class OracleDB(object):
             try:
                 connection = self.__connectionQueue.get_nowait()
                 connection.close()
-            except Queue.Empty:
-                self.logger.debug("No more connection in Queue")
+            except queue.Empty:
+                # self.logger.debug("No more connection in Queue")
                 break
 
     @staticmethod
@@ -136,19 +143,19 @@ class OracleDB(object):
         try:
             test = maxQueueSize - 1
         except TypeError:
-            raise TypeError("OracleDB.__init__: wrong type for maxQueueSize" + str(test))
+            raise TypeError(f"OracleDB.__init__: wrong type for maxQueueSize {type(maxQueueSize)}")
 
     def _except(self, methodName, x, err):
         """print Oracle error or exeption return S_ERROR with Exception."""
 
         try:
             raise x
-        except cx_Oracle.Error as e:
-            self.logger.error("%s: %s" % (methodName, err), "%s" % (e))
-            return S_ERROR("%s: ( %s )" % (err, e))
+        except oracledb.Error as e:
+            self.logger.error(f"{methodName}: {err}", str(e))
+            return S_ERROR(f"{err}: ( {e} )")
         except Exception as x:
-            self.logger.error("%s: %s" % (methodName, err), str(x))
-            return S_ERROR("%s: (%s)" % (err, str(x)))
+            self.logger.error(f"{methodName}: {err}", str(x))
+            return S_ERROR(f"{err}: ({x})")
 
     def _connect(self):
         """open connection to Oracle DB and put Connection into Queue set connected
@@ -157,7 +164,7 @@ class OracleDB(object):
         if self._connected:
             return S_OK()
 
-        self.logger.debug("_connect: Attempting to access DB", "by user %s." % self.__userName)
+        self.logger.debug("_connect: Attempting to access DB", f"by user {self.__connect_kwargs.get('user')}.")
         try:
             self.__newConnection()
             self.logger.debug("_connect: Connected.")
@@ -172,13 +179,13 @@ class OracleDB(object):
         S_ERROR upon error.
 
         Use of params and kwparams to pass bind variabes is strongly encouraged
-        to prevent SQL injection and improve performance. See the cx_Oracle
+        to prevent SQL injection and improve performance. See the python-oracledb
         documentation for more information.
 
         :param str cmd: the SQL string to be executed
         :param conn: the connection to use, optional
-        :param list params: positional bind variables to pass to cx_Oracle.Cursor.execute
-        :param dict kwparams: named bind variables to pass to cx_Oracle.Cursor.execute
+        :param list params: positional bind variables to pass to oracledb.Cursor.execute
+        :param dict kwparams: named bind variables to pass to oracledb.Cursor.execute
         """
         self.logger.debug("query:", f"{cmd!r} {params!r} {kwparams!r}")
 
@@ -237,27 +244,27 @@ class OracleDB(object):
             results = None
             if array:
                 fArray = array[0]
-                if isinstance(fArray, six.string_types):
-                    result = cursor.arrayvar(cx_Oracle.STRING, array)
+                if isinstance(fArray, str):
+                    result = cursor.arrayvar(oracledb_STRING, array)
                     parameters += [result]
-                elif isinstance(fArray, six.integer_types):
-                    result = cursor.arrayvar(cx_Oracle.NUMBER, array)
+                elif isinstance(fArray, int):
+                    result = cursor.arrayvar(oracledb_NUMBER, array)
                     parameters += [result]
                 elif isinstance(fArray, list):
                     for i in array:
-                        if isinstance(i, (bool,) + six.string_types + six.integer_types):
+                        if isinstance(i, (bool, str, int)):
                             parameters += [i]
                         elif i:
-                            if isinstance(i[0], six.string_types):
-                                result = cursor.arrayvar(cx_Oracle.STRING, i)
+                            if isinstance(i[0], str):
+                                result = cursor.arrayvar(oracledb_STRING, i)
                                 parameters += [result]
-                            elif isinstance(i[0], six.integer_types):
-                                result = cursor.arrayvar(cx_Oracle.NUMBER, i)
+                            elif isinstance(i[0], int):
+                                result = cursor.arrayvar(oracledb_NUMBER, i)
                                 parameters += [result]
                             else:
                                 return S_ERROR("The array type is not supported!!!")
                         else:
-                            result = cursor.arrayvar(cx_Oracle.STRING, [], 0)
+                            result = cursor.arrayvar(oracledb_STRING, [], 0)
                             parameters += [result]
                 else:
                     return S_ERROR("The array type is not supported!!!")
@@ -271,7 +278,6 @@ class OracleDB(object):
                 cursor.callproc(packageName, parameters)
             retDict = S_OK(results)
         except Exception as x:
-
             self.logger.debug("query:", packageName + "(" + str(parameters) + ")")
             retDict = self._except("query", x, "Execution failed.")
             connection.rollback()
@@ -299,7 +305,7 @@ class OracleDB(object):
             result = cursor.callfunc(packageName, returnType, parameters)
             retDict = S_OK(result)
         except Exception as x:
-            self.logger.debug("_query:", packageName + "(" + str(parameters) + ")")
+            self.logger.debug(f"_query: {packageName} ({parameters})")
             retDict = self._except("_query", x, "Execution failed.")
             connection.rollback()
 
@@ -313,9 +319,24 @@ class OracleDB(object):
 
     def __newConnection(self):
         """Create a New connection and put it in the Queue."""
+        global gModeFixed
         self.logger.debug("__newConnection:")
-
-        connection = cx_Oracle.connect(self.__userName, self.__passwd, self.__tnsName, threaded=True)
+        if not gModeFixed:
+            gModeFixed = True
+            if self.__mode == "":
+                try:
+                    connection = oracledb.connect(**self.__connect_kwargs)
+                except Exception as ex:
+                    self.logger.debug(f"Thin mode has failed: {ex}, we will try thick")
+                else:
+                    self.logger.debug("Using implicit thin mode")
+                    self.__putConnection(connection)
+                    return
+                self.__mode = "Thick"
+            if self.__mode == "Thick":
+                oracledb.init_oracle_client(config_dir=self.__connect_kwargs.get("config_dir"))
+            self.logger.debug(f'Using {"thin" if oracledb.is_thin_mode() else "thick"} mode')
+        connection = oracledb.connect(**self.__connect_kwargs)
         self.__putConnection(connection)
 
     def __putConnection(self, connection):
@@ -327,7 +348,7 @@ class OracleDB(object):
         self.__connectionSemaphore.release()
         try:
             self.__connectionQueue.put_nowait(connection)
-        except Queue.Full:
+        except queue.Full:
             self.logger.debug("__putConnection: Full Queue")
             try:
                 connection.close()
@@ -370,12 +391,12 @@ class OracleDB(object):
                     self.__connectionSemaphore.release()
                     return self.__getConnection()
                 return S_OK(connection)
-        except Queue.Empty:
+        except queue.Empty:
             self.__connectionSemaphore.release()
             self.logger.debug("__getConnection: Empty Queue")
             try:
                 if trial == min(100, maxConnectRetry):
-                    return S_ERROR("Could not get a connection after %s retries." % maxConnectRetry)
+                    return S_ERROR(f"Could not get a connection after {maxConnectRetry} retries.")
                 try:
                     self.__newConnection()
                     return self.__getConnection()
