@@ -9,6 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Bookkeeping utilities."""
+
 from DIRAC import gLogger, S_ERROR
 
 from DIRAC.FrameworkSystem.Client.NotificationClient import NotificationClient
@@ -74,20 +75,20 @@ def checkEnoughBKArguments(func):
                 res = self.getRemoteCredentials()
                 userName = res.get("username", "UNKNOWN")
                 address = self.email
-                subject = "%s method!" % funcName
+                subject = f"{funcName} method!"
                 body = (
                     "%s user has not provided enough input parameters! \n \
                 the input parameters:%s "
                     % (userName, str(arguments))
                 )
                 NotificationClient().sendMail(address, subject, body, "lhcb-bookkeeping@cern.ch")
-                gLogger.error("Got you: %s ---> %s" % (userName, str(arguments)))
+                gLogger.error(f"Got you: {userName} ---> {str(arguments)}")
                 if self.forceExecution:  # we can force to execute the methods even the user does not
                     # provide enough parameter
                     result = func(self, *args)
                     return result
                 else:
-                    return S_ERROR("Provide more parameters %s" % str(arguments))  # TODO: use errno.EINVAL
+                    return S_ERROR(f"Provide more parameters {str(arguments)}")  # TODO: use errno.EINVAL
             else:
                 result = func(self, *args)
                 return result
