@@ -9,39 +9,24 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_BKK_DB_OracleBookkeepingDB."""
-import mock
+from unittest import mock
 
-import LHCbDIRAC.BookkeepingSystem.DB.OracleBookkeepingDB as moduleTested
+from LHCbDIRAC.BookkeepingSystem.DB.LegacyOracleBookkeepingDB import LegacyOracleBookkeepingDB
 from LHCbDIRAC.BookkeepingSystem.DB.OracleDB import OracleDB
 from DIRAC.ConfigurationSystem.Client.Config import gConfig
 
-# mock_OracleDB = mock.Mock(spec=OracleDB)
-testClass = moduleTested.OracleBookkeepingDB
-# self.moduleTested.OracleDB = mock_OracleDB
 
-mock_getDatabaseSection = mock.Mock()
-mock_getDatabaseSection.return_value = "/Systems/Bookkeeping/Development/Databases/BookkeepingDB"
-mock_getDatabaseSection = mock_getDatabaseSection
-mock_gConfig = mock.Mock(spec=gConfig)
-mock_gConfig.getOption.return_value = {"OK": True, "Value": "exp1"}
-mock_gConfig = mock_gConfig.getOption
-
-moduleTested.getDatabaseSection = mock_getDatabaseSection
-moduleTested.gConfig.getOption = mock_gConfig
-moduleTested.OracleDB = mock.MagicMock()
-
-
-def test_instantiate():
+def test_instantiate(monkeypatch):
     """tests that we can instantiate one object of the tested class."""
 
-    module = testClass()
-    assert module.__class__.__name__ == "OracleBookkeepingDB"
+    module = LegacyOracleBookkeepingDB(dbW=None, dbR=None)
+    assert module.__class__.__name__ == "LegacyOracleBookkeepingDB"
 
 
 def test_buildRunNumbers():
     """It test the method which used to build the conditions when runnumbers is
     a list/number, and end run and start run is a number."""
-    client = testClass()
+    client = LegacyOracleBookkeepingDB(dbW=None, dbR=None)
     runnumbers = [1, 3, 4]
     startRunID = None
     endRunID = None
@@ -49,28 +34,28 @@ def test_buildRunNumbers():
     tables = ""
     retVal = client._buildRunnumbers(runnumbers, startRunID, endRunID, condition, tables)
     assert retVal["OK"] is True
-    outVal = " and prview.runnumber=j.runnumber  and  (  j.runnumber=1 or  j.runnumber=3 or  j.runnumber=4 ) "
-    assert retVal["Value"] == (outVal, " ,prodrunview prview ,productionscontainer cont")
+    outVal = "AND prview.runnumber=j.runnumber AND  ( j.runnumber=1 OR  j.runnumber=3 OR  j.runnumber=4 ) "
+    assert retVal["Value"] == (outVal, " , prodrunview prview")
 
     startRunID = 1
     retVal = client._buildRunnumbers(runnumbers, startRunID, endRunID, condition, tables)
     assert retVal["OK"] is True
-    assert retVal["Value"] == (outVal, " ,prodrunview prview ,productionscontainer cont")
+    assert retVal["Value"] == (outVal, " , prodrunview prview")
 
     startRunID = None
     endRunID = 1
     retVal = client._buildRunnumbers(runnumbers, startRunID, endRunID, condition, tables)
     assert retVal["OK"] is True
-    assert retVal["Value"] == (outVal, " ,prodrunview prview ,productionscontainer cont")
+    assert retVal["Value"] == (outVal, " , prodrunview prview")
 
     startRunID = 1
     endRunID = 2
     runnumbers = [33, 44]
     retVal = client._buildRunnumbers(runnumbers, startRunID, endRunID, condition, tables)
     assert retVal["OK"] is True
-    outVal = " and prview.runnumber=j.runnumber  "
-    outVal += "and (j.runnumber>=1 and unnumber<=2 or  (  j.runnumber=33 or  j.runnumber=44 ))"
-    assert retVal["Value"] == (outVal, " ,prodrunview prview ,productionscontainer cont")
+    outVal = "AND prview.runnumber=j.runnumber "
+    outVal += "AND (j.runnumber>=1 AND j.runnumber<=2 OR  ( j.runnumber=33 OR  j.runnumber=44 )) "
+    assert retVal["Value"] == (outVal, " , prodrunview prview")
 
     for i in [[], None]:
         runnumbers = i
@@ -78,26 +63,26 @@ def test_buildRunNumbers():
         endRunID = 2
         retVal = client._buildRunnumbers(runnumbers, startRunID, endRunID, condition, tables)
         assert retVal["OK"] is True
-        assert retVal["Value"] == (" and j.runnumber>=1 and j.runnumber<=2", "")
+        assert retVal["Value"] == ("AND j.runnumber>=1 AND j.runnumber<=2 ", "")
 
 
 def test_buildConditions():
     """it test the simulation/data taking condition string creation
     procedure."""
-    client = testClass()
+    mock_db = mock.Mock(spec=OracleDB)
+    client = LegacyOracleBookkeepingDB(dbW=mock_db, dbR=mock_db)
     condition = ""
     tables = ""
     for i in [[], None, "ALL"]:
         simdesc = i
         daqdesc = "BeamReal"
-        mock_db = mock.Mock(spec=OracleDB)
         mock_db.query.return_value = {"OK": True, "Value": [(1,)]}
         client.dbR_ = mock_db
         retVal = client._buildConditions(simdesc, daqdesc, condition, tables)
         assert retVal["OK"] is True
         assert retVal["Value"] == (
-            " and cont.DAQPERIODID=1 and cont.DAQPERIODID is not null ",
-            " ,productionscontainer cont ",
+            " AND cont.DAQPERIODID=1 AND cont.DAQPERIODID is not null ",
+            " , productionscontainer cont ",
         )
 
 
