@@ -9,6 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """It stores the job related information."""
+from DIRAC import gLogger
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.JobConfiguration import JobConfiguration
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.JobOption import JobOption
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.File import File
@@ -22,10 +23,9 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Replica.FileReplica import Fi
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Replica.ReplicaParam import ReplicaParam
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.Quality import Quality
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.QualityParameters import QualityParameters
-from DIRAC import gLogger
 
 
-class JobReader(object):
+class JobReader:
     """JobReader class."""
 
     def readJob(self, doc, fileName):
@@ -53,7 +53,6 @@ class JobReader(object):
         conf = JobConfiguration()
         jobElements = doc.getElementsByTagName("Job")
         for node in jobElements:
-
             name = node.getAttributeNode("ConfigName")
             if name is not None:
                 conf.configName = name.value
@@ -155,6 +154,7 @@ class JobReader(object):
     def __readJobOutputFiles(self, doc, job):
         """reads the jobs output files."""
         jobOutputFiles = doc.getElementsByTagName("OutputFile")
+        replicas = doc.getElementsByTagName("Replica")  # I have to check doc ? no node? !!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         for node in jobOutputFiles:
             outputFile = File()
 
@@ -193,15 +193,14 @@ class JobReader(object):
                     gLogger.error("<Value> outputfile Parameter XML tag is missing!!")
 
                 outputFile.addFileParam(outputFileParams)
-            self.__readFilereplica(doc, outputFile)
+            self.__readFilereplica(replicas, outputFile)
             self.__readDataquality(node, outputFile)
             job.addJobOutputFiles(outputFile)
 
     ########################################################################
     @staticmethod
-    def __readFilereplica(doc, outputFile):
+    def __readFilereplica(replicas, outputFile):
         """It creates the replica object and adds to the output file."""
-        replicas = doc.getElementsByTagName("Replica")  # I have to check doc ? no node? !!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         for replica in replicas:
             rep = FileReplica()
             param = ReplicaParam()
