@@ -22,14 +22,14 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.ReplicaReader import ReplicaR
 from LHCbDIRAC.BookkeepingSystem.DB.DataTakingConditionInterpreter import generateConditionDescription
 
 
-class XMLFilesReaderManager(object):
+class XMLFilesReaderManager:
     """XMLFilesReaderManager class."""
 
     #############################################################################
 
     def __init__(self):
         """initialize the member of class."""
-        self.bkClient_ = OracleBookkeepingDB()
+        self.db = OracleBookkeepingDB()
         self.log = gLogger.getSubLogger("XMLFilesReaderManager")
 
     #############################################################################
@@ -82,11 +82,11 @@ class XMLFilesReaderManager(object):
         # prepare for the insert, check the existence of the input files and retreive the fileid
         inputFiles = [inputFile.name for inputFile in job.inputFiles]
         if inputFiles:
-            result = self.bkClient_.bulkgetIDsFromFilesTable(inputFiles)
+            result = self.db.bulkgetIDsFromFilesTable(inputFiles)
             if not result["OK"]:
                 return result
             if result["Value"]["Failed"]:
-                self.log.error("The following files are not in the bkk", "%s" % (",".join(result["Value"]["Failed"])))
+                self.log.error("The following files are not in the bkk", f"{','.join(result['Value']['Failed'])}")
                 return S_ERROR("Files not in bkk")
 
             for inputFile in job.inputFiles:
@@ -94,7 +94,6 @@ class XMLFilesReaderManager(object):
 
         fileTypeCache = {}
         for outputfile in job.outputFiles:
-
             typeName = outputfile.type
             typeVersion = outputfile.version
             cachedTypeNameVersion = typeName + "<<" + typeVersion
@@ -103,9 +102,9 @@ class XMLFilesReaderManager(object):
                 typeID = fileTypeCache[cachedTypeNameVersion]
                 outputfile.typeID = typeID
             else:
-                result = self.bkClient_.checkFileTypeAndVersion(typeName, typeVersion)
+                result = self.db.checkFileTypeAndVersion(typeName, typeVersion)
                 if not result["OK"]:
-                    self.log.error("The [type:version] is missing", "[%s: %s]" % (str(typeName), str(typeVersion)))
+                    self.log.error("The [type:version] is missing", f"[{typeName}: {typeVersion}]")
                     return S_ERROR("[type:version] missing")
 
                 self.log.debug(cachedTypeNameVersion + " added to the cache!")
@@ -128,14 +127,14 @@ class XMLFilesReaderManager(object):
                 self.log.debug("ParamName check of " + str(param.name))
 
                 if param.name == "EventType" and param.value:
-                    result = self.bkClient_.checkEventType(int(param.value))
+                    result = self.db.checkEventType(int(param.value))
                     if not result["OK"]:
-                        return S_ERROR("The event type %s is missing!" % (str(param.value)))
+                        return S_ERROR(f"The event type {str(param.value)} is missing!")
 
                 if param.name == "EventTypeId" and param.value:
-                    result = self.bkClient_.checkEventType(int(param.value))
+                    result = self.db.checkEventType(int(param.value))
                     if not result["OK"]:
-                        return S_ERROR("The event type %s is missing!" % (str(param.value)))
+                        return S_ERROR(f"The event type {str(param.value)} is missing!")
                     evtExists = True
 
             if not evtExists and outputfile.type != "LOG":
@@ -143,7 +142,7 @@ class XMLFilesReaderManager(object):
 
                 if inputFiles:
                     fileName = inputFiles[0].name
-                    res = self.bkClient_.getFileMetadata([fileName])
+                    res = self.db.getFileMetadata([fileName])
                     if not res["OK"]:
                         return res
                     fileMetadata = res["Value"]["Successful"].get(fileName)
@@ -158,7 +157,7 @@ class XMLFilesReaderManager(object):
                                 newFileParams.value = str(fileMetadata["EventTypeId"])
                                 outputfile.addFileParam(newFileParams)
                     else:
-                        errMsg = "Can not get the metadata of %s file" % fileName
+                        errMsg = f"Can not get the metadata of {fileName} file"
                         self.log.error(errMsg)
                         return S_ERROR(errMsg)
 
@@ -195,7 +194,7 @@ class XMLFilesReaderManager(object):
 
                 if job.getParam("JobType") and job.getParam("JobType").value == "DQHISTOMERGING":
                     self.log.debug("DQ merging!")
-                    retVal = self.bkClient_.getJobInfo(job.inputFiles[0].name)
+                    retVal = self.db.getJobInfo(job.inputFiles[0].name)
                     if not retVal["OK"]:
                         return retVal
                     prod = retVal["Value"][0][18]
@@ -206,9 +205,9 @@ class XMLFilesReaderManager(object):
                     self.log.debug("Production inherited from input", prod)
                 else:
                     prod = job.getParam("Production").value
-                    self.log.debug("Production:", "%s" % prod)
+                    self.log.debug("Production:", f"{prod}")
 
-                retVal = self.bkClient_.getProductionProcessingPassID(prod)
+                retVal = self.db.getProductionProcessingPassID(prod)
                 if not retVal["OK"]:
                     return retVal
 
@@ -223,7 +222,7 @@ class XMLFilesReaderManager(object):
                     )
 
             if len(tcks) > 1:
-                self.log.debug("More than 1 TCK", "[%s]" % ",".join(tcks))
+                self.log.debug("More than 1 TCK", f"[{','.join(tcks)}]")
                 tck = -2
             elif len(tcks) == 1:
                 tck = tcks.pop()
@@ -247,7 +246,7 @@ class XMLFilesReaderManager(object):
         # ## It is not urgent as we do not have a huge load on the database
         for i in inputfiles:
             fname = i.name
-            res = self.bkClient_.getJobInfo(fname)
+            res = self.db.getJobInfo(fname)
             if not res["OK"]:
                 return res
 
@@ -255,7 +254,7 @@ class XMLFilesReaderManager(object):
             if value and value[0][2] is not None:
                 sumEventInputStat += value[0][2]
 
-            res = self.bkClient_.getFileMetadata([fname])
+            res = self.db.getFileMetadata([fname])
             if not res["OK"]:
                 return res
 
@@ -268,7 +267,7 @@ class XMLFilesReaderManager(object):
                 if dqvalue is None:
                     dqvalue = fileMetadata.get("DataqualityFlag", fileMetadata.get("DQFlag"))
             else:
-                errMsg = "Can not get the metadata of %s file" % fname
+                errMsg = f"Can not get the metadata of {fname} file"
                 self.log.error(errMsg)
                 return S_ERROR(errMsg)
 
@@ -309,7 +308,7 @@ class XMLFilesReaderManager(object):
         result = self.__insertJob(job)
         if not result["OK"]:
             config = job.configuration
-            errorMessage = "Unable to create Job: %s , %s, %s .\n Error: %s" % (
+            errorMessage = "Unable to create Job: {} , {}, {} .\n Error: {}".format(
                 str(config.configName),
                 str(config.configVersion),
                 str(config.date),
@@ -325,12 +324,12 @@ class XMLFilesReaderManager(object):
             except ValueError:
                 runnumber = -1
             if runnumber != -1:
-                self.log.verbose("Registering the run status for ", "Run number %s,  JobId %s" % (runnumber, job.jobID))
-                result = self.bkClient_.insertRunStatus(runnumber, job.jobID, "N")
+                self.log.verbose("Registering the run status for ", f"Run number {runnumber},  JobId {job.jobID}")
+                result = self.db.insertRunStatus(runnumber, job.jobID, "N")
                 if not result["OK"]:
                     errorMessage = ("Unable to register run status", runnumber + result["Message"])
                     self.log.error(errorMessage[0], errorMessage[1])
-                    res = self.bkClient_.deleteJob(job.jobID)
+                    res = self.db.deleteJob(job.jobID)
                     if not res["OK"]:
                         self.log.warn("Unable to delete job", str(job.jobID) + res["Message"])
                     return S_ERROR(errorMessage[0])
@@ -349,11 +348,11 @@ class XMLFilesReaderManager(object):
 
         inputFiles = job.inputFiles
         for inputfile in inputFiles:
-            result = self.bkClient_.insertInputFile(job.jobID, inputfile.fileID)
+            result = self.db.insertInputFile(job.jobID, inputfile.fileID)
             if not result["OK"]:
                 errorMessage = ("Unable to insert input file", (str(inputfile.name)) + result["Message"])
                 self.log.error(errorMessage[0], errorMessage[1])
-                res = self.bkClient_.deleteJob(job.jobID)
+                res = self.db.deleteJob(job.jobID)
                 if not res["OK"]:
                     self.log.warn("Unable to delete job", str(job.jobID) + res["Message"])
                 return S_ERROR(errorMessage[0])
@@ -361,7 +360,7 @@ class XMLFilesReaderManager(object):
         outputFiles = job.outputFiles
         prod = job.getParam("Production").value
         stepid = job.getParam("StepID").value
-        retVal = self.bkClient_.getProductionOutputFileTypes(prod, stepid)
+        retVal = self.db.getProductionOutputFileTypes(prod, stepid)
         if not retVal["OK"]:
             return retVal
         outputFileTypes = retVal["Value"]
@@ -388,13 +387,13 @@ class XMLFilesReaderManager(object):
             if not result["OK"]:
                 errorMessage = (
                     "Unable to insert output file",
-                    "%s ! ERROR: %s" % (str(outputfile.name), result["Message"]),
+                    f"{outputfile.name} ! ERROR: {result['Message']}",
                 )
                 self.log.error(errorMessage[0], errorMessage[1])
-                res = self.bkClient_.deleteInputFiles(job.jobID)
+                res = self.db.deleteInputFiles(job.jobID)
                 if not res["OK"]:
                     self.log.warn("Unable to delete inputfiles of", str(job.jobID) + res["Message"])
-                res = self.bkClient_.deleteJob(job.jobID)
+                res = self.db.deleteJob(job.jobID)
                 if not res["OK"]:
                     self.log.warn("Unable to delete job", str(job.jobID) + res["Message"])
                 return S_ERROR(errorMessage[0])
@@ -408,9 +407,9 @@ class XMLFilesReaderManager(object):
                 for param in params:
                     # just one param exist in params list, because JobReader only one param add to Replica
                     name = param.name
-                result = self.bkClient_.updateReplicaRow(outputfile.fileID, "No")
+                result = self.db.updateReplicaRow(outputfile.fileID, "No")
                 if not result["OK"]:
-                    return S_ERROR("Unable to create Replica %s !" % (str(name)))
+                    return S_ERROR(f"Unable to create Replica {str(name)} !")
 
         self.log.debug("End Processing!")
 
@@ -422,7 +421,7 @@ class XMLFilesReaderManager(object):
         runnumbers = set()
         tcks = set()
         for lfn in fileList:
-            for runtck in returnValueOrRaise(self.bkClient_.getRunNbAndTck(lfn)):
+            for runtck in returnValueOrRaise(self.db.getRunNbAndTck(lfn)):
                 if runtck[0]:
                     runnumbers.add(runtck[0])
                 if runtck[1] and runtck[1] != "None":
@@ -437,8 +436,8 @@ class XMLFilesReaderManager(object):
         """
         if not runNumber:
             return None
-        procID = returnValueOrRaise(self.bkClient_.getProductionProcessingPassID(prod or runNumber * -1))
-        return self.bkClient_.getRunAndProcessingPassDataQuality(runNumber, procID).get("Value")
+        procID = returnValueOrRaise(self.db.getProductionProcessingPassID(prod or runNumber * -1))
+        return self.db.getRunAndProcessingPassDataQuality(runNumber, procID).get("Value")
 
     def __insertJob(self, job):
         """Inserts the job to the database."""
@@ -454,12 +453,12 @@ class XMLFilesReaderManager(object):
             ver = config.configVersion  # online bug fix
             ver = ver.capitalize()
             config.configVersion = ver
-            self.log.debug("Data taking:", "%s" % datataking)
+            self.log.debug("Data taking:", f"{datataking}")
             dtDescription = generateConditionDescription(datataking, config.configName)
             self.log.debug(dtDescription)
             datataking["Description"] = dtDescription
 
-            res = self.bkClient_._getDataTakingConditionId(dtDescription)
+            res = self.db._getDataTakingConditionId(dtDescription)
             if not res["OK"]:
                 self.log.error(
                     "Error retrieving the DataTaking Condition ID",
@@ -470,7 +469,7 @@ class XMLFilesReaderManager(object):
             daqid = res["Value"]
             # If there is no condition matching the description, create one
             if daqid == -1:  # yes... -1 for non existing conditions
-                res = self.bkClient_.insertDataTakingCondDesc(dtDescription)
+                res = self.db.insertDataTakingCondDesc(dtDescription)
                 if not res["OK"]:
                     self.log.error("Cannot insert DataTaking Condition Description", res["Message"])
                     return res
@@ -504,7 +503,7 @@ class XMLFilesReaderManager(object):
                 self.log.error("Run number is missing!")
                 return S_ERROR("Run number is missing!")
 
-            retVal = self.bkClient_.getStepIdandNameForRUN(programName, programVersion, conddb, dddb)
+            retVal = self.db.getStepIdandNameForRUN(programName, programVersion, conddb, dddb)
 
             if not retVal["OK"]:
                 return retVal
@@ -531,8 +530,8 @@ class XMLFilesReaderManager(object):
                 ]
             }
 
-            self.log.debug("Pass_indexid", "%s" % steps)
-            self.log.debug("Data taking", "%s" % dtDescription)
+            self.log.debug("Pass_indexid", f"{steps}")
+            self.log.debug("Data taking", f"{dtDescription}")
             self.log.debug("production", production)
 
             newJobParams = JobParameters()
@@ -540,10 +539,10 @@ class XMLFilesReaderManager(object):
             newJobParams.value = str(stepid)
             job.addJobParams(newJobParams)
 
-            message = "StepID for run: %s" % (str(production))
+            message = f"StepID for run: {str(production)}"
             self.log.info(message, stepid)
 
-            res = self.bkClient_.addProduction(
+            res = self.db.addProduction(
                 production,
                 simcond=None,
                 daq=dtDescription,
@@ -560,7 +559,7 @@ class XMLFilesReaderManager(object):
                 self.log.warn("The run already registered!")
             else:
                 self.log.error("Failing adding production", production + res["Message"])
-                retVal = self.bkClient_.deleteStepContainer(production)
+                retVal = self.db.deleteStepContainer(production)
                 if not retVal["OK"]:
                     return retVal
                 return S_ERROR("Failing adding production")
@@ -570,14 +569,14 @@ class XMLFilesReaderManager(object):
         for param in job.parameters:
             attrList[str(param.name)] = param.value
 
-        res = self.bkClient_.checkProcessingPassAndSimCond(attrList["Production"])
+        res = self.db.checkProcessingPassAndSimCond(attrList["Production"])
         if not res["OK"]:
             self.log.error("check processing pass and simulation condition error", res["Message"])
         else:
             value = res["Value"]
             if value[0][0] == 0:
                 errorMessage = "Missing processing pass and simulation conditions: "
-                errorMessage += "please fill it. Production = %s" % (str(attrList["Production"]))
+                errorMessage += f"please fill it. Production = {str(attrList['Production'])}"
                 self.log.warn(errorMessage)
 
         if attrList["JobStart"] is None:
@@ -589,11 +588,11 @@ class XMLFilesReaderManager(object):
         if production is not None:  # for the online registration
             attrList["Production"] = production
 
-        res = self.bkClient_.insertJob(attrList)
+        res = self.db.insertJob(attrList)
 
         if not res["OK"] and production is not None and production < 0:
             self.log.error("Failed inserting job", res["Message"])
-            retVal = self.bkClient_.deleteProductionsContainer(production)
+            retVal = self.db.deleteProductionsContainer(production)
             if not retVal["OK"]:
                 self.log.error(retVal["Message"])
         return res
@@ -605,13 +604,13 @@ class XMLFilesReaderManager(object):
 
         for param in outputfile.params:
             attrList[str(param.name)] = param.value
-        return self.bkClient_.insertOutputFile(attrList)
+        return self.db.insertOutputFile(attrList)
 
     #############################################################################
     def processReplicas(self, replica):
         """process the replica registration request."""
         outputfile = replica.name
-        self.log.debug("Processing replicas:", "%s" % outputfile)
+        self.log.debug("Processing replicas:", f"{outputfile}")
         fileID = -1
 
         delete = True
@@ -622,7 +621,7 @@ class XMLFilesReaderManager(object):
             location = param.location
             delete = param.action == "Delete"
 
-            result = self.bkClient_.checkfile(replicaFileName)
+            result = self.db.checkfile(replicaFileName)
             if not result["OK"]:
                 message = "No replica can be "
                 if delete:
@@ -639,12 +638,12 @@ class XMLFilesReaderManager(object):
                 result = DataManager().getReplicas(replicaFileName)
                 replicaList = result["Value"]["Successful"]
                 if len(replicaList) == 0:
-                    result = self.bkClient_.updateReplicaRow(fileID, "No")
+                    result = self.db.updateReplicaRow(fileID, "No")
                     if not result["OK"]:
-                        self.log.warn("Unable to set the Got_Replica flag for ", "%s" % replicaFileName)
-                        return S_ERROR("Unable to set the Got_Replica flag for ", "%s" % replicaFileName)
+                        self.log.warn("Unable to set the Got_Replica flag for ", f"{replicaFileName}")
+                        return S_ERROR("Unable to set the Got_Replica flag for ", f"{replicaFileName}")
             else:
-                result = self.bkClient_.updateReplicaRow(fileID, "Yes")
+                result = self.db.updateReplicaRow(fileID, "Yes")
                 if not result["OK"]:
                     return S_ERROR("Unable to set the Got_Replica flag for " + str(replicaFileName))
 
