@@ -8,11 +8,10 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-
 import datetime
 import pytest
 from xml.dom.minidom import parseString
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 mockBKDB = MagicMock()
 mockBKDB.return_value = None
@@ -75,7 +74,6 @@ xmlString = (
 
 
 def test_JobReader():
-
     currentTime = datetime.datetime.now()
     jobStart = jobEnd = datetime.datetime.now()
     jobStart = jobEnd = jobStart.replace(second=0, microsecond=0)
@@ -114,8 +112,8 @@ def test__getRunNumbersAndTCKs(mocker, inputfiles, getRunNbAndTckRV, expected):
         side_effect=mockBKDB,
     )
     xfrm = XMLFilesReaderManager()
-    xfrm.bkClient_ = MagicMock()
-    xfrm.bkClient_.getRunNbAndTck.return_value = getRunNbAndTckRV
+    xfrm.db = MagicMock()
+    xfrm.db.getRunNbAndTck.return_value = getRunNbAndTckRV
 
     res = xfrm._getRunNumbersAndTCKs(inputfiles)
     assert res == expected
@@ -148,9 +146,9 @@ def test__getDataQuality(
         side_effect=mockBKDB,
     )
     xfrm = XMLFilesReaderManager()
-    xfrm.bkClient_ = MagicMock()
-    xfrm.bkClient_.getProductionProcessingPassID.return_value = getProductionProcessingPassID_RV
-    xfrm.bkClient_.getRunAndProcessingPassDataQuality.return_value = getRunAndProcessingPassDataQuality_RV
+    xfrm.db = MagicMock()
+    xfrm.db.getProductionProcessingPassID.return_value = getProductionProcessingPassID_RV
+    xfrm.db.getRunAndProcessingPassDataQuality.return_value = getRunAndProcessingPassDataQuality_RV
 
     res = xfrm._getDataQuality(prod, runNumber)
     assert res == expected
