@@ -16,15 +16,14 @@
 """
 import DIRAC
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s eventType  " % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} eventType  "]))
 
     Script.registerSwitch("p", "production", "Obtain the paths in ``Production format'' for Ganga")
     Script.parseCommandLine(ignoreErrors=True)
@@ -46,7 +45,7 @@ def main():
     # # get productions for given event type
     res = bkClient.getProductionSummaryFromView({"EventType": eventType, "Visible": True})
     if not res["OK"]:
-        gLogger.error("Could not retrieve production summary for event %s" % eventType, res["Message"])
+        gLogger.error(f"Could not retrieve production summary for event {eventType}", res["Message"])
         DIRAC.exit(1)
 
     # # get production-IDs
@@ -54,10 +53,9 @@ def main():
 
     # # loop over all productions
     for prodID in sorted(prodIDs):
-
         res = bkClient.getProductionInformation(prodID)
         if not res["OK"]:
-            gLogger.error("Could not retrieve production infos for production %s" % prodID, res["Message"])
+            gLogger.error(f"Could not retrieve production infos for production {prodID}", res["Message"])
             continue
         prodInfo = res["Value"]
         steps = prodInfo["Steps"]
@@ -74,7 +72,10 @@ def main():
         for i in events:
             if i[0] in ["GAUSSHIST", "LOG", "SIM", "DIGI", "RAW"]:
                 continue
-            evts += i[1]
+            # NB of events can sometimes be None
+            if i[1] is not None:
+                evts += i[1]
+
             if not ftype:
                 ftype = i[0]
 
