@@ -18,12 +18,11 @@ DESCRIPTION="<description>", PRIMARY="<primary description>"
 import re
 import DIRAC
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def process_event(eventline):
     """process one event."""
-    from DIRAC.Core.Base import Script
 
     try:
         eventline.index("EVTTYPEID")
@@ -69,16 +68,14 @@ def process_event(eventline):
     return result
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         "\n".join(
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] ... File" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... File",
                 "Arguments:",
                 "  File:     Name of the file including the description of the Types (mandatory)",
             ]
@@ -104,7 +101,7 @@ def main():
             for line in fd:
                 evt = process_event(line)
                 eventtypes.append(evt)
-    except IOError:
+    except OSError:
         gLogger.error("Cannot open file " + fileName)
         DIRAC.exit(2)
 
@@ -117,10 +114,10 @@ def main():
             gLogger.error("Failed to update the following event types:")
             for evt in result["Value"]["Failed"]:
                 for i in evt.values():
-                    gLogger.error("%s : %s" % (repr(i.get("EvtentType")), i.get("Error")))
+                    gLogger.error(f"{repr(i.get('EvtentType'))} : {i.get('Error')}")
 
         if result["Value"]["Successful"]:
-            gLogger.notice("The following event types are updated: %s" % repr(result["Value"]["Successful"]))
+            gLogger.notice(f"The following event types are updated: {repr(result['Value']['Successful'])}")
 
     DIRAC.exit(exitCode)
 
