@@ -10,12 +10,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Retrieve metadata from the Bookkeeping for the given files."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    import DIRAC.Core.Base.Script as Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -26,7 +26,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... LFN|File" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... LFN|File",
                 "Arguments:",
                 "  LFN:      Logical File Name",
                 "  File:     Name of the file with a list of LFNs",
