@@ -11,22 +11,17 @@
 ###############################################################################
 """List file types from the Bookkeeping."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile]" % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile]"]))
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
-    bk = BookkeepingClient()
-    exitCode = 0
-
-    res = bk.getAvailableFileTypes()
+    res = BookkeepingClient().getAvailableFileTypes()
 
     if res["OK"]:
         dbresult = res["Value"]
@@ -34,7 +29,7 @@ def main():
         for record in dbresult["Records"]:
             print(str(record[0]).ljust(30) + str(record[1]))
 
-    DIRAC.exit(exitCode)
+    DIRAC.exit()
 
 
 if __name__ == "__main__":
