@@ -10,17 +10,18 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Returns list of Conditions for a run range, by default only if there is a FULL stream."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import Script
 
     Script.registerSwitch("", "Runs=", "Run range or list")
     Script.registerSwitch("", "ByRange", "List by range rather than by item value")
     Script.registerSwitch("", "Force", "Include runs even if no FULL stream is present")
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ... " % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ... "]))
 
     Script.parseCommandLine(ignoreErrors=True)
 
