@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """returns ancestors for a (list of) LFN(s)"""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -28,7 +29,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... [LFN|File] [Level]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [LFN|File] [Level]",
                 "Arguments:",
                 "  LFN:      Logical File Name",
                 "  File:     Name of the file with a list of LFNs",
