@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Report sisters or cousins (i.e. descendant of a parent or ancestor) for a (list of) LFN(s)"""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -28,7 +29,7 @@ def main():
     Script.registerSwitch("", "Production=", "Production to check for sisters (default=same production)")
     Script.registerSwitch("", "AllFileTypes", "Consider also files with a different type")
     Script.setUsageMessage(
-        __doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ... [LFN|File] [Level]" % Script.scriptName])
+        __doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ... [LFN|File] [Level]"])
     )
 
     Script.parseCommandLine(ignoreErrors=True)
