@@ -9,13 +9,15 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-"""Retrieve files of a BK query."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+"""Retrieve list of LFNs registered in a BK path.
+"""
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerBKSwitches()
@@ -27,7 +29,7 @@ def main():
     Script.registerSwitch(
         "", "MaxFiles=", "   Print only <MaxFiles> lines on stdout (%d if output, else All)" % maxFiles
     )
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ... " % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ... "]))
 
     Script.parseCommandLine()
 
