@@ -11,10 +11,11 @@
 ###############################################################################
 """List all BK paths matching a wildcard path ('...' is the wildcard character,
 or '*' but enclose with quotes)"""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import Script, ProgressBar
     from DIRAC import gLogger
@@ -25,7 +26,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
@@ -46,7 +47,7 @@ def main():
         if i:
             gLogger.notice("=========================")
         bkQuery = BKQuery(bkPath.replace("Real Data", "RealData"))
-        progressBar = ProgressBar(1, title="Getting processing passes for BK path %s" % bkPath)
+        progressBar = ProgressBar(1, title=f"Getting processing passes for BK path {bkPath}")
         processingPasses = getProcessingPasses(bkQuery)
         progressBar.endLoop()
         if processingPasses:
