@@ -10,10 +10,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Returns run ranges, split by conditions and by run gaps or time interval between them."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import Script
 
@@ -23,7 +24,7 @@ def main():
     Script.registerSwitch("", "DQFlag=", "Specify the DQ flag (default: all)")
     Script.registerSwitch("", "RunGap=", "Gap between run ranges, in number of runs")
     Script.registerSwitch("", "TimeGap=", "Gap between run ranges, in number of days")
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ... " % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ... "]))
 
     Script.parseCommandLine(ignoreErrors=True)
 
