@@ -10,20 +10,20 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Retrieve from the Bookkeeping runs from a given date range."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC import gLogger, exit as DIRACexit
-    from DIRAC.Core.Base import Script
 
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... Start [End]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... Start [End]",
                 "Arguments:",
                 "  Start:    Start date (Format: YYYY-MM-DD) (mandatory)",
                 "  End:      End date (Format: YYYY-MM-DD). Default is Start",
@@ -50,7 +50,7 @@ def main():
 
     res = BookkeepingClient().getRunsForAGivenPeriod(in_dict)
     if not res["OK"]:
-        gLogger.error("Failed to retrieve runs: %s" % res["Message"])
+        gLogger.error(f"Failed to retrieve runs: {res['Message']}")
         DIRACexit(1)
 
     if not res["Value"]["Runs"]:
