@@ -13,21 +13,19 @@
 import DIRAC
 
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
-            ["Usage:", "  %s [option|cfgfile] ... Run ..." % Script.scriptName, "Arguments:", "  Run:      Run number"]
+            ["Usage:", f"  {Script.scriptName} [option|cfgfile] ... Run ...", "Arguments:", "  Run:      Run number"]
         )
     )
     Script.parseCommandLine(ignoreErrors=True)
-    runSet = set(int(id) for arg in Script.getPositionalArgs() for id in arg.split(","))
+    runSet = {int(id) for arg in Script.getPositionalArgs() for id in arg.split(",")}
 
     if not runSet:
         Script.showHelp(exitCode=1)
