@@ -13,13 +13,12 @@
 Returns metadata of the job step(s) that created a (list of) LFNs,
 or all steps for a (list of) JobID
 """
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     from DIRAC import gLogger
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, printDMResult
 
@@ -31,7 +30,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... [LFN|File|JobID]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [LFN|File|JobID]",
                 "Arguments:",
                 "  LFN:      Logical File Name",
                 "  File:     Name of the file with a list of LFNs",
@@ -82,7 +81,7 @@ def main():
                 if int(jobID) in retVal["Value"]["Failed"]:
                     # For some reason sometimes (always?) the jobID is also in Failed
                     retVal["Value"]["Failed"].remove(int(jobID))
-                jobStr = "Job %s" % jobID
+                jobStr = f"Job {jobID}"
                 stepDict = {"Job": {"CPUTIME": 0.0, "ExecTime": 0.0, "NumberOfSteps": len(jobs)}}
                 for job in jobs:
                     # Group common info into a separate dictionary (and remove it from steps)
@@ -105,7 +104,7 @@ def main():
                     # Sum up CPU and wall clock times
                     for info in ("CPUTIME", "ExecTime"):
                         stepDict["Job"][info] += job[info]
-                    step = "Step %s" % job.pop("Name")
+                    step = f"Step {job.pop('Name')}"
                     stepDict[step] = job
                 success[jobStr] = stepDict
 
@@ -113,11 +112,11 @@ def main():
         if not summary and jobLFNs:
             # Group files produced by the same job
             lfnsByJob = {}
-            for name, job in jobDict.items():  # Can be an iterator
+            for name, job in jobDict.items():
                 # For each jobID get set of LFNs and job steps
                 lfnsByJob.setdefault(job["DIRACJobId"], []).append((jobLFNs[name], job))
-            for jobID, lfnJobs in lfnsByJob.items():  # Can be an iterator
-                jobStr = "Job %s" % jobID
+            for jobID, lfnJobs in lfnsByJob.items():
+                jobStr = f"Job {jobID}"
                 # Split job and step information
                 stepDict = {jobStr: {}}
                 lfnSet = set()
@@ -139,14 +138,12 @@ def main():
                     ):
                         stepDict[jobStr][info] = job.pop(info, None)
                     job[" LFN"] = ",".join(sorted(lfns))
-                    stepDict["Step %s" % job.pop("Name")] = job
+                    stepDict[f"Step {job.pop('Name')}"] = job
                 success[",".join(sorted(lfnSet))] = stepDict
 
     if summary and jobLFNs:
         gLogger.always("List of DIRAC jobs:")
-        gLogger.always(
-            ",".join(sorted(set("%s" % val["DIRACJobId"] for val in jobDict.values())))
-        )  # Can be an iterator
+        gLogger.always(",".join(sorted({f"{val['DIRACJobId']}" for val in jobDict.values()})))
     else:
         printDMResult(retVal, empty="File/job does not exist in the Bookkeeping")
 
