@@ -11,12 +11,11 @@
 ###############################################################################
 """It returns the input and output files of a given list of DIRAC Jobids."""
 import os
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, printDMResult
 
     bkScript = DMScript()
@@ -28,7 +27,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... [DIRACJobid|File]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [DIRACJobid|File]",
                 "Arguments:",
                 "  DIRACJobid:      DIRAC Jobids",
                 "  File:     Name of the file with contains a list of DIRACJobids",
