@@ -11,9 +11,8 @@
 ###############################################################################
 """Get production numbers given a dataset path."""
 import time
-import six
 from DIRAC import gLogger, exit
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def printProds(title, prods):
@@ -22,11 +21,10 @@ def printProds(title, prods):
         typeDict.setdefault(prodType, []).append(prod)
     gLogger.notice(title)
     for prodType, prodList in typeDict.items():
-        gLogger.notice("(%s): %s" % (prodType, ",".join([str(prod) for prod in sorted(prodList)])))
+        gLogger.notice(f"({prodType}): {','.join([str(prod) for prod in sorted(prodList)])}")
 
 
 def execute(dmScript):
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
     tr = TransformationClient()
@@ -48,12 +46,12 @@ def execute(dmScript):
         ptype = tr.getTransformation(prod).get("Value", {}).get("Type", "Unknown")
         productions[prod] = ptype
         parent = tr.getBookkeepingQuery(prod).get("Value", {}).get("ProductionID", "")
-        while isinstance(parent, six.integer_types):
+        while isinstance(parent, int):
             ptype = tr.getTransformation(parent).get("Value", {}).get("Type", "Unknown")
             parents[parent] = ptype
             parent = tr.getBookkeepingQuery(parent).get("Value", {}).get("ProductionID", "")
 
-    gLogger.notice("For BK path %s:" % bkQuery.getPath())
+    gLogger.notice(f"For BK path {bkQuery.getPath()}:")
     if not prods:
         gLogger.notice("No productions found!")
     else:
@@ -61,12 +59,11 @@ def execute(dmScript):
         if parents:
             printProds("Parent productions", parents)
 
-    gLogger.notice("Completed in %.1f seconds" % (time.time() - startTime))
+    gLogger.notice(f"Completed in {time.time() - startTime:.1f} seconds")
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -76,7 +73,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile]",
             ]
         )
     )
