@@ -10,19 +10,18 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Retrieve files of a given type for a production."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... ProdID Type" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... ProdID Type",
                 "Arguments:",
                 "  ProdID:   Production ID (integer)",
                 "  Type:     File Type (For example: ALL, DST, SIM, DIGI, RDST, MDF)",
@@ -51,7 +50,7 @@ def main():
         DIRACexit(1)
 
     if not res["Value"]:
-        gLogger.notice("No files found for production %s with type %s" % (prodID, filetype))
+        gLogger.notice(f"No files found for production {prodID} with type {filetype}")
     else:
         gLogger.notice(
             "%s %s %s %s %s"
