@@ -11,19 +11,17 @@
 ###############################################################################
 """Retrieve information from the Bookkeeping for a given production."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... ProdID" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... ProdID",
                 "Arguments:",
                 "  ProdID:   Production ID (mandatory)",
             ]
@@ -35,8 +33,6 @@ def main():
     if len(args) < 1:
         Script.showHelp(exitCode=1)
 
-    exitCode = 0
-
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
     bk = BookkeepingClient()
@@ -44,7 +40,7 @@ def main():
 
     res = bk.getProductionInformation(prod)
     if not res["OK"]:
-        print("ERROR %s: %s" % (str(prod), res["Message"]))
+        print(f"ERROR {prod}: {res['Message']}")
         DIRAC.exit(2)
 
     val = res["Value"]
@@ -62,15 +58,15 @@ def main():
 
     for step in steps:
         print("-----------------------")
-        print(" StepName: %s " % (step[0]))
-        print("    StepId             : %s" % (step[7]))
-        print("    ApplicationName    : %s" % (step[1]))
-        print("    ApplicationVersion : %s" % (step[2]))
-        print("    OptionFiles        : %s" % (step[3]))
-        print("    DDB                : %s" % (step[4]))
-        print("    CONDDB             : %s" % (step[5]))
-        print("    ExtraPackages      : %s" % (step[6]))
-        print("    Visible            : %s" % (step[8]))
+        print(f" StepName: {step[0]} ")
+        print(f"    StepId             : {step[7]}")
+        print(f"    ApplicationName    : {step[1]}")
+        print(f"    ApplicationVersion : {step[2]}")
+        print(f"    OptionFiles        : {step[3]}")
+        print(f"    DDB                : {step[4]}")
+        print(f"    CONDDB             : {step[5]}")
+        print(f"    ExtraPackages      : {step[6]}")
+        print(f"    Visible            : {step[8]}")
         print("-----------------------")
     print("Number of Steps  ", val["Number of jobs"][0][0])
     files = val["Number of files"]
