@@ -11,19 +11,17 @@
 ###############################################################################
 """Retrieve from Bookkeeping the number of Jobs at each Site for a given Production."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... ProdID" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... ProdID",
                 "Arguments:",
                 "  ProdID:   Production ID (mandatory)",
             ]
@@ -35,8 +33,6 @@ def main():
     if len(args) < 1:
         Script.showHelp()
 
-    exitCode = 0
-
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
     bk = BookkeepingClient()
@@ -51,7 +47,7 @@ def main():
         if not res["Value"]:
             print("No jobs for production", prod)
             DIRAC.exit(0)
-        sites = dict([(site, num) for num, site in res["Value"]])
+        sites = {site: num for num, site in res["Value"]}
         shift = 0
         for site in sites:
             shift = max(shift, len(site) + 2)
@@ -59,8 +55,7 @@ def main():
         for site in sorted(sites):
             print(site.ljust(shift), str(sites[site]))
     else:
-        print("ERROR getting number of jobs for %s:" % str(prod), res["Message"])
-        exitCode = 2
+        print(f"ERROR getting number of jobs for {str(prod)}:", res["Message"])
 
 
 if __name__ == "__main__":
