@@ -11,19 +11,17 @@
 ###############################################################################
 """Retrieve files for a given run."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... Run" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... Run",
                 "Arguments:",
                 "  Run:      Run number (integer)",
             ]
@@ -43,18 +41,18 @@ def main():
 
     res = BookkeepingClient().getRunFiles(runID)
     if not res["OK"]:
-        print("Failed to retrieve run files: %s" % res["Message"])
+        print(f"Failed to retrieve run files: {res['Message']}")
         exitCode = 2
     else:
         if not res["Value"]:
-            print("No files found for run %s" % runID)
+            print(f"No files found for run {runID}")
         else:
-            print("%s %s %s %s" % ("FileName".ljust(100), "Size".ljust(10), "GUID".ljust(40), "Replica".ljust(8)))
+            print(f"{'FileName'.ljust(100)} {'Size'.ljust(10)} {'GUID'.ljust(40)} {'Replica'.ljust(8)}")
             for lfn in sorted(res["Value"]):
                 size = res["Value"][lfn]["FileSize"]
                 guid = res["Value"][lfn]["GUID"]
                 hasReplica = res["Value"][lfn]["GotReplica"]
-                print("%s %s %s %s" % (lfn.ljust(100), str(size).ljust(10), guid.ljust(40), str(hasReplica).ljust(8)))
+                print(f"{lfn.ljust(100)} {str(size).ljust(10)} {guid.ljust(40)} {str(hasReplica).ljust(8)}")
 
     DIRAC.exit(exitCode)
 
