@@ -12,13 +12,11 @@
 """Retrieve from Bookkeeping information for a given run."""
 import DIRAC
 from DIRAC import gLogger, S_OK
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch("", "Production=", "   <prodID>, get the run list from a production")
     Script.registerSwitch("", "Active", "   only get Active runs")
     Script.registerSwitch("", "Information=", "   <item> returns only the relevant information item")
@@ -28,7 +26,7 @@ def main():
     Script.setUsageMessage(
         __doc__
         + "\n".join(
-            ["Usage:", "  %s [option|cfgfile] ... Run" % Script.scriptName, "Arguments:", "  Run:      Run Number"]
+            ["Usage:", f"  {Script.scriptName} [option|cfgfile] ... Run", "Arguments:", "  Run:      Run Number"]
         )
     )
     Script.parseCommandLine(ignoreErrors=True)
@@ -84,7 +82,7 @@ def main():
         else:
             gLogger.fatal("Error getting production runs", res["Message"])
             DIRAC.exit(2)
-        gLogger.notice("Found %d runs" % len(runSet))
+        gLogger.notice(f"Found {len(runSet)} runs")
 
     # Use this call to get information but also the actual list of existing runs
     res = bk.getRunStatus(list(runSet))
@@ -107,7 +105,7 @@ def main():
                 else:
                     success[run] = finished
         else:
-            progressBar = ProgressBar(len(runStatus), title="Getting %s for %d runs" % (item, len(runStatus)), step=10)
+            progressBar = ProgressBar(len(runStatus), title=f"Getting {item} for {len(runStatus)} runs", step=10)
 
     if item != "Finished":
         for run in sorted(runStatus):
@@ -120,7 +118,7 @@ def main():
                 info = res["Value"]
                 if item:
                     if item not in info:
-                        gLogger.error("Item not found", "\n Valid items: %s" % str(sorted(info)))
+                        gLogger.error("Item not found", f"\n Valid items: {str(sorted(info))}")
                         DIRAC.exit(3)
                     itemValue = info.get(item, "Unknown")
                     if byValue:
@@ -173,9 +171,7 @@ def main():
             del failed
         if byValue:
             for val in success:
-                success[val] = ("(%d runs) - " % len(success[val])) + (
-                    ",".join(sorted(str(run) for run in success[val]))
-                )
+                success[val] = f"({len(success[val])} runs) - " + (",".join(sorted(str(run) for run in success[val])))
         printDMResult(S_OK(result), empty="None", script="dirac-bookkeeping-run-information")
 
 
