@@ -10,13 +10,14 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set the visibility flag to a dataset."""
+
 from DIRAC import exit as dExit, gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerBKSwitches()
@@ -28,7 +29,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile]",
             ]
         )
     )
@@ -72,7 +73,7 @@ def main():
         if not res["OK"]:
             gLogger.error("Error setting files", msg)
             dExit(1)
-        gLogger.notice("Successfully set %d files %s" % (len(lfns), msg + (":" if dumpList else "")))
+        gLogger.notice(f"Successfully set {len(lfns)} files {msg + (':' if dumpList else '')}")
         if dumpList:
             gLogger.notice("\n".join(lfns))
 
