@@ -20,13 +20,11 @@
                  Derived data are left unchanged. If one wants to flag everything, use 1.
                - else that processing pass (and derived) and the RAW are flagged OK
 """
-
 import os
 
 import DIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
-from DIRAC.Core.Base import Script
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def checkDQFlag(dqFlag):
@@ -39,8 +37,7 @@ def checkDQFlag(dqFlag):
 
     if dqFlag in res["Value"]:
         return S_OK()
-    else:
-        return S_ERROR("Data quality flag is not in the db")
+    return S_ERROR("Data quality flag is not in the db")
 
 
 def flagFileList(filename, dqFlag):
@@ -54,7 +51,7 @@ def flagFileList(filename, dqFlag):
         with open(filename) as f:
             for lfn in f:
                 lfns.append(lfn.strip())
-    except IOError:
+    except OSError:
         lfns = filename.split(",")
 
     # Now flag the LFN
@@ -62,9 +59,8 @@ def flagFileList(filename, dqFlag):
 
     if not res["OK"]:
         return res
-    else:
-        gLogger.notice("The data quality has been set %s for %d files:" % (dqFlag, len(lfns)))
 
+    gLogger.notice("The data quality has been set", f"({dqFlag} for {len(lfns)} files)")
     return S_OK()
 
 
@@ -74,7 +70,7 @@ def flagRun(runNumber, procPass, dqFlag, flagRAW=False):
 
     res = getProcessingPasses(runNumber, "/Real Data")
     if not res["OK"]:
-        return S_ERROR("flagRun: %s" % res["Message"])
+        return S_ERROR(f"flagRun: {res['Message']}")
 
     allProcessingPasses = set(res["Value"])
 
@@ -92,7 +88,7 @@ def flagRun(runNumber, procPass, dqFlag, flagRAW=False):
         processingPasses.append("/Real Data")
 
     if not processingPasses:
-        return S_ERROR("%s is not a valid processing pass." % procPass)
+        return S_ERROR(f"{procPass} is not a valid processing pass.")
 
         # Flag the processing passes
     for processingPass in processingPasses:
@@ -102,9 +98,8 @@ def flagRun(runNumber, procPass, dqFlag, flagRAW=False):
             dqFlag,
         )
         if not res["OK"]:
-            return S_ERROR("flagRun: processing pass %s\n error: %s" % (processingPass, res["Message"]))
-        else:
-            gLogger.notice("Run %d Processing Pass %s flagged %s" % (runNumber, processingPass, dqFlag))
+            return S_ERROR("flagRun: processing pass {processingPass}\n error: {res['Message']}")
+        gLogger.notice(f"Run {runNumber} Processing Pass {processingPass} flagged {dqFlag}")
 
     return S_OK()
 
@@ -147,7 +142,7 @@ def browseBkkPath(bkDict, processingPass, visitedProcessingPass):
     if "Name" in records["ParameterNames"]:  # this mean we have processing passes
         # this is the name of the processing pass: 'ParameterNames': ['Name']
         index = records["ParameterNames"].index("Name")
-        passes = sorted([os.path.join(processingPass, record[index]) for record in records["Records"]])
+        passes = sorted(os.path.join(processingPass, record[index]) for record in records["Records"])
     else:
         passes = []
 
@@ -159,7 +154,7 @@ def browseBkkPath(bkDict, processingPass, visitedProcessingPass):
     return S_OK()
 
 
-@DIRACScript()
+@Script()
 def main():
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
@@ -183,8 +178,6 @@ def main():
 
     Script.parseCommandLine(ignoreErrors=True)
 
-    exitCode = 0
-
     params = {"lfn": None, "runnumber": None, "dqflag": None, "processingpass": None}
 
     for switch in Script.getUnprocessedSwitches():
@@ -221,14 +214,14 @@ def main():
 
     res = checkDQFlag(params["dqflag"])
     if not res["OK"]:
-        gLogger.fatal("%s - %s" % (params["dqflag"], res["Message"]))
+        gLogger.fatal(f"{params['dqflag']} - {res['Message']}")
         DIRAC.exit(1)
 
     if params["lfn"]:
         res = flagFileList(params["lfn"], params["dqflag"])
         if res["OK"]:
             gLogger.notice("Files are flagged!")
-            DIRAC.exit(exitCode)
+            DIRAC.exit()
         else:
             gLogger.fatal(res["Message"])
 
@@ -274,7 +267,7 @@ def main():
                         gLogger.fatal(res["Message"])
                         DIRAC.exit(1)
 
-    DIRAC.exit(exitCode)
+    DIRAC.exit()
 
 
 if __name__ == "__main__":
