@@ -11,19 +11,17 @@
 ###############################################################################
 """Set Quality Flag for the given files."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... LFN|File Flag" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... LFN|File Flag",
                 "Arguments:",
                 "  LFN:      Logical File Name",
                 "  File:     Name of the file with a list of LFNs",
@@ -41,7 +39,7 @@ def main():
     if len(args) < 2:
         result = bk.getAvailableDataQuality()
         if not result["OK"]:
-            print("ERROR: %s" % (result["Message"]))
+            print(f"ERROR: {result['Message']}")
             DIRAC.exit(2)
         flags = result["Value"]
         print("Available Data Quality Flags")
@@ -57,13 +55,13 @@ def main():
         files = open(filename)
         for f in files:
             lfns += [f.strip()]
-    except Exception as ex:
+    except Exception:
         lfns = [filename]
 
     result = bk.setFileDataQuality(lfns, flag)
 
     if not result["OK"]:
-        print("ERROR: %s" % (result["Message"]))
+        print(f"ERROR: {result['Message']}")
         exitCode = 2
     else:
         succ = result["Value"]["Successful"]
