@@ -10,21 +10,18 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set Data Quality Flag for the given run."""
-
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... Run Flag" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... Run Flag",
                 "Arguments:",
                 "  Run:      Run number",
                 "  Flag:     Quality Flag",
@@ -41,7 +38,7 @@ def main():
     if len(args) < 2:
         result = bk.getAvailableDataQuality()
         if not result["OK"]:
-            print("ERROR: %s" % (result["Message"]))
+            print(f"ERROR: {result['Message']}")
             DIRAC.exit(2)
         flags = result["Value"]
         print("Available Data Quality Flags")
@@ -55,7 +52,7 @@ def main():
     result = bk.setRunDataQuality(rnb, flag)
 
     if not result["OK"]:
-        print("ERROR: %s" % (result["Message"]))
+        print(f"ERROR: {result['Message']}")
         exitCode = 2
     else:
         succ = result["Value"]["Successful"]
