@@ -16,11 +16,9 @@ Parameters:
    <run> : run number
    <flag> : flag to set
 """
-
 import DIRAC
 from DIRAC import gLogger
-from DIRAC.Core.Base import Script
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def getProcessingPasses(bkDict, headPass):
@@ -56,16 +54,14 @@ def getProcessingPasses(bkDict, headPass):
     return passes
 
 
-@DIRACScript()
+@Script()
 def main():
-    Script.setUsageMessage("Usage: %s <Processing Pass> <run> <status> <flag>" % (Script.scriptName))
+    Script.setUsageMessage(f"Usage: {Script.scriptName} <Processing Pass> <run> <status> <flag>")
     Script.parseCommandLine()
     args = Script.getPositionalArgs()
     if len(args) < 3:
         Script.showHelp(exitCode=2)
 
-    exitCode = 0
-
     realData = "/Real Data"
     processing = args[0].replace("/RealData", realData)
     if processing == "":
@@ -106,7 +102,7 @@ def main():
     if processing != realData:
         knownPasses = getProcessingPasses(bkDict, "")
         if processing not in knownPasses:
-            gLogger.error("%s is not a valid processing pass." % (processing))
+            gLogger.error(f"{processing} is not a valid processing pass.")
             DIRAC.exit(2)
 
     recoPasses = getProcessingPasses(bkDict, processing)
@@ -133,7 +129,7 @@ def main():
         else:
             print("Run %d Processing Pass %s flagged %s" % (run, thisPass, flag))
 
-    DIRAC.exit(0)
+    DIRAC.exit()
 
 
 if __name__ == "__main__":
