@@ -11,14 +11,12 @@
 ###############################################################################
 """List simulation conditions from the Bookkeeping."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ..." % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ..."]))
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
