@@ -9,10 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """unit tests for Configuration Helpers."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-import mock
+from unittest import mock
 import os
 import pytest
 
