@@ -15,12 +15,11 @@ import os
 import sys
 from time import time
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from DIRAC import exit, gLogger
 
     Script.registerSwitch("", "User=", "  User name (no default, mandatory)")
@@ -70,7 +69,7 @@ def main():
             if success.get("SubDirs") or success.get("Files"):
                 gLogger.always(
                     "Directory is not empty:",
-                    " %d files / %d subdirectories" % (len(success["Files"]), len(success["SubDirs"])),
+                    f" {len(success['Files'])} files / {len(success['SubDirs'])} subdirectories",
                 )
             elif recursive:
                 gLogger.always("Empty directory, recursive is useless...")
@@ -82,7 +81,7 @@ def main():
             gLogger.fatal("Error creating directory", res["Message"])
             exit(2)
     else:
-        gLogger.always("Change%s ownership of directory" % " recursively" if recursive else "", baseDir)
+        gLogger.always(f"Change{' recursively'} ownership of directory" if recursive else "", baseDir)
     res = chown(baseDir, user, group="lhcb_user", mode=0o755, recursive=False, fcClient=dfc)
     if not res["OK"]:
         gLogger.fatal("Error changing directory owner", res["Message"])
@@ -97,7 +96,7 @@ def main():
             "Successfully changed owner in %d directories in %.1f seconds" % (res["Value"], time() - startTime)
         )
     else:
-        gLogger.always("Successfully changed owner in directory %s in %.1f seconds" % (baseDir, time() - startTime))
+        gLogger.always(f"Successfully changed owner in directory {baseDir} in {time() - startTime:.1f} seconds")
 
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
     from LHCbDIRAC.DataManagementSystem.Client.ScriptExecutors import executeLfnMetadata
