@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: iso-8859-1 -*-
 """
 HTML.py - v0.04 2009-07-28 Philippe Lagadec
 
@@ -69,7 +68,7 @@ TABLE_STYLE_THINBORDER = "border: 1px solid #000000; border-collapse: collapse;"
 # == CLASSES ===================================================================
 
 
-class TableCell(object):
+class TableCell:
     """a TableCell object is used to create a cell in a HTML table. (TD or TH)
 
     :param text: text in the cell (may contain HTML tags). May be any object which
@@ -132,22 +131,22 @@ class TableCell(object):
         if self.style:
             self.attribs["style"] = self.style
         for attr in self.attribs:
-            attribs_str += ' %s="%s"' % (attr, self.attribs[attr])
+            attribs_str += f' {attr}="{self.attribs[attr]}"'
         if self.text:
             text = str(self.text)
         else:
             # An empty cell should at least contain a non-breaking space
             text = "&nbsp;"
         if self.header:
-            return "  <TH%s>%s</TH>\n" % (attribs_str, text)
+            return f"  <TH{attribs_str}>{text}</TH>\n"
         else:
-            return "  <TD%s>%s</TD>\n" % (attribs_str, text)
+            return f"  <TD{attribs_str}>{text}</TD>\n"
 
 
 # ------------------------------------------------------------------------------
 
 
-class TableRow(object):
+class TableRow:
     """a TableRow object is used to create a row in a HTML table. (TR tag)
 
     :param cells: list, tuple or any iterable, containing one string or TableCell
@@ -191,8 +190,8 @@ class TableRow(object):
         if self.bgcolor:
             self.attribs["bgcolor"] = self.bgcolor
         for attr in self.attribs:
-            attribs_str += ' %s="%s"' % (attr, self.attribs[attr])
-        result = " <TR%s>\n" % attribs_str
+            attribs_str += f' {attr}="{self.attribs[attr]}"'
+        result = f" <TR{attribs_str}>\n"
         for cell in self.cells:
             col = self.cells.index(cell)  # cell column index
             if not isinstance(cell, TableCell):
@@ -217,7 +216,7 @@ class TableRow(object):
 # ------------------------------------------------------------------------------
 
 
-class Table(object):
+class Table:
     """a Table object is used to create a HTML table. (TABLE tag)
 
     :param rows: list, tuple or any iterable, containing one iterable or TableRow
@@ -291,12 +290,12 @@ class Table(object):
         if self.cellpadding:
             self.attribs["cellpadding"] = self.cellpadding
         for attr in self.attribs:
-            attribs_str += ' %s="%s"' % (attr, self.attribs[attr])
-        result = "<TABLE%s>\n" % attribs_str
+            attribs_str += f' {attr}="{self.attribs[attr]}"'
+        result = f"<TABLE{attribs_str}>\n"
         # insert column tags and attributes if specified:
         if self.col_width:
             for width in self.col_width:
-                result += '  <COL width="%s">\n' % width
+                result += f'  <COL width="{width}">\n'
             # The following code would also generate column attributes for style
             # and alignement according to HTML4 specs,
             # BUT it is not supported completely (only width) on Mozilla Firefox:
@@ -352,7 +351,7 @@ class Table(object):
 # ------------------------------------------------------------------------------
 
 
-class List(object):
+class List:
     """a List object is used to create an ordered or unordered list in HTML.
     (UL/OL tag)
 
@@ -383,15 +382,15 @@ class List(object):
         if self.start:
             self.attribs["start"] = self.start
         for attr in self.attribs:
-            attribs_str += ' %s="%s"' % (attr, self.attribs[attr])
+            attribs_str += f' {attr}="{self.attribs[attr]}"'
         if self.ordered:
             tag = "OL"
         else:
             tag = "UL"
-        result = "<%s%s>\n" % (tag, attribs_str)
+        result = f"<{tag}{attribs_str}>\n"
         for line in self.lines:
-            result += " <LI>%s\n" % str(line)
-        result += "</%s>\n" % tag
+            result += f" <LI>{str(line)}\n"
+        result += f"</{tag}>\n"
         return result
 
 
@@ -427,15 +426,16 @@ class List(object):
 
 # == FUNCTIONS ================================================================
 
+
 # much simpler definition of a link as a function:
 def Link(text, url):
     """create an reference link."""
-    return '<a href="%s">%s</a>' % (url, text)
+    return f'<a href="{url}">{text}</a>'
 
 
 def link(text, url):
     """create an reference link."""
-    return '<a href="%s">%s</a>' % (url, text)
+    return f'<a href="{url}">{text}</a>'
 
 
 def table(*args, **kwargs):
@@ -459,7 +459,6 @@ def list(*args, **kwargs):
 # Show sample usage when this file is launched as a script.
 
 if __name__ == "__main__":
-
     # open an HTML file to show output in a browser
     f = open("test.html", "w")
 
