@@ -25,7 +25,7 @@ from DIRAC import gLogger, gConfig
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 
 
-class NagiosConnector(object):
+class NagiosConnector:
     """Bundles functions in the stomp library for sending SAMJob-Results to SAM-
     Nagios."""
 
@@ -40,12 +40,12 @@ class NagiosConnector(object):
 
         self.config = {}
         for item in ["MsgBroker", "MsgQueue", "MsgPort"]:
-            path = self.opsHelper.getPath("/NagiosConnector/%s" % item)
+            path = self.opsHelper.getPath(f"/NagiosConnector/{item}")
             self.config[item] = gConfig.getValue(path)
             if not self.config[item]:
-                gLogger.verbose("Required Configuration Value is empty: %s" % item)
+                gLogger.verbose(f"Required Configuration Value is empty: {item}")
             else:
-                gLogger.verbose("Read Config Values for %s: %s" % (item, self.config[item]))
+                gLogger.verbose(f"Read Config Values for {item}: {self.config[item]}")
 
         try:
             self.config["MsgPort"] = int(self.config["MsgPort"])
@@ -87,11 +87,11 @@ EOT"""
 
             currentTime = datetime.datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")
             message = ""
-            message += "serviceURI: %s\n" % serviceURI
-            message += "metricStatus: %s\n" % status
-            message += "timestamp: %s\n" % currentTime
-            message += "nagiosName: %s\n" % nagiosName
-            message += "summaryData: %s\n" % details
+            message += f"serviceURI: {serviceURI}\n"
+            message += f"metricStatus: {status}\n"
+            message += f"timestamp: {currentTime}\n"
+            message += f"nagiosName: {nagiosName}\n"
+            message += f"summaryData: {details}\n"
             # all other fields are not used in SAM-Nagios
             # they are left here for compatibility / legacy
             # message += "gatheredAt: %s\n" % msginfos['ce']
@@ -123,6 +123,8 @@ EOT"""
         try:
             self.conn = stomp.Connection(
                 [(self.config["MsgBroker"], self.config["MsgPort"])],
+            )
+            self.conn.set_ssl(
                 use_ssl=_use_ssl,
                 ssl_key_file=_ssl_key_file,
                 ssl_cert_file=_ssl_cert_file,
@@ -132,10 +134,9 @@ EOT"""
             # There may be a need to receive messages.
             # In this case there should be a class with an on_message method
             # conn.set_listener('',MyListener()) python-messaging provides a useful class.
-            self.conn.start()
             self.conn.connect()
         except stomp.exception.ConnectFailedException as e:
-            gLogger.error("Error establishing connection: %s" % e)
+            gLogger.error(f"Error establishing connection: {e}")
 
     def sendMessage(self):
         """Use the conn object to send a message to the broker.
@@ -147,8 +148,8 @@ EOT"""
         if not self.message:
             gLogger.error("The message string is empty!")
         self.conn.send(destination=self.config["MsgQueue"], body=self.message)
-        gLogger.verbose("Message sent to %s on %s" % (self.config["MsgBroker"], self.config["MsgQueue"]))
-        gLogger.verbose("Message content %s" % self.message)
+        gLogger.verbose(f"Message sent to {self.config['MsgBroker']} on {self.config['MsgQueue']}")
+        gLogger.verbose(f"Message content {self.message}")
 
     def endConnection(self):
         """Call disconnect() on the conn object."""
