@@ -34,11 +34,10 @@ def constructProductionLFNs(paramDict, bkClient=None, quick=True):
     This works using the workflow commons for on the fly construction.
     """
     try:
-
         keys = ["PRODUCTION_ID", "JOB_ID", "configVersion", "outputList", "configName", "outputDataFileMask"]
         for k in keys:
             if k not in paramDict:
-                return S_ERROR("%s not defined" % k)
+                return S_ERROR(f"{k} not defined")
 
         productionID = paramDict["PRODUCTION_ID"]
         jobID = paramDict["JOB_ID"]
@@ -50,9 +49,7 @@ def constructProductionLFNs(paramDict, bkClient=None, quick=True):
         outputList = paramDict["outputList"]
 
         fileTupleList = []
-        gLogger.verbose(
-            "wfConfigName = %s, wfConfigVersion = %s, wfMask = %s" % (wfConfigName, wfConfigVersion, wfMask)
-        )
+        gLogger.verbose(f"wfConfigName = {wfConfigName}, wfConfigVersion = {wfConfigVersion}, wfMask = {wfMask}")
         for info in outputList:
             try:
                 fileName = info["outputDataName"]
@@ -62,16 +59,16 @@ def constructProductionLFNs(paramDict, bkClient=None, quick=True):
                 prodID = str(productionID).zfill(8)
                 jobID = str(jobID).zfill(8)
                 stepInstanceNumber = "1"  # can't be more precise at this stage
-                fileName = "%s_%s_%s" % (prodID, jobID, stepInstanceNumber)
+                fileName = f"{prodID}_{jobID}_{stepInstanceNumber}"
             fileTupleList.append((fileName, info["outputDataType"]))
 
         # Strip output data according to file mask
         fileTupleListMasked = _applyMask(wfMask, fileTupleList)
         lfnRoot = _getLFNRoot("", wfConfigName, wfConfigVersion, bkClient, quick=quick)
-        gLogger.debug("LFN_ROOT is: %s" % (lfnRoot))
+        gLogger.debug(f"LFN_ROOT is: {lfnRoot}")
         debugRoot = _getLFNRoot("", "debug", wfConfigVersion, bkClient, quick=quick)
 
-        gLogger.verbose("LFN_ROOT is: %s" % (lfnRoot))
+        gLogger.verbose(f"LFN_ROOT is: {lfnRoot}")
         if not lfnRoot:
             return S_ERROR("LFN root could not be constructed")
 
@@ -99,15 +96,15 @@ def constructProductionLFNs(paramDict, bkClient=None, quick=True):
                 _makeProductionLFN(
                     str(jobID).zfill(8),
                     debugRoot,
-                    ("%s_core" % str(jobID).zfill(8), "core"),
+                    (f"{str(jobID).zfill(8)}_core", "core"),
                     str(productionID).zfill(8),
                 )
             )
 
         # Get log file path - unique for all modules
         logPath = _makeProductionPath(str(jobID).zfill(8), lfnRoot, "LOG", str(productionID).zfill(8), log=True)
-        logFilePath = ["%s/%s" % (logPath, str(jobID).zfill(8))]
-        logTargetPath = ["%s/%s_%s.tar" % (logPath, str(productionID).zfill(8), str(jobID).zfill(8))]
+        logFilePath = [logPath]
+        logTargetPath = [f"{logPath}/{str(jobID).zfill(8)}.zip"]
         # [ aside, why does makeProductionPath not append the jobID itself ????
         # this is really only used in one place since the logTargetPath is just
         # written to a text file (should be reviewed)... ]
@@ -116,8 +113,8 @@ def constructProductionLFNs(paramDict, bkClient=None, quick=True):
             gLogger.info("No output data LFN(s) constructed")
         else:
             gLogger.verbose("Created the following output data LFN(s):\n%s" % ("\n".join(outputData)))
-        gLogger.verbose("Log file path is:\n%s" % logFilePath[0])
-        gLogger.verbose("Log target path is:\n%s" % logTargetPath[0])
+        gLogger.verbose(f"Log file path is:\n{logFilePath[0]}")
+        gLogger.verbose(f"Log target path is:\n{logTargetPath[0]}")
         if bkLFNs:
             gLogger.verbose("BookkeepingLFN(s) are:\n%s" % ("\n".join(bkLFNs)))
         if debugLFNs:
@@ -167,23 +164,23 @@ def getLogPath(paramDict, bkClient=None, quick=True):
         keys = ["PRODUCTION_ID", "JOB_ID", "configName", "configVersion"]
         for k in keys:
             if k not in paramDict:
-                return S_ERROR("%s not defined" % k)
+                return S_ERROR(f"{k} not defined")
 
         productionID = paramDict["PRODUCTION_ID"]
         jobID = paramDict["JOB_ID"]
         wfConfigName = paramDict["configName"]
         wfConfigVersion = paramDict["configVersion"]
 
-        gLogger.verbose("wfConfigName = %s, wfConfigVersion = %s" % (wfConfigName, wfConfigVersion))
+        gLogger.verbose(f"wfConfigName = {wfConfigName}, wfConfigVersion = {wfConfigVersion}")
         lfnRoot = _getLFNRoot("", wfConfigName, wfConfigVersion, bkClient, quick=quick)
 
         # Get log file path - unique for all modules
         logPath = _makeProductionPath(str(jobID).zfill(8), lfnRoot, "LOG", str(productionID).zfill(8), log=True)
-        logFilePath = ["%s/%s" % (logPath, str(jobID).zfill(8))]
-        logTargetPath = ["%s/%s_%s.tar" % (logPath, str(productionID).zfill(8), str(jobID).zfill(8))]
+        logFilePath = [logPath]
+        logTargetPath = [f"{logPath}/{str(jobID).zfill(8)}.zip"]
 
-        gLogger.verbose("Log file path is:\n%s" % logFilePath)
-        gLogger.verbose("Log target path is:\n%s" % logTargetPath)
+        gLogger.verbose(f"Log file path is:\n{logFilePath}")
+        gLogger.verbose(f"Log target path is:\n{logTargetPath}")
         jobOutputs = {"LogFilePath": logFilePath, "LogTargetPath": logTargetPath}
         return S_OK(jobOutputs)
     except Exception as e:
@@ -206,7 +203,7 @@ def constructUserLFNs(jobID, owner, outputFiles, outputPath="", prependString=""
 
     initial = owner[:1]
     timeTup = datetime.date.today().timetuple()
-    yearMonth = "%s_%s" % (timeTup[0], str(timeTup[1]).zfill(2))
+    yearMonth = f"{timeTup[0]}_{str(timeTup[1]).zfill(2)}"
     outputLFNs = {}
 
     outputPathStr = ""
@@ -343,8 +340,8 @@ def _getLFNRoot(lfn, namespace="", configVersion=0, bkClient=None, quick=False):
     LFN_ROOT = ""
 
     if not lfn:
-        LFN_ROOT = "/lhcb/%s/%s" % (namespace, configVersion)
-        gLogger.debug("LFN_ROOT will be %s" % (LFN_ROOT))
+        LFN_ROOT = f"/lhcb/{namespace}/{configVersion}"
+        gLogger.debug(f"LFN_ROOT will be {LFN_ROOT}")
         return LFN_ROOT
 
     lfn = [fname.replace(" ", "").replace("LFN:", "") for fname in lfn.split(";")]
@@ -352,7 +349,7 @@ def _getLFNRoot(lfn, namespace="", configVersion=0, bkClient=None, quick=False):
 
     if quick:
         for part in lfnroot[0:4]:
-            LFN_ROOT += "/%s" % (part)
+            LFN_ROOT += f"/{part}"
 
     else:
         if not bkClient:
@@ -364,12 +361,12 @@ def _getLFNRoot(lfn, namespace="", configVersion=0, bkClient=None, quick=False):
         if not dataTypes["OK"]:
             raise Exception(dataTypes["Message"])
         dataTypes = [x[0] for x in dataTypes["Value"]["Records"]]
-        gLogger.verbose("DataTypes retrieved from the BKK are:\n%s" % (", ".join(dataTypes)))
-        gLogger.verbose("wf lfn: %s, namespace: %s, configVersion: %s" % (lfn, namespace, configVersion))
+        gLogger.verbose(f"DataTypes retrieved from the BKK are:\n{', '.join(dataTypes)}")
+        gLogger.verbose(f"wf lfn: {lfn}, namespace: {namespace}, configVersion: {configVersion}")
 
         for part in lfnroot:
             if part not in dataTypes:
-                LFN_ROOT += "/%s" % (part)
+                LFN_ROOT += f"/{part}"
             else:
                 break
 
