@@ -22,8 +22,9 @@ from LHCbDIRAC.Core.Utilities.XMLTreeParser import XMLTreeParser
 
 def xmltojsonCat1(lCategory1):
     """returns a Category1 dictionary
+
     :param list lCategory1: list containing Category1 counters
-    e.g. Category1 counter : <counter name="MCVeloHitPacker/# PackedData">50809</counter>
+        e.g. Category1 counter : <counter name="MCVeloHitPacker/# PackedData">50809</counter>
     """
     result = {}
     for counter in lCategory1:
@@ -35,11 +36,12 @@ def xmltojsonCat1(lCategory1):
 
 def xmltojsonCat2(lCategory2):
     """returns a Category2 dictionary
+
     :param list lCategory2: list containing Category2 counters
-    e.g. Category2 counters:
-    <counter name="TTHitMonitor/DeltaRay">1249</counter>
-    <counter name="TTHitMonitor/betaGamma">28101829</counter>
-    <counter name="TTHitMonitor/numberHits">17105</counter>
+        e.g. Category2 counters:
+        <counter name="TTHitMonitor/DeltaRay">1249</counter>
+        <counter name="TTHitMonitor/betaGamma">28101829</counter>
+        <counter name="TTHitMonitor/numberHits">17105</counter>
     """
     result = {}
     for value in lCategory2:
@@ -52,32 +54,33 @@ def xmltojsonCat2(lCategory2):
 
 def xmltojsonCat3(lCategory3):
     """returns a Category3 dictionary
+
     :param list lCategory3: list containing Category3 counters
-    e.g. Category3 counters:
-    <counter name="CheckRichOpPhot/Diff.    - Aero. Exit x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Aero. Exit y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Aero. Exit z">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Cherenkov Phi">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Cherenkov Theta">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Emission Point x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Emission Point y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Emission Point z">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Energy">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD In. Point x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD In. Point y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD In. Point z">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD QW Point x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD QW Point y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - HPD QW Point z">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Parent Momentum x">38</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Parent Momentum y">46</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Parent Momentum z">-33</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. z">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. x">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. y">0</counter>
-    <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. z">0</counter>
+        e.g. Category3 counters:
+        <counter name="CheckRichOpPhot/Diff.    - Aero. Exit x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Aero. Exit y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Aero. Exit z">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Cherenkov Phi">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Cherenkov Theta">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Emission Point x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Emission Point y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Emission Point z">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Energy">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD In. Point x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD In. Point y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD In. Point z">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD QW Point x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD QW Point y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - HPD QW Point z">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Parent Momentum x">38</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Parent Momentum y">46</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Parent Momentum z">-33</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Prim. Mirr. z">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. x">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. y">0</counter>
+        <counter name="CheckRichOpPhot/Diff.    - Sec. Mirr. z">0</counter>
     """
     result = {}
     for counter in lCategory3:
@@ -111,9 +114,11 @@ def xmltojsonCat3(lCategory3):
 
 def ranges(mainList):
     """Returns a list containing the ranges of each category
+
     :param list mainList: list containing indices of a certain category of counters
-    e.g. mainList = [1, 2, 3, 4, 5, 6, 11, 12, 13, 14, 20, 21, 22]
-    ranges(mainList) = [1, 6, 11, 14, 20, 22]
+        e.g. mainList = [1, 2, 3, 4, 5, 6, 11, 12, 13, 14, 20, 21, 22]
+        ranges(mainList) = [1, 6, 11, 14, 20, 22]
+
     The role of this function is to know the intervals of each category
     """
     rangesList = [mainList[0], mainList[1]]
@@ -136,7 +141,6 @@ class XMLSummaryError(Exception):
     """Define error for XML summary."""
 
     def __init__(self, message=""):
-
         self.message = message
         Exception.__init__(self, message)
 
@@ -147,7 +151,7 @@ class XMLSummaryError(Exception):
 ################################################################################
 
 
-class XMLSummary(object):
+class XMLSummary:
     """XML summary class."""
 
     def __init__(self, xmlFileName, log=None):
@@ -162,11 +166,11 @@ class XMLSummary(object):
         self.xmlFileName = xmlFileName
 
         if not os.path.exists(self.xmlFileName):
-            self.log.error("XML Summary Not Available", "%s" % self.xmlFileName)
+            self.log.error("XML Summary Not Available", f"{self.xmlFileName}")
             raise XMLSummaryError("XML Summary Not Available")
 
         if os.stat(self.xmlFileName)[6] == 0:
-            self.log.error("Requested XML summary file is empty", "%s" % self.xmlFileName)
+            self.log.error("Requested XML summary file is empty", f"{self.xmlFileName}")
             raise XMLSummaryError("Requested XML summary file is empty")
 
         summary = XMLTreeParser()
@@ -174,7 +178,7 @@ class XMLSummary(object):
         try:
             self.xmlTree = summary.parse(self.xmlFileName)
         except Exception as e:
-            self.log.error("Error parsing xml summary", "%s" % str(e))
+            self.log.error("Error parsing xml summary", f"{str(e)}")
             raise XMLSummaryError("Error parsing xml summary")
 
         self.success = self.__getSuccess()
@@ -306,17 +310,16 @@ class XMLSummary(object):
         fileCounter = {"full": 0, "part": 0, "mult": 0, "fail": 0, "other": 0}
 
         for fileIn, status in self.inputStatus:
-
             if status == "fail":
-                self.log.warn("Input File on status", "%s: %s" % (fileIn, status))
+                self.log.warn("Input File on status", f"{fileIn}: {status}")
                 fileCounter["fail"] += 1
 
             elif status == "mult":
-                self.log.warn("Input File on status", "%s: %s" % (fileIn, status))
+                self.log.warn("Input File on status", f"{fileIn}: {status}")
                 fileCounter["mult"] += 1
 
             elif status == "part":
-                self.log.warn("Input File on status", "%s: %s" % (fileIn, status))
+                self.log.warn("Input File on status", f"{fileIn}: {status}")
                 fileCounter["part"] += 1
 
             elif status == "full":
@@ -326,7 +329,7 @@ class XMLSummary(object):
 
             # This should never happen, but just in case
             else:
-                self.log.warn("Input File on unknown status", "%s: %s" % (fileIn, status))
+                self.log.warn("Input File on unknown status", f"{fileIn}: {status}")
                 fileCounter["other"] += 1
 
         files = ["%d input file(s) on %s status" % (v, k) for k, v in fileCounter.items() if v > 0]
@@ -420,17 +423,16 @@ class XMLSummary(object):
         fileCounter = {"full": 0, "part": 0, "mult": 0, "fail": 0, "other": 0}
 
         for filename, status in res:
-
             if status == "fail":
-                self.log.warn("Output File on status", "%s: %s." % (filename, status))
+                self.log.warn("Output File on status", f"{filename}: {status}.")
                 fileCounter["fail"] += 1
 
             elif status == "mult":
-                self.log.warn("Output File on status", "%s: %s." % (filename, status))
+                self.log.warn("Output File on status", f"{filename}: {status}.")
                 fileCounter["mult"] += 1
 
             elif status == "part":
-                self.log.warn("Output File on status", "%s: %s." % (filename, status))
+                self.log.warn("Output File on status", f"{filename}: {status}.")
                 fileCounter["part"] += 1
 
             elif status == "full":
@@ -440,7 +442,7 @@ class XMLSummary(object):
 
             # This should never happen, but just in case
             else:
-                self.log.warn("Output File on unknown status", "%s: %s." % (filename, status))
+                self.log.warn("Output File on unknown status", f"{filename}: {status}.")
                 fileCounter["other"] += 1
 
         files = ["%d output file(s) on %s status" % (v, k) for k, v in fileCounter.items() if v > 0]
@@ -501,7 +503,7 @@ class XMLSummary(object):
         jsonTemp = dict()
         jsonFin = dict()
 
-        with io.open(self.xmlFileName, "r") as fp:
+        with open(self.xmlFileName) as fp:
             # storing the lines in a list
             fileLines = fp.readlines()
         # keeping only the counters lines
@@ -557,8 +559,8 @@ class XMLSummary(object):
         text = str(jsonFin).replace("Eta", "Theta")
         dico = ast.literal_eval(text)
         # Taking only the name of the file without the .xml in the end
-        with io.open(self.xmlFileName[:-3] + "json", "w", encoding="utf-8") as fp:
-            fp.write(six.text_type(json.dumps(dico, indent=2)))
+        with open(self.xmlFileName[:-3] + "json", "w", encoding="utf-8") as fp:
+            fp.write(str(json.dumps(dico, indent=2)))
 
         return dico
 
