@@ -15,7 +15,7 @@ import itertools
 import os
 import datetime
 
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 from DIRAC import gLogger
 
@@ -57,7 +57,6 @@ class UtilitiesTestCase(unittest.TestCase):
 
 class GangaDataFileSuccess(UtilitiesTestCase):
     def test_generateGangaDataFile(self):
-
         gdf = GangaDataFile()
 
         res = gdf.generateDataFile(["foo", "bar"], persistency="ROOT")
@@ -114,7 +113,6 @@ class GangaDataFileSuccess(UtilitiesTestCase):
 
 class GangaDataFileFailure(UtilitiesTestCase):
     def test_generateDataFile(self):
-
         gdf = GangaDataFile()
         self.assertRaises(TypeError, gdf.generateDataFile, (""))
         self.assertRaises(ValueError, gdf.generateDataFile, ([]))
@@ -124,11 +122,9 @@ class GangaDataFileFailure(UtilitiesTestCase):
 
 
 class ProductionDataSuccess(UtilitiesTestCase):
-
     #################################################
 
     def test_constructProductionLFNs(self):
-
         # + test with InputData
 
         paramDict = {
@@ -157,8 +153,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
         AllStreamsDST = "/lhcb/certification/test/ALLSTREAMS.DST/00012345/0005/00012345_00054321_5.AllStreams.dst"
         reslist = [
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -180,8 +176,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
                 ],
             },
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -198,8 +194,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
                 "ProductionOutputData": ["/lhcb/certification/test/DST/00012345/0005/00012345_00054321_4.dst"],
             },
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -216,8 +212,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
                 "ProductionOutputData": ["/lhcb/certification/test/DST/00012345/0005/00012345_00054321_4.dst"],
             },
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -237,8 +233,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
                 ],
             },
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -255,8 +251,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
                 "ProductionOutputData": [AllStreamsDST],
             },
             {
-                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00012345_00054321.tar"],
-                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005/00054321"],
+                "LogTargetPath": ["/lhcb/certification/test/LOG/00012345/0005/00054321.zip"],
+                "LogFilePath": ["/lhcb/certification/test/LOG/00012345/0005"],
                 "DebugLFNs": [
                     "/lhcb/debug/test/SIM/00012345/0005/00012345_00054321_1.sim",
                     "/lhcb/debug/test/DIGI/00012345/0005/00012345_00054321_2.digi",
@@ -295,7 +291,6 @@ class ProductionDataSuccess(UtilitiesTestCase):
     #################################################
 
     def test__makeProductionLFN(self):
-
         JOB_ID = "00054321"
         LFN_ROOT = "/lhcb/MC/MC10"
         filetuple = (("00012345_00054321_1.sim", "sim"), ("00012345_00054321_1.sim", "SIM"))
@@ -308,7 +303,6 @@ class ProductionDataSuccess(UtilitiesTestCase):
     #################################################
 
     def test__applymask(self):
-
         dtl = [
             ("00012345_00054321_1.sim", "sim"),
             ("00012345_00054321_4.dst", "dst"),
@@ -341,7 +335,6 @@ class ProductionDataSuccess(UtilitiesTestCase):
             self.assertEqual(r, res)
 
     def test_getLogPath(self):
-
         wkf_commons = {
             "PRODUCTION_ID": 12345,
             "JOB_ID": 0o0001,
@@ -357,8 +350,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
             {
                 "OK": True,
                 "Value": {
-                    "LogTargetPath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00012345_00000001.tar"],
-                    "LogFilePath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00000001"],
+                    "LogTargetPath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00000001.zip"],
+                    "LogFilePath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000"],
                 },
             },
         )
@@ -370,8 +363,8 @@ class ProductionDataSuccess(UtilitiesTestCase):
             {
                 "OK": True,
                 "Value": {
-                    "LogTargetPath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00012345_00000001.tar"],
-                    "LogFilePath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00000001"],
+                    "LogTargetPath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000/00000001.zip"],
+                    "LogFilePath": ["/lhcb/LHCb/Collision11/LOG/00012345/0000"],
                 },
             },
         )
@@ -387,7 +380,7 @@ class ProductionDataSuccess(UtilitiesTestCase):
 
     def test_constructUserLFNs(self):
         timeTup = datetime.date.today().timetuple()
-        yearMonth = "%s_%s" % (timeTup[0], str(timeTup[1]).zfill(2))
+        yearMonth = f"{timeTup[0]}_{str(timeTup[1]).zfill(2)}"
 
         res = constructUserLFNs(123, "fstagni", ["pippo.txt", "pluto.txt"])
         self.assertEqual(
@@ -436,7 +429,6 @@ class ProductionDataSuccess(UtilitiesTestCase):
 
 class InputDataResolutionSuccess(UtilitiesTestCase):
     def test__addPfnType(self):
-
         res = self.IDR._addPfnType({"lfn1": {"mdata": "mdata1"}, "lfn2": {"mdata": "mdata2"}})
         self.assertEqual(
             res,
@@ -483,7 +475,6 @@ class InputDataResolutionSuccess(UtilitiesTestCase):
 
 class NagiosConnectorSuccess(UtilitiesTestCase):
     def test_readConfig(self):
-
         nagConn = NagiosConnector()
         nagConn.readConfig()
         self.assertTrue(nagConn.config["MsgPort"])
