@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test XMLErr.py."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 import ast
 import xml.etree.ElementTree as ET
@@ -22,7 +18,7 @@ import LHCbDIRAC.Core.Utilities.XMLErr as XMLErr
 
 class XMLErrTestCase(unittest.TestCase):
     def __init__(self, *args, **kwargs):
-        super(XMLErrTestCase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def setUp(self):
         self.jobID = 1
@@ -34,7 +30,6 @@ class XMLErrTestCase(unittest.TestCase):
 
 
 class TestXMLErr(XMLErrTestCase):
-
     #########################################
     # Test extractData()
 
