@@ -11,7 +11,7 @@
 ###############################################################################
 """Returns the platform supported by the current WN."""
 import LbPlatformUtils
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def sendMail(msg=""):
@@ -25,7 +25,7 @@ def sendMail(msg=""):
     ce = gConfig.getValue("LocalSite/GridCE")
     queue = gConfig.getValue("LocalSite/CEQueue")
     body = "*** THIS IS AN AUTOMATED MESSAGE ***" + "\n\n" + msg + "\n\n"
-    body = body + "At site %s, CE = %s, queue = %s" % (site, ce, queue) + "\n\n"
+    body = body + f"At site {site}, CE = {ce}, queue = {queue}" + "\n\n"
 
     for mA in mailAddress.replace(" ", "").split(","):
         NotificationClient().sendMail(
@@ -33,10 +33,8 @@ def sendMail(msg=""):
         )
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch("", "BinaryTag", "   Print the host binary tag instead of the host dirac_platform")
     Script.parseCommandLine(ignoreErrors=True)
 
@@ -66,9 +64,9 @@ def main():
         grid = site.split(".")[0]
         ce = gConfig.getValue("/LocalSite/GridCE")
 
-        allowContainers = gConfig.getValue("/Resources/Sites/%s/%s/CEs/%s/AllowContainers" % (grid, site, ce), None)
+        allowContainers = gConfig.getValue(f"/Resources/Sites/{grid}/{site}/CEs/{ce}/AllowContainers", None)
         if allowContainers is None:
-            allowContainers = gConfig.getValue("/Resources/Sites/%s/%s/AllowContainers" % (grid, site), None)
+            allowContainers = gConfig.getValue(f"/Resources/Sites/{grid}/{site}/AllowContainers", None)
         if allowContainers is None:
             allowContainers = Operations().getValue("GaudiExecution/AllowContainers", "no")
 
