@@ -11,16 +11,14 @@
 ###############################################################################
 """Perform comprehensive checks on the supplied log file if it exists."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch("f:", "XMLSummary=", "Path to XML summary you wish to analyze (mandatory)")
 
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option|cfgfile] ... CE" % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option|cfgfile] ... CE"]))
     Script.parseCommandLine(ignoreErrors=True)
 
     from DIRAC import gLogger
@@ -43,7 +41,7 @@ def main():
     try:
         analyseXMLSummary(logFile, projectName)
     except Exception as x:
-        gLogger.exception('XML summary analysis failed with exception: "%s"' % x)
+        gLogger.exception(f'XML summary analysis failed with exception: "{x}"')
         exitCode = 2
         DIRAC.exit(exitCode)
 
