@@ -13,7 +13,7 @@
 import os
 
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 keep = None
 localFile = None
@@ -27,26 +27,24 @@ def leave(msg, error=None, exitCode=0):
 
     if not keep and os.path.exists(localFile):
         os.remove(localFile)
-        gLogger.info("Local file %s removed" % localFile)
+        gLogger.info(f"Local file {localFile} removed")
 
     if error:
         errMsg = error.get(
             "Message",
             list(error.get("Value", {}).get("Failed", {"": "Unknown reason"}).values())[0],
         )
-        gLogger.error(msg, ": %s" % errMsg)
+        gLogger.error(msg, f": {errMsg}")
     else:
         gLogger.always(msg)
     DIRAC.exit(exitCode)
 
 
-@DIRACScript()
+@Script()
 def main():
     global keep
     global localFile
 
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch("f:", "OldLFN=", "LFN of existing file to be fixed.")
     Script.registerSwitch(
         "n:", "NewLFN=", "Optional: specify a new LFN for the file (retaining the existing file with incorrect GUID)."
@@ -56,7 +54,7 @@ def main():
     Script.registerSwitch(
         "m", "SafeMode", "Optional: specify this switch to run the script in safe mode (will check the GUIDs only)"
     )
-    Script.setUsageMessage("\n".join([__doc__, "Usage:", "  %s [option|cfgfile] [OldLFN]" % Script.scriptName]))
+    Script.setUsageMessage("\n".join([__doc__, "Usage:", f"  {Script.scriptName} [option|cfgfile] [OldLFN]"]))
     Script.parseCommandLine(ignoreErrors=True)
 
     args = Script.getPositionalArgs()
@@ -99,61 +97,59 @@ def main():
         leave("The original LFN of the file to be fixed must be specified", exitCode=2)
 
     if not os.path.exists(directory):
-        leave("Optional directory %s doesn't exist" % directory, exitCode=2)
+        leave(f"Optional directory {directory} doesn't exist", exitCode=2)
 
     if not newLFN:
-        gLogger.verbose("No new LFN specified, will replace the existing LFN %s" % (oldLFN))
+        gLogger.verbose(f"No new LFN specified, will replace the existing LFN {oldLFN}")
         newLFN = oldLFN
 
-    gLogger.verbose("Directory for downloading file is set to %s" % directory)
+    gLogger.verbose(f"Directory for downloading file is set to {directory}")
 
     replicaInfo = dirac.getReplicas(oldLFN)
     if not replicaInfo["OK"] or replicaInfo["Value"]["Failed"]:
-        leave("Could not get replica information for %s" % oldLFN, replicaInfo, exitCode=2)
+        leave(f"Could not get replica information for {oldLFN}", replicaInfo, exitCode=2)
 
     replicas = replicaInfo["Value"]["Successful"][oldLFN]
     storageElements = list(replicas)
     if not storageElements:
-        leave("Could not determine SEs for replicas of %s" % oldLFN, exitCode=2)
+        leave(f"Could not determine SEs for replicas of {oldLFN}", exitCode=2)
 
-    gLogger.info("Existing LFN has replicas at: %s" % ", ".join(storageElements))
+    gLogger.info(f"Existing LFN has replicas at: {', '.join(storageElements)}")
 
     oldGUID = dirac.getLfnMetadata(oldLFN)
     if not oldGUID["OK"] or oldGUID["Value"]["Failed"]:
-        leave("Could not obtain GUID from LFC for %s - %s" % oldLFN, oldGUID, exitCode=2)
+        leave("Could not obtain GUID from FC for %s - %s" % oldLFN, oldGUID, exitCode=2)
     oldGUID = oldGUID["Value"]["Successful"][oldLFN]["GUID"]
-    gLogger.verbose("Existing GUID is %s" % oldGUID)
+    gLogger.verbose(f"Existing GUID is {oldGUID}")
 
     # retrieve original file
     localFile = os.path.join(directory, os.path.basename(oldLFN))
     if not os.path.exists(localFile):
         download = dirac.getFile(oldLFN, directory)
         if not download["OK"] or download["Value"]["Failed"]:
-            leave("Could not download file with message - %s" % download["Message"], download, exitCode=2)
+            leave(f"Could not download file with message - {download['Message']}", download, exitCode=2)
     else:
-        gLogger.always("Found file %s in local directory, will not re-download" % os.path.basename(oldLFN))
+        gLogger.always(f"Found file {os.path.basename(oldLFN)} in local directory, will not re-download")
 
     newGUID = makeGuid(localFile)[localFile]
 
     if newGUID == oldGUID:
-        leave("Old and new GUIDs have the same value (%s), exiting without changes" % oldGUID)
+        leave(f"Old and new GUIDs have the same value ({oldGUID}), exiting without changes")
 
     if safe:
-        leave("Safe mode - found file GUID = %s and existing GUID = %s, exiting without changes" % (newGUID, oldGUID))
+        leave(f"Safe mode - found file GUID = {newGUID} and existing GUID = {oldGUID}, exiting without changes")
 
-    gLogger.verbose("Will set old GUID to %s from %s" % (newGUID, oldGUID))
+    gLogger.verbose(f"Will set old GUID to {newGUID} from {oldGUID}")
     if newLFN == oldLFN:
         gLogger.always("Removing old LFN from storages before adding new LFN")
         result = dirac.removeFile(oldLFN)
         if not result["OK"]:
             leave("Could not remove existing LFN from Grid storage", result, exitCode=2)
 
-    gLogger.always(
-        "Uploading %s as LFN:%s with replica at %s and GUID = %s" % (localFile, newLFN, storageElements[0], newGUID)
-    )
+    gLogger.always(f"Uploading {localFile} as LFN:{newLFN} with replica at {storageElements[0]} and GUID = {newGUID}")
     result = dirac.addFile(newLFN, localFile, storageElements[0], fileGuid=newGUID, printOutput=False)
     if not result["OK"]:
-        leave("Failed to copy and register new LFN:%s" % newLFN, result, exitCode=2)
+        leave(f"Failed to copy and register new LFN:{newLFN}", result, exitCode=2)
 
     leave("")
 
