@@ -13,16 +13,12 @@
 an xrootd URL (root:...)"""
 import os
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
-    Script.setUsageMessage(
-        "\n".join([__doc__, "Usage:", "  %s [option|cfgfile] file1 [file2 ...]" % Script.scriptName])
-    )
+    Script.setUsageMessage("\n".join([__doc__, "Usage:", f"  {Script.scriptName} [option|cfgfile] file1 [file2 ...]"]))
     Script.parseCommandLine(ignoreErrors=True)
     files = []
     for oFile in Script.getPositionalArgs():
@@ -49,7 +45,7 @@ def main():
                 for se in ses:
                     res = dirac.getAccessURL(localFile, se, protocol=["root", "xroot"])
                     if res["OK"] and localFile in res["Value"]["Successful"]:
-                        existFiles[res["Value"]["Successful"][localFile]] = "%s @ %s" % (localFile, se)
+                        existFiles[res["Value"]["Successful"][localFile]] = f"{localFile} @ {se}"
             else:
                 nonExisting.append(localFile)
         elif localFile.startswith("root:"):
