@@ -11,19 +11,17 @@
 ###############################################################################
 """Report info on event types for MC"""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
     from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import BKQuery
 
     Script.registerSwitch("", "FileType=", "FileType to search [default:ALLSTREAMS.DST]")
 
-    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", "  %s [option] eventType (mandatory)" % Script.scriptName]))
+    Script.setUsageMessage(__doc__ + "\n".join(["Usage:", f"  {Script.scriptName} [option] eventType (mandatory)"]))
     fileType = "ALLSTREAMS.DST"
     Script.parseCommandLine(ignoreErrors=True)
     for switch in Script.getUnprocessedSwitches():
