@@ -31,7 +31,7 @@ import subprocess
 from collections import defaultdict
 
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 
 
@@ -78,7 +78,7 @@ def reduceArgs(noMerge, arguments, maxList=20):
         if len(condTuple) != 2:
             finalArgs += [path for (path, _c) in condTuple]
         else:
-            if len(set(["-".join(cond.split("-")[0:2])])) == 1:
+            if len({"-".join(cond.split("-")[0:2])}) == 1:
                 finalArgs.append(newPath)
             else:
                 finalArgs += [path for (path, _c) in condTuple]
@@ -86,10 +86,9 @@ def reduceArgs(noMerge, arguments, maxList=20):
     return sorted(others + finalArgs)
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC import gLogger, exit
-    from DIRAC.Core.Base import Script
 
     Script.registerSwitch("", "NoMerge", "If set, do not merge arguments if BK paths")
     Script.registerSwitch("", "Items=", "Alternative way of passing list of arguments")
@@ -137,7 +136,7 @@ def main():
             oFile = lastFile
         else:
             oFile = "/dev/stdin"
-        with open(oFile, "r") as fd:
+        with open(oFile) as fd:
             arguments = fd.read().split("\n")
         if showLast:
             gLogger.notice("Last items used:", "\n" + "\n".join(arguments))
@@ -178,7 +177,7 @@ def main():
 
     # Persitify items for later use
     if not last and argList:
-        with open(lastFile, "wt") as tmpFile:
+        with open(lastFile, "w") as tmpFile:
             tmpFile.write("\n".join(argList))
 
     for arg in reduceArgs(noMerge, argList):
@@ -191,7 +190,7 @@ def main():
                 else:
                     cmd = command + " " + arg
                 if not terse:
-                    gLogger.notice("======= %s =========" % cmd)
+                    gLogger.notice(f"======= {cmd} =========")
                 try:
                     output = subprocess.check_output(cmd.encode(), stderr=subprocess.STDOUT, shell=True).decode()
                     gLogger.notice(output[:-1] if terse else output)
