@@ -12,24 +12,24 @@
 """Use dirac-proxy-init to get a proxy."""
 import os
 import sys
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     if os.getenv("X509_CERT_DIR") is None:
         sys.exit("the variable X509_CERT_DIR do not exist")
 
     if not os.path.isdir(os.environ["X509_CERT_DIR"]):
-        sys.exit("the directory %s does not exist" % os.environ["X509_CERT_DIR"])
+        sys.exit(f"the directory {os.environ['X509_CERT_DIR']} does not exist")
 
     if os.getenv("X509_VOMS_DIR") is None:
         sys.exit("the variable X509_VOMS_DIR do not exist")
 
     if not os.path.isdir(os.environ["X509_VOMS_DIR"]):
-        sys.exit("the directory %s does not exist" % os.environ["X509_VOMS_DIR"])
+        sys.exit(f"the directory {os.environ['X509_VOMS_DIR']} does not exist")
 
-    out = os.system("dirac-proxy-init -o LogLevel=NOTICE --strict --rfc '%s'" % "' '".join(sys.argv[1:]))
+    out = os.system("dirac-proxy-init -o LogLevel=NOTICE --strict '%s'" % "' '".join(sys.argv[1:]))
     sys.exit(int(out / 256))
 
 
