@@ -13,9 +13,9 @@
 
 .. module: PopularityAgent
 
-:synopsis: The Popularity Agent creates reports about per LFC directory data usage.
+:synopsis: The Popularity Agent creates reports about per FC directory data usage.
 
-The Popularity Agent creates reports about per LFC directory data usage, based on the
+The Popularity Agent creates reports about per FC directory data usage, based on the
 StorageUsageDB/Popularity table. Then it creates an accounting record for each directory,
 adding all the relevant directory metadata, obtained from the StorageUsageDB/DirMetadata table.
 The accounting records are stored in the AccountingDB and then displayed via the web portal.
@@ -26,7 +26,6 @@ from datetime import datetime, timedelta
 # # from DIRAC
 from DIRAC import S_OK, S_ERROR
 from DIRAC.Core.Base.AgentModule import AgentModule
-from DIRAC.Core.Utilities import Time
 from DIRAC.Core.Utilities.File import mkDir
 from DIRAC.AccountingSystem.Client.DataStoreClient import gDataStoreClient
 from LHCbDIRAC.AccountingSystem.Client.Types.Popularity import Popularity
@@ -65,7 +64,7 @@ class PopularityAgent(AgentModule):
         self.__dataUsageClient = DataUsageClient()
         self.__workDirectory = self.am_getOption("WorkDirectory")
         mkDir(self.__workDirectory)
-        self.log.info("Working directory is %s" % self.__workDirectory)
+        self.log.info(f"Working directory is {self.__workDirectory}")
         # by default, collects raw records from Popularity table inserted in the last day
         self.timeInterval = self.am_getOption("timeIntervalForPopularityRecords", 1)
         self.queryTimeout = self.am_getOption("queryTimeout", 3600)
@@ -86,21 +85,21 @@ class PopularityAgent(AgentModule):
         startTimeQuery = startTime.isoformat()
         # query all traces in popularity in the time rage startTime,endTime and status =new
         # the condition to get th etraces is the AND of the time range and the status new
-        self.log.info("Querying Pop db to retrieve entries in time range %s - %s " % (startTimeQuery, endTimeQuery))
+        self.log.info(f"Querying Pop db to retrieve entries in time range {startTimeQuery} - {endTimeQuery} ")
         status = "New"
         res = self.__dataUsageClient.getDataUsageSummary(
             startTimeQuery, endTimeQuery, status, timeout=self.queryTimeout
         )
         if not res["OK"]:
-            self.log.error("Error querying Popularity table.. %s" % res["Message"])
+            self.log.error(f"Error querying Popularity table.. {res['Message']}")
             return S_ERROR(res["Message"])
         val = res["Value"]
-        self.log.info("Retrieved %d entries from Popularity table" % len(val))
+        self.log.info(f"Retrieved {len(val)} entries from Popularity table")
         # Build popularity report, and store the Ids in a  list:
         idList = set()
         traceDict = {}
         for row in val:
-            self.log.debug("row: %s" % str(row))
+            self.log.debug(f"row: {str(row)}")
             rowId, dirLfn, site, count, insertTime = row
             if rowId not in idList:
                 idList.add(rowId)
@@ -108,7 +107,7 @@ class PopularityAgent(AgentModule):
                 self.log.error("Same Id found twice! %d " % rowId)
                 continue
             if dirLfn.startswith("/lhcb/user/"):
-                self.log.verbose("Private user directory. No metadata stored in Bkk %s " % dirLfn)
+                self.log.verbose(f"Private user directory. No metadata stored in Bkk {dirLfn} ")
                 continue
             # get the day (to do )
             dayBin = (insertTime - startTime).days
@@ -119,23 +118,23 @@ class PopularityAgent(AgentModule):
         # print a summary
         dayList = sorted(traceDict)
         for day in dayList:
-            self.log.info(" ###### day %s (starting from %s ) " % (day, startTimeQuery))
-            self.log.info("---- %d directories touched:" % len(traceDict[day]))
+            self.log.info(f" ###### day {day} (starting from {startTimeQuery} ) ")
+            self.log.info(f"---- {len(traceDict[day])} directories touched:")
             for lfn in traceDict[day]:
-                self.log.verbose(" ---- lfn %s " % lfn)
+                self.log.verbose(f" ---- lfn {lfn} ")
                 for site in traceDict[day][lfn]:
                     self.log.verbose(" -------- site  %s  count: %d " % (site, traceDict[day][lfn][site]))
 
         self.log.info("Retrieve meta-data information for each directory ")
-        now = Time.dateTime()
+        now = datetime.utcnow()
         self.numPopRows = 0  # keep a counter of the records to send to accounting data-store
         for day in traceDict:
             timeForAccounting = self.computeTimeForAccounting(startTime, day)
-            self.log.info("Processing day %s - time for accounting %s " % (day, timeForAccounting))
+            self.log.info(f"Processing day {day} - time for accounting {timeForAccounting} ")
             for dirLfn in traceDict[day]:
                 # did = configName = configVersion = conditions = processingPass = eventType = fileType = production = "na"
                 # retrieve the directory meta-data from the DirMetadata table
-                self.log.info("Processing dir %s " % dirLfn)
+                self.log.info(f"Processing dir {dirLfn} ")
 
                 metaForDir = self.cacheMetadata.get(dirLfn)
                 if not metaForDir:
@@ -143,20 +142,20 @@ class PopularityAgent(AgentModule):
                     # this could be done in a bulk query for a list of directories... TBD
                     res = self.__dataUsageClient.getDirMetadata(dirList)
                     if not res["OK"]:
-                        self.log.error("Error retrieving directory meta-data %s " % res["Message"])
+                        self.log.error(f"Error retrieving directory meta-data {res['Message']} ")
                         continue
                     dirMetadata = res["Value"].get(dirLfn)
                     if not res["Value"] or not dirMetadata:
-                        self.log.info("Cache missed: query BK to retrieve '%s' metadata and store  cache" % dirList)
+                        self.log.info(f"Cache missed: query BK to retrieve '{dirList}' metadata and store  cache")
                         res = self.__bkClient.getDirectoryMetadata(dirList)
                         if not res["OK"]:
-                            self.log.error("Failed to query Bookkeeping %s" % res["Message"])
+                            self.log.error(f"Failed to query Bookkeeping {res['Message']}")
                             metadata = None
                         else:
-                            self.log.verbose("Successfully queried Bookkeeping, result: %s " % res)
+                            self.log.verbose(f"Successfully queried Bookkeeping, result: {res} ")
                             metadata = res["Value"].get("Successful", {}).get(dirLfn, [{}])[0]
                         if not metadata:
-                            self.log.warn("Directory is not registered in Bookkeeping! %s " % dirLfn)
+                            self.log.warn(f"Directory is not registered in Bookkeeping! {dirLfn} ")
                             configName = (
                                 configVersion
                             ) = conditions = processingPass = eventType = fileType = production = "na"
@@ -173,15 +172,15 @@ class PopularityAgent(AgentModule):
                             self.log.info("Cache this entry in DirMetadata table..")
                             res = self.__dataUsageClient.insertToDirMetadata({dirLfn: metadata})
                             if not res["OK"]:
-                                self.log.error("Failed to insert metadata in DirMetadata table! %s " % res["Message"])
+                                self.log.error(f"Failed to insert metadata in DirMetadata table! {res['Message']} ")
                             else:
                                 self.log.info(
-                                    "Successfully inserted metadata for directory %s in DirMetadata table " % dirLfn
+                                    f"Successfully inserted metadata for directory {dirLfn} in DirMetadata table "
                                 )
-                                self.log.verbose("result: %s " % res)
+                                self.log.verbose(f"result: {res} ")
 
                     else:
-                        self.log.info("Directory %s was cached in DirMetadata table" % dirLfn)
+                        self.log.info(f"Directory {dirLfn} was cached in DirMetadata table")
                         try:
                             (
                                 __did,
@@ -228,7 +227,7 @@ class PopularityAgent(AgentModule):
                     popRecord.setValueByKey("NormalizedUsage", normUsage)
                     res = gDataStoreClient.addRegister(popRecord)
                     if not res["OK"]:
-                        self.log.error("ERROR: addRegister returned: %s" % res["Message"])
+                        self.log.error(f"ERROR: addRegister returned: {res['Message']}")
                         continue
                     self.numPopRows += 1
                     self.log.info(
@@ -255,15 +254,15 @@ class PopularityAgent(AgentModule):
         res = self.__commitAccounting()
         if not res["OK"]:
             return res
-        self.log.info("Set the status to Used for %d entries" % len(idList))
+        self.log.info(f"Set the status to Used for {len(idList)} entries")
         from DIRAC.Core.Utilities.List import breakListIntoChunks
 
         for idChunk in breakListIntoChunks(list(idList), 1000):
             res = self.__dataUsageClient.updatePopEntryStatus(list(idChunk), "Used", timeout=self.queryTimeout)
             if not res["OK"]:
-                self.log.error("Error to update status in  Popularity table.. %s" % res["Message"])
+                self.log.error(f"Error to update status in  Popularity table.. {res['Message']}")
                 return res
-        self.log.info("Status updated to Used correctly for %s entries " % len(idList))
+        self.log.info(f"Status updated to Used correctly for {len(idList)} entries ")
 
         return S_OK()
 
@@ -274,16 +273,16 @@ class PopularityAgent(AgentModule):
         if not res["OK"]:
             self.log.error("while committing %d Popularity records" % self.numPopRows, res["Message"])
         else:
-            self.log.info("%s records for Popularity type successfully committed" % self.numPopRows)
+            self.log.info(f"{self.numPopRows} records for Popularity type successfully committed")
             self.numPopRows = 0
         return res
 
     def computeTimeForAccounting(self, startTime, day):
         """Compute the time for the accounting record, starting from the start time
         of the query and the day bin."""
-        self.log.verbose("find time for accounting for startTime: %s + day %s " % (startTime, day))
+        self.log.verbose(f"find time for accounting for startTime: {startTime} + day {day} ")
         daysToAdd = timedelta(days=day, hours=12)  # add 12h just to put the value in the middle of time bin
-        self.log.verbose("timedelta to add: %s " % daysToAdd)
+        self.log.verbose(f"timedelta to add: {daysToAdd} ")
         accTime = startTime + daysToAdd
-        self.log.verbose("accTime = %s " % accTime)
+        self.log.verbose(f"accTime = {accTime} ")
         return accTime
