@@ -15,7 +15,6 @@
 
 :synopsis: RAWIntegrityAgent determines whether RAW files in CASTOR were migrated correctly.
 """
-
 # # imports
 import datetime
 
@@ -25,7 +24,6 @@ from DIRAC import S_OK
 # # from Core
 from DIRAC.Core.Base.AgentModule import AgentModule
 from DIRAC.ConfigurationSystem.Client.ConfigurationData import gConfigurationData
-from DIRAC.FrameworkSystem.Client.MonitoringClient import gMonitor
 
 # # from DMS
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
@@ -65,55 +63,6 @@ class RAWIntegrityAgent(AgentModule):
         # the bookeeping by the DataMover
         self.fileCatalog = FileCatalog(catalogs="FileCatalog")
 
-        gMonitor.registerActivity("Iteration", "Agent Loops/min", "RAWIntegriryAgent", "Loops", gMonitor.OP_SUM)
-        gMonitor.registerActivity(
-            "WaitingFiles", "Files waiting for migration", "RAWIntegriryAgent", "Files", gMonitor.OP_MEAN
-        )
-        gMonitor.registerActivity("WaitSize", "Size of migration buffer", "RAWIntegrityAgent", "GB", gMonitor.OP_MEAN)
-
-        gMonitor.registerActivity(
-            "NewlyMigrated", "Newly migrated files", "RAWIntegriryAgent", "Files", gMonitor.OP_SUM
-        )
-        gMonitor.registerActivity("TotMigrated", "Total migrated files", "RAWIntegriryAgent", "Files", gMonitor.OP_ACUM)
-        gMonitor.registerActivity(
-            "TotMigratedSize", "Total migrated file size", "RAWIntegriryAgent", "GB", gMonitor.OP_ACUM
-        )
-
-        gMonitor.registerActivity("BadChecksum", "Checksums mismatch", "RAWIntegriryAgent", "Files", gMonitor.OP_SUM)
-        gMonitor.registerActivity(
-            "ErrorMetadata", "Error when getting files metadata", "RAWIntegriryAgent", "Files", gMonitor.OP_SUM
-        )
-        gMonitor.registerActivity(
-            "ErrorRegister", "Error when registering files", "RAWIntegriryAgent", "Files", gMonitor.OP_SUM
-        )
-        gMonitor.registerActivity(
-            "ErrorRemove", "Error when removing files", "RAWIntegriryAgent", "Files", gMonitor.OP_SUM
-        )
-
-        gMonitor.registerActivity(
-            "FailedMigrated",
-            "Number of files encountering error during migration",
-            "RAWIntegriryAgent",
-            "Files",
-            gMonitor.OP_SUM,
-        )
-        gMonitor.registerActivity(
-            "TotFailMigrated",
-            "Total number of files encountering error during migration",
-            "RAWIntegriryAgent",
-            "Files",
-            gMonitor.OP_ACUM,
-        )
-
-        gMonitor.registerActivity(
-            "MigrationTime", "Average migration time", "RAWIntegriryAgent", "Seconds", gMonitor.OP_MEAN
-        )
-        # gMonitor.registerActivity("TimeInQueue", "Average current wait for migration",
-        #                           "RAWIntegriryAgent", "Minutes", gMonitor.OP_MEAN)
-        gMonitor.registerActivity(
-            "MigrationRate", "Observed migration rate", "RAWIntegriryAgent", "MB/s", gMonitor.OP_MEAN
-        )
-
         # This sets the Default Proxy to used as that defined under
         # /Operations/Shifter/DataManager
         # the shifterProxy option in the Configuration can be used to change this default.
@@ -144,14 +93,14 @@ class RAWIntegrityAgent(AgentModule):
                 successful[lfn] = False
                 continue
             else:
-                self.log.info("%s is copied." % lfn)
+                self.log.info(f"{lfn} is copied.")
                 castorChecksum = seMetadata["Checksum"]
                 onlineChecksum = lfnsMetadata[lfn]["Checksum"]
                 if castorChecksum.lower().lstrip("0") == onlineChecksum.lower().lstrip("0").lstrip("x"):
-                    self.log.info("%s migrated checksum match." % lfn)
+                    self.log.info(f"{lfn} migrated checksum match.")
                     successful[lfn] = True
                 else:
-                    errStr = "Migrated checksum mis-match.", "%s %s %s" % (
+                    errStr = "Migrated checksum mis-match.", "{} {} {}".format(
                         lfn,
                         castorChecksum.lstrip("0"),
                         onlineChecksum.lstrip("0").lstrip("x"),
@@ -188,17 +137,16 @@ class RAWIntegrityAgent(AgentModule):
             if not res["OK"]:
                 errStr = "Failed to obtain physical file metadata."
                 self.log.error(errStr, res["Message"])
-                failedMetadata = dict((lfn, errStr) for lfn in lfnList)
+                failedMetadata = {lfn: errStr for lfn in lfnList}
             else:
                 successfulMetadata = res["Value"]["Successful"]
                 failedMetadata = res["Value"]["Failed"]
 
             if failedMetadata:
-                self.log.info("Failed to obtain physical file metadata for %s files." % len(failedMetadata))
-                gMonitor.addMark("ErrorMetadata", len(failedMetadata))
+                self.log.info(f"Failed to obtain physical file metadata for {len(failedMetadata)} files.")
 
             if successfulMetadata:
-                self.log.info("Obtained physical file metadata for %s files." % len(successfulMetadata))
+                self.log.info(f"Obtained physical file metadata for {len(successfulMetadata)} files.")
 
                 ############################################################
                 #
@@ -207,7 +155,6 @@ class RAWIntegrityAgent(AgentModule):
                 res = self._checkMigrationStatus(successfulMetadata, activeFiles)
                 if not res["OK"]:
                     self.log.error("Error when checking migration status", res)
-                    gMonitor.addMark("BadChecksum", len(successfulMetadata))
                 else:
                     succCompare = res["Value"]["Successful"]
                     failedCompare = res["Value"]["Failed"]
@@ -223,10 +170,8 @@ class RAWIntegrityAgent(AgentModule):
                     filesNewlyCopied.extend(seFilesCopied)
                     filesNotYetCopied.extend(seFilesNotCopied)
 
-                    gMonitor.addMark("BadChecksum", len(failedCompare))
-
-                    self.log.info("%s files newly copied at %s." % (len(seFilesCopied), se))
-                    self.log.info("Found %s checksum mis-matches at %s." % (len(failedCompare), se))
+                    self.log.info(f"{len(seFilesCopied)} files newly copied at {se}.")
+                    self.log.info(f"Found {len(failedCompare)} checksum mis-matches at {se}.")
 
         return filesNewlyCopied, filesNotYetCopied
 
@@ -250,7 +195,7 @@ class RAWIntegrityAgent(AgentModule):
             self.log.info("No files to be registered")
 
         # Update copiedFiles to also contain the newly copied files
-        copiedFiles.update(dict((lfn, allUnmigratedFilesMeta[lfn]) for lfn in filesNewlyCopied))
+        copiedFiles.update({lfn: allUnmigratedFilesMeta[lfn] for lfn in filesNewlyCopied})
 
         successfulRegister = {}
         failedRegister = {}
@@ -258,25 +203,24 @@ class RAWIntegrityAgent(AgentModule):
         # Try to register them by batch
         for lfnChunk in breakListIntoChunks(copiedFiles, 100):
             # Add the metadata
-            lfnDictChuck = dict((lfn, copiedFiles[lfn]) for lfn in lfnChunk)
+            lfnDictChuck = {lfn: copiedFiles[lfn] for lfn in lfnChunk}
             res = self.fileCatalog.addFile(lfnDictChuck)
 
             if not res["OK"]:
                 self.log.error("Completely failed to register some successfully copied file.", res["Message"])
-                failedRegister.update(dict((lfn, res["Message"]) for lfn in lfnDictChuck))
+                failedRegister.update({lfn: res["Message"] for lfn in lfnDictChuck})
             else:
                 successfulRegister.update(res["Value"]["Successful"])
                 failedRegister.update(res["Value"]["Failed"])
 
-        gMonitor.addMark("ErrorRegister", len(failedRegister))
         for lfn, reason in failedRegister.items():
-            self.log.error("Failed to register lfn. Setting to Copied", "%s: %s" % (lfn, reason))
+            self.log.error("Failed to register lfn. Setting to Copied", f"{lfn}: {reason}")
             res = self.rawIntegrityDB.setFileStatus(lfn, "Copied")
             if not res["OK"]:
-                self.log.error("Error setting file status to Copied", "%s: %s" % (lfn, res["Message"]))
+                self.log.error("Error setting file status to Copied", f"{lfn}: {res['Message']}")
 
         for lfn in successfulRegister:
-            self.log.info("Successfully registered %s in the File Catalog." % lfn)
+            self.log.info(f"Successfully registered {lfn} in the File Catalog.")
 
         return successfulRegister
 
@@ -300,7 +244,7 @@ class RAWIntegrityAgent(AgentModule):
             self.log.info("No files to be removed")
 
         # Update registeredFiles to also contain the newly registered files
-        registeredFiles.update(dict((lfn, allUnmigratedFilesMeta[lfn]) for lfn in filesNewlyRegistered))
+        registeredFiles.update({lfn: allUnmigratedFilesMeta[lfn] for lfn in filesNewlyRegistered})
 
         onlineSE = StorageElement("OnlineRunDB")
 
@@ -311,31 +255,22 @@ class RAWIntegrityAgent(AgentModule):
         failedRemove = {}
         if not res["OK"]:
             self.log.error("Completely failed to remove successfully registered files.", res["Message"])
-            failedRemove = dict((lfn, res["Message"]) for lfn in registeredFiles)
+            failedRemove = {lfn: res["Message"] for lfn in registeredFiles}
         else:
             filesNewlyRemoved = res["Value"]["Successful"]
             failedRemove = res["Value"]["Failed"]
 
-        gMonitor.addMark("ErrorRemove", len(failedRemove))
         for lfn, reason in failedRemove.items():
-            self.log.error("Failed to remove lfn. Setting to Registered", "%s: %s" % (lfn, reason))
+            self.log.error("Failed to remove lfn. Setting to Registered", f"{lfn}: {reason}")
             res = self.rawIntegrityDB.setFileStatus(lfn, "Registered")
             if not res["OK"]:
-                self.log.error("Error setting file status to Registered", "%s: %s" % (lfn, res["Message"]))
+                self.log.error("Error setting file status to Registered", f"{lfn}: {res['Message']}")
 
-        now = datetime.datetime.utcnow()
         for lfn in filesNewlyRemoved:
-            self.log.info("Successfully removed %s from the Online storage. Setting it to Done" % lfn)
+            self.log.info(f"Successfully removed {lfn} from the Online storage. Setting it to Done")
             res = self.rawIntegrityDB.setFileStatus(lfn, "Done")
             if not res["OK"]:
-                self.log.error("Error setting file status to Done", "%s: %s" % (lfn, res["Message"]))
-            else:
-                # SubmitTime is ALREADY a datetime since it is declared as such in the DB.
-                submitTime = allUnmigratedFilesMeta[lfn]["SubmitTime"]
-                migrationTime = (now - submitTime).total_seconds()
-                gMonitor.addMark("MigrationTime", migrationTime)
-                fileSizeMB = allUnmigratedFilesMeta[lfn]["Size"] / (1024 * 1024.0)
-                gMonitor.addMark("MigrationRate", fileSizeMB / migrationTime)
+                self.log.error("Error setting file status to Done", f"{lfn}: {res['Message']}")
 
         return filesNewlyRemoved
 
@@ -345,8 +280,6 @@ class RAWIntegrityAgent(AgentModule):
         # Don't use the server certificate otherwise the DFC wont let us write
         gConfigurationData.setOptionInCFG("/DIRAC/Security/UseServerCertificate", "false")
 
-        gMonitor.addMark("Iteration", 1)
-
         ############################################################
         #
         # Obtain the files which have not yet been migrated
@@ -361,7 +294,7 @@ class RAWIntegrityAgent(AgentModule):
         # allUnmigratedFilesMeta contain all the files that are not yet
         # migrated (not copied, not registered, not removed), as well as their metadata
         allUnmigratedFilesMeta = res["Value"]
-        self.log.info("Obtained %s un-migrated files." % len(allUnmigratedFilesMeta))
+        self.log.info(f"Obtained {len(allUnmigratedFilesMeta)} un-migrated files.")
         if not allUnmigratedFilesMeta:
             return S_OK()
 
@@ -382,12 +315,9 @@ class RAWIntegrityAgent(AgentModule):
             elif status == "Registered":
                 registeredFiles[lfn] = lfnMetadata
 
-        gMonitor.addMark("WaitingFiles", len(activeFiles))
         totalSize = 0
         for lfn, fileDict in activeFiles.items():
             totalSize += int(fileDict["Size"])
-            # gMonitor.addMark("TimeInQueue", (fileDict['WaitTime'] / 60))
-        gMonitor.addMark("WaitSize", (totalSize / (1024 * 1024 * 1024.0)))
 
         ############################################################
         #
@@ -423,10 +353,10 @@ class RAWIntegrityAgent(AgentModule):
 
         res = self.rawIntegrityDB.setLastMonitorTime()
         migratedSizeGB = migratedSize / (1024 * 1024 * 1024.0)
-        gMonitor.addMark("TotMigratedSize", migratedSizeGB)
-        gMonitor.addMark("NewlyMigrated", len(filesNewlyRemoved))
-        gMonitor.addMark("TotMigrated", len(filesNewlyRemoved))
-        gMonitor.addMark("FailedMigrated", failedMigrated)
-        gMonitor.addMark("TotFailMigrated", failedMigrated)
+        self.log.info("TotMigratedSize", migratedSizeGB)
+        self.log.info("NewlyMigrated", len(filesNewlyRemoved))
+        self.log.info("TotMigrated", len(filesNewlyRemoved))
+        self.log.info("FailedMigrated", failedMigrated)
+        self.log.info("TotFailMigrated", failedMigrated)
 
         return S_OK()
