@@ -20,7 +20,6 @@ LogUpload operation handler
 # # imports
 import os
 from DIRAC import S_OK, S_ERROR
-from DIRAC.FrameworkSystem.Client.MonitoringClient import gMonitor
 from DIRAC.DataManagementSystem.Agent.RequestOperations.DMSRequestOperationsBase import DMSRequestOperationsBase
 
 
@@ -38,17 +37,7 @@ class LogUpload(DMSRequestOperationsBase):
         :param str csPath: CS path for this handler
         """
         # # base class ctor
-        super(LogUpload, self).__init__(operation=operation, csPath=csPath)
-        # # gMonitor stuff
-        gMonitor.registerActivity(
-            "LogUploadAtt", "Log upload attempted", "RequestExecutingAgent", "Files/min", gMonitor.OP_SUM
-        )
-        gMonitor.registerActivity(
-            "LogUploadOK", "Replications successful", "RequestExecutingAgent", "Files/min", gMonitor.OP_SUM
-        )
-        gMonitor.registerActivity(
-            "LogUploadFail", "Replications failed", "RequestExecutingAgent", "Files/min", gMonitor.OP_SUM
-        )
+        super().__init__(operation=operation, csPath=csPath)
         self.workDirectory = os.environ.get("LOGUPLOAD_CACHE", os.environ.get("AGENT_WORKDIRECTORY", "/tmp/LogUpload"))
 
     def __call__(self):
@@ -57,24 +46,18 @@ class LogUpload(DMSRequestOperationsBase):
 
         if len(self.operation.targetSEList) != 1:
             self.log.error(
-                "wrong value for TargetSE list = %s, should contain only one target!" % self.operation.targetSEList
+                f"wrong value for TargetSE list = {self.operation.targetSEList}, should contain only one target!"
             )
             self.operation.Error = "Wrong parameters: TargetSE should contain only one targetSE"
             for opFile in self.operation:
-
                 opFile.Status = "Failed"
                 opFile.Error = "Wrong parameters: TargetSE should contain only one targetSE"
 
-                gMonitor.addMark("LogUploadAtt", 1)
-                gMonitor.addMark("LogUploadFail", 1)
-
-            return S_ERROR("TargetSE should contain only one target, got %s" % self.operation.targetSEList)
+            return S_ERROR(f"TargetSE should contain only one target, got {self.operation.targetSEList}")
 
         # # check targetSEs for write
         bannedTargets = self.checkSEsRSS()
         if not bannedTargets["OK"]:
-            gMonitor.addMark("LogUploadAtt", 1)
-            gMonitor.addMark("LogUploadFail", 1)
             return bannedTargets
 
         # # get waiting files
@@ -84,17 +67,25 @@ class LogUpload(DMSRequestOperationsBase):
         for opFile in waitingFiles:
             # # get LFN
             lfn = opFile.LFN
-            self.log.info("processing file %s" % lfn)
-            gMonitor.addMark("LogUploadAtt", 1)
+            self.log.info(f"processing file {lfn}")
+
+            # compatibility with the old way of doing failover log with tar files.
+            # Files were uploaded as
+            # LFN: /lhcb/MC/Upgrade/LOG/00162343/0000/00162343_00007130.tar
+            # destination: /lhcb/MC/Upgrade/LOG/00162343/0000/00007130/00162343_00007130.tar
+            # (although being a zip file !)
+            # Now we stick to zip file, and destination should be left empty
+            if os.path.split(lfn) == ".tar":
+                destination = "/".join(lfn.split("/")[0:-1]) + "/" + (os.path.basename(lfn)).split("_")[1].split(".")[0]
+            else:
+                destination = None
 
-            destination = "/".join(lfn.split("/")[0:-1]) + "/" + (os.path.basename(lfn)).split("_")[1].split(".")[0]
             logUpload = self.dm.replicate(
                 lfn, self.operation.targetSEList[0], destPath=destination, localCache=self.workDirectory
             )
             if not logUpload["OK"]:
-                gMonitor.addMark("LogUploadFail", 1)
                 #         self.dataLoggingClient().addFileRecord( lfn, "LogUploadFail", targetSE, "", "LogUpload" )
-                self.log.error("completely failed to upload log file: %s" % logUpload["Message"])
+                self.log.error(f"completely failed to upload log file: {logUpload['Message']}")
                 opFile.Error = str(logUpload["Message"])
                 opFile.Attempt += 1
                 self.operation.Error = opFile.Error
@@ -103,9 +94,8 @@ class LogUpload(DMSRequestOperationsBase):
                 continue
 
             if lfn in logUpload["Value"]:
-                gMonitor.addMark("LogUploadOK", 1)
                 #         self.dataLoggingClient().addFileRecord( lfn, "LogUpload", targetSE, "", "LogUpload" )
                 opFile.Status = "Done"
-                self.log.info("Uploaded %s to %s" % (lfn, self.operation.targetSEList[0]))
+                self.log.info(f"Uploaded {lfn} to {self.operation.targetSEList[0]}")
 
         return S_OK()
