@@ -59,7 +59,7 @@ def _fillMetadata(dictToFill, metadataValue):
         "EventType",
         "Visibility",
     )
-    if isinstance(metadataValue, six.string_types):
+    if isinstance(metadataValue, str):
         for k in keyList:
             dictToFill[k] = metadataValue
     elif isinstance(metadataValue, dict):
@@ -79,10 +79,10 @@ class StorageHistoryAgent(AgentModule):
             self.__stDB = StorageUsageClient()
         self.__workDirectory = self.am_getOption("WorkDirectory")
         mkDir(self.__workDirectory)
-        self.log.info("Working directory is %s" % self.__workDirectory)
+        self.log.info(f"Working directory is {self.__workDirectory}")
 
         self.__ignoreDirsList = self.am_getOption("Ignore", [])
-        self.log.info("List of directories to ignore for the DataStorage accounting: %s " % self.__ignoreDirsList)
+        self.log.info(f"List of directories to ignore for the DataStorage accounting: {self.__ignoreDirsList} ")
 
         self.__bkClient = BookkeepingClient()
         self.__dataUsageClient = DataUsageClient()
@@ -114,12 +114,12 @@ class StorageHistoryAgent(AgentModule):
         if not result["OK"]:
             return result
         userCatalogData = result["Value"]
-        self.log.notice("Got summary for %s users" % (len(userCatalogData)))
+        self.log.notice(f"Got summary for {len(userCatalogData)} users")
         result = self.__stDB.getUserSummaryPerSE()
         if not result["OK"]:
             return result
         userSEData = result["Value"]
-        self.log.notice("Got SE summary for %s users" % (len(userSEData)))
+        self.log.notice(f"Got SE summary for {len(userSEData)} users")
 
         now = datetime.datetime.utcnow()
         numRows = 0
@@ -147,13 +147,13 @@ class StorageHistoryAgent(AgentModule):
                 " User %s is using %.2f GiB (%s files)"
                 % (user, userCatalogData[user]["Size"] / (1024.0**3), userCatalogData[user]["Files"])
             )
-        self.log.notice("Sending %s records to accounting for user storage" % numRows)
+        self.log.notice(f"Sending {numRows} records to accounting for user storage")
         res = gDataStoreClient.commit()
         if not res["OK"]:
-            self.log.notice("ERROR: committing UserStorage records: %s " % res)
+            self.log.notice(f"ERROR: committing UserStorage records: {res} ")
             return S_ERROR(res)
         else:
-            self.log.notice("%s records for UserStorage type successfully committed" % numRows)
+            self.log.notice(f"{numRows} records for UserStorage type successfully committed")
 
     def __getTopDirUsage(self, dirToScan, topDirLogicalUsage):
         """
@@ -186,7 +186,7 @@ class StorageHistoryAgent(AgentModule):
                     topDirLogicalUsage[topDir]["Files"] += logicalUsage[row]["Files"]
                     topDirLogicalUsage[topDir]["Size"] += logicalUsage[row]["Size"]
             self.log.verbose(
-                "After scan of %s, total of %s: " % (directory, topDir),
+                f"After scan of {directory}, total of {topDir}: ",
                 "size: %.4f TB  files: %d"
                 % (
                     convertSizeUnits(topDirLogicalUsage[topDir]["Size"], "B", "TB"),
@@ -229,17 +229,15 @@ class StorageHistoryAgent(AgentModule):
             if not result["OK"]:
                 return result
             seData[directory] = result["Value"]
-            self.log.notice("Got SE summary for %s directories " % (len(seData)))
-            self.log.debug("SEData: %s" % seData)
+            self.log.notice(f"Got SE summary for {len(seData)} directories ")
+            self.log.debug(f"SEData: {seData}")
         # loop on top level directories to send the accounting records
         numRows = 0
         now = datetime.datetime.utcnow()
         for directory in seData:
-            self.log.debug("dir: %s SEData: %s " % (directory, seData[directory]))
+            self.log.debug(f"dir: {directory} SEData: {seData[directory]} ")
             if directory not in topDirLogicalUsage:
-                self.log.error(
-                    "Dir %s is in the summary per SE, but it is not in the logical files summary!" % directory
-                )
+                self.log.error(f"Dir {directory} is in the summary per SE, but it is not in the logical files summary!")
                 continue
             for se in sorted(seData[directory]):
                 storageRecord = Storage()
@@ -252,12 +250,12 @@ class StorageHistoryAgent(AgentModule):
                 try:
                     physicalFiles = seData[directory][se]["Files"]
                 except Exception:
-                    self.log.error("WARNING! no files replicas for directory %s on SE %s" % (directory, se))
+                    self.log.error(f"WARNING! no files replicas for directory {directory} on SE {se}")
                     physicalFiles = 0
                 try:
                     physicalSize = seData[directory][se]["Size"]
                 except Exception:
-                    self.log.error("WARNING! no size for replicas for directory %s on SE %s" % (directory, se))
+                    self.log.error(f"WARNING! no size for replicas for directory {directory} on SE {se}")
                     physicalSize = 0
                 storageRecord.setValueByKey("PhysicalFiles", physicalFiles)
                 storageRecord.setValueByKey("PhysicalSize", physicalSize)
@@ -268,13 +266,13 @@ class StorageHistoryAgent(AgentModule):
                     % (directory, se, convertSizeUnits(physicalSize, "B", "TB"), physicalFiles)
                 )
 
-        self.log.notice("Sending %s records to accounting for top level directories storage" % numRows)
+        self.log.notice(f"Sending {numRows} records to accounting for top level directories storage")
         res = gDataStoreClient.commit()
         if not res["OK"]:
-            self.log.notice("ERROR: committing Storage records: %s " % res)
+            self.log.notice(f"ERROR: committing Storage records: {res} ")
             return S_ERROR(res)
         else:
-            self.log.notice("%s records for Storage type successfully committed" % numRows)
+            self.log.notice(f"{numRows} records for Storage type successfully committed")
 
     def bkPathAccounting(self):
         """
@@ -307,17 +305,17 @@ class StorageHistoryAgent(AgentModule):
         # loop on all directories  to get the bkk metadata
         for dirLfn, fullDirectory in self.dirDict.items():
             if dirLfn not in fullDirectory:
-                self.log.error("ERROR: fullDirectory should include the dirname: %s %s " % (fullDirectory, dirLfn))
+                self.log.error(f"ERROR: fullDirectory should include the dirname: {fullDirectory} {dirLfn} ")
                 continue
-            self.log.verbose("Processing directory %s " % dirLfn)
+            self.log.verbose(f"Processing directory {dirLfn} ")
             if dirLfn not in self.pfnUsage:
-                self.log.error("ERROR: directory does not have PFN usage %s " % dirLfn)
+                self.log.error(f"ERROR: directory does not have PFN usage {dirLfn} ")
                 continue
-            self.log.verbose("PFN usage: %s " % self.pfnUsage[dirLfn])
+            self.log.verbose(f"PFN usage: {self.pfnUsage[dirLfn]} ")
             if dirLfn not in self.lfnUsage:
-                self.log.error("ERROR: directory does not have LFN usage %s " % dirLfn)
+                self.log.error(f"ERROR: directory does not have LFN usage {dirLfn} ")
                 continue
-            self.log.verbose("LFN usage: %s " % self.lfnUsage[dirLfn])
+            self.log.verbose(f"LFN usage: {self.lfnUsage[dirLfn]} ")
 
             # for DEBUGGING:
             for se in self.pfnUsage[dirLfn]:
@@ -328,11 +326,11 @@ class StorageHistoryAgent(AgentModule):
             # get metadata for this directory
             metaForDir = metaForList.get(fullDirectory, {})
             if not metaForDir:
-                self.log.warn("Metadata not available for directory %s" % fullDirectory)
+                self.log.warn(f"Metadata not available for directory {fullDirectory}")
                 continue
 
             # Fill in the accounting record
-            self.log.info("Fill the record for %s and metadata: %s " % (dirLfn, metaForDir))
+            self.log.info(f"Fill the record for {dirLfn} and metadata: {metaForDir} ")
             res = self.fillAndSendAccountingRecord(dirLfn, metaForDir, now)
             if not res["OK"]:
                 return res
@@ -349,7 +347,7 @@ class StorageHistoryAgent(AgentModule):
             result = self.__stDB.purgeOutdatedEntries("/lhcb/user", self.am_getOption("OutdatedSeconds", 86400 * 10))
             if not result["OK"]:
                 return result
-            self.log.notice("Purged %s outdated records" % result["Value"])
+            self.log.notice(f"Purged {result['Value']} outdated records")
 
         # User accounting (per user and SE)
         self.userStorageAccounting()
@@ -360,7 +358,7 @@ class StorageHistoryAgent(AgentModule):
 
         self.log.notice("-------------------------------------------------------------------------------------\n")
         self.log.notice("------ End of cycle report for DataStorage accounting--------------------------------\n")
-        self.log.notice("Total directories found in FC:  %d " % len(self.dirDict))
+        self.log.notice(f"Total directories found in FC:  {len(self.dirDict)} ")
         totalCallsToStorageUsage = self.callsToGetSummary + self.callsToDirectorySummary
         self.log.notice("Total calls to StorageUsage: %d , took: %d s " % (totalCallsToStorageUsage, self.genTotalTime))
         totalCallsToBkk = self.callsToBkkgetDirectoryMetadata + self.callsToBkkGetEvtType
@@ -370,12 +368,12 @@ class StorageHistoryAgent(AgentModule):
             % (totalCallsToBkk, self.callsToBkkgetDirectoryMetadata, self.callsToBkkGetEvtType)
         )
         self.log.notice("Total records sent to accounting for DataStorage:  %d " % self.totalRecords)
-        self.log.notice("Directories not found in Bookkeeping: %d " % (len(self.directoriesNotInBkk)))
+        self.log.notice(f"Directories not found in Bookkeeping: {len(self.directoriesNotInBkk)} ")
         fileName = os.path.join(self.__workDirectory, "directoriesNotInBkk.txt")
-        self.log.notice("written to file: %s " % fileName)
+        self.log.notice(f"written to file: {fileName} ")
         fd = open(fileName, "w")
         for dd in self.directoriesNotInBkk:
-            fd.write("%s\n" % dd)
+            fd.write(f"{dd}\n")
         fd.close()
         # for DEBUG only
         self.log.info("Summary of StorageUsage: files size ")
@@ -415,21 +413,21 @@ class StorageHistoryAgent(AgentModule):
                 notFound.append(dirName)
         notInCache = []
         if notFound:
-            self.log.info("Memory metadata cache missed for %d directories" % len(notFound))
-            self.log.verbose("call getDirMetadata for (first 10): %s " % str(notFound[0:10]))
+            self.log.info(f"Memory metadata cache missed for {len(notFound)} directories")
+            self.log.verbose(f"call getDirMetadata for (first 10): {str(notFound[0:10])} ")
             for dirChunk in breakListIntoChunks(notFound, 10000):
                 self.callsToDudbForMetadata += 1
                 res = self.__dataUsageClient.getDirMetadata(
                     dirChunk
                 )  # this could be a bulk query for a list of directories
                 if not res["OK"]:
-                    self.log.error("Error retrieving %d directories meta-data %s " % (len(dirChunk), res["Message"]))
+                    self.log.error(f"Error retrieving {len(dirChunk)} directories meta-data {res['Message']} ")
                     # this usually happens when directories are removed from FC between the StorageUsageDB dump and this call,
                     # if the Db is refreshed exactly in this time interval. Not really a problem.
                     # 3 just a try ##############################################3
                     notInCache += dirChunk
                     continue
-                self.log.verbose("getDirMetadata returned: %s " % str(res["Value"]))
+                self.log.verbose(f"getDirMetadata returned: {str(res['Value'])} ")
                 for dirName in dirChunk:
                     # Compatibility with old (list for single file) and new (dictionary) service
                     if isinstance(res["Value"], type({})):
@@ -458,7 +456,7 @@ class StorageHistoryAgent(AgentModule):
             if notInCache:
                 cachedFromBK = []
                 self.log.info(
-                    "Directory metadata cache missed for %d directories => query BK and cache" % len(notInCache)
+                    f"Directory metadata cache missed for {len(notInCache)} directories => query BK and cache"
                 )
                 for dirChunk in breakListIntoChunks(notInCache, 200):
                     self.callsToBkkgetDirectoryMetadata += 1
@@ -471,7 +469,7 @@ class StorageHistoryAgent(AgentModule):
                             _fillMetadata(metaForDir, "FailedBkkQuery")
                     else:
                         bkMetadata = res["Value"]
-                        self.log.debug("Successfully queried Bookkeeping, result: %s " % bkMetadata)
+                        self.log.debug(f"Successfully queried Bookkeeping, result: {bkMetadata} ")
                         for dirName in dirChunk:
                             metaForDir = metaForList[dirName]
                             # BK returns a list of metadata, chose the first one...
@@ -482,21 +480,19 @@ class StorageHistoryAgent(AgentModule):
                                 )
                                 # All is OK, directory found
                                 _fillMetadata(metaForDir, metadata)
-                                self.log.verbose("Cache entry %s in DirMetadata table.." % dirName)
+                                self.log.verbose(f"Cache entry {dirName} in DirMetadata table..")
                                 resInsert = self.__dataUsageClient.insertToDirMetadata({dirName: metadata})
                                 if not resInsert["OK"]:
                                     self.log.error(
-                                        "Failed to cache metadata:", "%s for dir %s" % (resInsert["Message"], dirName)
+                                        "Failed to cache metadata:", f"{resInsert['Message']} for dir {dirName}"
                                     )
                                 else:
                                     cachedFromBK.append(dirName)
-                                    self.log.verbose(
-                                        "Successfully cached metadata for %s : %s" % (dirName, str(metadata))
-                                    )
-                                    self.log.debug("result: %s " % str(resInsert))
+                                    self.log.verbose(f"Successfully cached metadata for {dirName} : {str(metadata)}")
+                                    self.log.debug(f"result: {str(resInsert)} ")
                             else:
                                 # Directory not found
-                                self.log.verbose("Directory %s not registered in Bookkeeping!" % dirName)
+                                self.log.verbose(f"Directory {dirName} not registered in Bookkeeping!")
                                 _fillMetadata(metaForDir, "notInBkk")
                                 failedBK.append(dirName)
                                 self.directoriesNotInBkk.append(dirName)
@@ -507,9 +503,9 @@ class StorageHistoryAgent(AgentModule):
                                 ("ConditionDescription", "Conditions"),
                             ):
                                 metaForDir[accName] = metaForDir.pop(bkName, "na")
-                self.log.info("Successfully cached %d directories from BK" % len(cachedFromBK))
+                self.log.info(f"Successfully cached {len(cachedFromBK)} directories from BK")
                 if self.directoriesNotInBkk:
-                    self.log.warn("%d directories not found in BK" % len(self.directoriesNotInBkk))
+                    self.log.warn(f"{len(self.directoriesNotInBkk)} directories not found in BK")
 
             # cache locally the metadata
             for dirName in [dn for dn in notFound if dn not in failedBK]:
@@ -518,18 +514,18 @@ class StorageHistoryAgent(AgentModule):
                 metaForDir["EventType"] = self.__getEventTypeDescription(metaForDir.pop("EventType", "na"))
                 self.cachedMetadata[dirName] = metaForDir.copy()
         else:
-            self.log.info("Memory metadata cache hit for %d directories" % len(dirList))
+            self.log.info(f"Memory metadata cache hit for {len(dirList)} directories")
         return metaForList
 
     def __commitRecords(self):
         if self.recordsToCommit:
             res = gDataStoreClient.commit()
             if not res["OK"]:
-                self.log.error("Accounting ERROR: commit returned %s" % res)
+                self.log.error(f"Accounting ERROR: commit returned {res}")
             else:
                 self.log.notice("%d records committed " % self.recordsToCommit)
                 self.recordsToCommit = 0
-                self.log.notice("commit for DataStorage returned: %s" % res)
+                self.log.notice(f"commit for DataStorage returned: {res}")
 
     def generateStorageUsagePerDir(self):
         """
@@ -543,7 +539,7 @@ class StorageHistoryAgent(AgentModule):
         if not res["OK"]:
             return S_ERROR()
         totalDirList = res["Value"]
-        self.log.info("Total directories retrieved from StorageUsageDB: %d " % len(totalDirList))
+        self.log.info(f"Total directories retrieved from StorageUsageDB: {len(totalDirList)} ")
         # select only terminal directories (directories without sub-directories)
         # mc directory structure: /lhcb/MC/[year]/[file type]/[prod]/0000/ => len = 7
         # raw data:               /lhcb/data/2011/RAW/FULL/LHCb/COLLISION11/99983
@@ -553,17 +549,17 @@ class StorageHistoryAgent(AgentModule):
         # data:                   /lhcb/LHCb/Collision12/ICHEP.DST/00017399/0000/
         self.dirDict = {}
         ignoredDirectories = dict.fromkeys(self.__ignoreDirsList, 0)
-        self.log.info("Directories to be ignored: %s " % str(sorted(ignoredDirectories)))
+        self.log.info(f"Directories to be ignored: {str(sorted(ignoredDirectories))} ")
         for dirItem in totalDirList:
             # make sure that last character is a '/'
             dirItem = _standardDirectory(dirItem)
             splitDir = dirItem.split(os.path.sep)
             if len(splitDir) < 4:  # avoid picking up intermediate directories which don't contain files, like /lhcb/
-                self.log.warn("Directory %s skipped, as top directory" % dirItem)
+                self.log.warn(f"Directory {dirItem} skipped, as top directory")
                 continue
             secDir = splitDir[2]
             if secDir in ignoredDirectories:
-                self.log.verbose("Directory to be ignored, skipped: %s " % dirItem)
+                self.log.verbose(f"Directory to be ignored, skipped: {dirItem} ")
                 ignoredDirectories[secDir] += 1
                 continue
             # for each type of directory (MC, reconstructed data and raw data) check the format,
@@ -580,12 +576,12 @@ class StorageHistoryAgent(AgentModule):
             try:
                 # RAW data directories have a special format, see above
                 if splitDir[-6] == "RAW":
-                    self.log.verbose("RAW DATA directory: %s" % splitDir)
+                    self.log.verbose(f"RAW DATA directory: {splitDir}")
                     directory = dirItem
                     fullDirectory = directory
                 else:
                     # These are production directories, see above for the format
-                    self.log.verbose("MC or reconstructed data directory: %s" % splitDir)
+                    self.log.verbose(f"MC or reconstructed data directory: {splitDir}")
                     # HIST directories do not have a "suffix" (i.e. all in the same directory)!
                     if splitDir[-3] == "HIST":
                         directory = dirItem
@@ -596,9 +592,9 @@ class StorageHistoryAgent(AgentModule):
                         fullDirectory = dirItem
                 # Keep the link between the accounting directory and the full directory name
                 self.dirDict.setdefault(directory, fullDirectory)
-                self.log.verbose("Directory contains production files: %s " % directory)
+                self.log.verbose(f"Directory contains production files: {directory} ")
             except Exception:
-                self.log.warn("The directory has unexpected format: %s " % dirItem)
+                self.log.warn(f"The directory has unexpected format: {dirItem} ")
 
         self.lfnUsage = defaultdict(lambda: {"LfnSize": 0, "LfnFiles": 0})
         self.pfnUsage = {}
@@ -610,11 +606,11 @@ class StorageHistoryAgent(AgentModule):
             totalDiscardedDirs += ignoredDirectories[dd]
         self.log.info("Total discarded directories: %d " % totalDiscardedDirs)
 
-        self.log.info("Retrieved %d dirs from StorageUsageDB containing prod files" % len(self.dirDict))
+        self.log.info(f"Retrieved {len(self.dirDict)} dirs from StorageUsageDB containing prod files")
         self.log.info("Getting the number of files and size from StorageUsage service")
 
         for directory in self.dirDict:
-            self.log.verbose("Get storage usage for directory %s " % directory)
+            self.log.verbose(f"Get storage usage for directory {directory} ")
             res = self.__stDB.getDirectorySummaryPerSE(directory)
             self.callsToDirectorySummary += 1
             if not res["OK"]:
@@ -623,7 +619,7 @@ class StorageHistoryAgent(AgentModule):
             # save the PFN usage per SE in a dictionary
             self.pfnUsage.setdefault(directory, res["Value"])
 
-            self.log.verbose("Get logical usage for directory %s " % directory)
+            self.log.verbose(f"Get logical usage for directory {directory} ")
             # This returns the number of files and size for the directory and all its subdirectories
             res = self.__stDB.getSummary(directory)
             self.callsToGetSummary += 1
@@ -631,14 +627,14 @@ class StorageHistoryAgent(AgentModule):
                 self.log.error("Cannot retrieve LFN usage", res["Message"])
                 continue
             if not res["Value"]:
-                self.log.error("getSummary returned empty value", "for %s: %s" % (directory, str(res)))
+                self.log.error("getSummary returned empty value", f"for {directory}: {str(res)}")
                 continue
             # Sum up all subdirectories
             for dirInfo in res["Value"].values():  # can be an iterator
                 self.lfnUsage[directory]["LfnSize"] += dirInfo["Size"]
                 self.lfnUsage[directory]["LfnFiles"] += dirInfo["Files"]
-            self.log.verbose("PFN usage: %s" % self.pfnUsage[directory])
-            self.log.verbose("LFN usage: %s" % self.lfnUsage[directory])
+            self.log.verbose(f"PFN usage: {self.pfnUsage[directory]}")
+            self.log.verbose(f"LFN usage: {self.lfnUsage[directory]}")
 
         end = time.time()
         self.genTotalTime = end - start
@@ -654,17 +650,17 @@ class StorageHistoryAgent(AgentModule):
             pass
         # check that the event type description is in the cached dictionary, and otherwise query the Bkk
         if eventType not in self.eventTypeDescription:
-            self.log.notice("Event type description not available for eventTypeID %s, getting from Bkk" % eventType)
+            self.log.notice(f"Event type description not available for eventTypeID {eventType}, getting from Bkk")
             res = self.__bkClient.getAvailableEventTypes()
             self.callsToBkkGetEvtType += 1
             if not res["OK"]:
                 self.log.error("Error querying the Bkk:", res["Message"])
             else:
                 self.eventTypeDescription.update(dict(res["Value"]))
-            self.log.verbose("Updated  self.eventTypeDescription dict: %s " % str(self.eventTypeDescription))
+            self.log.verbose(f"Updated  self.eventTypeDescription dict: {str(self.eventTypeDescription)} ")
             # If still not found, log it!
             if eventType not in self.eventTypeDescription:
-                self.log.error("EventType %s is not in cached dictionary" % str(eventType))
+                self.log.error(f"EventType {str(eventType)} is not in cached dictionary")
 
         return self.eventTypeDescription.get(eventType, "na")
 
@@ -684,7 +680,7 @@ class StorageHistoryAgent(AgentModule):
         self.log.verbose("\tlfnFiles: %d lfnSize: %d " % (logicalFiles, logicalSize))
 
         for se in self.pfnUsage[lfnDir]:
-            self.log.verbose("Filling accounting record for se %s" % se)
+            self.log.verbose(f"Filling accounting record for se {se}")
             physicalSize = self.pfnUsage[lfnDir][se]["Size"]
             physicalFiles = self.pfnUsage[lfnDir][se]["Files"]
 
@@ -698,8 +694,8 @@ class StorageHistoryAgent(AgentModule):
             # addRegister is NOT making a copy, therefore all records are otherwise overwritten
             res = gDataStoreClient.addRegister(copy.deepcopy(dataRecord))
             if not res["OK"]:
-                self.log.error("addRegister returned: %s" % res)
-                return S_ERROR("addRegister returned: %s" % res)
+                self.log.error(f"addRegister returned: {res}")
+                return S_ERROR(f"addRegister returned: {res}")
             # Reset logical information to zero in order to send it only once!
             dataRecord.setValueByKey("LogicalSize", 0)
             dataRecord.setValueByKey("LogicalFiles", 0)
