@@ -17,6 +17,7 @@
   determine storage usage.
 """
 # # imports
+import datetime
 import time
 import random
 import os
@@ -30,11 +31,10 @@ from DIRAC.ConfigurationSystem.Client.Helpers import Registry
 from DIRAC.Core.Utilities.DirectoryExplorer import DirectoryExplorer
 from DIRAC.Core.Utilities.File import mkDir
 from DIRAC.FrameworkSystem.Client.ProxyManagerClient import gProxyManager
-from DIRAC.FrameworkSystem.Client.MonitoringClient import gMonitor
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 from DIRAC.Core.Utilities.ReturnValues import returnSingleResult
 from DIRAC.Core.Utilities import List
-from DIRAC.Core.Utilities.Time import timeInterval, dateTime, week
+from DIRAC.Core.Utilities.TimeUtilities import timeInterval, week
 from DIRAC.Core.Utilities.DictCache import DictCache
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
@@ -112,7 +112,7 @@ class StorageUsageAgent(AgentModule):
 
         if self.enableStartupSleep:
             rndSleep = random.randint(1, self.pollingTime)
-            self.log.info("Sleeping for %s seconds" % rndSleep)
+            self.log.info(f"Sleeping for {rndSleep} seconds")
             time.sleep(rndSleep)
 
         # This sets the Default Proxy to used as that defined under
@@ -126,25 +126,23 @@ class StorageUsageAgent(AgentModule):
         """dump replicas list to files."""
         self.replicaListLock.acquire()
         try:
-            self.log.info("Dumping replicas for %s dirs" % len(dirPathList))
+            self.log.info(f"Dumping replicas for {len(dirPathList)} dirs")
             result = self.catalog.getDirectoryReplicas(dirPathList)
             if not result["OK"]:
-                self.log.error("Could not get directory replicas", "%s -> %s" % (dirPathList, result["Message"]))
+                self.log.error("Could not get directory replicas", f"{dirPathList} -> {result['Message']}")
                 return result
             resData = result["Value"]
             filesOpened = {}
             for dirPath in dirPathList:
                 if dirPath in result["Value"]["Failed"]:
-                    self.log.error(
-                        "Could not get directory replicas", "%s -> %s" % (dirPath, resData["Failed"][dirPath])
-                    )
+                    self.log.error("Could not get directory replicas", f"{dirPath} -> {resData['Failed'][dirPath]}")
                     continue
                 dirData = resData["Successful"][dirPath]
                 for lfn in dirData:
                     for seName in dirData[lfn]:
                         if seName not in filesOpened:
                             filePath = os.path.join(
-                                self.__replicaListFilesDir, "replicas.%s.%s.filling" % (seName, self.__baseDirLabel)
+                                self.__replicaListFilesDir, f"replicas.{seName}.{self.__baseDirLabel}.filling"
                             )
                             # Check if file is opened and if not open it
                             if seName not in filesOpened:
@@ -154,7 +152,7 @@ class StorageUsageAgent(AgentModule):
                                 else:
                                     filesOpened[seName] = open(filePath, "a")
                         # seName file is opened. Write
-                        filesOpened[seName].write("%s -> %s\n" % (lfn, dirData[lfn][seName]))
+                        filesOpened[seName].write(f"{lfn} -> {dirData[lfn][seName]}\n")
             # Close the files
             for seName in filesOpened:
                 filesOpened[seName].close()
@@ -167,7 +165,7 @@ class StorageUsageAgent(AgentModule):
         self.__replicaFilesUsed = set()
         self.__replicaListFilesDir = os.path.join(self.am_getOption("WorkDirectory"), "replicaLists")
         mkDir(self.__replicaListFilesDir)
-        self.log.info("Replica Lists directory is %s" % self.__replicaListFilesDir)
+        self.log.info(f"Replica Lists directory is {self.__replicaListFilesDir}")
 
     def __replicaListFilesDone(self):
         """rotate replicas list files."""
@@ -185,7 +183,7 @@ class StorageUsageAgent(AgentModule):
             for fileName in os.listdir(self.__replicaListFilesDir):
                 match = current.match(fileName)
                 if match:
-                    newFileName = "replicas.%s.%s.old" % (match.group(1), self.__baseDirLabel)
+                    newFileName = f"replicas.{match.group(1)}.{self.__baseDirLabel}.old"
                     self.log.info(
                         "Moving \n %s\n to \n %s"
                         % (
@@ -201,7 +199,7 @@ class StorageUsageAgent(AgentModule):
             for fileName in os.listdir(self.__replicaListFilesDir):
                 match = filling.match(fileName)
                 if match:
-                    newFileName = "replicas.%s.%s" % (match.group(1), self.__baseDirLabel)
+                    newFileName = f"replicas.{match.group(1)}.{self.__baseDirLabel}"
                     self.log.info(
                         "Moving \n %s\n to \n %s"
                         % (
@@ -226,33 +224,12 @@ class StorageUsageAgent(AgentModule):
             self.log.notice("============================================================")
             self.log.notice("%-40s %20s %20s" % ("Storage Element", "Number of files", "Total size"))
 
-            for se in sorted(res["Value"]):
-                site = se.split("_")[0].split("-")[0]
-                gMonitor.registerActivity(
-                    "%s-used" % se,
-                    "%s usage" % se,
-                    "StorageUsage/%s usage" % site,
-                    "",
-                    gMonitor.OP_MEAN,
-                    bucketLength=600,
-                )
-                gMonitor.registerActivity(
-                    "%s-files" % se,
-                    "%s files" % se,
-                    "StorageUsage/%s files" % site,
-                    "Files",
-                    gMonitor.OP_MEAN,
-                    bucketLength=600,
-                )
-
             time.sleep(2)
 
             for se in sorted(res["Value"]):
                 usage = res["Value"][se]["Size"]
                 files = res["Value"][se]["Files"]
                 self.log.notice("%-40s %20s %20s" % (se, str(files), str(usage)))
-                gMonitor.addMark("%s-used" % se, usage)
-                gMonitor.addMark("%s-files" % se, files)
 
     def execute(self):
         """execution in one cycle."""
@@ -273,7 +250,7 @@ class StorageUsageAgent(AgentModule):
         self.__printSummary()
 
         self.__dirExplorer.addDir(self.__baseDir)
-        self.log.notice("Initiating with %s as base directory." % self.__baseDir)
+        self.log.notice(f"Initiating with {self.__baseDir} as base directory.")
         # Loop over all the directories and sub-directories
         totalIterTime = 0.0
         numIterations = 0.0
@@ -285,8 +262,8 @@ class StorageUsageAgent(AgentModule):
             iterTime = time.time() - startT
             totalIterTime += iterTime
             numIterations += len(d2E)
-            self.log.verbose("Query took %.2f seconds for %s dirs" % (iterTime, len(d2E)))
-        self.log.verbose("Average query time: %2.f secs/dir" % (totalIterTime / numIterations))
+            self.log.verbose(f"Query took {iterTime:.2f} seconds for {len(d2E)} dirs")
+        self.log.verbose(f"Average query time: {totalIterTime / numIterations:.2f} secs/dir")
 
         # Publish remaining directories
         self.__publishData(background=False)
@@ -303,14 +280,14 @@ class StorageUsageAgent(AgentModule):
             result = self.storageUsage.purgeOutdatedEntries(self.__baseDir, int(outdatedSeconds), self.__ignoreDirsList)
             if not result["OK"]:
                 return result
-            self.log.notice("Purged %s outdated records" % result["Value"])
+            self.log.notice(f"Purged {result['Value']} outdated records")
         return S_OK()
 
     def __exploreDirList(self, dirList):
         """collect directory size for directory in :dirList:"""
         # Normalise dirList first
         dirList = [os.path.realpath(d) for d in dirList]
-        self.log.notice("Retrieving info for %s dirs" % len(dirList))
+        self.log.notice(f"Retrieving info for {len(dirList)} dirs")
         # For top directories, no files anyway, hence no need to get full size
         dirContents = {}
         failed = {}
@@ -349,9 +326,11 @@ class StorageUsageAgent(AgentModule):
             error = str(failed[dirPath])
             errorReason.setdefault(error, []).append(dirPath)
         for error in errorReason:
-            self.log.error("Failed to get directory info", "- %s for:\n\t%s" % (error, "\n\t".join(errorReason[error])))
+            self.log.error(
+                "Failed to get directory info", "- {} for:\n\t{}".format(error, "\n\t".join(errorReason[error]))
+            )
         self.log.info(
-            "Time to retrieve size of %d directories: %.1f seconds" % (len(dirListSize), time.time() - startTime1)
+            f"Time to retrieve size of {len(dirListSize)} directories: {time.time() - startTime1:.1f} seconds"
         )
         for dirPath in [d for d in dirList if d not in failed]:
             metadata = successfull.get(dirPath, {})
@@ -389,7 +368,7 @@ class StorageUsageAgent(AgentModule):
         errorReason = {}
         for subDir in subDirs:
             self.__directoryOwners.setdefault(subDir, (subDirs[subDir]["Owner"], subDirs[subDir]["OwnerGroup"]))
-            subDirs[subDir] = subDirs[subDir].get("CreationTime", dateTime())
+            subDirs[subDir] = subDirs[subDir].get("CreationTime", datetime.datetime.utcnow())
             if dirUsage:
                 # This part here is for removing the recursivity introduced by the DFC
                 args = [subDir]
@@ -418,13 +397,15 @@ class StorageUsageAgent(AgentModule):
                             dirUsage[se]["Files"] -= seUsage[se]["Files"]
                             dirUsage[se]["Size"] -= seUsage[se]["Size"]
         for error in errorReason:
-            self.log.error("Failed to get directory info", "- %s for:\n\t%s" % (error, "\n\t".join(errorReason[error])))
+            self.log.error(
+                "Failed to get directory info", "- {} for:\n\t{}".format(error, "\n\t".join(errorReason[error]))
+            )
         for se, usage in list(dirUsage.items()):
             # Both info should be 0 or #0
             if not usage["Files"] and not usage["Size"]:
                 dirUsage.pop(se)
             elif not usage["Files"] * usage["Size"]:
-                self.log.error("Directory inconsistent", "%s @ %s: %s" % (dirPath, se, str(usage)))
+                self.log.error("Directory inconsistent", f"{dirPath} @ {se}: {str(usage)}")
         return self.__processDir(dirPath, dirMetadata)
 
     def __processDir(self, dirPath, dirMetadata):
@@ -435,15 +416,15 @@ class StorageUsageAgent(AgentModule):
         # FIXME: Until we understand while closed dirs are not working...
         ##############################
         closedDirs = []
-        prStr = "%s: found %s sub-directories" % (dirPath, len(subDirs) if subDirs else "no")
+        prStr = f"{dirPath}: found {len(subDirs) if subDirs else 'no'} sub-directories"
         if closedDirs:
-            prStr += ", %s are closed (ignored)" % len(closedDirs)
+            prStr += f", {len(closedDirs)} are closed (ignored)"
         for rmDir in closedDirs + self.__ignoreDirsList:
             subDirs.pop(rmDir, None)
         numberOfFiles = int(dirMetadata["Files"])
         totalSize = int(dirMetadata["TotalSize"])
         if numberOfFiles:
-            prStr += " and %s files (%s bytes)" % (numberOfFiles, totalSize)
+            prStr += f" and {numberOfFiles} files ({totalSize} bytes)"
         else:
             prStr += " and no files"
         self.log.notice(prStr)
@@ -465,7 +446,7 @@ class StorageUsageAgent(AgentModule):
                 return
         # We don't need the cached information about owner
         self.__directoryOwners.pop(dirPath, None)
-        rightNow = dateTime()
+        rightNow = datetime.datetime.utcnow()
         chosenDirs = [
             subDir
             for subDir in subDirs
@@ -488,7 +469,7 @@ class StorageUsageAgent(AgentModule):
             ownerRole = result["Value"]["OwnerRole"]
             ownerDN = result["Value"]["OwnerDN"]
             if ownerRole[0] != "/":
-                ownerRole = "/%s" % ownerRole
+                ownerRole = f"/{ownerRole}"
             cacheKey = (ownerDN, ownerRole)
             ownerName = "unknown"
             byGroup = False
@@ -526,7 +507,7 @@ class StorageUsageAgent(AgentModule):
             else:
                 result = gProxyManager.downloadProxy(ownerDN, ownerGroup, limited=False)
             if not result["OK"]:
-                downErrors.append("%s : %s" % (cacheKey, result["Message"]))
+                downErrors.append(f"{cacheKey} : {result['Message']}")
                 continue
             userProxy = result["Value"]
             secsLeft = max(0, userProxy.getRemainingSecs()["Value"])
@@ -536,15 +517,15 @@ class StorageUsageAgent(AgentModule):
             else:
                 return upFile
             self.proxyCache.add(cacheKey, secsLeft, upFile)
-            self.log.info("Got proxy for %s %s@%s [%s]" % (ownerName, ownerDN, ownerGroup, ownerRole))
+            self.log.info(f"Got proxy for {ownerName} {ownerDN}@{ownerGroup} [{ownerRole}]")
             return S_OK(upFile)
         self.__noProxy.add(cacheKey)
         return S_ERROR(
-            "Could not download proxy for user (%s, %s):\n%s " % (ownerDN, ownerRole, "\n ".join(downErrors))
+            "Could not download proxy for user ({}, {}):\n{} ".format(ownerDN, ownerRole, "\n ".join(downErrors))
         )
 
     def removeEmptyDir(self, dirPath):
-        self.log.notice("Deleting empty directory %s" % dirPath)
+        self.log.notice(f"Deleting empty directory {dirPath}")
         for useOwnerProxy in (False, True):
             result = self.__removeEmptyDir(dirPath, useOwnerProxy=useOwnerProxy)
             if result["OK"]:
@@ -630,7 +611,7 @@ class StorageUsageAgent(AgentModule):
                     toPublish[dirName] = self.__dirsToPublish.pop(dirName)
             else:
                 toPublish = self.__dirsToPublish
-            self.log.info("Publishing usage for %d directories" % len(toPublish))
+            self.log.info(f"Publishing usage for {len(toPublish)} directories")
             res = self.storageUsage.publishDirectories(toPublish)
             if res["OK"]:
                 # All is OK, reset the dictionary, even if data member!
