@@ -16,7 +16,7 @@ from collections import defaultdict
 
 import DIRAC
 from DIRAC import gLogger
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 from DIRAC.Core.Utilities.ObjectLoader import ObjectLoader
 
@@ -42,7 +42,7 @@ def _checkMCReplication(bkPaths):
         gLogger.fatal("Error getting transformations", res["Message"])
         DIRAC.exit(1)
     transPaths = [(dt["TransformationID"], dt["TransformationName"].replace("Replication-", "")) for dt in res["Value"]]
-    gLogger.notice("Checking %d transformations against %d BK paths" % (len(transPaths), len(bkPaths)))
+    gLogger.notice(f"Checking {len(transPaths)} transformations against {len(bkPaths)} BK paths")
     # Only keep BK paths
     transPaths = [trans for trans in transPaths if trans[1].startswith("/MC/")]
     obsoleteTrans = []
@@ -143,7 +143,7 @@ def executeAddTransformation(pluginScript):
             nameOption = val
         elif opt == "MCVersion":
             if not mcVersionSet:
-                mcVersionSet = set(x.lower() for x in val.split(","))
+                mcVersionSet = {x.lower() for x in val.split(",")}
         elif opt == "CheckMCReplication":
             # Force to check all versions
             mcVersionSet = {"all"}
@@ -192,7 +192,7 @@ def executeAddTransformation(pluginScript):
         gLogger.notice("This script can only create Removal or Replication plugins")
         gLogger.notice("Replication :", str(getReplicationPlugins()))
         gLogger.notice("Removal     :", str(getRemovalPlugins()))
-        gLogger.notice("If needed, ask for adding %s to the known list of plugins" % plugin)
+        gLogger.notice(f"If needed, ask for adding {plugin} to the known list of plugins")
         DIRAC.exit(2)
 
     bk = BookkeepingClient()
@@ -205,7 +205,7 @@ def executeAddTransformation(pluginScript):
     # If mcVersions are defined, get the processing passes
     if mcVersionSet:
         # We keep only numerical values or "all"
-        mcVersions = set(mcv for mcv in mcVersionSet if mcv.isdigit() or mcv == "all")
+        mcVersions = {mcv for mcv in mcVersionSet if mcv.isdigit() or mcv == "all"}
         if not mcVersions:
             gLogger.fatal("Invalid MC versions", ",".join(sorted(mcVersionSet)))
             DIRAC.exit(2)
@@ -229,7 +229,7 @@ def executeAddTransformation(pluginScript):
         bkPaths = []
         for mcVersion, simVersions in reqDict.items():
             for simVersion in simVersions:
-                bkPaths.append("/MC/%s//%s/*Reco*" % (mcVersion, simVersion))
+                bkPaths.append(f"/MC/{mcVersion}//{simVersion}/*Reco*")
     elif not requestedLFNs:
         # If BK path is given, set it such that one goes through the loop below
         bkPaths = [None]
@@ -243,9 +243,9 @@ def executeAddTransformation(pluginScript):
         if bkPath:
             bkQuery = BKQuery(bkPath)
             if checkMCReplication:
-                gLogger.notice("Getting list of BK paths for %s" % bkPath)
+                gLogger.notice(f"Getting list of BK paths for {bkPath}")
             elif not listProcessingPasses:
-                gLogger.notice("For BK path: %s" % bkPath)
+                gLogger.notice(f"For BK path: {bkPath}")
         else:
             bkQuery = pluginScript.getBKQuery()
         if not bkQuery and not force:
@@ -289,7 +289,7 @@ def executeAddTransformation(pluginScript):
         obsoleteTrans = _checkMCReplication(bkPaths)
         # Print list of BK paths
         gLogger.notice(
-            "List of %d transformations to set Completed:" % len(obsoleteTrans),
+            f"List of {len(obsoleteTrans)} transformations to set Completed:",
             "\n" + ",".join(str(transID) for transID in obsoleteTrans),
         )
         DIRAC.exit(0)
@@ -315,18 +315,18 @@ def executeAddTransformation(pluginScript):
         if bkQuery:
             transBKQuery = bkQuery.getQueryDict()
         if requestedLFNs:
-            longName = transGroup + " for %d LFNs" % len(requestedLFNs)
+            longName = transGroup + f" for {len(requestedLFNs)} LFNs"
             transName += "-LFNs"
         elif prods:
             if not fileType:
                 fileType = ["All"]
             prodsStr = ",".join(str(p) for p in prods)
             fileStr = ",".join(fileType)
-            longName = transGroup + " of " + fileStr + " for productions %s " % prodsStr
+            longName = transGroup + " of " + fileStr + f" for productions {prodsStr} "
             if len(prods) > 5:
-                prodsStr = "%d-productions" % len(prods)
+                prodsStr = f"{len(prods)}-productions"
             if len(fileStr) > 30:
-                fileStr = "%d-fileTypes" % len(fileType)
+                fileStr = f"{len(fileType)}-fileTypes"
             transName += "-" + fileStr + "-" + prodsStr
         elif transBKQuery and "FileType" in transBKQuery and "BKPath" not in pluginScript.getOptions():
             if isinstance(transBKQuery["FileType"], list):
@@ -344,12 +344,12 @@ def executeAddTransformation(pluginScript):
 
         dqFlag = transBKQuery.get("DataQuality", [])
         if "BAD" in dqFlag:
-            dqFlag = " (DQ: %s)" % ",".join(dqFlag)
+            dqFlag = f" (DQ: {','.join(dqFlag)})"
             transName += dqFlag
             longName += dqFlag
 
         if requestID:
-            transName += "-Request%s" % (requestID)
+            transName += f"-Request{requestID}"
         # If a name is given in the options, use it
         if nameOption:
             transName = nameOption
@@ -378,7 +378,7 @@ def executeAddTransformation(pluginScript):
         # If we have a body plugin, load it
         if bodyPlugin:
             objLoader = ObjectLoader()
-            _class = objLoader.loadObject("TransformationSystem.Client.BodyPlugin.%s" % bodyPlugin, bodyPlugin)
+            _class = objLoader.loadObject(f"TransformationSystem.Client.BodyPlugin.{bodyPlugin}", bodyPlugin)
 
             if not _class["OK"]:
                 raise Exception(_class["Message"])
@@ -421,7 +421,7 @@ def executeAddTransformation(pluginScript):
             if transBKQuery:
                 gLogger.notice("BK Query:", transBKQuery)
             elif requestedLFNs:
-                gLogger.notice("List of %d LFNs" % len(requestedLFNs))
+                gLogger.notice(f"List of {len(requestedLFNs)} LFNs")
             else:
                 # Should not happen here, but who knows ;-)
                 gLogger.error("No BK query provided...")
@@ -440,7 +440,7 @@ def executeAddTransformation(pluginScript):
             lfns = bkQuery.getLFNs(
                 printSEUsage=(transType == "Removal" and not pluginScript.getOption("Runs")), printOutput=test
             )
-            progressBar.endLoop(message=("found %d files" % len(lfns) if lfns else "no files found"))
+            progressBar.endLoop(message=(f"found {len(lfns)} files" if lfns else "no files found"))
         else:
             lfns = requestedLFNs
         nfiles = len(lfns)
@@ -456,7 +456,7 @@ def executeAddTransformation(pluginScript):
             continue
 
         if userGroup:
-            directories = set(os.path.dirname(lfn) for lfn in lfns)
+            directories = {os.path.dirname(lfn) for lfn in lfns}
             res = chown(directories, user=userGroup[0], group=userGroup[1])
             if not res["OK"]:
                 gLogger.fatal("Error changing ownership", res["Message"])
@@ -472,7 +472,7 @@ def executeAddTransformation(pluginScript):
             success = 0
             missingLFNs = set()
             chunkSize = 1000
-            progressBar = ProgressBar(len(lfns), title="Checking %d files in FC" % len(lfns), chunk=chunkSize)
+            progressBar = ProgressBar(len(lfns), title=f"Checking {len(lfns)} files in FC", chunk=chunkSize)
             for lfnChunk in breakListIntoChunks(lfns, chunkSize):
                 progressBar.loop()
                 res = fc.exists(lfnChunk)
@@ -513,7 +513,7 @@ def executeAddTransformation(pluginScript):
         setInvisiblePlugins = tuple()
         if invisible or plugin in setInvisiblePlugins:
             chunkSize = 1000
-            progressBar = ProgressBar(len(lfns), title="Setting %d files invisible" % len(lfns), chunk=chunkSize)
+            progressBar = ProgressBar(len(lfns), title=f"Setting {len(lfns)} files invisible", chunk=chunkSize)
             okFiles = 0
             for lfnChunk in breakListIntoChunks(lfns, chunkSize):
                 progressBar.loop()
@@ -557,7 +557,7 @@ def executeAddTransformation(pluginScript):
                 if not res["OK"]:
                     errMsg = "Could not add files to transformation"
                     break
-                gLogger.notice("%d files successfully added to transformation" % len(res["Value"]["Successful"]))
+                gLogger.notice(f"{len(res['Value']['Successful'])} files successfully added to transformation")
                 if res["Value"]["Failed"]:
                     errors = defaultdict(int)
                     for error in res["Value"]["Failed"].values():
@@ -569,7 +569,7 @@ def executeAddTransformation(pluginScript):
             if start:
                 transformation.setStatus("Active")
                 transformation.setAgentType("Automatic")
-            gLogger.notice("Name: %s" % transName)
+            gLogger.notice(f"Name: {transName}")
             gLogger.notice("Transformation body:", transBody)
             gLogger.notice("Plugin:", plugin)
             if pluginParams:
