@@ -10,7 +10,6 @@
 ###############################################################################
 """Set of functions used by the DMS checking scripts."""
 import os
-import six
 from DIRAC import gLogger, S_OK
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 from DIRAC.Resources.Storage.StorageElement import StorageElement
@@ -27,7 +26,7 @@ from LHCbDIRAC.DataManagementSystem.Client.ScriptExecutors import (
 
 def __removeFile(lfns):
     """Use the ScriptExecutors removeFile method."""
-    if isinstance(lfns, six.string_types):
+    if isinstance(lfns, str):
         lfns = [lfns]
     removeFiles(lfns)
 
@@ -38,7 +37,7 @@ def __removeReplica(lfnDict):
     for lfn in lfnDict:
         for se in lfnDict[lfn]:
             seLFNs.setdefault(se, []).append(lfn)
-    for se, lfns in seLFNs.items():  # can be an iterator
+    for se, lfns in seLFNs.items():
         removeReplicas(lfns, [se])
     return seLFNs
 
@@ -50,7 +49,7 @@ def __replaceReplica(dm, seLFNs):
         gLogger.notice("Now replicating bad replicas...")
         success = {}
         failed = {}
-        for se, lfns in seLFNs.items():  # can be an iterator
+        for se, lfns in seLFNs.items():
             for lfn in lfns:
                 res = dm.replicateAndRegister(lfn, se)
                 if res["OK"]:
@@ -61,7 +60,7 @@ def __replaceReplica(dm, seLFNs):
 
         failures = 0
         errors = {}
-        for lfn, reason in failed.items():  # can be an iterator
+        for lfn, reason in failed.items():
             reason = str(reason)
             errors[reason] = errors.setdefault(reason, 0) + 1
             failures += 1
@@ -81,7 +80,7 @@ def _dumpErrorAndFiles(title, lfnList, maxFiles, dumpStr, fileName, fp):
     if fileName is None:
         return None
     if fp is None:
-        fp = open(fileName, "wt")
+        fp = open(fileName, "w")
     dumpStr1 = dumpStr.strip().replace("\n", "")
     if not dumpStr.endswith(" "):
         dumpStr += " "
@@ -89,7 +88,7 @@ def _dumpErrorAndFiles(title, lfnList, maxFiles, dumpStr, fileName, fp):
         dumpStr = "\n" + dumpStr
     fp.write(dumpStr)
     fp.write(dumpStr.join([""] + sorted(lfnList)))
-    gLogger.notice("Whole list available with 'grep %s %s'" % (dumpStr1, fileName))
+    gLogger.notice(f"Whole list available with 'grep {dumpStr1} {fileName}'")
     return fp
 
 
@@ -98,7 +97,7 @@ def _getUniqueFileName(name):
     suffix = ""
     nb = 0
     while True:
-        fileName = name + "%s.txt" % suffix
+        fileName = name + f"{suffix}.txt"
         if not os.path.exists(fileName):
             break
         nb += 1
@@ -122,9 +121,9 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
         if fixIt:
             gLogger.notice("Going to register files from BK to FC")
             regResult = {"Successful": [], "Failed": {}}
-        for lfn, seList in cc.inSEbutNotInFC.items():  # can be an iterator
+        for lfn, seList in cc.inSEbutNotInFC.items():
             inBK = lfn in cc.existLFNsBKRepNo or lfn in cc.existLFNsBKRepYes
-            gLogger.notice("\t%s (%s): %s" % (lfn, "in BK" if inBK else "not in BK", ",".join(seList)))
+            gLogger.notice(f"\t{lfn} ({'in BK' if inBK else 'not in BK'}): {','.join(seList)}")
             if fixIt:
                 if inBK:
                     res = registerBK2FC([lfn], seList)
@@ -156,7 +155,7 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
             dm = DataManager()
             replicaTuples = []
             regRepResult = {"Successful": {}, "Failed": {}}
-            for lfn, seList in cc.notRegisteredAtSE.items():  # can be an iterator
+            for lfn, seList in cc.notRegisteredAtSE.items():
                 for se in seList:
                     res = StorageElement(se).getURL(lfn, protocol=registrationProtocol)
                     if res["OK"]:
@@ -175,7 +174,7 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
 
     if cc.existLFNsBKRepNo:
         gLogger.notice(">>>>")
-        affectedRuns = set(str(run) for run in cc.existLFNsBKRepNo.values() if run)  # can be an iterator
+        affectedRuns = {str(run) for run in cc.existLFNsBKRepNo.values() if run}
         title = "%d files are in the FC (or SE) but have replica = NO in BK:\nAffected runs: %s" % (
             len(cc.existLFNsBKRepNo),
             ",".join(sorted(affectedRuns)) if affectedRuns else "None",
@@ -189,7 +188,7 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
             else:
                 gLogger.error("Failed to set the replica flag", res["Message"])
         else:
-            gLogger.notice("Use --%s to fix it (set the replica flag)" % fixOption)
+            gLogger.notice(f"Use --{fixOption} to fix it (set the replica flag)")
         gLogger.notice("<<<<")
 
     elif bkCheck:
@@ -198,13 +197,13 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
     if cc.existLFNsNotInBK:
         gLogger.notice(">>>>")
 
-        title = "%d files are in the FC but are NOT in BK" % len(cc.existLFNsNotInBK)
+        title = f"{len(cc.existLFNsNotInBK)} files are in the FC but are NOT in BK"
         fp = _dumpErrorAndFiles(title, cc.existLFNsNotInBK, maxFiles, "InFCButNotInBK ", fileName, fp)
         if fixIt:
             gLogger.notice("Going to fix them, by removing from the FC and storage")
             __removeFile(cc.existLFNsNotInBK)
         else:
-            gLogger.notice("Use --%s to fix it (remove from FC and storage)" % fixOption)
+            gLogger.notice(f"Use --{fixOption} to fix it (remove from FC and storage)")
         gLogger.notice("<<<<")
 
     else:
@@ -215,14 +214,17 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
         gLogger.notice(">>>>")
 
         seOK = False
-        title = "%d files are in the BK and FC but are missing at some SEs" % len(cc.existLFNsNoSE)
+        nOfExistLFNsNoSE = len(cc.existLFNsNoSE)
+        title = f"{nOfExistLFNsNoSE} file{'' if nOfExistLFNsNoSE == 1 else 's'}"
+        title += f" {'is' if nOfExistLFNsNoSE == 1 else 'are'} in the BK and FC"
+        title += f" but {'is' if nOfExistLFNsNoSE == 1 else 'are'} missing at some SEs"
         fixStr = "removing them from catalogs" if not replace else "re-replicating them"
         fp = _dumpErrorAndFiles(title, cc.existLFNsNoSE, maxFiles, "InFCButNotInSE ", fileName, fp)
         if fixIt:
             gLogger.notice("Going to fix, " + fixStr)
             removeLfns = []
             replicasToRemove = {}
-            for lfn, ses in cc.existLFNsNoSE.items():  # can be an iterator
+            for lfn, ses in cc.existLFNsNoSE.items():
                 if ses == "All":
                     removeLfns.append(lfn)
                 else:
@@ -236,7 +238,7 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
         else:
             if not replace:
                 fixStr += "; use --Replace if you want to re-replicate them"
-            gLogger.notice("Use --%s to fix it (%s)" % (fixOption, fixStr))
+            gLogger.notice(f"Use --{fixOption} to fix it ({fixStr})")
         gLogger.notice("<<<<")
 
     else:
@@ -247,27 +249,25 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
 
         seOK = False
         if cc.existLFNsBadFiles:
-            title = "%d files have a bad checksum" % len(cc.existLFNsBadFiles)
+            title = f"{len(cc.existLFNsBadFiles)} files have a bad checksum"
             fp = _dumpErrorAndFiles(title, cc.existLFNsBadFiles, maxFiles, "BadFiles", fileName, fp)
         if cc.existLFNsNotExisting:
-            title = "%d files don't exist at any SE" % len(cc.existLFNsNotExisting)
+            title = f"{len(cc.existLFNsNotExisting)} files don't exist at any SE"
             fp = _dumpErrorAndFiles(title, cc.existLFNsNotExisting, maxFiles, "LostFiles", fileName, fp)
         toRemove = sorted(set(cc.existLFNsBadFiles) | set(cc.existLFNsNotExisting))
         if fixIt:
             gLogger.notice("Going to fix them, removing files from catalogs and storage")
             __removeFile(toRemove)
         else:
-            gLogger.notice("Use --%s to fix it (remove files from SE and catalogs)" % fixOption)
+            gLogger.notice(f"Use --{fixOption} to fix it (remove files from SE and catalogs)")
         gLogger.notice("<<<<")
 
     if cc.existLFNsBadReplicas:
         gLogger.notice(">>>>")
 
         seOK = False
-        title = "%d replicas have a bad checksum" % len(cc.existLFNsBadReplicas)
-        badChecksum = [
-            "%s @ %s" % (lfn, ",".join(sorted(se))) for lfn, se in cc.existLFNsBadReplicas.items()
-        ]  # can be an iterator
+        title = f"{len(cc.existLFNsBadReplicas)} replicas have a bad checksum"
+        badChecksum = [f"{lfn} @ {','.join(sorted(se))}" for lfn, se in cc.existLFNsBadReplicas.items()]
         fp = _dumpErrorAndFiles(title, badChecksum, maxFiles, "BadChecksum", fileName, fp)
         fixStr = "remove replicas from SE and catalogs" if not replace else "re-replicating them"
         if fixIt:
@@ -278,7 +278,7 @@ def doCheckFC2SE(cc, bkCheck=True, fixIt=False, replace=False, maxFiles=None, fi
         else:
             if not replace:
                 fixStr += "; use --Replace if you want to re-replicate them"
-            gLogger.notice("Use --%s to fix it (%s)" % (fixOption, fixStr))
+            gLogger.notice(f"Use --{fixOption} to fix it ({fixStr})")
         gLogger.notice("<<<<")
 
     if not cc.existLFNsBadFiles and not cc.existLFNsBadReplicas:
@@ -295,9 +295,9 @@ def doCheckFC2BK(cc, fixFC=False, fixBK=False, listAffectedRuns=False, checkFC2S
     maxFiles = 10
     suffix = ""
     nb = 0
-    baseName = "CheckFC2BK" + ("-%s" % cc.prod if cc.prod else "")
+    baseName = "CheckFC2BK" + (f"-{cc.prod}" if cc.prod else "")
     while True:
-        fileName = baseName + "%s.txt" % suffix
+        fileName = baseName + f"{suffix}.txt"
         if not os.path.exists(fileName):
             break
         nb += 1
@@ -306,13 +306,16 @@ def doCheckFC2BK(cc, fixFC=False, fixBK=False, listAffectedRuns=False, checkFC2S
     if cc.existLFNsBKRepNo:
         gLogger.notice(">>>>")
 
-        affectedRuns = list(set(str(run) for run in cc.existLFNsBKRepNo.values()))  # can be an iterator
-        gLogger.error("%d files are in the FC but have replica = NO in BK" % len(cc.existLFNsBKRepNo))
+        affectedRuns = list({str(run) for run in cc.existLFNsBKRepNo.values()})
+        nOfExistLFNsBKRepNo = len(cc.existLFNsBKRepNo)
+        errMsg = f"{nOfExistLFNsBKRepNo} file{'' if nOfExistLFNsBKRepNo == 1 else 's'} "
+        errMsg += f"{'is' if nOfExistLFNsBKRepNo == 1 else 'are'} in the FC but have replica = NO in BK"
+        gLogger.error(errMsg)
         if checkFC2SE:
             from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import ConsistencyChecks
 
             ccAux = ConsistencyChecks()
-            gLogger.notice("====== Now checking %d files from FC to SE ======" % len(cc.existLFNsBKRepNo))
+            gLogger.notice(f"====== Now checking {nOfExistLFNsBKRepNo} files from FC to SE ======")
             ccAux.lfns = list(cc.existLFNsBKRepNo)
             doCheckFC2SE(ccAux, bkCheck=False, fixIt=fixFC, fixOption="FixFC")
             cc.existLFNsBKRepNo = set(cc.existLFNsBKRepNo)
@@ -321,30 +324,27 @@ def doCheckFC2BK(cc, fixFC=False, fixBK=False, listAffectedRuns=False, checkFC2S
             cc.existLFNsBKRepNo -= set(ccAux.existLFNsBadFiles)
         cc.existLFNsBKRepNo = sorted(cc.existLFNsBKRepNo)
         if cc.existLFNsBKRepNo:
-            gLogger.notice(
-                "====== Completed, %d files are in the FC and SE but have replica = NO in BK ======"
-                % len(cc.existLFNsBKRepNo)
-            )
+            msg = f"====== Completed, {nOfExistLFNsBKRepNo} file{'s' if nOfExistLFNsBKRepNo == 1 else 's'} "
+            msg += f"{'is' if nOfExistLFNsBKRepNo == 1 else 'are'} in the FC and SE but have replica = NO in BK ======"
+            gLogger.notice(msg)
             if fp is None:
-                fp = open(fileName, "wt")
+                fp = open(fileName, "w")
             fp.write("\nInFCButBKNo ".join([""] + sorted(cc.existLFNsBKRepNo)))
             res = cc.bkClient.getFileMetadata(cc.existLFNsBKRepNo)
             if not res["OK"]:
                 gLogger.fatal("Unable to get file metadata", res["Message"])
                 return
             if res["Value"]["Failed"]:
-                gLogger.error("No metadata found for some files", "%d files" % len(res["Value"]["Failed"]))
+                gLogger.error("No metadata found for some files", f"{len(res['Value']['Failed'])} files")
             success = res["Value"]["Successful"]
-            filesInvisible = set(
-                lfn for lfn, meta in success.items() if meta["VisibilityFlag"][0].upper() == "N"
-            )  # can be an iterator
+            filesInvisible = {lfn for lfn, meta in success.items() if meta["VisibilityFlag"][0].upper() == "N"}
             filesVisible = set(success) - filesInvisible
-            gLogger.notice("%d files are visible, %d files are invisible" % (len(filesVisible), len(filesInvisible)))
+            gLogger.notice(f"{len(filesVisible)} files are visible, {len(filesInvisible)} files are invisible")
             # Try and print the whole as INFO (in case --Verbose was used).
             #   If nothing printed, print a limited number of files as ERROR
             if not gLogger.info(
                 "\n".join(
-                    "%s : Visi %s" % (lfn, success.get(lfn, {}).get("VisibilityFlag", "?"))
+                    f"{lfn} : Visi {success.get(lfn, {}).get('VisibilityFlag', '?')}"
                     for lfn in sorted(cc.existLFNsBKRepNo)
                 )
             ):
@@ -352,18 +352,18 @@ def doCheckFC2BK(cc, fixFC=False, fixBK=False, listAffectedRuns=False, checkFC2S
                     gLogger.notice("First %d files:" % maxFiles)
                 gLogger.error(
                     "\n".join(
-                        "%s : Visi %s" % (lfn, success.get(lfn, {}).get("VisibilityFlag", "?"))
+                        f"{lfn} : Visi {success.get(lfn, {}).get('VisibilityFlag', '?')}"
                         for lfn in sorted(cc.existLFNsBKRepNo)[0:maxFiles]
                     )
                 )
             if listAffectedRuns:
-                gLogger.notice("Affected runs: %s" % ",".join(affectedRuns))
-            gLogger.notice("Full list of files:    grep InFCButBKNo %s" % fileName)
+                gLogger.notice(f"Affected runs: {','.join(affectedRuns)}")
+            gLogger.notice(f"Full list of files:    grep InFCButBKNo {fileName}")
             if fixBK:
                 gLogger.notice("Going to fix them, setting the replica flag")
                 res = cc.bkClient.addFiles(list(success))
                 if res["OK"]:
-                    gLogger.notice("\tSuccessfully added replica flag to %d files" % len(success))
+                    gLogger.notice(f"\tSuccessfully added replica flag to {len(success)} files")
                 else:
                     gLogger.error("Failed to set the replica flag", res["Message"])
             elif fixFC:
@@ -383,15 +383,15 @@ def doCheckFC2BK(cc, fixFC=False, fixBK=False, listAffectedRuns=False, checkFC2S
     if cc.existLFNsNotInBK:
         gLogger.notice(">>>>")
 
-        gLogger.error("%d files are in the FC but are NOT in BK:" % len(cc.existLFNsNotInBK))
+        gLogger.error(f"{len(cc.existLFNsNotInBK)} files are in the FC but are NOT in BK:")
         if fp is None:
-            fp = open(fileName, "wt")
+            fp = open(fileName, "w")
         fp.write("\nInFCNotInBK ".join([""] + sorted(cc.existLFNsNotInBK)))
         if not gLogger.info("\n".join(sorted(cc.existLFNsNotInBK))):
             if len(cc.existLFNsNotInBK) > maxFiles:
                 gLogger.notice("First %d files:" % maxFiles)
             gLogger.error("\n".join(sorted(cc.existLFNsNotInBK[0:maxFiles])))
-        gLogger.notice("Full list of files:    grep InFCNotInBK %s" % fileName)
+        gLogger.notice(f"Full list of files:    grep InFCNotInBK {fileName}")
         if fixFC:
             gLogger.notice("Going to fix them, by removing from the FC and storage")
             __removeFile(cc.existLFNsNotInBK)
@@ -413,9 +413,9 @@ def doCheckBK2FC(cc, checkAll=False, fixIt=False):
     chunkSize = 100
     suffix = ""
     nb = 0
-    baseName = "CheckBK2FC" + ("-%s" % cc.prod if cc.prod else "")
+    baseName = "CheckBK2FC" + (f"-{cc.prod}" if cc.prod else "")
     while True:
-        fileName = baseName + "%s.txt" % suffix
+        fileName = baseName + f"{suffix}.txt"
         if not os.path.exists(fileName):
             break
         nb += 1
@@ -433,17 +433,17 @@ def doCheckBK2FC(cc, checkAll=False, fixIt=False):
             comment += "\n".join(cc.existLFNsBKRepNo[:maxPrint])
             gLogger.error(comment)
             if fp is None:
-                fp = open(fileName, "wt")
+                fp = open(fileName, "w")
             fp.write("\nInFCButBKNo ".join([""] + sorted(cc.existLFNsBKRepNo)))
             gLogger.notice("To get the full list:")
-            gLogger.notice("    grep InFCButBKNo %s" % fileName)
+            gLogger.notice(f"    grep InFCButBKNo {fileName}")
             if fixIt:
                 gLogger.notice("Setting the replica flag...")
                 nFiles = 0
                 for lfnChunk in breakListIntoChunks(cc.existLFNsBKRepNo, chunkSize):
                     res = cc.bkClient.addFiles(lfnChunk)
                     if not res["OK"]:
-                        gLogger.error("Something wrong: %s" % res["Message"])
+                        gLogger.error(f"Something wrong: {res['Message']}")
                     else:
                         nFiles += len(lfnChunk)
                 gLogger.notice("Successfully set replica flag to %d files" % nFiles)
@@ -464,10 +464,10 @@ def doCheckBK2FC(cc, checkAll=False, fixIt=False):
         comment += "\n".join(cc.absentLFNsBKRepYes[:maxPrint])
         gLogger.error(comment)
         if fp is None:
-            fp = open(fileName, "wt")
+            fp = open(fileName, "w")
         fp.write("\nInBKButNotInFC ".join([""] + sorted(cc.absentLFNsBKRepYes)))
         gLogger.notice("To get the full list:")
-        gLogger.notice("    grep InBKButNotInFC %s" % fileName)
+        gLogger.notice(f"    grep InBKButNotInFC {fileName}")
         if fixIt:
             gLogger.notice("Removing the replica flag...")
             nFiles = 0
@@ -493,7 +493,7 @@ def doCheckSE(cc, seList, fixIt=False):
 
     if cc.absentLFNsInFC:
         gLogger.notice(">>>>")
-        gLogger.notice("%d files are not in the FC" % len(cc.absentLFNsInFC))
+        gLogger.notice(f"{len(cc.absentLFNsInFC)} files are not in the FC")
         if fixIt:
             __removeFile(cc.absentLFNsInFC)
         else:
@@ -502,7 +502,7 @@ def doCheckSE(cc, seList, fixIt=False):
 
     if cc.existLFNsNoSE:
         gLogger.notice("<<<<")
-        gLogger.notice("%d files are not present at %s" % (len(cc.existLFNsNoSE), ", ".join(sorted(seList))))
+        gLogger.notice(f"{len(cc.existLFNsNoSE)} files are not present at {', '.join(sorted(seList))}")
         gLogger.notice("\n".join(sorted(cc.existLFNsNoSE)))
     else:
-        gLogger.notice("No LFNs missing at %s" % ", ".join(sorted(seList)))
+        gLogger.notice(f"No LFNs missing at {', '.join(sorted(seList))}")
