@@ -18,7 +18,6 @@ import time
 import ast
 import os
 import copy
-import six
 
 import DIRAC
 
@@ -40,7 +39,7 @@ from LHCbDIRAC.TransformationSystem.Client.TransformationClient import Transform
 prodsWithMerge = ("MCSimulation", "MCFastSimulation", "DataStripping", "MCStripping", "DataSwimming", "WGProduction")
 
 
-def getFileDescendants(transID, lfns, transClient=None, dm=None, bkClient=None, descendantsDepth=None):
+def getFileDescendents(transID, lfns, transClient=None, dm=None, bkClient=None, descendantsDepth=None):
     """Function that returns the list of descendants from BKK
 
     Args:
@@ -51,7 +50,7 @@ def getFileDescendants(transID, lfns, transClient=None, dm=None, bkClient=None,
         dict: a dictionary of files with descendants (lfn as key)
 
     Examples:
-        >>> getFileDescendants(55032, ['/lhcb/LHCb/anLFN_1.dst', '/lhcb/LHCb/anLFN_2.dst',
+        >>> getFileDescendents(55032, ['/lhcb/LHCb/anLFN_1.dst', '/lhcb/LHCb/anLFN_2.dst',
                                        '/lhcb/LHCb/anLFN_3_NODESCENDANTS.dst'])
         {'/lhcb/LHCb/anLFN_1.dst': ['/lhcb/validation/desc_1.PIDCALIB.mdst',
                                     '/lhcb/validation/desc_1.pidcalib.root'],
@@ -83,7 +82,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
 
     def __init__(self, interactive=True, transClient=None, dm=None, bkClient=None, fc=None):
         """c'tor"""
-        super(ConsistencyChecks, self).__init__(interactive, transClient, dm, fc)
+        super().__init__(interactive, transClient, dm, fc)
 
         self.dmsHelpers = DMSHelpers()
         self.bkClient = BookkeepingClient() if bkClient is None else bkClient
@@ -134,7 +133,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
 
     def __logVerbose(self, msg, msg1=""):
         if self._verbose:
-            newMsg = "[ConsistencyChecks] " + ("[%s] " % str(self.prod)) if self.prod else ""
+            newMsg = "[ConsistencyChecks] " + f"[{str(self.prod)}] " if self.prod else ""
             # Add that prefix to all lines of the message
             newMsg1 = msg1.replace("\n", "\n" + newMsg)
             newMsg += msg.replace("\n", "\n" + newMsg)
@@ -154,7 +153,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             lfnsReplicaNo = list(lfnsReplicaNo) + lfnsNotInBK
         else:
             bkQuery = self.__getBKQuery()
-            gLogger.notice("Getting files for BK query %s..." % str(bkQuery))
+            gLogger.notice(f"Getting files for BK query {str(bkQuery)}...")
             if checkAll:
                 lfnsReplicaNo = self._getBKFiles(bkQuery, "No")
             lfnsReplicaYes = self._getBKFiles(bkQuery, "Yes")
@@ -196,7 +195,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 len(self.existLFNsBKRepNo),
             )
             if self.transType:
-                msg = "For prod %s of type %s, " % (self.prod, self.transType) + msg
+                msg = f"For prod {self.prod} of type {self.transType}, " + msg
             gLogger.info(msg)
 
         if self.absentLFNsBKRepYes:
@@ -205,7 +204,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 len(self.absentLFNsBKRepYes),
             )
             if self.transType:
-                msg = "For prod %s of type %s, " % (self.prod, self.transType) + msg
+                msg = f"For prod {self.prod} of type {self.transType}, " + msg
             gLogger.info(msg)
 
         ################################################################################
@@ -221,7 +220,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         startTime = time.time()
         lfnsRes = bkQueryRes.getLFNs(printOutput=False)
         if not lfnsRes:
-            gLogger.info("No files found with replica flag = %s" % replicaFlag)
+            gLogger.info(f"No files found with replica flag = {replicaFlag}")
         else:
             gLogger.info(
                 "Found %d files with replica flag = %s (%.1f seconds)"
@@ -266,7 +265,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         if not ignoreFailover:
             progressBar = ProgressBar(
                 len(lfns),
-                title="Checking replicas for %d %s" % (len(lfns), typeStr),
+                title=f"Checking replicas for {len(lfns)} {typeStr}",
                 chunk=chunkSize,
                 interactive=self.interactive,
             )
@@ -294,7 +293,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 else:
                     time.sleep(0.1)
         if progressBar:
-            progressBar.endLoop("found %d files with replicas and %d without" % (len(present), len(notPresent)))
+            progressBar.endLoop(f"found {len(present)} files with replicas and {len(notPresent)} without")
 
         if notPresent:
             self.__logVerbose("Files without replicas:", "\n".join([""] + sorted(notPresent)))
@@ -317,16 +316,16 @@ class ConsistencyChecks(DiracConsistencyChecks):
             dirs.setdefault(dirN, []).append(lfn)
 
         if compare:
-            title = "Checking File Catalog for %d %s from %d directories " % (len(lfns), typeStr, len(dirs))
+            title = f"Checking File Catalog for {len(lfns)} {typeStr} from {len(dirs)} directories "
         else:
-            title = "Getting files from %d directories " % len(dirs)
+            title = f"Getting files from {len(dirs)} directories "
         progressBar = ProgressBar(len(dirs), title=title)
 
         for dirN in sorted(dirs):
             progressBar.loop()
             startTime1 = time.time()
             lfnsFound = self._getFilesFromDirectoryScan(dirN)
-            self.__logVerbose("Obtained %d files in %.1f seconds" % (len(lfnsFound), time.time() - startTime1))
+            self.__logVerbose(f"Obtained {len(lfnsFound)} files in {time.time() - startTime1:.1f} seconds")
             if compare:
                 pr, notPr = self.__compareLFNLists(dirs[dirN], lfnsFound)
                 notPresent += notPr
@@ -334,7 +333,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             else:
                 present += lfnsFound
 
-        progressBar.endLoop("found %d files with replicas and %d without" % (len(present), len(notPresent)))
+        progressBar.endLoop(f"found {len(present)} files with replicas and {len(notPresent)} without")
         return present, notPresent
 
     ################################################################################
@@ -344,7 +343,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         present = []
         notPresent = lfns
         startTime = time.time()
-        self.__logVerbose("Comparing list of %d LFNs with second list of %d" % (len(lfns), len(lfnsFound)))
+        self.__logVerbose(f"Comparing list of {len(lfns)} LFNs with second list of {len(lfnsFound)}")
         if lfnsFound:
             # print sorted( lfns )
             # print sorted( lfnsFound )
@@ -354,7 +353,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             notPresent = list(setLfns - setLfnsFound)
             # print sorted( present )
             # print sorted( notPresent )
-        self.__logVerbose("End of comparison: %.1f seconds" % (time.time() - startTime))
+        self.__logVerbose(f"End of comparison: {time.time() - startTime:.1f} seconds")
         return present, notPresent
 
     def _getFilesFromDirectoryScan(self, dirs):
@@ -366,7 +365,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         gLogger.setLevel(level)
         if not res["OK"]:
             if "No such file or directory" not in res["Message"]:
-                gLogger.error("Error getting files from directories %s:" % dirs, res["Message"])
+                gLogger.error(f"Error getting files from directories {dirs}:", res["Message"])
             return []
         if res["Value"]:
             lfnsFound = res["Value"]
@@ -418,26 +417,26 @@ class ConsistencyChecks(DiracConsistencyChecks):
         if self.prcdWithoutDesc:
             self.__logVerbose(
                 "For prod %s of type %s, %d files are processed," % prTuple,
-                "and %d of those do not have descendants" % len(self.prcdWithoutDesc),
+                f"and {len(self.prcdWithoutDesc)} of those do not have descendants",
             )
 
         if self.prcdWithMultDesc:
             self.__logVerbose(
                 "For prod %s of type %s, %d files are processed," % prTuple,
-                "and %d of those have multiple descendants: " % len(self.prcdWithMultDesc),
+                f"and {len(self.prcdWithMultDesc)} of those have multiple descendants: ",
             )
 
         prTuple = (self.prod, self.transType, len(nonProcessedLFNs))
         if self.nonPrcdWithDesc:
             self.__logVerbose(
                 "For prod %s of type %s, %d files are not processed," % prTuple,
-                "but %d of those have descendants" % len(self.nonPrcdWithDesc),
+                f"but {len(self.nonPrcdWithDesc)} of those have descendants",
             )
 
         if self.nonPrcdWithMultDesc:
             self.__logVerbose(
                 "For prod %s of type %s, %d files are not processed," % prTuple,
-                "but %d of those have multiple descendants: " % len(self.nonPrcdWithMultDesc),
+                f"but {len(self.nonPrcdWithMultDesc)} of those have multiple descendants: ",
             )
 
     ################################################################################
@@ -450,7 +449,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             fileType = []
         else:
             bkQuery = self.__getBKQuery()
-            gLogger.notice("Getting files for BK query: %s" % bkQuery)
+            gLogger.notice(f"Getting files for BK query: {bkQuery}")
             fileType = bkQuery.getFileTypeList()
             files = self._getBKFiles(bkQuery)
 
@@ -466,7 +465,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         listAncestors = []
         progressBar = ProgressBar(
             len(files),
-            title="Getting ancestors for %d files" % len(files),
+            title=f"Getting ancestors for {len(files)} files",
             chunk=chunkSize,
             interactive=self.interactive,
         )
@@ -480,7 +479,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 for lfn, metadata in res["Value"]["Successful"].items():
                     fileType = metadata.get("FileType")
                     if fileType is None:
-                        gLogger.notice("File type unavailable for %s" % lfn, str(metadata))
+                        gLogger.notice(f"File type unavailable for {lfn}", str(metadata))
                     fileTypes.setdefault(fileType, set()).add(lfn)
             res = self.bkClient.getFileAncestors(
                 lfnChunk, depth=self.ancestorsDepth, replica=(self.ancestorsDepth == 10)
@@ -498,19 +497,19 @@ class ConsistencyChecks(DiracConsistencyChecks):
         self.commonAncestors = {}
         self.multipleDescendants = {}
         if not getFileType and len(listAncestors) == len(set(listAncestors)):
-            gLogger.notice("Found %d ancestors, no common one" % len(listAncestors))
+            gLogger.notice(f"Found {len(listAncestors)} ancestors, no common one")
             return
 
-        gLogger.notice("Found files with %d file types" % len(fileTypes))
+        gLogger.notice(f"Found files with {len(fileTypes)} file types")
         for fileType in fileTypes:
             lfns = fileTypes[fileType] & set(ancestors)
-            gLogger.notice("File type %s, checking %d files" % (fileType, len(lfns)))
+            gLogger.notice(f"File type {fileType}, checking {len(lfns)} files")
             listAncestors = []
             for lfn in lfns:
                 listAncestors += ancestors[lfn]
             setAncestors = set(listAncestors)
             if len(listAncestors) == len(setAncestors):
-                gLogger.notice("Found %d ancestors for file type %s, no common one" % (len(listAncestors), fileType))
+                gLogger.notice(f"Found {len(listAncestors)} ancestors for file type {fileType}, no common one")
                 continue
             # There are common ancestors
             descendants = {}
@@ -522,7 +521,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             for anc in sorted(descendants):
                 if len(descendants[anc]) > 1:
                     desc = sorted(descendants[anc])
-                    gLogger.notice("For ancestor %s, found %d descendants: %s" % (anc, len(desc), desc))
+                    gLogger.notice(f"For ancestor {anc}, found {len(desc)} descendants: {desc}")
                     self.multipleDescendants[anc] = desc
                     self.commonAncestors.setdefault(",".join(sorted(desc)), []).append(anc)
 
@@ -546,7 +545,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                         run["RunNumber"] for run in res["Value"] if run["RunNumber"] not in self.runsList
                     )
                     gLogger.notice(
-                        "%d runs selected:" % len(res["Value"]), ",".join(str(run["RunNumber"]) for run in res["Value"])
+                        f"{len(res['Value'])} runs selected:", ",".join(str(run["RunNumber"]) for run in res["Value"])
                     )
                 elif not self.runsList:
                     gLogger.notice("No runs selected, check completed")
@@ -556,13 +555,11 @@ class ConsistencyChecks(DiracConsistencyChecks):
 
         res = self.transClient.getTransformation(self.prod)
         if not res["OK"]:
-            gLogger.error("Failed to find transformation %s" % self.prod)
+            gLogger.error(f"Failed to find transformation {self.prod}")
             return [], [], []
         status = res["Value"]["Status"]
         if status not in ("Active", "Stopped", "Completed", "Idle"):
-            gLogger.notice(
-                "Transformation %s in status %s, will not check if files are processed" % (self.prod, status)
-            )
+            gLogger.notice(f"Transformation {self.prod} in status {status}, will not check if files are processed")
             processedLFNs = []
             nonProcessedLFNs = []
             nonProcessedStatuses = []
@@ -576,9 +573,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             else:
                 processedLFNs = [item["LFN"] for item in res["Value"] if item["Status"] == "Processed"]
                 nonProcessedLFNs = [item["LFN"] for item in res["Value"] if item["Status"] != "Processed"]
-                nonProcessedStatuses = list(
-                    set(item["Status"] for item in res["Value"] if item["Status"] != "Processed")
-                )
+                nonProcessedStatuses = list({item["Status"] for item in res["Value"] if item["Status"] != "Processed"})
 
         return processedLFNs, nonProcessedLFNs, nonProcessedStatuses
 
@@ -601,7 +596,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         for lfnChunk in breakListIntoChunks(lfns, chunkSize):
             progressBar.loop()
             while True:
-                resChunk = self.bkClient.getFileDescendants(
+                resChunk = self.bkClient.getFileDescendents(
                     lfnChunk, depth=self.descendantsDepth, production=self.prod, checkreplica=False
                 )
                 # If error, global or for some files, retry
@@ -610,11 +605,11 @@ class ConsistencyChecks(DiracConsistencyChecks):
                     descDict = self._selectByFileType(resChunk["Value"]["WithMetadata"])
                     # Do the daughters have a replica flag in BK? Store file type as well... Key is daughter
                     daughtersBKInfo.update(
-                        dict(
-                            (lfn, (desc[lfn]["GotReplica"] == "Yes", desc[lfn]["FileType"]))
+                        {
+                            lfn: (desc[lfn]["GotReplica"] == "Yes", desc[lfn]["FileType"])
                             for desc in descDict.values()
                             for lfn in desc
-                        )
+                        }
                     )
                     # Count the daughters per file type (key is ancestor)
                     ft_count = self._getFileTypesCount(descDict)
@@ -624,7 +619,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                             # Assign the daughters list to the initial LFN
                             filesWithDescendants[lfn] = list(descDict[lfn])
                             # Is there a file type with more than one daughter of a given file type?
-                            multi = dict((ft, ftc) for ft, ftc in ft_count[lfn].items() if ftc > 1)
+                            multi = {ft: ftc for ft, ftc in ft_count[lfn].items() if ftc > 1}
                             if multi:
                                 filesWithMultipleDescendants[lfn] = multi
                         else:
@@ -633,7 +628,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                     break
                 else:
                     progressBar.comment(
-                        "Error getting daughters for %d files, retry" % len(lfnChunk), resChunk["Message"]
+                        f"Error getting daughters for {len(lfnChunk)} files, retry", resChunk["Message"]
                     )
         prStr = ""
         if filesWithDescendants:
@@ -648,7 +643,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 prStr = "found"
             else:
                 prStr += " and"
-            prStr += " no descendants for %d files" % len(filesWithoutDescendants)
+            prStr += f" no descendants for {len(filesWithoutDescendants)} files"
         progressBar.endLoop(message=prStr)
         return daughtersBKInfo
 
@@ -658,7 +653,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         Args:
             lfns (str, list, dict): a string for a single lfn, a list of strings, or a dict with lfns as keys
         """
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = [lfns]
         elif isinstance(lfns, dict):
             lfns = list(lfns)
@@ -696,12 +691,12 @@ class ConsistencyChecks(DiracConsistencyChecks):
         # This is the list of all daughters, sets will contain unique entries
         setAllDaughters = set(daughtersBKInfo)
         allDaughters = list(setAllDaughters)
-        inBK = set(lfn for lfn in setAllDaughters if daughtersBKInfo[lfn][0])
+        inBK = {lfn for lfn in setAllDaughters if daughtersBKInfo[lfn][0]}
         setRealDaughters = set()
         # Now check whether these daughters files have replicas or have descendants that have replicas
         chunkSize = 100 if self.transType == "DataStripping" and len(self.fileType) > 1 else 500
         if filesWithDescendants:
-            # First check in LFC the presence of daughters
+            # First check in FC the presence of daughters
             if not self.noFC:
                 present, notPresent = (
                     self.getReplicasPresenceFromDirectoryScan(allDaughters, typeStr="daughters")
@@ -724,7 +719,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 chunkSize = 20 if self.transType == "DataStripping" and len(self.fileType) > 1 else 50
                 progressBar = ProgressBar(
                     len(setNotPresent),
-                    title="Now getting descendants from %d daughters without replicas" % len(setNotPresent),
+                    title=f"Now getting descendants from {len(setNotPresent)} daughters without replicas",
                     chunk=chunkSize,
                     interactive=self.interactive,
                 )
@@ -733,16 +728,16 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 for lfnChunk in breakListIntoChunks(setNotPresent, chunkSize):
                     progressBar.loop()
                     while True:
-                        res = self.bkClient.getFileDescendants(lfnChunk, depth=99, checkreplica=True)
+                        res = self.bkClient.getFileDescendents(lfnChunk, depth=99, checkreplica=True)
                         if res["OK"]:
                             # Exclude ignored file types, but select any other file type, key is daughters
                             notPresentDescendants.update(res["Value"]["WithMetadata"])
                             break
                         else:
                             progressBar.comment(
-                                "Error getting descendants for %d files, retry" % len(lfnChunk), res["Message"]
+                                f"Error getting descendants for {len(lfnChunk)} files, retry", res["Message"]
                             )
-                uniqueDescendants = set(lfn for desc in notPresentDescendants.values() for lfn in desc)
+                uniqueDescendants = {lfn for desc in notPresentDescendants.values() for lfn in desc}
                 progressBar.endLoop(
                     message="found %d descendants of %d daughters"
                     % (len(uniqueDescendants), len(notPresentDescendants))
@@ -797,15 +792,15 @@ class ConsistencyChecks(DiracConsistencyChecks):
                     else:
                         self.__logVerbose("No real daughters found")
                     # descToCheck: dictionary with key = daughter and value = dictionary of file type counts
-                    daughtersDict = dict(
-                        (daughter, {daughter: {"FileType": daughtersBKInfo[daughter][1]}}) for daughter in realDaughters
-                    )
+                    daughtersDict = {
+                        daughter: {daughter: {"FileType": daughtersBKInfo[daughter][1]}} for daughter in realDaughters
+                    }
                     descToCheck = self._getFileTypesCount(daughtersDict)
 
                     # Update the result dictionaries according to the final set of descendants
                     if not descToCheck:
                         # Mother has no descendant
-                        self.__logVerbose("%s has no real descendants" % lfn)
+                        self.__logVerbose(f"{lfn} has no real descendants")
                         filesWithMultipleDescendants.pop(lfn, None)
                         filesWithDescendants.pop(lfn, None)
                         filesWithoutDescendants[lfn] = None
@@ -818,7 +813,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                         for counts in descToCheck.values():
                             for ft in counts:
                                 ft_count[ft] = ft_count.setdefault(ft, 0) + counts.get(ft, 0)
-                        multi = dict((ft, ftc) for ft, ftc in ft_count.items() if ftc > 1)
+                        multi = {ft: ftc for ft, ftc in ft_count.items() if ftc > 1}
                         # Mother has at least one real descendant
                         # Now check whether there are more than one descendant of the same file type
                         if not multi:
@@ -827,8 +822,8 @@ class ConsistencyChecks(DiracConsistencyChecks):
                         else:
                             filesWithMultipleDescendants[lfn] = multi
                             prStr = "multiple"
-                        self.__logVerbose("Found %s descendants" % prStr)
-                progressBar.endLoop(message="found %d files with existing descendants" % len(filesWithDescendants))
+                        self.__logVerbose(f"Found {prStr} descendants")
+                progressBar.endLoop(message=f"found {len(filesWithDescendants)} files with existing descendants")
         # print 'Final multiple descendants', filesWithMultipleDescendants
 
         # File files without descendants don't exist, not important
@@ -845,13 +840,13 @@ class ConsistencyChecks(DiracConsistencyChecks):
         if inFCNotInBK:
             progressBar = ProgressBar(
                 len(inFCNotInBK),
-                title="Checking Failover for %d descendants found in FC and not in BK" % len(inFCNotInBK),
+                title=f"Checking Failover for {len(inFCNotInBK)} descendants found in FC and not in BK",
                 step=1,
                 interactive=self.interactive,
             )
             notInFailover, _notFound = self.getReplicasPresence(inFCNotInBK, ignoreFailover=True)
             inFailover = list(set(inFCNotInBK) - set(notInFailover))
-            progressBar.endLoop(message="found %d in Failover" % len(inFailover))
+            progressBar.endLoop(message=f"found {len(inFailover)} in Failover")
             inFCNotInBK = notInFailover
         return (
             filesWithDescendants,
@@ -938,7 +933,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             prStr = " are in the FC but"
         else:
             if notPresent and self._seList:
-                gLogger.notice("Found %d files not in FC, check if they are in specified SEs" % len(notPresent))
+                gLogger.notice(f"Found {len(notPresent)} files not in FC, check if they are in specified SEs")
                 foundInSE = self._checkFilesInSE(notPresent, self._seList)
                 if foundInSE:
                     self.inSEbutNotInFC = foundInSE
@@ -955,11 +950,11 @@ class ConsistencyChecks(DiracConsistencyChecks):
             self.existLFNsBKRepYes = res[2]
             msg = ""
             if self.transType:
-                msg = "For prod %s of type %s, " % (self.prod, self.transType)
+                msg = f"For prod {self.prod} of type {self.transType}, "
             if self.existLFNsBKRepNo:
-                gLogger.warn("%s %d files%s have replica = NO in BK" % (msg, len(self.existLFNsBKRepNo), prStr))
+                gLogger.warn(f"{msg} {len(self.existLFNsBKRepNo)} files{prStr} have replica = NO in BK")
             if self.existLFNsNotInBK:
-                gLogger.warn("%s %d files%s not in BK" % (msg, len(self.existLFNsNotInBK), prStr))
+                gLogger.warn(f"{msg} {len(self.existLFNsNotInBK)} files{prStr} not in BK")
         else:
             self.existLFNsBKRepYes = present
 
@@ -1006,7 +1001,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             else:
                 directories = []
                 dirList = res["Value"]
-                if isinstance(dirList, six.string_types) and dirList[0] == "[" and dirList[-1] == "]":
+                if isinstance(dirList, str) and dirList[0] == "[" and dirList[-1] == "]":
                     dirList = ast.literal_eval(dirList)
                 for dirName in dirList:
                     # There is a shortcut when multiple streams are used, only the stream name is repeated!
@@ -1046,7 +1041,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         chunkSize = 1000
         progressBar = ProgressBar(
             len(lfns),
-            title="Getting %d files metadata from BK" % len(lfns),
+            title=f"Getting {len(lfns)} files metadata from BK",
             chunk=chunkSize,
             interactive=self.interactive,
         )
@@ -1060,17 +1055,13 @@ class ConsistencyChecks(DiracConsistencyChecks):
                     metadata = res["Value"]["Successful"]
                     missingLFNs += [lfn for lfn in lfnChunk if lfn not in metadata]
                     noFlagLFNs.update(
-                        dict(
-                            (lfn, metadata[lfn]["RunNumber"]) for lfn in metadata if metadata[lfn]["GotReplica"] == "No"
-                        )
+                        {lfn: metadata[lfn]["RunNumber"] for lfn in metadata if metadata[lfn]["GotReplica"] == "No"}
                     )
                     okLFNs += [lfn for lfn in metadata if metadata[lfn]["GotReplica"] == "Yes"]
                     break
         progressBar.endLoop()
         return missingLFNs, noFlagLFNs, okLFNs
 
-    ################################################################################
-
     def checkBK2TS(self):
         """check that files present in the BK are also in the FC (re-check of BKWatchAgent)"""
         bkQuery = self.__getBKQuery(fromTS=True)
@@ -1078,12 +1069,11 @@ class ConsistencyChecks(DiracConsistencyChecks):
         proc, nonProc, _statuses = self._getTSFiles()
         self.filesInBKNotInTS = list(set(lfnsReplicaYes) - set(proc + nonProc))
         if self.filesInBKNotInTS:
-            gLogger.error(
-                "There are %d files in BK that are not in TS: %s"
-                % (len(self.filesInBKNotInTS), str(self.filesInBKNotInTS))
-            )
-
-    ################################################################################
+            nOfFilesInBKNotInTS = len(self.filesInBKNotInTS)
+            errMsg = f"There {'is' if nOfFilesInBKNotInTS == 1 else 'are'} {nOfFilesInBKNotInTS} "
+            errMsg += f"file{'' if nOfFilesInBKNotInTS == 1 else 's'} in BK that "
+            errMsg += "{'is' if nOfFilesInBKNotInTS == 1 else 'are'} not in TS: {self.filesInBKNotInTS}"
+            gLogger.error(errMsg)
 
     def checkFC2SE(self, bkCheck=True):  # pylint: disable=arguments-differ
         self.checkFC2BK(bkCheck=bkCheck)
@@ -1105,7 +1095,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         else:
             lfns = lfnsReplicaYes
             notPresent = []
-        gLogger.notice("Checking presence of %d files at %s" % (len(lfns), ", ".join(seList)))
+        gLogger.notice(f"Checking presence of {len(lfns)} files at {', '.join(seList)}")
         replicaRes = self.dataManager.getReplicas(lfns)
         if not replicaRes["OK"]:
             gLogger.error("Error getting replicas", replicaRes["Message"])
@@ -1140,7 +1130,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         if lfnsLeft:
             progressBar = ProgressBar(
                 len(lfnsLeft),
-                title="Get replicas for %d files" % len(lfnsLeft),
+                title=f"Get replicas for {len(lfnsLeft)} files",
                 chunk=chunkSize,
                 interactive=self.interactive,
             )
@@ -1167,12 +1157,12 @@ class ConsistencyChecks(DiracConsistencyChecks):
                     notAtSE.append(lfn)
             if notAtSE:
                 gLogger.notice(
-                    "%d files are not registered at requested SEs, check if they exist in SE..." % len(notAtSE)
+                    f"{len(notAtSE)} files are not registered at requested SEs, check if they exist in SE..."
                 )
                 foundInSE = self._checkFilesInSE(notAtSE, self._seList)
                 if foundInSE:
                     gLogger.notice(
-                        "Of these, %d files were found at requested SEs but are not registered" % len(foundInSE)
+                        f"Of these, {len(foundInSE)} files were found at requested SEs but are not registered"
                     )
                     retDict["NotRegisteredAtSE"] = foundInSE
                 else:
@@ -1184,7 +1174,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
             return retDict
         progressBar = ProgressBar(
             len(replicas),
-            title="Get FC metadata for %d files to be checked: " % len(replicas),
+            title=f"Get FC metadata for {len(replicas)} files to be checked: ",
             chunk=chunkSize,
             interactive=self.interactive,
         )
@@ -1202,9 +1192,9 @@ class ConsistencyChecks(DiracConsistencyChecks):
         seFiles = {}
         # Reverse the LFN->SE dictionary
         nReps = 0
-        for lfn in replicas:
+        for lfn, lfnReplicas in replicas.items():
             csDict.setdefault(lfn, {})["LFCChecksum"] = metadata.get(lfn, {}).get("Checksum")
-            for se in replicas[lfn]:
+            for se in lfnReplicas:
                 seFiles.setdefault(se, []).append(lfn)
                 nReps += 1
 
@@ -1228,7 +1218,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
                 progressBar.loop()
                 metadata = oSe.getFileMetadata(surlChunk)
                 if not metadata["OK"]:
-                    errMsg = "Error: getFileMetadata returns %s. Ignore those replicas" % (metadata["Message"])
+                    errMsg = f"Error: getFileMetadata returns {metadata['Message']}. Ignore those replicas"
                     progressBar.comment(errMsg)
                     # Remove from list of replicas as we don't know whether it is OK or not
                     for lfn in seFiles[se]:
@@ -1246,10 +1236,9 @@ class ConsistencyChecks(DiracConsistencyChecks):
             progressBar.endLoop(errMsg)
         gLogger.setLevel(logLevel)
 
-        gLogger.notice("Verifying checksum of %d files" % len(replicas))
-        for lfn in replicas:
-            # get the lfn checksum from the LFC
-            replicaDict = replicas[lfn]
+        gLogger.notice(f"Verifying checksum of {len(replicas)} files")
+        for lfn, replicaDict in replicas.items():
+            # get the lfn checksum from the FC
             oneGoodReplica = False if lfn not in otherReplicas else True
             allGoodReplicas = True
             lfcChecksum = csDict[lfn].pop("LFCChecksum")
@@ -1339,7 +1328,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
 
     def set_bkQuery(self, value):
         """Setter"""
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             self._bkQuery = ast.literal_eval(value)
         else:
             self._bkQuery = value
@@ -1352,7 +1341,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
 
     def set_lfns(self, value):
         """Setter"""
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = [value]
         value = [v.replace(" ", "").replace("//", "/") for v in value]
         self._lfns = value
