@@ -19,7 +19,7 @@ import tempfile
 
 import DIRAC
 from DIRAC import gLogger, gConfig
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
 
 from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import BKQuery
@@ -41,21 +41,21 @@ def __printDictionary(dictionary, offset=0, shift=0, empty="Empty directory", de
             if not depth:
                 value = list(value)
             elif value != {}:
-                gLogger.notice("%s%s : " % (offset * " ", key))
+                gLogger.notice(f"{offset * ' '}{key} : ")
                 __printDictionary(value, offset=newOffset, shift=shift, empty=empty, depth=depth - 1)
             elif key not in ("Failed", "Successful"):
-                gLogger.notice("%s%s : %s" % (offset * " ", key, empty))
+                gLogger.notice(f"{offset * ' '}{key} : {empty}")
         if isinstance(value, (list, set)):
             if not value:
-                gLogger.notice("%s%s : %s" % (offset * " ", key, "[]"))
+                gLogger.notice(f"{offset * ' '}{key} : {'[]'}")
             else:
-                gLogger.notice("%s%s : " % (offset * " ", key))
+                gLogger.notice(f"{offset * ' '}{key} : ")
                 for val in sorted(value):
-                    gLogger.notice("%s%s" % (newOffset * " ", val))
+                    gLogger.notice(f"{newOffset * ' '}{val}")
         elif not isinstance(value, dict):
             # In case value contains \n, indent the lines
             toPrint = str(value).split("\n")
-            gLogger.notice("%s : %s" % (str(key).rjust(center), toPrint.pop(0)))
+            gLogger.notice(f"{str(key).rjust(center)} : {toPrint.pop(0)}")
             for line in toPrint:
                 gLogger.notice((center + 3) * " " + line)
 
@@ -70,15 +70,15 @@ def printDMResult(result, shift=4, empty="Empty directory", script=None, depth=9
             if result["Value"].get("Failed"):
                 return 1
             return 0
-        gLogger.notice("Error in %s :" % script, result["Message"])
+        gLogger.notice(f"Error in {script} :", result["Message"])
         return 2
     except Exception as e:  # pylint: disable=broad-except
-        gLogger.notice("Exception while printing results in %s - Results:" % script, repr(e))
+        gLogger.notice(f"Exception while printing results in {script} - Results:", repr(e))
         gLogger.notice(result)
         return 2
 
 
-class ProgressBar(object):
+class ProgressBar:
     """This object prints a title and a progress bar on stderr."""
 
     def __init__(self, items, width=None, title=None, chunk=None, step=None, interactive=None, log=None):
@@ -129,7 +129,7 @@ class ProgressBar(object):
         if not self._interactive:
             return
         if self._showBar:
-            sys.stderr.write("%s|%s|" % (self._title, self._width * " "))
+            sys.stderr.write(f"{self._title}|{self._width * ' '}|")
             self._backspace = self._width + 1
         else:
             sys.stderr.write(self._title)
@@ -176,30 +176,30 @@ class ProgressBar(object):
         bar was created."""
         if message is None:
             message = "completed"
-        timingMsg = " in %.1f seconds" % (time.time() - self._startTime)
+        timingMsg = f" in {time.time() - self._startTime:.1f} seconds"
         if not self._interactive:
             # Print out message if defined
             if self._log:
-                self._log("%s %s %s" % (self._title, message, timingMsg))
+                self._log(f"{self._title} {message} {timingMsg}")
             return
         if self._showBar:
-            sys.stderr.write("%s\033[K: %s" % ((self._progress + self._backspace + 1) * "\b", message))
+            sys.stderr.write("{}\033[K: {}".format((self._progress + self._backspace + 1) * "\b", message))
         if timing:
             if not self._showBar:
-                sys.stderr.write(": %s" % message)
+                sys.stderr.write(f": {message}")
             sys.stderr.write(timingMsg)
         sys.stderr.write("\n")
         sys.stderr.flush()
 
     def comment(self, message, optMsg=""):
         """Print a comment."""
-        fullMsg = "\n" + message + " %s" % optMsg if optMsg else ""
+        fullMsg = "\n" + message + f" {optMsg}" if optMsg else ""
         gLogger.notice(fullMsg)
         self._writeTitle()
         self.loop(increment=False)
 
 
-class DMScript(object):
+class DMScript:
     """DMScript is a class that creates default switches for DM scripts, decodes
     them and sets flags."""
 
@@ -293,7 +293,7 @@ class DMScript(object):
                     prods.append(prod)
             self.options["Productions"] = [int(prod) for prod in prods]
         except ValueError as e:
-            gLogger.error("Invalid production switch value: %s" % arg, repr(e))
+            gLogger.error(f"Invalid production switch value: {arg}", repr(e))
             self.options["Productions"] = ["Invalid"]
             return DIRAC.S_ERROR()
         return DIRAC.S_OK()
@@ -355,7 +355,7 @@ class DMScript(object):
         if arg.lower() in ("yes", "no", "all"):
             self.options["Visibility"] = arg
         else:
-            gLogger.error("Unknown visibility flag: %s" % arg)
+            gLogger.error(f"Unknown visibility flag: {arg}")
             return DIRAC.exit(1)
         return DIRAC.S_OK()
 
@@ -364,14 +364,14 @@ class DMScript(object):
         if arg.lower() in ("yes", "no", "all"):
             self.options["ReplicaFlag"] = arg
         else:
-            gLogger.error("Unknown replica flag: %s" % arg)
+            gLogger.error(f"Unknown replica flag: {arg}")
             return DIRAC.exit(1)
         return DIRAC.S_OK()
 
     def setDirectory(self, arg):
         """Setter."""
         if os.path.exists(arg) and not os.path.isdir(arg):
-            with open(arg, "rt") as inFile:
+            with open(arg) as inFile:
                 directories = [line.split()[0] for line in inFile.read().splitlines() if line.strip()]
         else:
             directories = arg.split(",")
@@ -420,16 +420,17 @@ class DMScript(object):
         occurence of /<vo>/ in the file name and ends with a set of delimiters If
         directories is True, only normalized directories (ending with a "/" are
         returned."""
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfnList = lfns.strip().split(",")
         elif isinstance(lfns, (list, set, dict)):
             lfnList = [lfn.strip() for lfn1 in lfns for lfn in lfn1.split(",")]
         else:
-            gLogger.error("getLFNsFromList: invalid type %s" % type(lfns))
+            gLogger.error(f"getLFNsFromList: invalid type {type(lfns)}")
             return []
         vo = self.__voName()
         if vo:
-            vo = "/%s" % vo
+            vo = f"/{vo}"
+            lfnList = [x.replace("LFN: ", "LFN  ") for x in lfnList]
             lfnList = [x.split("LFN:")[-1].strip() for x in lfnList]
             for sep in ('"', ",", "'", ":", "(", ")", ";", "|"):
                 lfnList = [x.replace(sep, " ") for x in lfnList]
@@ -446,7 +447,7 @@ class DMScript(object):
     def getJobIDsFromList(jobids):
         """it returns a list of jobids using a string."""
         jobidsList = []
-        if isinstance(jobids, six.string_types):
+        if isinstance(jobids, str):
             jobidsList = jobids.split(",")
         elif isinstance(jobids, list):
             jobidsList = [jobid for jobid1 in jobids for jobid in jobid1.split(",")]
@@ -457,16 +458,16 @@ class DMScript(object):
         """Setter when --Last is used."""
         if os.path.exists(self.lastFile):
             return self.setLFNsFromFile(self.lastFile)
-        gLogger.fatal("Last file %s does not exist" % self.lastFile)
+        gLogger.fatal(f"Last file {self.lastFile} does not exist")
         DIRAC.exit(2)
 
     def setLFNsFromFile(self, arg):
         """Reads the content of a file or from stdin (in which case a temporary
         file will be created) LFNs are not parsed at this stage."""
-        if isinstance(arg, six.string_types) and arg.lower() == "last":
+        if isinstance(arg, str) and arg.lower() == "last":
             arg = self.lastFile
         # Make a list of files
-        if isinstance(arg, six.string_types):
+        if isinstance(arg, str):
             files = arg.split(",")
         elif isinstance(arg, list):
             files = arg
@@ -475,10 +476,10 @@ class DMScript(object):
         nfiles = 0
         for fName in files:
             try:
-                with open(fName if fName else "/dev/stdin", "rt") as inFile:
+                with open(fName if fName else "/dev/stdin") as inFile:
                     lfns = inFile.read().splitlines()
                 nfiles += len(lfns)
-            except (EOFError, IOError):
+            except (EOFError, OSError):
                 lfns = fName.split(",")
             self.options.setdefault("LFNs", set()).update(lfns)
         if nfiles:
@@ -509,10 +510,10 @@ class DMScript(object):
                 value = self.getLFNsFromList(value, directories=switch == "Directory")
             if value and self.setLastFile and switch == "LFNs":
                 # Storethe list of LFNs in a temporary file
-                gLogger.always("Got %d LFNs" % len(value))
+                gLogger.always(f"Got {len(value)} LFNs")
                 if self.setLastFile != self.lastFile:
                     self.setLastFile = False
-                    with open(self.lastFile, "wt") as tmpFile:
+                    with open(self.lastFile, "w") as tmpFile:
                         tmpFile.write("\n".join(sorted(value)))
         if isinstance(value, set):
             # Return a sorted list from a set
@@ -544,7 +545,7 @@ class DMScript(object):
         bkQueryDict = self.bkClientQuery.getQueryDict()
         found = False
         for key in mandatoryKeys:
-            if isinstance(key, six.string_types) and key in bkQueryDict:
+            if isinstance(key, str) and key in bkQueryDict:
                 found = True
                 break
             elif isinstance(key, (list, tuple)) and not set(key) - set(bkQueryDict):
@@ -574,7 +575,7 @@ class DMScript(object):
         if not prod:
             prod = self.options.get("Productions", [])
         requestID = None
-        if isinstance(prod, six.string_types):
+        if isinstance(prod, str):
             prods = [prod]
         else:
             prods = prod
@@ -589,9 +590,9 @@ class DMScript(object):
         NOTE: The file format is equivalent to the file format when the content is
         a list of LFNs."""
         try:
-            with open(arg if arg else "/dev/stdin", "rt") as inFile:
+            with open(arg if arg else "/dev/stdin") as inFile:
                 jobids = self.getJobIDsFromList(inFile.read().splitlines())
-        except IOError as error:
+        except OSError as error:
             gLogger.exception("Reading jobids from a file is failed with exception:", repr(error))
             jobids = self.getJobIDsFromList(arg)
         self.options.setdefault("JobIDs", set()).update(jobids)
