@@ -27,7 +27,7 @@ from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import ConsistencyC
 class DataIntegrityClient(DIRACDataIntegrityClient):
     def __init__(self):
         """Extending DIRAC's DIRACDataIntegrityClient init."""
-        super(DataIntegrityClient, self).__init__()
+        super().__init__()
 
         self.cc = ConsistencyChecks()
 
@@ -75,7 +75,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
 
     def __checkCatalogForBKNoReplicas(self, lfns):
         """Checks the catalog existence for given files."""
-        gLogger.info("Checking the catalog existence of %s files" % len(lfns))
+        gLogger.info(f"Checking the catalog existence of {len(lfns)} files")
 
         res = self.fc.getFileMetadata(lfns)
         if not res["OK"]:
@@ -91,7 +91,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
     def __getProductionFiles(self, productionID):
         """This method queries the bookkeeping and obtains the file metadata for
         the given production."""
-        gLogger.info("Attempting to get files for production %s" % productionID)
+        gLogger.info(f"Attempting to get files for production {productionID}")
         res = BookkeepingClient().getProductionFiles(productionID, "ALL")
         if not res["OK"]:
             return res
@@ -101,7 +101,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
         badBKFileSize = []
         badBKGUID = []
         allMetadata = res["Value"]
-        gLogger.info("Obtained at total of %s files" % len(allMetadata))
+        gLogger.info(f"Obtained at total of {len(allMetadata)} files")
         totalSize = 0
         for lfn, bkMetadata in allMetadata.items():
             if bkMetadata["FileType"] != "LOG":
@@ -123,8 +123,8 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
             self._reportProblematicFiles(badBKFileSize, "BKSizeBad")
         if badBKGUID:
             self._reportProblematicFiles(badBKGUID, "BKGUIDBad")
-        gLogger.info("%s files marked with replicas with total size %s bytes" % (len(yesReplicaFiles), totalSize))
-        gLogger.info("%s files marked without replicas" % len(noReplicaFiles))
+        gLogger.info(f"{len(yesReplicaFiles)} files marked with replicas with total size {totalSize} bytes")
+        gLogger.info(f"{len(noReplicaFiles)} files marked without replicas")
         resDict = {"BKMetadata": allMetadata, "GotReplicaYes": yesReplicaFiles, "GotReplicaNo": noReplicaFiles}
         return S_OK(resDict)
 
@@ -139,7 +139,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
         gLogger.info("-" * 40)
         gLogger.info("Performing the FC->BK check")
         gLogger.info("-" * 40)
-        if isinstance(lfnDir, six.string_types):
+        if isinstance(lfnDir, str):
             lfnDir = [lfnDir]
         res = self.__getCatalogDirectoryContents(lfnDir)
         if not res["OK"]:
@@ -148,7 +148,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
         catalogMetadata = res["Value"]["Metadata"]
         resDict = {"CatalogMetadata": catalogMetadata, "CatalogReplicas": replicas}
         if not catalogMetadata:
-            gLogger.warn("No files found in directory %s" % lfnDir)
+            gLogger.warn(f"No files found in directory {lfnDir}")
             return S_OK(resDict)
         lfns = []
         for repDict in replicas:
@@ -166,7 +166,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
         gLogger.info("-" * 40)
         gLogger.info("Performing the FC->BK check")
         gLogger.info("-" * 40)
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = [lfns]
 
         res = self.cc._getCatalogMetadata(lfns)
@@ -268,12 +268,12 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
                 if (ses) and (se not in ses):
                     continue
                 seLfns.setdefault(se, []).append(lfn)
-        gLogger.info("%s %s" % ("Storage Element".ljust(20), "Replicas".rjust(20)))
+        gLogger.info(f"{'Storage Element'.ljust(20)} {'Replicas'.rjust(20)}")
 
         for se in seLfns:
             res = StorageElement(se).isValid("Check")
             if not res["OK"]:
-                gLogger.error("Unable to checkPhysicalFiles at", "%s: %s" % (se, res["Message"]))
+                gLogger.error("Unable to checkPhysicalFiles at", f"{se}: {res['Message']}")
                 return res
 
         for se, lfns in sorted(seLfns.items()):
@@ -288,7 +288,16 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
                 if lfn in catalogMetadata:
                     if (metadata["Size"] != catalogMetadata[lfn]["Size"]) and (metadata["Size"] != 0):
                         sizeMismatch.append((lfn, "deprecatedUrl", se, "CatalogPFNSizeMismatch"))
-                    if not compareAdler(metadata["Checksum"], catalogMetadata[lfn]["Checksum"]):
+                    if not metadata["Checksum"]:
+                        checksumMismatch.append(
+                            (
+                                lfn,
+                                "deprecatedUrl",
+                                se,
+                                "Error fetching checksum",
+                            )
+                        )
+                    elif not compareAdler(metadata["Checksum"], catalogMetadata[lfn]["Checksum"]):
                         if compareAdler(
                             metadata["Checksum"].replace("x", "0"), catalogMetadata[lfn]["Checksum"].replace("x", "0")
                         ):
@@ -297,7 +306,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
                                     lfn,
                                     "deprecatedUrl",
                                     se,
-                                    "%s %s" % (metadata["Checksum"], catalogMetadata[lfn]["Checksum"]),
+                                    f"{metadata['Checksum']} {catalogMetadata[lfn]['Checksum']}",
                                 )
                             )
                         else:
@@ -306,7 +315,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
                                     lfn,
                                     "deprecatedUrl",
                                     se,
-                                    "%s %s" % (metadata["Checksum"], catalogMetadata[lfn]["Checksum"]),
+                                    f"{metadata['Checksum']} {catalogMetadata[lfn]['Checksum']}",
                                 )
                             )
             if sizeMismatch:
@@ -320,7 +329,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
     def __checkPhysicalFileMetadata(self, lfns, se):
         """Check obtain the physical file metadata and check the files are
         available."""
-        gLogger.info("Checking the integrity of %s physical files at %s" % (len(lfns), se))
+        gLogger.info(f"Checking the integrity of {len(lfns)} physical files at {se}")
 
         res = StorageElement(se).getFileMetadata(lfns)
         if not res["OK"]:
@@ -351,12 +360,12 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
             self.reportProblematicReplicas(unavailableReplicas, se, "PFNUnavailable")
         if zeroSizeReplicas:
             self.reportProblematicReplicas(zeroSizeReplicas, se, "PFNZeroSize")
-        gLogger.info("Checking the integrity of physical files at %s complete" % se)
+        gLogger.info(f"Checking the integrity of physical files at {se} complete")
         return S_OK(pfnMetadataDict)
 
     def reportProblematicReplicas(self, replicaTuple, se, reason, fixIt=False):
         """Simple wrapper function around setReplicaProblematic."""
-        gLogger.info("The following %s files had %s at %s" % (len(replicaTuple), reason, se))
+        gLogger.info(f"The following {len(replicaTuple)} files had {reason} at {se}")
         for lfn, pfn, se, reason1 in sorted(replicaTuple):
             if reason1 == reason:
                 reason1 = ""
@@ -378,7 +387,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
 
     def __getCatalogDirectoryContents(self, lfnDir):
         """Obtain the contents of the supplied directory."""
-        gLogger.info("Obtaining the catalog contents for %s directories" % len(lfnDir))
+        gLogger.info(f"Obtaining the catalog contents for {len(lfnDir)} directories")
 
         activeDirs = list(lfnDir)
         allFiles = {}
@@ -390,9 +399,7 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
                 gLogger.error("Failed to get directory contents", res["Message"])
                 return res
             elif currentDir in res["Value"]["Failed"]:
-                gLogger.error(
-                    "Failed to get directory contents", "%s %s" % (currentDir, res["Value"]["Failed"][currentDir])
-                )
+                gLogger.error("Failed to get directory contents", f"{currentDir} {res['Value']['Failed'][currentDir]}")
             else:
                 dirContents = res["Value"]["Successful"][currentDir]
                 activeDirs.extend(dirContents["SubDirs"])
@@ -416,6 +423,6 @@ class DataIntegrityClient(DIRACDataIntegrityClient):
             self._reportProblematicFiles(zeroReplicaFiles, "LFNZeroReplicas")
         if zeroSizeFiles:
             self._reportProblematicFiles(zeroSizeFiles, "LFNZeroSize")
-        gLogger.info("Obtained at total of %s files for the supplied directories" % len(allMetadataDict))
+        gLogger.info(f"Obtained at total of {len(allMetadataDict)} files for the supplied directories")
         resDict = {"Metadata": allMetadataDict, "Replicas": allReplicaDict}
         return S_OK(resDict)
