@@ -76,7 +76,7 @@ def cacheDirectories(directories):
     if not dirSet:
         return
     startTime = time.time()
-    gLogger.always("\nCaching %d directories, %d not cached yet" % (len(directories), len(dirSet)))
+    gLogger.always(f"\nCaching {len(directories)} directories, {len(dirSet)} not cached yet")
 
     # Some DBs refer to "long" directory names (i.e. with additional number, see below)
     #     while others refer to the unnumbered directory.
@@ -97,7 +97,7 @@ def cacheDirectories(directories):
     # # Cache BK path for directories
     # First try cached information in Data Usage DB
     chunkSize = 1000
-    gLogger.always("Getting cache metadata for %d directories" % len(dirShort2Long))
+    gLogger.always(f"Getting cache metadata for {len(dirShort2Long)} directories")
     dirMetadata = {}
     for longDirs in breakListIntoChunks(dirShort2Long.values(), chunkSize):
         res = duClient.getDirMetadata(longDirs)
@@ -126,7 +126,7 @@ def cacheDirectories(directories):
     # For those not available ask the BK
     chunkSize = 100
     if lfnsFromBK:
-        gLogger.always("Getting BK metadata for %d directories" % len(lfnsFromBK))
+        gLogger.always(f"Getting BK metadata for {len(lfnsFromBK)} directories")
         success = {}
         for lfns in breakListIntoChunks(lfnsFromBK, chunkSize):
             for trial in range(10, -1, -1):
@@ -140,7 +140,7 @@ def cacheDirectories(directories):
                 else:
                     break
             success.update(res["Value"].get("Successful", {}))
-        gLogger.always("Successfully obtained BK metadata for %d directories" % len(success))
+        gLogger.always(f"Successfully obtained BK metadata for {len(success)} directories")
         for dirLfn in dirSet - set(bkPathForDir):
             longDir = dirShort2Long[dirLong2Short[dirLfn]]
             metadata = success.get(longDir, [{}])[0]
@@ -161,14 +161,14 @@ def cacheDirectories(directories):
 
     # Ignore invisible directories
     if invisible:
-        gLogger.always("%d paths are ignored as invisible" % len(invisible))
+        gLogger.always(f"{len(invisible)} paths are ignored as invisible")
         cachedInvisible.update(invisible)
         dirSet -= invisible
 
     # For remaining directories, get the LFN information and the PFN information SE by SE
     if dirSet:
-        missingSU = set(dirLong2Short[dirLfn] for dirLfn in dirSet)
-        gLogger.always("Get LFN Storage Usage for %d directories" % len(missingSU))
+        missingSU = {dirLong2Short[dirLfn] for dirLfn in dirSet}
+        gLogger.always(f"Get LFN Storage Usage for {len(missingSU)} directories")
         for dirLfn in missingSU:
             # LFN usage
             for trial in range(10, -1, -1):
@@ -176,27 +176,27 @@ def cacheDirectories(directories):
                 if res["OK"]:
                     break
                 if not trial:
-                    gLogger.fatal("Error getting LFN storage usage %s" % dirLfn, res["Message"])
+                    gLogger.fatal(f"Error getting LFN storage usage {dirLfn}", res["Message"])
                     DIRAC.exit(1)
             bkPath = bkPathForDir[dirShort2Long[dirLfn]]
             infoType = "LFN"
-            gLogger.verbose("Directory %s: %s" % (dirLfn, str(res["Value"])))
+            gLogger.verbose(f"Directory {dirLfn}: {str(res['Value'])}")
             bkPathUsage.setdefault(bkPath, {}).setdefault(infoType, [0, 0])
             bkPathUsage[bkPath][infoType][0] += sum(val.get("Files", 0) for val in res["Value"].values())
             bkPathUsage[bkPath][infoType][1] += sum(val.get("Size", 0) for val in res["Value"].values())
 
         # # get the PFN usage per storage type
         # Storage type is Disk, Archived, Tape and All
-        gLogger.always("Check storage type and PFN usage for %d directories" % len(dirSet))
+        gLogger.always(f"Check storage type and PFN usage for {len(dirSet)} directories")
         for dirLfn in dirSet:
             for trial in range(10, -1, -1):
                 res = suClient.getDirectorySummaryPerSE(dirLfn)
                 if not res["OK"]:
                     if not trial:
-                        gLogger.fatal("Error getting storage usage per SE", "%s %s" % (dirLfn, res["Message"]))
+                        gLogger.fatal("Error getting storage usage per SE", f"{dirLfn} {res['Message']}")
                         DIRAC.exit(1)
                     else:
-                        gLogger.warn("Error getting storage usage per SE, retrying", "%s %s" % (dirLfn, res["Message"]))
+                        gLogger.warn("Error getting storage usage per SE, retrying", f"{dirLfn} {res['Message']}")
                 else:
                     break
             info = physicalStorageUsage.setdefault(dirLfn, {})
@@ -223,7 +223,7 @@ def cacheDirectories(directories):
             datasetStorage[storageType(res["Value"])].add(bkPath)
 
     gLogger.always(
-        "Obtained BK path and storage usage of %d directories in %.1f seconds" % (len(dirSet), time.time() - startTime)
+        f"Obtained BK path and storage usage of {len(dirSet)} directories in {time.time() - startTime:.1f} seconds"
     )
 
 
@@ -259,7 +259,7 @@ def prSize(size):
     units = ("Bytes", "kB", "MB", "GB", "TB", "PB")
     for unit in units:
         if size < 1000.0:
-            return "%.1f %s" % (size, unit)
+            return f"{size:.1f} {unit}"
         size /= 1000.0
     return "???"
 
@@ -270,7 +270,7 @@ def getPhysicalUsage(baseDir):
         res = suClient.getStorageDirectoryData(baseDir, None, None, None, timeout=3600)
         if not res["OK"]:
             if not trial:
-                gLogger.fatal("Error getting list of directories for %s" % baseDir, res["Message"])
+                gLogger.fatal(f"Error getting list of directories for {baseDir}", res["Message"])
                 DIRAC.exit(1)
         else:
             break
@@ -279,7 +279,7 @@ def getPhysicalUsage(baseDir):
     dirSet = set()
     nf = 0
     size = 0
-    gLogger.info("Storage usage OK for %d directories in %s" % (len(info), baseDir))
+    gLogger.info(f"Storage usage OK for {len(info)} directories in {baseDir}")
     for directory in info:
         nodes = directory.split("/")
         try:
@@ -303,9 +303,8 @@ def getPhysicalUsage(baseDir):
 def storageType(seList):
     """Return the storage type: disk, tape or archive."""
     if not (
-        set(se for se in seList if not dmsHelper.isSEArchive(se))
-        - set(["CERN-SWTEST", "CERN-FREEZER-EOS", "CERN-FREEZER"])
-    ) and set(se for se in seList if dmsHelper.isSEArchive(se)):
+        {se for se in seList if not dmsHelper.isSEArchive(se)} - {"CERN-SWTEST", "CERN-FREEZER-EOS", "CERN-FREEZER"}
+    ) and {se for se in seList if dmsHelper.isSEArchive(se)}:
         # Only -ARCHIVE
         return "Archived"
     tapeSEs = resolveSEGroup("Tier1-RAW") + resolveSEGroup("Tier1-RDST")
@@ -355,14 +354,14 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
         if not res["OK"]:
             gLogger.fatal("Cannot get list of directories", res["Message"])
             DIRAC.exit(1)
-        directories = set(
+        directories = {
             subDir
             for subDir in res["Value"]["Successful"][topDirectory]["SubDirs"]
             if subDir.split("/")[2] not in ignoreDirectories
             and "RAW" not in subDir
             and "RDST" not in subDir
             and "SDST" not in subDir
-        )
+        }
         allDirectoriesSet = set()
         for baseDir in directories:
             allDirectoriesSet.update(getPhysicalUsage(baseDir))
@@ -399,7 +398,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
             entries += len(val)
 
             # Get information on useful directories
-            directories = set(row[1] for row in val if row[1].split("/")[2] not in ignoreDirectories)
+            directories = {row[1] for row in val if row[1].split("/")[2] not in ignoreDirectories}
             usedDirectories.update(directories)
             cacheDirectories(directories)
 
@@ -414,7 +413,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
                 if not bkPath:
                     if dirLfn not in notCached:
                         notCached.add(dirLfn)
-                        gLogger.error("Directory %s was not cached" % dirLfn)
+                        gLogger.error(f"Directory {dirLfn} was not cached")
                     bkPath = "Unknown-" + dirLfn
                 bkPathPopularity[bkPath][binNumber] = (
                     bkPathPopularity.setdefault(bkPath, {}).setdefault(binNumber, 0) + count
@@ -425,15 +424,13 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
         gLogger.always("Retrieved %d entries from Popularity table in %.1f seconds" % (entries, time.time() - stTime))
         gLogger.always("Found %d datasets used since %d days" % (len(bkPathPopularity), since))
         counters = {}
-        strangeBKPaths = set(
+        strangeBKPaths = {
             bkPath for bkPath in bkPathPopularity if not bkPathUsage.get(bkPath, {}).get("LFN", (0, 0))[0]
-        )
+        }
         if strangeBKPaths:
-            gLogger.always("%d used datasets do not have an LFN count:" % len(strangeBKPaths))
-            gLogger.always(
-                "\n".join("%s : %s" % (bkPath, str(bkPathUsage.get(bkPath, {}))) for bkPath in strangeBKPaths)
-            )
-        gLogger.always("\nDataset usage for %d datasets" % len(bkPathPopularity))
+            gLogger.always(f"{len(strangeBKPaths)} used datasets do not have an LFN count:")
+            gLogger.always("\n".join(f"{bkPath} : {str(bkPathUsage.get(bkPath, {}))}" for bkPath in strangeBKPaths))
+        gLogger.always(f"\nDataset usage for {len(bkPathPopularity)} datasets")
         for infoType in ("All", "LFN"):
             for i in range(2):
                 counters.setdefault(infoType, []).append(
@@ -483,27 +480,25 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
         unusedDirectories = allDirectoriesSet - usedDirectories
         if unusedDirectories:
             gLogger.always("\n=============================================================")
-            gLogger.always("%d directories have not been used" % len(unusedDirectories))
+            gLogger.always(f"{len(unusedDirectories)} directories have not been used")
             # Remove the used datasets (from other directories)
-            unusedBKPaths = set(bkPathForDir[dirLfn] for dirLfn in unusedDirectories if dirLfn in bkPathForDir) - set(
+            unusedBKPaths = {bkPathForDir[dirLfn] for dirLfn in unusedDirectories if dirLfn in bkPathForDir} - set(
                 bkPathPopularity
             )
             # Remove empty datasets
-            strangeBKPaths = set(
+            strangeBKPaths = {
                 bkPath for bkPath in unusedBKPaths if not bkPathUsage.get(bkPath, {}).get("LFN", (0, 0))[0]
-            )
+            }
             if strangeBKPaths:
-                gLogger.always("%d unused datasets do not have an LFN count:" % len(strangeBKPaths))
-                gLogger.always(
-                    "\n".join("%s : %s" % (bkPath, str(bkPathUsage.get(bkPath, {}))) for bkPath in strangeBKPaths)
-                )
-            unusedBKPaths = set(bkPath for bkPath in unusedBKPaths if bkPathUsage.get(bkPath, {}).get("LFN", (0, 0))[0])
+                gLogger.always(f"{len(strangeBKPaths)} unused datasets do not have an LFN count:")
+                gLogger.always("\n".join(f"{bkPath} : {str(bkPathUsage.get(bkPath, {}))}" for bkPath in strangeBKPaths))
+            unusedBKPaths = {bkPath for bkPath in unusedBKPaths if bkPathUsage.get(bkPath, {}).get("LFN", (0, 0))[0]}
 
             # In case there are datasets both on tape and disk, priviledge tape
             datasetStorage["Disk"] -= datasetStorage["Tape"]
             gLogger.always("\nThe following %d BK paths were not used since %d days" % (len(unusedBKPaths), since))
             for infoType in storageTypes[0:3]:
-                gLogger.always("\n=========== %s datasets ===========" % infoType)
+                gLogger.always(f"\n=========== {infoType} datasets ===========")
                 unusedPaths = unusedBKPaths & datasetStorage[infoType]
                 counters = {}
                 for ty in ("All", "LFN"):
@@ -539,7 +534,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
     gLogger.always("Creating %s file with %d datasets" % (csvFile, len(bkPathPopularity) + len(unusedBKPaths)))
     with open(csvFile, "w") as fd:
         title = (
-            "Name;Configuration;ProcessingPass;FileType;Type;Creation-%s;" % binSize
+            f"Name;Configuration;ProcessingPass;FileType;Type;Creation-{binSize};"
             + "NbLFN;LFNSize;NbDisk;DiskSize;NbTape;TapeSize;NbArchived;ArchivedSize;"
             + ";".join(site.split(".")[1] for site in storageSites)
             + ";Nb Replicas;Nb ArchReps;Storage;FirstUsage;LastUsage;Now"
@@ -571,7 +566,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
                 if prodDict["Status"] in ("Active", "Idle", "Completed"):
                     active.append(str(prodDict["TransformationID"]))
             if active:
-                gLogger.always("Active productions %s found in %s" % (",".join(sorted(active)), bkPath))
+                gLogger.always(f"Active productions {','.join(sorted(active))} found in {bkPath}")
             if info["LFN"][0] == 0:
                 continue
             for infoType in info:
@@ -581,7 +576,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
             if "," in bkPath:
                 gLogger.always("BK path found with ',':", bkPath)
             # Name,Configuration,ProcessingPass, FileType
-            row = "%s;%s;%s;%s" % (
+            row = "{};{};{};{}".format(
                 bkPath.replace("Real Data", "RealData"),
                 config,
                 processingPass.get(bkPath, "Unknown").replace("Real Data", "RealData"),
@@ -597,8 +592,8 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
             for infoType in ("LFN", "Disk", "Tape", "Archived"):
                 row += ";%d;%f" % tuple(info[infoType])
             for site in storageSites:
-                row += ";%f" % info[site][1]
-            row += ";%f;%f" % (
+                row += f";{info[site][1]:f}"
+            row += ";{:f};{:f}".format(
                 float(info["Disk"][0]) / float(info["LFN"][0]),
                 float(info["Archived"][0]) / float(info["LFN"][0]),
             )
@@ -610,7 +605,7 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
                     if bkPath in datasetStorage[infoType]:
                         dsType = infoType
                         break
-            row += ";%s" % dsType
+            row += f";{dsType}"
             bins = sorted(bkPathPopularity.get(bkPath, {}))
             if not bins:
                 bins = [0]
@@ -620,4 +615,4 @@ def scanPopularity(since, getAllDatasets, topDirectory="/lhcb", csvFile=None):
                 usage += bkPathPopularity.get(bkPath, {}).get(nowBin - binNumber, 0)
                 row += ";%d" % usage
             fd.write(row + "\n")
-    gLogger.always("\nSuccessfully wrote CSV file %s" % csvFile)
+    gLogger.always(f"\nSuccessfully wrote CSV file {csvFile}")
