@@ -22,7 +22,7 @@ from xml.dom import minidom
 
 from DIRAC import gLogger, gConfig, S_OK
 from DIRAC.Core.Utilities.List import breakListIntoChunks
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from DIRAC.DataManagementSystem.Client.DataManager import DataManager
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 from DIRAC.Resources.Storage.StorageElement import StorageElement
@@ -95,18 +95,18 @@ def parseArguments(dmScript, allSEs=False, printOutput=True):
             bkFile = bkQuery.getPath()
             # Trick to be able to pass a file containing BKpaths
             if os.path.exists(bkFile):
-                with open(bkFile, "rt") as fc:
+                with open(bkFile) as fc:
                     lines = fc.read().splitlines()
                 bkQueries = [BKQuery(ll.strip().split()[0]) for ll in lines]
-                gLogger.notice("Executing %d BKQueries" % len(bkQueries))
+                gLogger.notice(f"Executing {len(bkQueries)} BKQueries")
             else:
                 # Handle wildcard in processing pass
                 processingPass = bkQuery.getProcessingPass().replace("...", "*")
                 if "*" in processingPass:
                     depth = None if processingPass.endswith("/*") else 1
-                    progressBar = ProgressBar(1, title="Getting list of processing passes (depth=%s)" % depth)
+                    progressBar = ProgressBar(1, title=f"Getting list of processing passes (depth={depth})")
                     processingPasses = getProcessingPasses(bkQuery, depth=depth)
-                    progressBar.endLoop(message="obtained %d processing passes" % len(processingPasses))
+                    progressBar.endLoop(message=f"obtained {len(processingPasses)} processing passes")
                     if len(processingPasses) > 1:
                         gLogger.notice("\n".join(processingPasses))
                     bkQuery.setProcessingPass(None)
@@ -124,7 +124,7 @@ def parseArguments(dmScript, allSEs=False, printOutput=True):
             for bkQuery in bkQueries:
                 progressBar.loop()
                 lfnList += bkQuery.getLFNs(printOutput=progressBar is None and printOutput)
-            progressBar.endLoop(message="Got %d LFNs" % len(lfnList))
+            progressBar.endLoop(message=f"Got {len(lfnList)} LFNs")
 
     return sorted(lfnList), seList
 
@@ -217,9 +217,9 @@ def removeReplicas(lfnList, seList, minReplicas=1, checkFC=True, allDisk=False,
                     gLogger.notice("Successfully removed %d replicas from %s" % (nrep, se))
         for reason, seDict in errorReasons.items():  # can be an iterator
             for se, lfns in seDict.items():  # can be an iterator
-                gLogger.error("Failed to remove %d replicas from %s with reason: %s" % (len(lfns), se, reason))
+                gLogger.error(f"Failed to remove {len(lfns)} replicas from {se} with reason: {reason}")
         if not successfullyRemoved and not errorReasons and not checkFC:
-            gLogger.notice("Replicas were found at no SE in %s" % str(seList))
+            gLogger.notice(f"Replicas were found at no SE in {str(seList)}")
     return 0, errorReasons
 
 
@@ -273,7 +273,7 @@ def removeReplicasWithFC(lfnList, seList, minReplicas=1, allDisk=False, force=Fa
                 if allDisk:
                     reason = "Only ARCHIVE replicas"
                 else:
-                    reason = "No replicas at requested SEs (%d existing)" % len(existingReps)
+                    reason = f"No replicas at requested SEs ({len(existingReps)} existing)"
                 errorReasons.setdefault(reason, {}).setdefault("anywhere", []).append(lfn)
             elif len(existingReps) <= minReplicas:
                 if force and not existingReps - seList:
@@ -338,7 +338,7 @@ def removeReplicasWithFC(lfnList, seList, minReplicas=1, allDisk=False, force=Fa
     if notExisting:
         res = dm.getReplicas(list(notExisting))
         if not res["OK"]:
-            gLogger.error("Error getting replicas of %d non-existing files" % len(notExisting), res["Message"])
+            gLogger.error(f"Error getting replicas of {len(notExisting)} non-existing files", res["Message"])
             errorReasons.setdefault(str(res["Message"]), {}).setdefault("getReplicas", []).extend(list(notExisting))
         else:
             for lfn, reason in res["Value"]["Failed"].items():  # can be an iterator
@@ -373,7 +373,7 @@ def removeReplicasNoFC(lfnList, seList):
     ##################################
     # Try and remove PFNs if not in FC
     ##################################
-    gLogger.notice("Removing %d physical replica from %s, for replicas not in the FC" % (len(lfnList), str(seList)))
+    gLogger.notice(f"Removing {len(lfnList)} physical replica from {str(seList)}, for replicas not in the FC")
     # Remove the replica flag in BK just in case
     errorReasons = {}
     successfullyRemoved = {}
@@ -408,12 +408,12 @@ def removeReplicasNoFC(lfnList, seList):
                 bkOK += len(bkToRemove) - len(bkFailed)
     progressBar.endLoop(message=("Removed replica flag for %d files" % bkOK) if bkOK else "No such files found")
     for reason, lfns in notInBK.items():  # can be an iterator
-        gLogger.notice("Failed to remove replica flag in BK for %d files with error: %s" % (len(lfns), reason))
+        gLogger.notice(f"Failed to remove replica flag in BK for {len(lfns)} files with error: {reason}")
 
     inFC = {}
     for seName in seList:
         se = StorageElement(seName)
-        progressBar = ProgressBar(len(lfnList), title="Checking and removing files from %s" % seName, chunk=chunkSize)
+        progressBar = ProgressBar(len(lfnList), title=f"Checking and removing files from {seName}", chunk=chunkSize)
         for lfnChunk in breakListIntoChunks(lfnList, chunkSize):
             progressBar.loop()
             lfnChunk = set(lfnChunk)
@@ -461,7 +461,7 @@ def removeReplicasNoFC(lfnList, seList):
         progressBar.endLoop(message=("%d files removed" % removed) if removed else "No replicas found to be removed")
     if inFC:
         for se, lfns in inFC.items():  # can be an iterator
-            gLogger.notice("%d files have replica in FC at %s, not removed" % (len(lfns), se))
+            gLogger.notice(f"{len(lfns)} files have replica in FC at {se}, not removed")
     return S_OK({"Successful": successfullyRemoved, "FullyRemoved": notInFC, "Failed": errorReasons})
 
 
@@ -586,12 +586,12 @@ def getAccessURL(lfnList, seList, protocol=None, active=True, diskOnly=False, pr
             res = dm.getReplicas(lfnList, active=False, diskOnly=diskOnly, preferDisk=preferDisk, getUrl=False)
 
     replicas = res.get("Value", {}).get("Successful", {})
-    if isinstance(seList, six.string_types):
+    if isinstance(seList, str):
         seList = seList.split(",")
     if not seList:
-        seList = sorted(set(se for lfn in lfnList for se in replicas.get(lfn, {})))
+        seList = sorted({se for lfn in lfnList for se in replicas.get(lfn, {})})
         if len(seList) > 1:
-            gLogger.notice("Using the following list of SEs: %s" % str(seList))
+            gLogger.notice(f"Using the following list of SEs: {str(seList)}")
     bk = BookkeepingClient()
     notFoundLfns = set(lfnList)
     results = {"OK": True, "Value": {"Successful": {}, "Failed": {}}}
@@ -599,7 +599,7 @@ def getAccessURL(lfnList, seList, protocol=None, active=True, diskOnly=False, pr
     gLogger.setLevel("FATAL")
     # Check if files are MDF
     bkRes = bk.getFileTypeVersion(lfnList)
-    mdfFiles = set(lfn for lfn, fileType in bkRes.get("Value", {}).items() if fileType == "MDF")  # can be an iterator
+    mdfFiles = {lfn for lfn, fileType in bkRes.get("Value", {}).items() if fileType == "MDF"}  # can be an iterator
     for se in seList:
         lfns = [lfn for lfn in lfnList if se in replicas.get(lfn, [])]
         if lfns:
@@ -655,7 +655,7 @@ def removeFiles(lfnList, setProcessed=False):
     # Avoid spurious error messages
     savedLevel = gLogger.getLevel()
     chunkSize = max(10, min(100, len(lfnList) // 10))
-    progressBar = ProgressBar(len(lfnList), title="Removing %d files" % len(lfnList), chunk=chunkSize)
+    progressBar = ProgressBar(len(lfnList), title=f"Removing {len(lfnList)} files", chunk=chunkSize)
     for lfnChunk in breakListIntoChunks(lfnList, chunkSize):
         progressBar.loop()
         # gLogger.setLevel( 'FATAL' )
@@ -681,14 +681,14 @@ def removeFiles(lfnList, setProcessed=False):
     if notExisting:
         # The files are not yet removed from the catalog!! :(((
         progressBar = ProgressBar(
-            len(notExisting), title="Removing %d non-existing files from FC " % len(notExisting), chunk=chunkSize
+            len(notExisting), title=f"Removing {len(notExisting)} non-existing files from FC ", chunk=chunkSize
         )
         notExistingRemoved = []
         for lfnChunk in breakListIntoChunks(notExisting, chunkSize):
             progressBar.loop()
             res = dm.getReplicas(lfnChunk)
             if not res["OK"]:
-                gLogger.error("\nError getting replicas of %d non-existing files" % len(lfnChunk), res["Message"])
+                gLogger.error(f"\nError getting replicas of {len(lfnChunk)} non-existing files", res["Message"])
                 errorReasons.setdefault(str(res["Message"]), []).extend(lfnChunk)
             else:
                 replicas = res["Value"]["Successful"]
@@ -706,7 +706,7 @@ def removeFiles(lfnList, setProcessed=False):
                     res = fc.removeFile(lfnChunk)
                     if not res["OK"]:
                         gLogger.error(
-                            "\nError removing %d non-existing files from the FC" % len(lfnChunk), res["Message"]
+                            f"\nError removing {len(lfnChunk)} non-existing files from the FC", res["Message"]
                         )
                         errorReasons.setdefault(str(res["Message"]), []).extend(lfnChunk)
                     else:
@@ -720,10 +720,10 @@ def removeFiles(lfnList, setProcessed=False):
         progressBar.endLoop()
         if notExistingRemoved:
             successfullyRemoved += notExistingRemoved
-            gLogger.notice("Removed from FC %d non-existing files" % len(notExistingRemoved))
+            gLogger.notice(f"Removed from FC {len(notExistingRemoved)} non-existing files")
 
     if successfullyRemoved:
-        gLogger.notice("Successfully removed %d files" % len(successfullyRemoved))
+        gLogger.notice(f"Successfully removed {len(successfullyRemoved)} files")
     maxLfns = 20
     for reason, lfns in errorReasons.items():  # can be an iterator
         nbLfns = len(lfns)
@@ -763,7 +763,7 @@ def removeFilesInTransformations(lfns, setProcessed=False):
         for transID, lfns in lfnsToSet.items():  # can be an iterator
             res = transClient.setFileStatusForTransformation(transID, "Removed", lfns, force=True)
             if not res["OK"]:
-                gLogger.error("Error setting %d files to Removed" % len(lfns), res["Message"])
+                gLogger.error(f"Error setting {len(lfns)} files to Removed", res["Message"])
             else:
                 gLogger.notice("Successfully set %d files as Removed in transformation %d" % (len(lfns), transID))
 
@@ -813,8 +813,8 @@ def printLfnReplicas(lfnList, active=True, diskOnly=False, preferDisk=False, for
             break
     if res["OK"] and not active:
         replicas = res["Value"]["Successful"]
-        seSet = set(se for ses in replicas.values() for se in ses)
-        seStatus = dict((se, {True: "Active", False: "Banned"}[StorageElement(se).status()["Read"]]) for se in seSet)
+        seSet = {se for ses in replicas.values() for se in ses}
+        seStatus = {se: {True: "Active", False: "Banned"}[StorageElement(se).status()["Read"]] for se in seSet}
         value = {"Failed": res["Value"]["Failed"], "Successful": {}}
         for lfn in sorted(replicas):
             value["Successful"].setdefault(lfn, {})
@@ -823,12 +823,12 @@ def printLfnReplicas(lfnList, active=True, diskOnly=False, preferDisk=False, for
                 if not res["OK"]:
                     value["Failed"][lfn] = "Can't get replica status"
                 else:
-                    key = "%s (%s)" % (se, seStatus[se])
-                    value["Successful"][lfn][key] = "%s (%s)" % (replicas[lfn][se], res["Value"]["Successful"][lfn])
+                    key = f"{se} ({seStatus[se]})"
+                    value["Successful"][lfn][key] = f"{replicas[lfn][se]} ({res['Value']['Successful'][lfn]})"
         res = S_OK(value)
     return printDMResult(
         res,
-        empty="No %sreplica found" % ("active disk " if diskOnly else "allowed " if active else ""),
+        empty=f"No {'active disk ' if diskOnly else 'allowed ' if active else ''}replica found",
         script="dirac-dms-lfn-replicas",
     )
 
@@ -862,7 +862,7 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
     from DIRAC.Core.Utilities.Adler import compareAdler
 
     if len(seList) > 1:
-        gLogger.notice("Using the following list of SEs: %s" % str(seList))
+        gLogger.notice(f"Using the following list of SEs: {str(seList)}")
 
     fc = FileCatalog()
 
@@ -871,12 +871,12 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
     replicas = {}
     # restrict seList to those where the replicas are
     chunkSize = 20
-    progressBar = ProgressBar(len(lfnList), title="Getting replicas for %d files" % len(lfnList), chunk=chunkSize)
+    progressBar = ProgressBar(len(lfnList), title=f"Getting replicas for {len(lfnList)} files", chunk=chunkSize)
     for lfnChunk in breakListIntoChunks(lfnList, chunkSize):
         progressBar.loop()
         res = fc.getReplicas(lfnChunk, allStatus=True)
         if not res["OK"]:
-            gLogger.fatal("Error getting replicas for %d files" % len(lfnChunk), res["Message"])
+            gLogger.fatal(f"Error getting replicas for {len(lfnChunk)} files", res["Message"])
             return 2
         else:
             replicas.update(res["Value"]["Successful"])
@@ -885,7 +885,7 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
     progressBar.endLoop()
     for lfn in sorted(replicas):
         if seList and not [se for se in replicas[lfn] if se in seList]:
-            metadata["Failed"][lfn] = {"FC": "No such file at %s" % " ".join(seList)}
+            metadata["Failed"][lfn] = {"FC": f"No such file at {' '.join(seList)}"}
             replicas.pop(lfn)
             lfnList.remove(lfn)
     metadata["Failed"].update(
@@ -896,7 +896,7 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
     )
     if not seList:
         # take all seList in replicas and add a fake '' to printout the SE name
-        seList = [""] + sorted(set(se for lfn in replicas for se in replicas[lfn]))
+        seList = [""] + sorted({se for lfn in replicas for se in replicas[lfn]})
     if replicas:
         if check:
             res = fc.getFileMetadata(lfnList)
@@ -920,8 +920,8 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
                     seMetadata = res["Value"]
                     for url in seMetadata["Successful"]:
                         pfnMetadata = seMetadata["Successful"][url].copy()
-                        if isinstance(pfnMetadata.get("Mode"), six.integer_types):
-                            pfnMetadata["Mode"] = "%o" % pfnMetadata["Mode"]
+                        if isinstance(pfnMetadata.get("Mode"), int):
+                            pfnMetadata["Mode"] = f"{pfnMetadata['Mode']:o}"
                         metadata["Successful"].setdefault(url, {})[se] = (
                             pfnMetadata
                             if not exists
@@ -945,7 +945,7 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
                                         if field == "Checksum" and compareAdler(lfnMetadata[field], pfnMetadata[field]):
                                             continue
                                         ok = False
-                                        diff += " %s: (LFN %s, PFN %s)" % (
+                                        diff += " {}: (LFN {}, PFN {})".format(
                                             field,
                                             lfnMetadata[field],
                                             pfnMetadata[field],
@@ -969,7 +969,7 @@ def printPfnMetadata(lfnList, seList, check=False, exists=False, summary=False):
         success = {}
         for lfn, reason in metadata["Failed"].items():  # can be an iterator
             nFiles += 1
-            if isinstance(reason, six.string_types):
+            if isinstance(reason, str):
                 failed.setdefault("FC", defaultdict(int))
                 if reason == "FC: No active replicas":
                     failed["FC"]["No active replicas"] += 1
@@ -1109,8 +1109,9 @@ def printReplicaStats(
             lfnReplicas.update(res["Value"])
     elif lfnList:
         chunkSize = max(50, min(500, len(lfnList) // 10))
+        chunkSize = 1000
         lfnReplicas = {}
-        progressBar = ProgressBar(len(lfnList), title="Getting replicas for %d LFNs" % len(lfnList), chunk=chunkSize)
+        progressBar = ProgressBar(len(lfnList), title=f"Getting replicas for {len(lfnList)} LFNs", chunk=chunkSize)
         for lfnChunk in breakListIntoChunks(lfnList, chunkSize):
             progressBar.loop()
             res = dm.getReplicas(lfnChunk, getUrl=False)
@@ -1142,9 +1143,7 @@ def printReplicaStats(
     if getSize:
         lfnSize = {}
         chunkSize = max(50, min(500, len(lfnReplicas) // 10))
-        progressBar = ProgressBar(
-            len(lfnReplicas), title="Getting size for %d LFNs" % len(lfnReplicas), chunk=chunkSize
-        )
+        progressBar = ProgressBar(len(lfnReplicas), title=f"Getting size for {len(lfnReplicas)} LFNs", chunk=chunkSize)
         for lfns in breakListIntoChunks(lfnReplicas, chunkSize):
             progressBar.loop()
             res = FileCatalog().getFileSize(lfns)
@@ -1158,7 +1157,7 @@ def printReplicaStats(
         if (
             (not isinstance(prWithReplicas, list) and not prFailover)
             or (isinstance(prWithReplicas, list) and len(replicas) in prWithReplicas)
-            or (prFailover and prFailover in set(dmsHelper.isSEFailover(se) for se in replicas))
+            or (prFailover and prFailover in {dmsHelper.isSEFailover(se) for se in replicas})
         ):
             if dumpSE and not notAtSE:
                 seStr = ",".join(sorted(dumpSE))
@@ -1198,7 +1197,7 @@ def printReplicaStats(
 
     gigaByte = 1000.0 * 1000.0 * 1000.0
     if directories:
-        dirStr = " in %s" % str(directories)
+        dirStr = f" in {str(directories)}"
     else:
         dirStr = " with replicas"
     if totSize:
@@ -1239,7 +1238,7 @@ def printReplicaStats(
             string = "%16s: %s files" % (se, repSEs[se][0])
             if getSize:
                 size, sizeUnit = scaleSize(repSEs[se][1])
-                string += " - %.3f %s" % (size, sizeUnit)
+                string += f" - {size:.3f} {sizeUnit}"
             gLogger.notice(string)
 
         gLogger.notice("\nSites statistics:")
@@ -1247,7 +1246,7 @@ def printReplicaStats(
             string = "%16s: %d files" % (site, repSites[site][0])
             if getSize:
                 size, sizeUnit = scaleSize(repSites[site][1])
-                string += " - %.3f %s" % (size, sizeUnit)
+                string += f" - {size:.3f} {sizeUnit}"
             gLogger.notice(string)
 
     if prNoReplicas and noReplicas:
@@ -1269,22 +1268,22 @@ def printReplicaStats(
         # Requested set of SEs
         atOrNot = "not " if notAtSE else ""
         if not dumpFromSE:
-            prStr = "\nNo files found %sat %s" % (atOrNot, ",".join(sorted((prSEList))))
+            prStr = f"\nNo files found {atOrNot}at {','.join(sorted(prSEList))}"
         else:
-            prStr = "\nFiles %spresent at %s" % (atOrNot, ",".join(sorted(dumpFromSE)))
+            prStr = f"\nFiles {atOrNot}present at {','.join(sorted(dumpFromSE))}"
         if prWithReplicas:
             if len(prWithReplicas) == 1:
                 prStr += " with %d non-archive replicas" % prWithReplicas[0]
             else:
-                prStr += " with # of non-archive replicas in %s" % str(prWithReplicas)
+                prStr += f" with # of non-archive replicas in {str(prWithReplicas)}"
         elif prFailover:
             prStr += " with replicas in Failover"
         gLogger.notice(prStr)
         for se in dumpFromSE:
             if not notAtSE:
-                gLogger.notice("At %s" % se)
+                gLogger.notice(f"At {se}")
             for lfn in dumpFromSE[se]:
-                gLogger.notice("\t%s" % lfn)
+                gLogger.notice(f"\t{lfn}")
     else:
         # No list of SEs: dump as requested for replicas
         if isinstance(prWithReplicas, list):
@@ -1303,7 +1302,7 @@ def printReplicaStats(
                 if len(prWithReplicas) == 1:
                     prStr += " with %d non-archive replicas" % prWithReplicas[0]
                 else:
-                    prStr += " with # of non-archive replicas in %s" % str(prWithReplicas)
+                    prStr += f" with # of non-archive replicas in {str(prWithReplicas)}"
                 gLogger.notice(prStr)
         elif not prNoReplicas and prFailover:
             if withFailover:
@@ -1418,8 +1417,7 @@ def replicateLfn(lfnList, sourceSE, destList, localCache=None, removeSource=Fals
     finalResult = {"OK": True, "Value": {"Failed": {}, "Successful": {}}}
     if len(lfnList) > 1 or len(destList) > 1 or verbose:
         gLogger.notice(
-            "Replicating %d files to %s" % (len(lfnList), ",".join(destList))
-            + (" from %s" % sourceSE if sourceSE else "")
+            f"Replicating {len(lfnList)} files to {','.join(destList)}" + (f" from {sourceSE}" if sourceSE else "")
         )
 
     # Get the list of replicas to remove if any
@@ -1455,7 +1453,7 @@ def replicateLfn(lfnList, sourceSE, destList, localCache=None, removeSource=Fals
 
     # If there are replicas to remove, do it
     for ses, lfnList in replicasToRemove.items():  # can be an iterator
-        gLogger.info("Removing %d files from %s" % (len(lfnList), ses))
+        gLogger.info(f"Removing {len(lfnList)} files from {ses}")
         seList = ses.split(",")
         lfnList = list(set(lfnList) & replicated)
         code, errorReasons = removeReplicas(lfnList, seList, verbose=False)
@@ -1464,7 +1462,7 @@ def replicateLfn(lfnList, sourceSE, destList, localCache=None, removeSource=Fals
             for reason, seDict in errorReasons.items():  # can be an iterator
                 for se, lfns in seDict.items():  # can be an iterator
                     for lfn in lfns:
-                        finalResult["Value"]["Failed"].setdefault("Remove from %s" % se, {}).update({lfn: reason})
+                        finalResult["Value"]["Failed"].setdefault(f"Remove from {se}", {}).update({lfn: reason})
                     if se in seList:
                         seList.remove(se)
             finalResult["Value"]["Successful"].setdefault("Remove", {}).update(dict.fromkeys(lfnList, ",".join(seList)))
@@ -1504,7 +1502,7 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
     tr = TransformationClient()
     bk = BookkeepingClient()
 
-    gLogger.notice("Now processing %d files" % len(lfnList))
+    gLogger.notice(f"Now processing {len(lfnList)} files")
     chunkSize = max(50, min(500, len(lfnList) // 10))
     progressBar = ProgressBar(len(lfnList), title="Getting replicas from FC ", chunk=chunkSize)
     replicas = {"Successful": {}, "Failed": {}}
@@ -1537,7 +1535,7 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
                 notFoundAtSE.append(lfn)
                 continue
             # Set the file problematic in the FC
-            repsDict[lfn] = dict((se, reps[se]) for se in overlapSEs)
+            repsDict[lfn] = {se: reps[se] for se in overlapSEs}
             # Now see if the file is present in a transformation
             otherSEs = repsSet - overlapSEs
             if not otherSEs or reset:
@@ -1570,14 +1568,14 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
     savedLevel = gLogger.getLevel()
     gLogger.setLevel("INFO" if fullInfo else "WARNING")
     if notFound:
-        gLogger.notice("\n%d files not found in FC" % len(notFound))
+        gLogger.notice(f"\n{len(notFound)} files not found in FC")
         for lfn in notFound:
-            gLogger.info("\t%s" % lfn)
+            gLogger.info(f"\t{lfn}")
 
     if notFoundAtSE:
-        gLogger.notice("%d files not found in FC at any of %s" % (len(notFoundAtSE), targetSEs))
+        gLogger.notice(f"{len(notFoundAtSE)} files not found in FC at any of {targetSEs}")
         for lfn in notFoundAtSE:
-            gLogger.info("\t%s" % lfn)
+            gLogger.info(f"\t{lfn}")
 
     status = "problematic" if not reset else "OK"
     if repsDict:
@@ -1588,7 +1586,7 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
         errors = {}
         for lfnChunk in breakListIntoChunks(repsDict, chunkSize):
             progressBar.loop()
-            chunkDict = dict((lfn, repsDict[lfn]) for lfn in lfnChunk)
+            chunkDict = {lfn: repsDict[lfn] for lfn in lfnChunk}
             res = fc.setReplicaProblematic(chunkDict, revert=reset) if action else {"OK": True}
             if not res["OK"]:
                 errors[res["Message"]] = errors.setdefault(res["Message"], 0) + len(lfnChunk)
@@ -1632,12 +1630,12 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
             res = tr.setFileStatusForTransformation(transID, status, lfns, force=True) if action else {"OK": True}
             if not res["OK"]:
                 gLogger.error(
-                    "\tError setting %d files %s for transformation %s" % (len(lfns), status, transID), res["Message"]
+                    f"\tError setting {len(lfns)} files {status} for transformation {transID}", res["Message"]
                 )
             else:
-                gLogger.notice("\t%d files set %s for transformation %s" % (len(lfns), status, transID))
+                gLogger.notice(f"\t{len(lfns)} files set {status} for transformation {transID}")
             for lfn in lfns:
-                gLogger.info("\t\t%s" % lfn)
+                gLogger.info(f"\t\t{lfn}")
 
     gLogger.setLevel(savedLevel)
     if transNotSet:
@@ -1654,9 +1652,9 @@ def setProblematicFiles(lfnList, targetSEs, reset=False, fullInfo=False, action=
                     % (len(transDict[transID]), status, str(transID))
                 )
                 for lfn in transDict[transID]:
-                    gLogger.verbose("\t\t%s" % lfn)
+                    gLogger.verbose(f"\t\t{lfn}")
 
-    gLogger.notice("Execution completed in %.2f seconds" % (time.time() - startTime))
+    gLogger.notice(f"Execution completed in {time.time() - startTime:.2f} seconds")
     return 0
 
 
@@ -1711,7 +1709,7 @@ def executeLfnMetadata(dmScript):
             failed.update(res["Value"]["Failed"])
     for metadata in success.values():
         if "Mode" in metadata:
-            metadata["Mode"] = "%o" % metadata["Mode"]
+            metadata["Mode"] = f"{metadata['Mode']:o}"
     gLogger.setLevel(savedLevel)
     return printDMResult(
         S_OK({"Successful": success, "Failed": failed}), empty="File not in FC", script="dirac-dms-lfn-metadata"
@@ -1758,7 +1756,7 @@ def executeGetFile(dmScript):
             if not res["OK"]:
                 gLogger.error("Error reporting popularity", res["Message"])
             else:
-                gLogger.info("Successfully reported data usage", "(site: %s, usage: %s)" % (localSite, str(popReport)))
+                gLogger.info("Successfully reported data usage", f"(site: {localSite}, usage: {str(popReport)})")
 
     return printDMResult(result, empty="No allowed replica found", script="dirac-dms-get-file")
 
@@ -1787,7 +1785,7 @@ def executeAddFile():
     if len(args) == 1:
         inputFileName = args[0]
         if os.path.exists(inputFileName):
-            inputFile = open(inputFileName, "rt")
+            inputFile = open(inputFileName)
             for line in inputFile:
                 items = line.rstrip().split()
                 items[0] = items[0].replace("LFN:", "").replace("lfn:", "")
@@ -1814,10 +1812,10 @@ def executeAddFile():
             remoteFile = localFile
         elif os.path.exists(localFile):
             if not os.path.isfile(localFile):
-                gLogger.error("%s is not a file" % localFile)
+                gLogger.error(f"{localFile} is not a file")
                 continue
         else:
-            gLogger.error("File %s doesn't exist locally" % localFile)
+            gLogger.error(f"File {localFile} doesn't exist locally")
             continue
 
         if remoteFile:
@@ -1836,7 +1834,7 @@ def executeAddFile():
             gLogger.notice("Attempting to download file to", localFile)
             from subprocess import Popen, PIPE
 
-            process = Popen([eos, "cp", "%s%s" % (prefix, remoteFile), localFile], stdout=PIPE, stderr=PIPE)
+            process = Popen([eos, "cp", f"{prefix}{remoteFile}", localFile], stdout=PIPE, stderr=PIPE)
             out = process.stdout.read()
             err = process.stderr.read()
             process.stdout.close()
@@ -1854,13 +1852,13 @@ def executeAddFile():
             lfnDict["guid"] = makeGuid(localFile)[localFile]
         # normalize the LFN
         lfn = dms.getLFNsFromList(lfnDict["lfn"])[0]
-        gLogger.notice("\nUploading %s as %s" % (localFile, lfn))
+        gLogger.notice(f"\nUploading {localFile} as {lfn}")
         gLogger.setLevel("FATAL")
         res = dm.putAndRegister(lfn, localFile, lfnDict["SE"], lfnDict["guid"])
         gLogger.setLevel(logLevel)
         if not res["OK"]:
             exitCode = 3
-            gLogger.error("Error: failed to upload %s to %s" % (localFile, lfnDict["SE"]), res["Message"])
+            gLogger.error(f"Error: failed to upload {localFile} to {lfnDict['SE']}", res["Message"])
         else:
             success = res["Value"]["Successful"].get(lfn, [])
             if success and not ({"put", "register"} - set(success)):
@@ -1871,7 +1869,7 @@ def executeAddFile():
             else:
                 gLogger.error(
                     "Error: failed to upload file",
-                    "%s to %s:\n\t %s" % (lfn, lfnDict["SE"], res["Value"]["Failed"][lfn]),
+                    f"{lfn} to {lfnDict['SE']}:\n\t {res['Value']['Failed'][lfn]}",
                 )
         if remoteFile:
             os.remove(localFile)
@@ -1944,13 +1942,13 @@ def executeListDirectory(dmScript, days=0, months=0, years=0, wildcard=None, dep
         # We should get the list of directories from that query
         baseDirs += bkQuery.getDirs()
 
-    progressBar = ProgressBar(len(baseDirs), title="Getting files from %d directories" % len(baseDirs), chunk=1)
+    progressBar = ProgressBar(len(baseDirs), title=f"Getting files from {len(baseDirs)} directories", chunk=1)
     filesInDirs = {}
     for baseDir in baseDirs:
         progressBar.loop()
         if baseDir[-1] == "/":
             baseDir = baseDir[:-1]
-        gLogger.info("Will search for files in %s" % baseDir)
+        gLogger.info(f"Will search for files in {baseDir}")
         activeDirs = [baseDir]
 
         allFiles = set()
@@ -1961,12 +1959,12 @@ def executeListDirectory(dmScript, days=0, months=0, years=0, wildcard=None, dep
             if not res["OK"]:
                 gLogger.error(
                     "Error retrieving directory contents -",
-                    "%s %s/" % (res["Message"].replace(currentDir, ""), currentDir),
+                    f"{res['Message'].replace(currentDir, '')} {currentDir}/",
                 )
             elif currentDir in res["Value"]["Failed"]:
                 gLogger.error(
                     "Error retrieving directory contents -",
-                    "%s %s/" % (res["Value"]["Failed"][currentDir].replace(currentDir, ""), currentDir),
+                    f"{res['Value']['Failed'][currentDir].replace(currentDir, '')} {currentDir}/",
                 )
             else:
                 dirContents = res["Value"]["Successful"][currentDir]
@@ -1997,20 +1995,20 @@ def executeListDirectory(dmScript, days=0, months=0, years=0, wildcard=None, dep
 
     for baseDir, allFiles in filesInDirs.items():  # can be an iterator
         if outputFlag:
-            outputFileName = "%s.lfns" % baseDir[1:].replace("/", "-")
-            outputFile = open(outputFileName, "wt")
+            outputFileName = f"{baseDir[1:].replace('/', '-')}.lfns"
+            outputFile = open(outputFileName, "w")
             outputFile.write("\n".join(sorted(allFiles)))
             outputFile.close()
-            gLogger.notice("%d matched files have been put in %s" % (len(allFiles), outputFileName))
+            gLogger.notice(f"{len(allFiles)} matched files have been put in {outputFileName}")
         else:
             gLogger.notice("\n".join(sorted(allFiles)))
 
         if emptyDirsFlag:
-            outputFileName = "%s.emptydirs" % baseDir[1:].replace("/", "-")
-            outputFile = open(outputFileName, "wt")
+            outputFileName = f"{baseDir[1:].replace('/', '-')}.emptydirs"
+            outputFile = open(outputFileName, "w")
             outputFile.write("\n".join(sorted(emptyDirs)))
             outputFile.close()
-            gLogger.notice("%d empty directories have been put in %s" % (len(emptyDirs), outputFileName))
+            gLogger.notice(f"{len(emptyDirs)} empty directories have been put in {outputFileName}")
 
     return 0
 
@@ -2036,7 +2034,7 @@ def registerBK2FC(lfnList, seList, printResult=False):
         return 1 if printResult else res
     replicas = res["Value"]["Successful"]
     if replicas:
-        gLogger.notice("%d files already registered in FC" % len(replicas))
+        gLogger.notice(f"{len(replicas)} files already registered in FC")
         result["Successful"].update(replicas)
         lfnList = list(set(lfnList) - set(replicas))
 
@@ -2051,12 +2049,11 @@ def registerBK2FC(lfnList, seList, printResult=False):
     if failed:
         if isinstance(failed, list):
             failed = dict.fromkeys(failed, "Not in BK")
-        gLogger.notice("%d files are not in the BK" % len(failed))
+        gLogger.notice(f"{len(failed)} files are not in the BK")
         result["Failed"].update(failed)
         lfnList = list(set(lfnList) - set(failed))
 
     if lfnList:
-
         fc = FileCatalog()
         registrationProtocol = DMSHelpers().getRegistrationProtocols()
         seListString = ",".join(seList)
@@ -2076,7 +2073,7 @@ def registerBK2FC(lfnList, seList, printResult=False):
                     size = metadata["Size"]
                     if size != bkMetadata[lfn]["FileSize"]:
                         gLogger.error("BK-SE file size mismatch", "BK %d - SE %d" % (bkMetadata[lfn]["FileSize"], size))
-                        result["Failed"][lfn] = "Size mismatch between BK and SE %s" % se
+                        result["Failed"][lfn] = f"Size mismatch between BK and SE {se}"
                         continue
                     guid = bkMetadata[lfn]["GUID"]
                     res = storageElement.getURL(lfn, protocol=registrationProtocol)
@@ -2098,7 +2095,7 @@ def registerBK2FC(lfnList, seList, printResult=False):
         if lfnList:
             result["Failed"].update(
                 dict.fromkeys(
-                    (lfn for lfn in lfnList if lfn not in result["Failed"]), "Not found at any of %s" % seListString
+                    (lfn for lfn in lfnList if lfn not in result["Failed"]), f"Not found at any of {seListString}"
                 )
             )
 
