@@ -15,6 +15,7 @@
 
 :synopsis: Lightweight possbile client to the StorageUsageDB.
 """
+
 from DIRAC.Core.Base.Client import Client, createClient
 
 
@@ -26,7 +27,7 @@ class StorageUsageClient(Client):
 
     def __init__(self, url=None, **kwargs):
         """c'tor."""
-        super(StorageUsageClient, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         if url:
             self.setServer(url)
         self.setServer("DataManagement/StorageUsage")
