@@ -15,8 +15,6 @@
 
 :synopsis: StorageUsageDB class is a front-end to the Storage Usage Database.
 """
-import six
-
 import os
 
 # # from DIRAC
@@ -35,9 +33,9 @@ def _standardDirectory(dirPath):
 class StorageUsageDB(DB):
     """.. class:: StorageUsageDB"""
 
-    def __init__(self):
+    def __init__(self, parentLogger=None):
         """Standard Constructor."""
-        DB.__init__(self, "StorageUsageDB", "DataManagement/StorageUsageDB")
+        DB.__init__(self, "StorageUsageDB", "DataManagement/StorageUsageDB", parentLogger=parentLogger)
         self.__initializeDB()
 
     def __initializeDB(self):
@@ -127,7 +125,7 @@ class StorageUsageDB(DB):
                 "Conditions": "VARCHAR(128) NOT NULL",
                 "ProcessingPass": "VARCHAR(255) NOT NULL",
                 "EventType": "VARCHAR(255) NOT NULL",
-                "FileType": "VARCHAR(64) NOT NULL",
+                "FileType": "VARCHAR(255) NOT NULL",
                 "Production": "VARCHAR(64) NOT NULL",
                 "Visibility": "VARCHAR(4) NOT NULL",
             },
@@ -173,7 +171,7 @@ class StorageUsageDB(DB):
 
         if not directoryDict:
             return S_OK()
-        self.log.debug("in publishDirectories: directoryDict is: \n %s" % str(directoryDict))
+        self.log.debug(f"in publishDirectories: directoryDict is: \n {str(directoryDict)}")
         result = self.__getIDs(directoryDict)
         if not result["OK"]:
             return result
@@ -184,14 +182,14 @@ class StorageUsageDB(DB):
                 files = int(pathInfo["Files"])
                 size = int(pathInfo["TotalSize"])
             except ValueError as e:
-                return S_ERROR("Values must be ints: %s" % repr(e))
+                return S_ERROR(f"Values must be ints: {repr(e)}")
             seUsage = pathInfo["SEUsage"]
             sqlpath = self._escapeString(path)["Value"]
             if path in dirIDs:
                 sqlCmd = "UPDATE `su_Directory` SET Files=%d, Size=%d WHERE Path = %s" % (files, size, sqlpath)
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot update directory", "%s: %s" % (path, result["Message"]))
+                    self.log.error("Cannot update directory", f"{path}: {result['Message']}")
                     return result
             else:
                 sqlCmd = "INSERT INTO `su_Directory` (DID, Path, Files, Size) VALUES ( 0, %s, %d, %d )" % (
@@ -201,12 +199,12 @@ class StorageUsageDB(DB):
                 )
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot insert directory", "%s: %s" % (path, result["Message"]))
+                    self.log.error("Cannot insert directory", f"{path}: {result['Message']}")
                     continue
                 dirIDs[path] = result["lastRowId"]
             result = self.__updateSEUsage(dirIDs[path], seUsage, path)
             if not result["OK"]:
-                self.log.error("Cannot update SE usage", "%s:%s: %s" % (path, seUsage, result["Message"]))
+                self.log.error("Cannot update SE usage", f"{path}:{seUsage}: {result['Message']}")
                 return result
         return S_OK()
 
@@ -234,12 +232,12 @@ class StorageUsageDB(DB):
             sqlProblem = self._escapeString(problem)["Value"]
             sqlSite = self._escapeString(site)["Value"]
             sqlReplicaType = self._escapeString(replicaType)["Value"]
-            sqlCmd = "SELECT DID FROM problematicDirs WHERE Path=%s AND Site=%s AND SpaceToken=%s" % (
+            sqlCmd = "SELECT DID FROM problematicDirs WHERE Path={} AND Site={} AND SpaceToken={}".format(
                 sqlPath,
                 sqlSite,
                 sqlSpaceToken,
             )
-            self.log.verbose("in publishToProblematicDirs, sqlCmd: %s" % sqlCmd)
+            self.log.verbose(f"in publishToProblematicDirs, sqlCmd: {sqlCmd}")
             result = self._query(sqlCmd)
             if not result["OK"]:
                 self.log.error("Failed to query problematicDirs")
@@ -253,10 +251,10 @@ class StorageUsageDB(DB):
                     "Path = %s and Site = %s and SpaceToken=%s"
                     % (seFiles, seSize, lfcFiles, lfcSize, sqlProblem, sqlReplicaType, sqlPath, sqlSite, sqlSpaceToken)
                 )
-                self.log.verbose("in publishToProblematicDirs, sqlCmd: %s" % sqlCmd)
+                self.log.verbose(f"in publishToProblematicDirs, sqlCmd: {sqlCmd}")
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot update row (%s, %s) in problematicDirs" % (path, site))
+                    self.log.error(f"Cannot update row ({path}, {site}) in problematicDirs")
                     return result
             else:
                 # entry is not there, make an insert of a new row
@@ -266,10 +264,10 @@ class StorageUsageDB(DB):
                     "( %s, %s, %s, %d, %d, %d, %d, %s, %s, UTC_TIMESTAMP())"
                     % (sqlPath, sqlSite, sqlSpaceToken, seFiles, seSize, lfcFiles, lfcSize, sqlProblem, sqlReplicaType)
                 )
-                self.log.verbose("in publishToProblematicDirs, sqlCmd: %s" % sqlCmd)
+                self.log.verbose(f"in publishToProblematicDirs, sqlCmd: {sqlCmd}")
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot insert row (%s, %s) in problematicDirs" % (path, site))
+                    self.log.error(f"Cannot insert row ({path}, {site}) in problematicDirs")
                     return result
         return S_OK()
 
@@ -294,7 +292,7 @@ class StorageUsageDB(DB):
                 "SELECT d.DID FROM su_Directory AS d, se_Usage AS u WHERE "
                 "d.DID=u.DID AND d.Path=%s AND u.SEName=%s" % (sqlPath, sqlSeName)
             )
-            self.log.verbose("in publishToEReplias, sqlCmd: %s" % sqlCmd)
+            self.log.verbose(f"in publishToEReplias, sqlCmd: {sqlCmd}")
             result = self._query(sqlCmd)
             if not result["OK"]:
                 self.log.error("Failed to query se_Usage")
@@ -310,17 +308,17 @@ class StorageUsageDB(DB):
                     "UPDATE `se_Usage` SET Files=%d, Size=%d, Updated=UTC_TIMESTAMP() WHERE "
                     "DID=%d AND SEName=%s" % (files, size, did, sqlSeName)
                 )
-                self.log.verbose("in publishToEReplias, sqlCmd: %s" % sqlCmd)
+                self.log.verbose(f"in publishToEReplias, sqlCmd: {sqlCmd}")
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot update row (%s, %s) in se_Usage" % (path, seName))
+                    self.log.error(f"Cannot update row ({path}, {seName}) in se_Usage")
                     return result
             else:
                 # entry is not there, make an insert of a new row
                 # get the DID corresponding to this Path, from su_Directory table:
                 result = self.__getIDs(directoryDict)
                 if not result["OK"]:
-                    self.log.error("Cannot getIds for directory %s" % (path))
+                    self.log.error(f"Cannot getIds for directory {path}")
                     return result
                 for dirKey in result["Value"]:
                     try:
@@ -331,10 +329,10 @@ class StorageUsageDB(DB):
                     "INSERT INTO se_Usage (DID, SEName, Files, Size, Updated) VALUES "
                     " ( %d, %s, %d, %d, UTC_TIMESTAMP())" % (did, sqlSeName, files, size)
                 )
-                self.log.verbose("in publishToEReplias, sqlCmd: %s" % sqlCmd)
+                self.log.verbose(f"in publishToEReplias, sqlCmd: {sqlCmd}")
                 result = self._update(sqlCmd)
                 if not result["OK"]:
-                    self.log.error("Cannot insert row (%s, %s) in se_Usage" % (path, seName))
+                    self.log.error(f"Cannot insert row ({path}, {seName}) in se_Usage")
                     return result
         return S_OK()
 
@@ -345,8 +343,8 @@ class StorageUsageDB(DB):
     def __getIDs(self, dirList):
         """get IDs for list of directories."""
         dl = self.__sqlDirList(dirList)
-        sqlCmd = "SELECT Path, DID FROM `su_Directory` WHERE Path in ( %s )" % ", ".join(dl)
-        self.log.verbose("in __getIDs, query: %s" % sqlCmd)
+        sqlCmd = f"SELECT Path, DID FROM `su_Directory` WHERE Path in ( {', '.join(dl)} )"
+        self.log.verbose(f"in __getIDs, query: {sqlCmd}")
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -355,7 +353,7 @@ class StorageUsageDB(DB):
     def __getIDsFromProblematicDirs(self, dirList):
         """Get the ID from the problematicDirs table, for a given directory
         {Path:seInfo}"""
-        self.log.verbose("entry to be removed: %s" % dirList)
+        self.log.verbose(f"entry to be removed: {dirList}")
         dirPath, dirInfo = list(dirList.items())[0]
         dirPath = _standardDirectory(dirPath)
         spaceToken = dirInfo["SpaceToken"]
@@ -363,12 +361,12 @@ class StorageUsageDB(DB):
         sqlSpaceToken = self._escapeString(spaceToken)["Value"]
         site = dirInfo["Site"]
         sqlSite = self._escapeString(site)["Value"]
-        sqlCmd = "SELECT Path, DID FROM problematicDirs WHERE Path=%s AND Site=%s and SpaceToken=%s" % (
+        sqlCmd = "SELECT Path, DID FROM problematicDirs WHERE Path={} AND Site={} and SpaceToken={}".format(
             sqlPath,
             sqlSite,
             sqlSpaceToken,
         )
-        self.log.verbose("in __getIDsFromProblematicDirs, query: %s" % sqlCmd)
+        self.log.verbose(f"in __getIDsFromProblematicDirs, query: {sqlCmd}")
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -416,7 +414,7 @@ class StorageUsageDB(DB):
         else:
             self.log.error("Not enough information to formulate the query: either Site or SEName should be provided ")
             return S_ERROR()
-        self.log.verbose("in __getIDsFromSe_Usage, query: %s" % sqlCmd)
+        self.log.verbose(f"in __getIDsFromSe_Usage, query: {sqlCmd}")
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -430,7 +428,7 @@ class StorageUsageDB(DB):
             return result
         if not seUsage:
             # This indicates there are files without replicas in the FC
-            self.log.warn("Ooops. Dir has no SEUsage!", "ID %s, path %s" % (dirID, path))
+            self.log.warn("Ooops. Dir has no SEUsage!", f"ID {dirID}, path {path}")
             return S_OK()
         sqlVals = []
         # Insert data
@@ -447,11 +445,11 @@ class StorageUsageDB(DB):
                     "( %d, %s, %d, %d, UTC_TIMESTAMP() )" % (dirID, self._escapeString(seName)["Value"], size, files)
                 )
             except ValueError as e:
-                return S_ERROR("Values must be ints: %s" % repr(e))
+                return S_ERROR(f"Values must be ints: {repr(e)}")
         # It may happen that no SE is OK
         if not sqlVals:
             return S_OK()
-        sqlIn = "INSERT INTO `su_SEUsage` ( DID, SEname, Size, Files, Updated ) VALUES %s" % ", ".join(sqlVals)
+        sqlIn = f"INSERT INTO `su_SEUsage` ( DID, SEname, Size, Files, Updated ) VALUES {', '.join(sqlVals)}"
         return self._update(sqlIn)
 
     #############
@@ -460,7 +458,7 @@ class StorageUsageDB(DB):
 
     def __getIDsLike(self, dirPath):
         dirPath = self.__stripDirectory(dirPath)
-        sqlCmd = "SELECT Path, DID FROM `su_Directory` WHERE Path LIKE '%s/%%'" % dirPath
+        sqlCmd = f"SELECT Path, DID FROM `su_Directory` WHERE Path LIKE '{dirPath}/%'"
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -475,7 +473,7 @@ class StorageUsageDB(DB):
             return S_OK()
         sqlIDs = ", ".join([str(dirIDs[path]) for path in dirIDs])
         for tableName in ("su_Directory", "su_SEUsage"):
-            sqlCmd = "DELETE FROM `%s` WHERE DID in ( %s )" % (tableName, sqlIDs)
+            sqlCmd = f"DELETE FROM `{tableName}` WHERE DID in ( {sqlIDs} )"
             result = self._update(sqlCmd)
             if not result["OK"]:
                 return result
@@ -503,7 +501,7 @@ class StorageUsageDB(DB):
         if deletedDirs > 1:
             return S_ERROR("There should not be more than 1 match for a tuple (path,SE)!!")
         sqlIDs = ", ".join([str(dirIDs[path]) for path in dirIDs])
-        sqlCmd = "DELETE FROM se_Usage WHERE DID in ( %s )" % (sqlIDs)
+        sqlCmd = f"DELETE FROM se_Usage WHERE DID in ( {sqlIDs} )"
         result = self._update(sqlCmd)
         if not result["OK"]:
             return result
@@ -521,7 +519,7 @@ class StorageUsageDB(DB):
         result = self.__getIDsFromProblematicDirs(dirDict)
         if not result["OK"]:
             return result
-        self.log.verbose("sqlCmd result for __getIDsFromProblematicDirs is: %s" % result)
+        self.log.verbose(f"sqlCmd result for __getIDsFromProblematicDirs is: {result}")
         dirIDs = result["Value"]
         if not dirIDs:
             self.log.info("No directory to remove")
@@ -529,13 +527,13 @@ class StorageUsageDB(DB):
         deletedDirs = len(dirIDs)
         if deletedDirs > 1:
             return S_ERROR("There should not be more than 1 match for a tuple (path,SE)!!")
-        self.log.info("remove directories: %s" % dirIDs)
+        self.log.info(f"remove directories: {dirIDs}")
         sqlIDs = ", ".join([str(dirIDs[path]) for path in dirIDs])
-        sqlCmd = "DELETE FROM problematicDirs WHERE DID in ( %s )" % (sqlIDs)
+        sqlCmd = f"DELETE FROM problematicDirs WHERE DID in ( {sqlIDs} )"
         result = self._update(sqlCmd)
         if not result["OK"]:
             return result
-        self.log.verbose("sqlCmd result for DELETE is: %s" % result)
+        self.log.verbose(f"sqlCmd result for DELETE is: {result}")
         return S_OK(deletedDirs)
 
     def removeAllFromProblematicDirs(self, site=False):
@@ -543,14 +541,14 @@ class StorageUsageDB(DB):
         (optional)."""
         if site:
             sqlSite = self._escapeString(site)["Value"]
-            sqlCmd = "DELETE FROM problematicDirs WHERE Site=%s" % sqlSite
+            sqlCmd = f"DELETE FROM problematicDirs WHERE Site={sqlSite}"
         else:
             sqlCmd = "DELETE FROM problematicDirs"
-        self.log.verbose("in removeAllFromProblematicDirs, command: %s" % sqlCmd)
+        self.log.verbose(f"in removeAllFromProblematicDirs, command: {sqlCmd}")
         result = self._update(sqlCmd)
         if not result["OK"]:
             return result
-        self.log.verbose("sqlCmd result for DELETE is: %s" % result)
+        self.log.verbose(f"sqlCmd result for DELETE is: {result}")
         deletedDirs = result["Value"]
         return S_OK(deletedDirs)
 
@@ -571,12 +569,12 @@ class StorageUsageDB(DB):
         if rootDir:
             rootDir = self.__stripDirectory(rootDir)
             sqlTables.append("`su_Directory` as d")
-            sqlCond.append("d.Path LIKE '%s/%%'" % rootDir)
+            sqlCond.append(f"d.Path LIKE '{rootDir}/%'")
             sqlCond.append("d.DID = su.DID")
         if preserveDirsList:
             for ignoreDir in preserveDirsList:
                 ignoreDir = self.__stripDirectory(ignoreDir)
-                sqlCond.append("d.Path NOT LIKE '%s/%%'" % ignoreDir)
+                sqlCond.append(f"d.Path NOT LIKE '{ignoreDir}/%'")
         sqlCmd = "SELECT DISTINCT su.DID FROM %s WHERE %s LIMIT %d" % (
             ", ".join(sqlTables),
             " AND ".join(sqlCond),
@@ -593,7 +591,7 @@ class StorageUsageDB(DB):
             cleaned += len(idList)
             sqlIdList = ", ".join(idList)
             for tblName in ("su_Directory", "su_SEUsage"):
-                result = self._update("DELETE FROM `%s` WHERE DID IN ( %s )" % (tblName, sqlIdList))
+                result = self._update(f"DELETE FROM `{tblName}` WHERE DID IN ( {sqlIdList} )")
                 if not result["OK"]:
                     return result
             if len(idList) < sqlLimit:
@@ -614,17 +612,17 @@ class StorageUsageDB(DB):
 
     def __getStorageCond(self, path, fileType, production, SEs):
         path = self.__stripDirectory(path)
-        sqlCond = ["d.DID = su.DID", "d.Path LIKE '%s/%%'" % path]
+        sqlCond = ["d.DID = su.DID", f"d.Path LIKE '{path}/%'"]
         if fileType:
             fileType = self._escapeString(fileType)["Value"][1:-1]
-            sqlCond.append("d.Path LIKE '%%/%s%%'" % fileType)
+            sqlCond.append(f"d.Path LIKE '%/{fileType}%'")
         if production:
             try:
                 sqlCond.append("d.Path LIKE '%%/%08.d%%'" % int(production))
             except ValueError:
                 return S_ERROR("production has to be a number")
         if SEs:
-            sqlCond.append("su.SEName in ( %s )" % ", ".join([self._escapeString(SEName)["Value"] for SEName in SEs]))
+            sqlCond.append(f"su.SEName in ( {', '.join([self._escapeString(SEName)['Value'] for SEName in SEs])} )")
         return sqlCond
 
     def __getStorageSummary(self, path, fileType=False, production=False, SEs=None, groupingField="su.SEName"):
@@ -633,7 +631,7 @@ class StorageUsageDB(DB):
             SEs = []
         sqlCond = self.__getStorageCond(path, fileType, production, SEs)
         sqlFields = (groupingField, "SUM(su.Size)", "SUM(su.Files)")
-        sqlCmd = "SELECT %s FROM `su_SEUsage` as su,`su_Directory` as d WHERE %s GROUP BY %s" % (
+        sqlCmd = "SELECT {} FROM `su_SEUsage` as su,`su_Directory` as d WHERE {} GROUP BY {}".format(
             ", ".join(sqlFields),
             " AND ".join(sqlCond),
             groupingField,
@@ -654,7 +652,7 @@ class StorageUsageDB(DB):
 
     def getStorageDirectories(self, path, fileType=False, production=False, SEs=[]):
         sqlCond = self.__getStorageCond(path, fileType, production, SEs)
-        sqlCmd = "SELECT DISTINCT d.Path FROM `su_SEUsage` as su,`su_Directory` as d WHERE %s" % (" AND ".join(sqlCond))
+        sqlCmd = f"SELECT DISTINCT d.Path FROM `su_SEUsage` as su,`su_Directory` as d WHERE {' AND '.join(sqlCond)}"
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -662,14 +660,14 @@ class StorageUsageDB(DB):
 
     @staticmethod
     def __userExpression(fieldName="d.Path"):
-        return "SUBSTRING_INDEX( SUBSTRING_INDEX( %s, '/', 5 ), '/', -1 )" % fieldName
+        return f"SUBSTRING_INDEX( SUBSTRING_INDEX( {fieldName}, '/', 5 ), '/', -1 )"
 
     def getUserStorageUsage(self, userName=False):
         """Get the usage in the SEs."""
         sqlCond = ["d.DID = su.DID"]
         if userName:
             userName = self._escapeString(userName)["Value"][1:-1]
-            sqlCond.append("d.Path LIKE '/lhcb/user/%s/%s/%%" % (userName[0], userName))
+            sqlCond.append(f"d.Path LIKE '/lhcb/user/{userName[0]}/{userName}/%")
         else:
             sqlCond.append("d.Path LIKE '/lhcb/user/_/%'")
         sqlCmd = "SELECT %s, SUM( su.Size ) FROM `su_Directory` AS d, `su_SEUsage` AS su " "WHERE %s GROUP BY %s" % (
@@ -690,9 +688,9 @@ class StorageUsageDB(DB):
         sqlFields = (sqlUser, "su.SEName", "SUM(su.Size)", "SUM(su.Files)")
         sqlCond = ["d.DID = su.DID", "d.Path LIKE '/lhcb/user/_/%'"]
         if userName:
-            sqlCond.append("%s = %s" % (sqlUser, self._escapeString(userName)["Value"]))
+            sqlCond.append(f"{sqlUser} = {self._escapeString(userName)['Value']}")
         sqlGroup = (sqlUser, "su.SEName")
-        sqlCmd = "SELECT % s FROM `su_Directory` AS d, `su_SEUsage` AS su WHERE %s GROUP BY %s" % (
+        sqlCmd = "SELECT {} FROM `su_Directory` AS d, `su_SEUsage` AS su WHERE {} GROUP BY {}".format(
             ", ".join(sqlFields),
             " AND ".join(sqlCond),
             ", ".join(sqlGroup),
@@ -716,7 +714,7 @@ class StorageUsageDB(DB):
             "SELECT su.SEName, SUM(su.Size), SUM(su.Files) FROM su_Directory AS d, su_SEUsage AS su "
             " WHERE d.DID=su.DID AND d.Path LIKE '%s%%' GROUP BY su.SEName" % (directory)
         )
-        self.log.verbose("in getDirectorySummaryPerSE, sqlCmd: %s " % sqlCmd)
+        self.log.verbose(f"in getDirectorySummaryPerSE, sqlCmd: {sqlCmd} ")
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -735,33 +733,33 @@ class StorageUsageDB(DB):
             sqlTotalSize = int(totalSize)
             sqlTotalFiles = int(totalFiles)
         except ValueError as e:
-            return S_ERROR("Values must be ints: %s" % repr(e))
+            return S_ERROR(f"Values must be ints: {repr(e)}")
         sqlSpaceToken = self._escapeString(spaceToken)["Value"]
         sqlSite = self._escapeString(site)["Value"]
         sqlSDUpdate = self._escapeString(storageDumpLastUpdate)["Value"]
         # check if there is already an entry for the tuple (site, spaceTok)
         res = self.__getSTSummary(site, spaceToken)
-        self.log.verbose(" __getSTSummary returned: %s " % res)
+        self.log.verbose(f" __getSTSummary returned: {res} ")
         if not res["OK"]:
             return S_ERROR(res)
         if not res["Value"]:
-            self.log.warn("Entry for site=%s, spaceToken=%s is not there => insert new entry " % (site, spaceToken))
+            self.log.warn(f"Entry for site={site}, spaceToken={spaceToken} is not there => insert new entry ")
             sqlCmd = (
                 "INSERT INTO `se_STSummary` (Site, SpaceToken, TotalSize, TotalFiles, Updated) VALUES "
                 "( %s, %s, %d, %d, %s)" % (sqlSite, sqlSpaceToken, sqlTotalSize, sqlTotalFiles, sqlSDUpdate)
             )
 
         else:
-            self.log.verbose("Entry for site=%s, spaceToken=%s is there => update entry " % (site, spaceToken))
+            self.log.verbose(f"Entry for site={site}, spaceToken={spaceToken} is there => update entry ")
             sqlCmd = (
                 "UPDATE `se_STSummary` SET TotalSize=%d, TotalFiles=%d, Updated=%s WHERE "
                 "Site=%s and SpaceToken=%s" % (sqlTotalSize, sqlTotalFiles, sqlSDUpdate, sqlSite, sqlSpaceToken)
             )
 
-        self.log.verbose("in publishTose_STSummary, sqlCmd: %s " % sqlCmd)
+        self.log.verbose(f"in publishTose_STSummary, sqlCmd: {sqlCmd} ")
         result = self._update(sqlCmd)
         if not result["OK"]:
-            self.log.error("Cannot insert entry", "%s,%s: %s" % (sqlSite, sqlSpaceToken, result["Message"]))
+            self.log.error("Cannot insert entry", f"{sqlSite},{sqlSpaceToken}: {result['Message']}")
             return result
         return S_OK()
 
@@ -771,17 +769,17 @@ class StorageUsageDB(DB):
         return all entries relative to the site."""
 
         sqlSite = self._escapeString(site)["Value"]
-        sqlCond = ["Site=%s" % sqlSite]
+        sqlCond = [f"Site={sqlSite}"]
         if spaceToken:
             sqlSpaceToken = self._escapeString(spaceToken)["Value"]
-            sqlCond.append("SpaceToken=%s" % sqlSpaceToken)
+            sqlCond.append(f"SpaceToken={sqlSpaceToken}")
 
         sqlCmd = "SELECT Site, SpaceToken, TotalSize, TotalFiles, Updated FROM `se_STSummary` WHERE %s" % " AND ".join(
             sqlCond
         )
-        self.log.verbose("in __getSTSummary sqlCmd is: %s " % sqlCmd)
+        self.log.verbose(f"in __getSTSummary sqlCmd is: {sqlCmd} ")
         result = self._query(sqlCmd)
-        self.log.verbose(" __getSTSummary result: %s " % result)
+        self.log.verbose(f" __getSTSummary result: {result} ")
         if not result["OK"]:
             return S_ERROR(result)
         return S_OK(result["Value"])
@@ -798,15 +796,15 @@ class StorageUsageDB(DB):
         If no space token is specified, remove all entries relative to site
         """
         sqlSite = self._escapeString(site)["Value"]
-        sqlCond = ["Site=%s" % sqlSite]
+        sqlCond = [f"Site={sqlSite}"]
         if spaceToken:
             sqlSpaceToken = self._escapeString(spaceToken)["Value"]
-            sqlCond.append("SpaceToken=%s" % sqlSpaceToken)
+            sqlCond.append(f"SpaceToken={sqlSpaceToken}")
 
-        sqlCmd = "DELETE FROM `se_STSummary` WHERE %s" % (" AND ".join(sqlCond))
-        self.log.verbose("in __getSTSummary, sqlCmd: %s " % sqlCmd)
+        sqlCmd = f"DELETE FROM `se_STSummary` WHERE {' AND '.join(sqlCond)}"
+        self.log.verbose(f"in __getSTSummary, sqlCmd: {sqlCmd} ")
         result = self._update(sqlCmd)
-        self.log.verbose("in __getSTSummary result: %s " % result)
+        self.log.verbose(f"in __getSTSummary result: {result} ")
         if not result["OK"]:
             return S_ERROR(result)
         return S_OK(result["Value"])
@@ -815,18 +813,18 @@ class StorageUsageDB(DB):
         """Get a summary of problematic directories for a given site and given
         problem (optional)"""
         sqlSite = self._escapeString(site)["Value"]
-        sqlCond = ["Site=%s" % sqlSite]
+        sqlCond = [f"Site={sqlSite}"]
         if problem:
             sqlProblem = self._escapeString(problem)["Value"]
-            sqlCond.append("Problem=%s" % sqlProblem)
+            sqlCond.append(f"Problem={sqlProblem}")
 
         sqlCmd = (
             "SELECT Site, SpaceToken, LFCFiles, SEFiles, Path, Problem, ReplicaType FROM `problematicDirs` "
             "WHERE %s" % (" AND ".join(sqlCond))
         )
-        self.log.verbose("in getProblematicDirsSummary sqlCmd: %s " % sqlCmd)
+        self.log.verbose(f"in getProblematicDirsSummary sqlCmd: {sqlCmd} ")
         result = self._query(sqlCmd)
-        self.log.verbose("in getProblematicDirsSummary result: %s " % result)
+        self.log.verbose(f"in getProblematicDirsSummary result: {result} ")
         if not result["OK"]:
             return S_ERROR(result["Message"])
         return S_OK(result["Value"])
@@ -847,7 +845,7 @@ class StorageUsageDB(DB):
                     "SELECT su.SEName, SUM(su.Size), SUM(su.Files)  FROM su_Directory AS d, su_SEUsage AS su WHERE "
                     "d.DID=su.DID AND d.Path LIKE '/lhcb/data/%%/RAW/%%/%%/%%/%d/' GROUP BY su.SEName" % (thisRun)
                 )
-                self.log.verbose("in getRunSummaryPerSE, sqlCmd: %s " % sqlCmd)
+                self.log.verbose(f"in getRunSummaryPerSE, sqlCmd: {sqlCmd} ")
                 result = self._query(sqlCmd)
                 if not result["OK"]:
                     return S_ERROR(result)
@@ -860,7 +858,7 @@ class StorageUsageDB(DB):
                 "SELECT su.SEName, SUM(su.Size), SUM(su.Files)  FROM su_Directory AS d, su_SEUsage AS su WHERE "
                 "d.DID=su.DID and d.Path LIKE '/lhcb/data/%%/RAW/%%/%%/%%/%d/' GROUP BY su.SEName" % (run)
             )
-            self.log.verbose("in getRunSummaryPerSE, sqlCmd: %s " % sqlCmd)
+            self.log.verbose(f"in getRunSummaryPerSE, sqlCmd: {sqlCmd} ")
             result = self._query(sqlCmd)
             if not result["OK"]:
                 return S_ERROR(result)
@@ -878,7 +876,7 @@ class StorageUsageDB(DB):
         total size
         """
         path = _standardDirectory(path)
-        sqlCmd = "SELECT DID FROM su_Directory where Path like '%s%%'" % (path)
+        sqlCmd = f"SELECT DID FROM su_Directory where Path like '{path}%'"
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -890,7 +888,7 @@ class StorageUsageDB(DB):
             # warning! this has to be corrected! there is no need to make a loop! the query should return only one row
             # add a check for that. And return an error if it return more than one row
 
-        sqlCmd = "SELECT Files, Updated, SEName, Size FROM su_SEUsage WHERE DID=%s" % (did)
+        sqlCmd = f"SELECT Files, Updated, SEName, Size FROM su_SEUsage WHERE DID={did}"
         result = self._query(sqlCmd)
         if not result["OK"]:
             return result
@@ -916,10 +914,10 @@ class StorageUsageDB(DB):
 
     def __getCatalogCond(self, path, fileType, production):
         path = self.__stripDirectory(path)
-        sqlCond = ["Path LIKE '%s/%%'" % path]
+        sqlCond = [f"Path LIKE '{path}/%'"]
         if fileType:
             fileType = self._escapeString(fileType)["Value"][1:-1]
-            sqlCond.append("Path LIKE '%%/%s%%'" % fileType)
+            sqlCond.append(f"Path LIKE '%/{fileType}%'")
         if production:
             try:
                 sqlCond.append("Path LIKE '%%/%08.d%%'" % int(production))
@@ -931,7 +929,7 @@ class StorageUsageDB(DB):
         """Retrieves the storage summary for all of the known directories."""
         sqlCond = self.__getCatalogCond(path, fileType, production)
         sqlFields = (groupingField, "SUM(Size)", "SUM(Files)")
-        sqlCmd = "SELECT %s FROM `su_Directory` WHERE %s GROUP BY %s" % (
+        sqlCmd = "SELECT {} FROM `su_Directory` WHERE {} GROUP BY {}".format(
             ", ".join(sqlFields),
             " AND ".join(sqlCond),
             groupingField,
@@ -950,7 +948,7 @@ class StorageUsageDB(DB):
     def getUserSummary(self, userName=False):
         if userName:
             userName = self._escapeString(userName)["Value"][1:-1]
-            path = "/lhcb/user/%s/%s" % (userName[0], userName)
+            path = f"/lhcb/user/{userName[0]}/{userName}"
         else:
             path = "/lhcb/user/_/%"
         return self.__getSummary(path, groupingField=self.__userExpression("Path"))
@@ -961,7 +959,7 @@ class StorageUsageDB(DB):
 
     def sendDataUsageReport(self, site, directoryDict, status="New"):
         """Add a new trace in the Popularity table."""
-        self.log.verbose("in addPopCount: dirDict: %s site: %s" % (directoryDict, site))
+        self.log.verbose(f"in addPopCount: dirDict: {directoryDict} site: {site}")
         if not directoryDict:
             return S_OK()
         sqlSite = self._escapeString(site)["Value"]
@@ -971,16 +969,16 @@ class StorageUsageDB(DB):
             sqlPath = self._escapeString(di)["Value"]
             sqlStatus = self._escapeString(status)["Value"]
             if not isinstance(count, int):
-                self.log.warn("in sendDataUsageReport: type is not correct %s" % count)
+                self.log.warn(f"in sendDataUsageReport: type is not correct {count}")
                 continue
             sqlCmd = (
                 "INSERT INTO `Popularity` ( Path, Site, Count, Status, InsertTime) VALUES "
                 "( %s, %s, %d, %s, UTC_TIMESTAMP() )" % (sqlPath, sqlSite, count, sqlStatus)
             )
-            self.log.verbose("in sendDataUsageReport, sqlCmd: %s " % sqlCmd)
+            self.log.verbose(f"in sendDataUsageReport, sqlCmd: {sqlCmd} ")
             result = self._update(sqlCmd)
             if not result["OK"]:
-                self.log.error("Cannot insert entry: %s" % (result["Message"]))
+                self.log.error(f"Cannot insert entry: {result['Message']}")
                 continue
             insertedEntries += 1
         return S_OK(insertedEntries)
@@ -992,7 +990,7 @@ class StorageUsageDB(DB):
 
         Optional keys are the status and the creation time
         """
-        self.log.verbose("in addPopCount: dirDict: %s" % (directoryDict))
+        self.log.verbose(f"in addPopCount: dirDict: {directoryDict}")
         if not directoryDict:
             return S_OK()
         insertedEntries = 0
@@ -1001,7 +999,7 @@ class StorageUsageDB(DB):
                 site = directoryDict[di]["site"]
                 count = directoryDict[di]["count"]
             except KeyError:
-                self.log.error("input directoryDict should specify site and count keys . %s " % str(directoryDict))
+                self.log.error(f"input directoryDict should specify site and count keys . {str(directoryDict)} ")
                 return S_ERROR("wrong arguments format")
             # set default value for status
             status = directoryDict[di].get("status", "New")
@@ -1011,7 +1009,7 @@ class StorageUsageDB(DB):
             sqlStatus = self._escapeString(status)["Value"]
             sqlSite = self._escapeString(site)["Value"]
             if not isinstance(count, int):
-                self.log.warn("in sendDataUsageReport: type is not correct %s" % count)
+                self.log.warn(f"in sendDataUsageReport: type is not correct {count}")
                 continue
             # by default, insert the record with the current time, unless the input directoryDict specifies the creation time
             insertTime = directoryDict[di].get("creationTime")
@@ -1020,10 +1018,10 @@ class StorageUsageDB(DB):
                 "INSERT INTO `Popularity` ( Path, Site, Count, Status, InsertTime) VALUES "
                 "( %s, %s, %d, %s, %s )" % (sqlPath, sqlSite, count, sqlStatus, sqlInsertTime)
             )
-            self.log.verbose("in sendDataUsageReport_2, sqlCmd: %s " % sqlCmd)
+            self.log.verbose(f"in sendDataUsageReport_2, sqlCmd: {sqlCmd} ")
             result = self._update(sqlCmd)
             if not result["OK"]:
-                self.log.error("Cannot insert entry: %s" % (result["Message"]))
+                self.log.error(f"Cannot insert entry: {result['Message']}")
                 continue
             insertedEntries += 1
         return S_OK(insertedEntries)
@@ -1033,7 +1031,7 @@ class StorageUsageDB(DB):
         time interval."""
         if startTime > endTime:
             return S_OK()
-        if not isinstance(startTime, six.string_types) or not isinstance(endTime, six.string_types):
+        if not isinstance(startTime, str) or not isinstance(endTime, str):
             return S_ERROR("wrong arguments format")
 
         sqlStartTime = self._escapeString(startTime)["Value"]
@@ -1043,7 +1041,7 @@ class StorageUsageDB(DB):
             "SELECT ID, Path, Site, Count, InsertTime from `Popularity` WHERE "
             "Status = %s AND InsertTime > %s AND InsertTime < %s " % (sqlStatus, sqlStartTime, sqlEndTime)
         )
-        self.log.verbose("in getDataUsageSummary, sqlCmd: %s " % sqlCmd)
+        self.log.verbose(f"in getDataUsageSummary, sqlCmd: {sqlCmd} ")
         return self._query(sqlCmd)
 
     def getDataUsageForDirectory(self, path):
@@ -1064,8 +1062,8 @@ class StorageUsageDB(DB):
         sqlStatus = self._escapeString(newStatus)["Value"]
         strIdList = [str(iD) for iD in idList]
         sqlIdList = ", ".join(strIdList)
-        self.log.verbose("updatePopEntryStatus: sqlIdList %s " % sqlIdList)
-        sqlCmd = "UPDATE `Popularity` SET Status=%s WHERE ID IN ( %s )" % (sqlStatus, sqlIdList)
+        self.log.verbose(f"updatePopEntryStatus: sqlIdList {sqlIdList} ")
+        sqlCmd = f"UPDATE `Popularity` SET Status={sqlStatus} WHERE ID IN ( {sqlIdList} )"
         result = self._update(sqlCmd)
         if not result["OK"]:
             return result
@@ -1087,16 +1085,16 @@ class StorageUsageDB(DB):
             return result
         dirIDs = result["Value"]
         if not dirIDs:
-            errMsg = "ERROR! the directory %s was not found in the LFN directory table! " % directoryDict
-            self.log.error("%s" % errMsg)
+            errMsg = f"ERROR! the directory {directoryDict} was not found in the LFN directory table! "
+            self.log.error(f"{errMsg}")
             return S_ERROR(errMsg)
-        self.log.verbose("in insertToDirMetadata: dirIDs: %s" % (dirIDs))
+        self.log.verbose(f"in insertToDirMetadata: dirIDs: {dirIDs}")
         # returns a dictionary of type:
         #  {dir1: ID1, dir2: ID2, ...}
         insertedEntries = 0
         for dirKey in directoryDict:
             if dirKey not in dirIDs:
-                self.log.warn("in insertToDirMetadata: found no DID for directory %s" % dirKey)
+                self.log.warn(f"in insertToDirMetadata: found no DID for directory {dirKey}")
                 continue
             iD = int(dirIDs[dirKey])
             try:
@@ -1110,8 +1108,8 @@ class StorageUsageDB(DB):
                 sqlProd = self._escapeString(info["Production"])["Value"]
                 sqlVisi = self._escapeString(info["Visibility"])["Value"]
             except KeyError:
-                self.log.error("in insertToDirMetadata: the input dict was not correctly formatted: %s" % directoryDict)
-                return S_ERROR("Key error in input dictionary %s" % directoryDict)
+                self.log.error(f"in insertToDirMetadata: the input dict was not correctly formatted: {directoryDict}")
+                return S_ERROR(f"Key error in input dictionary {directoryDict}")
             sqlCmd = (
                 "INSERT INTO `DirMetadata` ( DID, ConfigName, ConfigVersion, Conditions, ProcessingPass, "
                 "EventType, FileType, Production, Visibility ) VALUES ( %d, %s, %s, %s, %s, %s, %s, %s, %s )"
@@ -1127,10 +1125,10 @@ class StorageUsageDB(DB):
                     sqlVisi,
                 )
             )
-            self.log.verbose("in insertToDirMetadata, sqlCmd: %s " % sqlCmd)
+            self.log.verbose(f"in insertToDirMetadata, sqlCmd: {sqlCmd} ")
             result = self._update(sqlCmd)
             if not result["OK"]:
-                self.log.error("Cannot insert entry: %s" % (result["Message"]))
+                self.log.error(f"Cannot insert entry: {result['Message']}")
                 return S_ERROR(result["Message"])
             insertedEntries += 1
         return S_OK(insertedEntries)
@@ -1150,16 +1148,16 @@ class StorageUsageDB(DB):
             return S_ERROR(result["Message"])
         dirIDs = result["Value"]
         if not dirIDs:
-            errMsg = "ERROR! the directories %s were not found in the LFN directory table! " % str(stdDirList)
-            self.log.error("%s" % errMsg)
+            errMsg = f"ERROR! the directories {str(stdDirList)} were not found in the LFN directory table! "
+            self.log.error(f"{errMsg}")
             return S_ERROR(errMsg)
-        self.log.verbose("in getDirMetadata, dirIDs: %s" % (dirIDs))
+        self.log.verbose(f"in getDirMetadata, dirIDs: {dirIDs}")
         # returns a dictionary of type:
         #  {dir1: ID1, dir2: ID2, ...}
         idList = []
         for dirKey in stdDirList:
             if dirKey not in dirIDs:
-                self.log.warn("in getDirMetadata: found no DID for directory %s" % dirKey)
+                self.log.warn(f"in getDirMetadata: found no DID for directory {dirKey}")
             else:
                 idList.append(str(dirIDs[dirKey]))
         sqlCmd = (
@@ -1167,7 +1165,7 @@ class StorageUsageDB(DB):
             "Production, Visibility FROM `DirMetadata` WHERE DID in ( %s )"
             % ", ".join(["'%s'" % did for did in idList])
         )
-        self.log.verbose("in getDirMetadata, sqlCmd: %s " % sqlCmd)
+        self.log.verbose(f"in getDirMetadata, sqlCmd: {sqlCmd} ")
         result = self._query(sqlCmd)
         if not result["OK"]:
             return S_ERROR(result["Message"])
@@ -1182,7 +1180,7 @@ class StorageUsageDB(DB):
                     if t[0] == did:
                         metadata[dirPath] = t
                         break
-        self.log.verbose("getDirMetadata returns %s" % str(metadata))
+        self.log.verbose(f"getDirMetadata returns {str(metadata)}")
         return S_OK(metadata)
 
 
