@@ -15,9 +15,6 @@
 
 :synopsis: Implementation of the Data Usage service in the DISET framework.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import six
 
 # # from DIRAC
@@ -28,8 +25,6 @@ from DIRAC.Core.DISET.RequestHandler import RequestHandler
 from LHCbDIRAC.DataManagementSystem.DB.StorageUsageDB import StorageUsageDB
 
 # # RCSID
-__RCSID__ = "$Id$"
-
 # global instance of the StorageUsageDB class
 gStorageUsageDB = False
 
@@ -46,21 +41,21 @@ class DataUsageHandler(RequestHandler):
     .. class:: DataUsageHandler
     """
 
-    types_sendDataUsageReport = [six.string_types, dict]
+    types_sendDataUsageReport = [(str,), dict]
 
     @staticmethod
     def export_sendDataUsageReport(site, directoryDict, status="New"):
         """export of sendDataUsageReport."""
         return gStorageUsageDB.sendDataUsageReport(site, directoryDict, status)
 
-    types_getDataUsageSummary = [six.string_types, six.string_types, six.string_types]
+    types_getDataUsageSummary = [(str,), (str,), (str,)]
 
     @staticmethod
     def export_getDataUsageSummary(startTime, endTime, status):
         """export of getDataUsageSummary."""
         return gStorageUsageDB.getDataUsageSummary(startTime, endTime, status)
 
-    types_getDataUsageForDirectory = [six.string_types]
+    types_getDataUsageForDirectory = [(str,)]
 
     @staticmethod
     def export_getDataUsageForDirectory(path):
@@ -74,7 +69,7 @@ class DataUsageHandler(RequestHandler):
         """export of sendDataUsageReport (new version)"""
         return gStorageUsageDB.sendDataUsageReport_2(directoryDict)
 
-    types_updatePopEntryStatus = [list, six.string_types]
+    types_updatePopEntryStatus = [list, (str,)]
 
     @staticmethod
     def export_updatePopEntryStatus(idList, newStatus):
