@@ -15,7 +15,6 @@
 
 :synopsis: DISET interface to the RAWIntegrityDB.
 """
-
 # imports
 import six
 
@@ -46,19 +45,19 @@ class RAWIntegrityHandler(RequestHandler):
     """
 
     types_addFile = [
-        six.string_types,
-        six.string_types,
-        six.integer_types,
-        six.string_types,
-        six.string_types,
-        six.string_types,
+        (str,),
+        (str,),
+        (int,),
+        (str,),
+        (str,),
+        (str,),
     ]
 
     @staticmethod
     def export_addFile(lfn, pfn, size, se, guid, checksum):
         """Add a file to the RAW integrity DB."""
         try:
-            gLogger.info("RAWIntegrityHandler.addFile: Attempting to add %s to the gRAWIntegrityDB." % lfn)
+            gLogger.info(f"RAWIntegrityHandler.addFile: Attempting to add {lfn} to the gRAWIntegrityDB.")
             res = gRAWIntegrityDB.addFile(lfn, pfn, size, se, guid, checksum)
             return res
         except Exception as x:
@@ -102,7 +101,7 @@ class RAWIntegrityHandler(RequestHandler):
             gLogger.exception(errStr, lException=x)
             return S_ERROR(errStr)
 
-    types_getFilesSummaryWeb = [dict, list, six.integer_types, six.integer_types]
+    types_getFilesSummaryWeb = [dict, list, (int,), (int,)]
 
     @staticmethod
     def export_getFilesSummaryWeb(selectDict, sortList, startItem, maxItems):
@@ -162,7 +161,7 @@ class RAWIntegrityHandler(RequestHandler):
         resultDict["Extras"] = statusCountDict
         return S_OK(resultDict)
 
-    types_getStatistics = [six.string_types, dict]
+    types_getStatistics = [(str,), dict]
 
     @staticmethod
     def export_getStatistics(attribute, selectDict):
