@@ -15,10 +15,6 @@
 
 :synopsis: DISET request handler base class for the DatasetDB
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import time
 import sys
@@ -29,8 +25,6 @@ import six
 from DIRAC import gLogger, S_OK, S_ERROR
 from DIRAC.Core.DISET.RequestHandler import RequestHandler
 
-__RCSID__ = "$Id$"
-
 allRunFields = [
     "runID",
     "fillID",
@@ -77,7 +71,7 @@ def initializeRunDBInterfaceHandler(serviceInfo):
         ORACLE_HOME = os.environ["ORACLE_HOME"]
     except BaseException:
         print("ERROR: ORACLE_HOME environment variable should be set")
-    sys.path.append("%s" % str(ORACLE_HOME))
+    sys.path.append(f"{str(ORACLE_HOME)}")
     import RunDatabase_Defines  # pylint: disable=import-error
 
     # print dir(RunDatabase_Defines)
@@ -129,22 +123,22 @@ class RunDBInterfaceHandler(RequestHandler):
                     for strState in selectValue:
                         intStates.append(fileStateRev[strState])
                     selectValue = intStates
-                if isinstance(selectValue, six.string_types):
-                    paramString = "%s,%s='%s'" % (paramString, selectParam, selectValue)
+                if isinstance(selectValue, str):
+                    paramString = f"{paramString},{selectParam}='{selectValue}'"
                 else:
-                    paramString = "%s,%s=%s" % (paramString, selectParam, selectValue)
+                    paramString = f"{paramString},{selectParam}={selectValue}"
         decending = False
         if sortList:
-            paramString = "%s,orderBy='%s'" % (paramString, sortList[0][0])
+            paramString = f"{paramString},orderBy='{sortList[0][0]}'"
             if sortList[0][1] == "DESC":
                 decending = True
-        paramString = "%s,no=%s" % (paramString, sys.maxsize)
+        paramString = f"{paramString},no={sys.maxsize}"
         if paramString:
-            filesQueryString = "success,result = server.getFilesDirac(fields=allFileFields%s)" % paramString
+            filesQueryString = f"success,result = server.getFilesDirac(fields=allFileFields{paramString})"
         else:
             filesQueryString = "success,result = server.getFilesDirac(fields=allFileFields)"
         print(filesQueryString)
-        exec (filesQueryString)
+        exec(filesQueryString)
         if not success:  # using exec statement above -> pylint: disable=undefined-variable
             return S_ERROR(result)  # using exec statement above -> pylint: disable=undefined-variable
         resultDict = {}
@@ -232,24 +226,24 @@ class RunDBInterfaceHandler(RequestHandler):
                     for strState in selectValue:
                         intStates.append(runStateRev[strState])
                     selectValue = intStates
-                if isinstance(selectValue, six.string_types):
-                    paramString = "%s,%s='%s'" % (paramString, selectParam, selectValue)
+                if isinstance(selectValue, str):
+                    paramString = f"{paramString},{selectParam}='{selectValue}'"
                 else:
-                    paramString = "%s,%s=%s" % (paramString, selectParam, selectValue)
+                    paramString = f"{paramString},{selectParam}={selectValue}"
         decending = False
         if sortList:
-            paramString = "%s,orderBy='%s'" % (paramString, sortList[0][0])
+            paramString = f"{paramString},orderBy='{sortList[0][0]}'"
             if sortList[0][1] == "DESC":
                 decending = True
-        paramString = "%s,no=%s" % (paramString, sys.maxsize)
+        paramString = f"{paramString},no={sys.maxsize}"
         jobsQueryString = "success,result = "
         jobsQueryString += "server.getRunsDirac("
         jobsQueryString += "fields=allRunFields,runExtraParams=['magnetCurrent','magnetState']"
         if paramString:
-            jobsQueryString += "%s" % paramString
+            jobsQueryString += f"{paramString}"
         jobsQueryString += ")"
         print(jobsQueryString)
-        exec (jobsQueryString)
+        exec(jobsQueryString)
         if not success:  # using exec statement above -> pylint: disable=E0601
             return S_ERROR(result)  # using exec statement above -> pylint: disable=E0601
         resultDict = {}
@@ -325,12 +319,12 @@ class RunDBInterfaceHandler(RequestHandler):
             totalFiles += runCounters[runID]["Files"]
             totalEvents += runCounters[runID]["Events"]
             totalSize += runCounters[runID]["Size"]
-            size = "%.2f" % (runCounters[runID]["Size"] / (1000 * 1000 * 1000.0))
+            size = f"{runCounters[runID]['Size'] / (1000 * 1000 * 1000.0):.2f}"
             runCounters[runID]["Size"] = size
         resultDict["Counters"] = {
             "Files": totalFiles,
             "Events": totalEvents,
-            "Size": "%.2f" % (totalSize / (1000 * 1000 * 1000.0)),
+            "Size": f"{totalSize / (1000 * 1000 * 1000.0):.2f}",
         }
 
         records = []
@@ -415,15 +409,15 @@ class RunDBInterfaceHandler(RequestHandler):
 
             for key, query in queries:
                 startTime = time.time()
-                execString = "success,result = server.%s()" % query
+                execString = f"success,result = server.{query}()"
                 print(execString)
-                exec (execString)  # pylint: disable=exec-used
+                exec(execString)  # pylint: disable=exec-used
                 gLogger.debug(
                     "RunDBInterfaceHandler.getSelections: server.%s() took %.2f seconds."
                     % (query, time.time() - startTime)
                 )
                 if not success:  # using exec statement above -> pylint: disable=used-before-assignment
-                    errStr = "RunDBInterfaceHandler.getSelections: Failed to get distinct %s." % key
+                    errStr = f"RunDBInterfaceHandler.getSelections: Failed to get distinct {key}."
                     gLogger.error(errStr, result)  # using exec statement above -> pylint: disable=E0601
                     return S_ERROR(errStr)
                 paramDict[key] = [res for res in result if res]
@@ -447,7 +441,7 @@ class RunDBInterfaceHandler(RequestHandler):
         except Exception as x:
             errStr = "RunDBInterfaceHandler.getSelections: Exception while obtaining possible run configurations."
             gLogger.exception(errStr, "", x)
-            return S_ERROR("%s %s" % (errStr, x))
+            return S_ERROR(f"{errStr} {x}")
 
     types_getRunParams = [int]
 
