@@ -13,6 +13,7 @@
 """
 import random
 import itertools
+import re
 from DIRAC import S_OK, S_ERROR
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import DMSHelpers
 from DIRAC.DataManagementSystem.private.FTS3Plugins.DefaultFTS3Plugin import DefaultFTS3Plugin
@@ -21,20 +22,35 @@ from DIRAC.Resources.Storage.StorageElement import StorageElement
 
 class LHCbFTS3Plugin(DefaultFTS3Plugin):
     @staticmethod
-    def _isCERNEOSCTATransfer(ftsJob=None, sourceSEName=None, destSEName=None, **kwargs):
-        """Check if the transfer involves both CERN EOS and CTA"""
+    def _isRalAntaresEchoStaging(sourceSEName=None, destSEName=None):
+        """Check if the transfer goes from Antares to Echo at RAL"""
         try:
-            if not sourceSEName:
-                sourceSEName = ftsJob.sourceSE
-            if not destSEName:
-                destSEName = ftsJob.targetSE
-
             srcSE = StorageElement(sourceSEName)
             srcBaseSEName = srcSE.options.get("BaseSE")
             dstSE = StorageElement(destSEName)
             dstBaseSEName = dstSE.options.get("BaseSE")
 
-            if (srcBaseSEName, dstBaseSEName) in list(itertools.product(("CERN-EOS", "CERN-CTA"), repeat=2)):
+            if srcBaseSEName in ("RAL-ANTARES-DATACHALLENGE", "RAL-ANTARES"):
+                if dstBaseSEName in ("RAL-ECHO", "RAL-ECHO-DATACHALLENGE"):
+                    return True
+
+        except Exception:
+            pass
+
+        return False
+
+    @staticmethod
+    def _isCERNEOSCTATransfer(sourceSEName=None, destSEName=None):
+        """Check if the transfer involves both CERN EOS and CTA"""
+        try:
+            srcSE = StorageElement(sourceSEName)
+            srcBaseSEName = srcSE.options.get("BaseSE")
+            dstSE = StorageElement(destSEName)
+            dstBaseSEName = dstSE.options.get("BaseSE")
+
+            if (srcBaseSEName, dstBaseSEName) in list(
+                itertools.product(("CERN-EOS", "CERN-CTA", "CERN-CTA-DATACHALLENGE"), repeat=2)
+            ):
                 return True
 
         except Exception:
@@ -45,38 +61,49 @@ class LHCbFTS3Plugin(DefaultFTS3Plugin):
     def selectTPCProtocols(self, ftsJob=None, sourceSEName=None, destSEName=None, **kwargs):
         """Specialised TPC selection"""
 
+        if not sourceSEName:
+            sourceSEName = ftsJob.sourceSE
+        if not destSEName:
+            destSEName = ftsJob.targetSE
+
         # If the transfer involves both CERN EOS and CTA, return root as TPC
-        if self._isCERNEOSCTATransfer(ftsJob=ftsJob, sourceSEName=sourceSEName, destSEName=destSEName, **kwargs):
+        if self._isCERNEOSCTATransfer(sourceSEName=sourceSEName, destSEName=destSEName):
             return ["root"]
 
-        return super(LHCbFTS3Plugin, self).selectTPCProtocols(
-            ftsJob=ftsJob, sourceSEName=sourceSEName, destSEName=destSEName, **kwargs
-        )
+        # if we stage from Antares to Echo, return root as TPC
+        if self._isRalAntaresEchoStaging(sourceSEName=sourceSEName, destSEName=destSEName):
+            return ["root"]
 
-    # According to RAL, their problem is fixed,
-    # (https://ggus.eu/?mode=ticket_info&ticket_id=151955#update#13
-    # so I comment this out, but I'll keep it a bit
-    # for ease of hotfixing, you know, just in case...
+        return super().selectTPCProtocols(ftsJob=ftsJob, sourceSEName=sourceSEName, destSEName=destSEName, **kwargs)
 
-    # def selectSourceSE(self, ftsFile, replicaDict, allowedSources):
-    #   """
-    #     This is basically a copy/paste of the parent method, with the exception
-    #     of not staging between CTA and Echo....
-    #   """
+    def selectSourceSE(self, ftsFile, replicaDict, allowedSources):
+        """
+        This is basically a copy/paste of the parent method, with the exception
+        of prefering local staging.
+        """
 
-    #   allowedSourcesSet = set(allowedSources) if allowedSources else set()
-    #   # Only consider the allowed sources
+        allowedSourcesSet = set(allowedSources) if allowedSources else set()
 
-    #   # If we have a restriction, apply it, otherwise take all the replicas
-    #   allowedReplicaSource = (set(replicaDict) & allowedSourcesSet) if allowedSourcesSet else replicaDict
+        # If we have a restriction, apply it, otherwise take all the replicas
+        allowedReplicaSource = (set(replicaDict) & allowedSourcesSet) if allowedSourcesSet else replicaDict
 
-    #   # If we have CTA and RAL as a tape source, choose RAL.
-    #   if 'CERN-RAW' in allowedReplicaSource and 'RAL-RAW' in allowedReplicaSource:
-    #     allowedReplicaSource = {'RAL-RAW': True}
-    #   # pick a random source
+        # If we have a replica at the same site as the destination
+        # use that one
+        # This is mostly done in order to favor local staging
+        #
+        # We go with the naive assumption that the site name
+        # is always the first part of the SE name, separated
+        # by either a - or a _ (like `_MC-DST`)
+        # (I know there are "proper tools" for checking if a SE is on the same site
+        # but since we are in the sheltered LHCb only environment, I can do that
+        # sort of optimization)
+        targetSite = re.split("-|_", ftsFile.targetSE)[0]
+        sameSiteSE = [srcSE for srcSE in allowedReplicaSource if targetSite in srcSE]
+        if sameSiteSE:
+            allowedReplicaSource = sameSiteSE
 
-    #   randSource = random.choice(list(allowedReplicaSource))  # one has to convert to list
-    #   return randSource
+        randSource = random.choice(list(allowedReplicaSource))  # one has to convert to list
+        return randSource
 
     def inferFTSActivity(self, ftsOperation, rmsRequest, rmsOperation):
         """
@@ -90,4 +117,4 @@ class LHCbFTS3Plugin(DefaultFTS3Plugin):
         if any("-DC-" in se for se in targetSEs):
             return "Data Challenge"
 
-        return super(LHCbFTS3Plugin, self).inferFTSActivity(ftsOperation, rmsRequest, rmsOperation)
+        return super().inferFTSActivity(ftsOperation, rmsRequest, rmsOperation)
