@@ -10,19 +10,18 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Upload a file to the grid storage and register it in the File Catalog."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... LFN Path SE [GUID]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... LFN Path SE [GUID]",
                 "Arguments:",
                 "  LFN:      Logical File Name",
                 "  Path:     Local path of the file",
@@ -32,7 +31,7 @@ def main():
                 " ** OR **",
                 "",
                 "Usage:",
-                "  %s [option|cfgfile] ... LocalFile" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... LocalFile",
                 "Arguments:",
                 "  LocalFile: Path to local file containing all the above, i.e.:",
                 "  lfn1 localfile1 SE [GUID1]",
