@@ -9,13 +9,12 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         """
   Check the integrity of the state of the storages and information in the File Catalogs
@@ -48,7 +47,7 @@ def main():
     directories = []
     for inputFileName in inputNames:
         try:
-            with open(inputFileName, "r") as inputFile:
+            with open(inputFileName) as inputFile:
                 stringIn = inputFile.read()
                 directories += stringIn.splitlines()
         except Exception:
@@ -63,14 +62,14 @@ def main():
         gLogger.error(res["Message"])
         DIRAC.exit(-2)
     for directory, error in res["Value"]["Failed"]:
-        gLogger.error("Failed to determine existence of directory", "%s %s" % (directory, error))
+        gLogger.error("Failed to determine existence of directory", f"{directory} {error}")
     if res["Value"]["Failed"]:
         DIRAC.exit(-2)
     directoryExists = res["Value"]["Successful"]
     for directory in sorted(directoryExists):
         if not directoryExists[directory]:
             continue
-        gLogger.info("Checking the integrity of %s" % directory)
+        gLogger.info(f"Checking the integrity of {directory}")
         iRes = integrity.catalogDirectoryToBK(directory)
         if not iRes["OK"]:
             gLogger.error("Error getting directory content:", iRes["Message"])
