@@ -17,13 +17,14 @@
 If --FixFC is set, remove from SE and FC
 If --FixBK is set and no replica flag, set replica flag in the BK
 """
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     # Script initialization
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
     import DIRAC
 
     Script.setUsageMessage(
@@ -31,7 +32,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] [values]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [values]",
             ]
         )
     )
