@@ -13,13 +13,13 @@
 import six
 
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def inaccessibleReplicas(lfn, se):
     from DIRAC.DataManagementSystem.Client.DataManager import DataManager
 
-    if isinstance(se, six.string_types):
+    if isinstance(se, str):
         seList = [se]
     else:
         seList = se
@@ -27,7 +27,7 @@ def inaccessibleReplicas(lfn, se):
     for se in seList:
         res = DataManager().getReplicaMetadata(lfn, se)
         if not res["OK"]:
-            gLogger.always("Error getting metadata of %s at %s" % (lfn, se), res["Message"])
+            gLogger.always(f"Error getting metadata of {lfn} at {se}", res["Message"])
             continue
         if lfn in res["Value"]["Failed"]:
             failed[se] = res["Value"]["Failed"][lfn]
@@ -36,12 +36,11 @@ def inaccessibleReplicas(lfn, se):
 
 def prettyMsg(msg, msgList):
     areIs = "s are" if len(msgList) > 1 else " is"
-    gLogger.always("The following file%s %s:\n%s" % (areIs, msg, "\n".join(msgList)))
+    gLogger.always("The following file{} {}:\n{}".format(areIs, msg, "\n".join(msgList)))
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, ProgressBar
 
     dmScript = DMScript()
@@ -92,24 +91,24 @@ def main():
         }
         prStr = "all jobs"
         if production:
-            prStr = "production %s" % " ".join(production)
+            prStr = f"production {' '.join(production)}"
             if len(production) == 1:
                 production = production[0]
             conditions["JobGroup"] = production
         if userName:
-            prStr = "user %s" % userName
+            prStr = f"user {userName}"
             conditions["Owner"] = userName
-        gLogger.always("Obtaining IDR jobs for %s" % prStr)
+        gLogger.always(f"Obtaining IDR jobs for {prStr}")
         res = monitoring.getJobs(conditions)
         if not res["OK"]:
-            gLogger.always("Error selecting jobs for production %s" % str(production), res["Message"])
+            gLogger.always(f"Error selecting jobs for production {str(production)}", res["Message"])
             DIRAC.exit(2)
         if not res["Value"]:
-            gLogger.always("No jobs found with IDR for production %s" % str(production))
+            gLogger.always(f"No jobs found with IDR for production {str(production)}")
         elif verbose:
-            gLogger.always("Selected %d jobs from production %s" % (len(res["Value"]), str(production)))
+            gLogger.always(f"Selected {len(res['Value'])} jobs from production {str(production)}")
         jobs = [int(job) for job in res["Value"]]
-        gLogger.always("Obtained %d jobs... Now analyzing them" % len(jobs))
+        gLogger.always(f"Obtained {len(jobs)} jobs... Now analyzing them")
     if not jobs:
         gLogger.always("No jobs to check, exiting...")
         DIRAC.exit(0)
@@ -121,7 +120,7 @@ def main():
     gLogger.setLevel("FATAL")
     jobSites = res["Value"]
     filesAtSite = {}
-    progressBar = ProgressBar(len(jobs), title="Getting JDL for %d jobs" % len(jobs), step=2)
+    progressBar = ProgressBar(len(jobs), title=f"Getting JDL for {len(jobs)} jobs", step=2)
     errors = {}
     for jobID in jobs:
         progressBar.loop()
@@ -156,13 +155,14 @@ def main():
             gLogger.always("Input Data for job %d\n%s" % (jobID, "\n".join(inputData)))
         site = jobSites.get(jobID, {}).get("Site", "Unknown")
         if verbose:
-            gLogger.always("Site: %s" % site)
+            gLogger.always(f"Site: {site}")
         for lfn in inputData:
             filesAtSite.setdefault(site, {}).setdefault(lfn, []).append(jobID)
 
     progressBar.endLoop()
     sep = ""
     for site in filesAtSite:
+        pbFound = False
         seUsed = ""
         try:
             jobs = []
@@ -173,22 +173,22 @@ def main():
                         jobs.append(jobID)
             res = getSEsForSite(site)
             if not res["OK"] or not res["Value"]:
-                gLogger.always("Couldn't find SEs for site %s" % site)
+                gLogger.always(f"Couldn't find SEs for site {site}")
                 continue
             seList = res["Value"]
             inputData = sorted(filesAtSite[site])
             if verbose:
-                gLogger.always("%sSite: %s, jobs: %s, %d files" % (sep, site, ",".join(jobs), len(inputData)))
+                gLogger.always(f"{sep}Site: {site}, jobs: {','.join(jobs)}, {len(inputData)} files")
             else:
-                gLogger.always("%sSite: %s, %d jobs, %d files" % (sep, site, len(jobs), len(inputData)))
+                gLogger.always(f"{sep}Site: {site}, {len(jobs)} jobs, {len(inputData)} files")
             sep = "=====================================\n"
             if verbose:
-                gLogger.always("For %s, SEs: %s" % (site, str(seList)))
+                gLogger.always(f"For {site}, SEs: {str(seList)}")
             pbFound = False
 
             res = dm.getReplicas(inputData)
             if not res["OK"]:
-                gLogger.always("Error getting replicas for %d files" % len(inputData), res["Message"])
+                gLogger.always(f"Error getting replicas for {len(inputData)} files", res["Message"])
                 continue
             replicas = res["Value"]["Successful"]
             notInFC = res["Value"]["Failed"]
@@ -196,7 +196,7 @@ def main():
                 # Check if files has replica flag in the FC, If not ignore the problem
                 res = bk.getFileMetadata(list(notInFC))
                 if not res["OK"]:
-                    gLogger.always("Error getting BK metadata for %d files" % len(notInFC), res["Message"])
+                    gLogger.always(f"Error getting BK metadata for {len(notInFC)} files", res["Message"])
                     continue
                 metadata = res["Value"]["Successful"]
                 notInFC = [lfn for lfn in notInFC if metadata.get(lfn, {}).get("GotReplica") == "Yes"]
@@ -225,14 +225,14 @@ def main():
                                 lfn,
                                 se,
                                 reason,
-                                "Accessible at %s" % str(accessible) if accessible else "No other accessible replicas",
+                                f"Accessible at {str(accessible)}" if accessible else "No other accessible replicas",
                             )
                         )
                         prStr = "not"
                     else:
                         prStr = ""
                     if verbose:
-                        gLogger.always("%s is %s accessible at %s" % (lfn, prStr, se))
+                        gLogger.always(f"{lfn} is {prStr} accessible at {se}")
             if missingReplicas:
                 pbFound = True
                 msgList = ["%s at %s: %s\n\t%s" % x for x in missingReplicas]
@@ -240,10 +240,10 @@ def main():
             if notFoundReplicas:
                 pbFound = True
                 gLogger.always(
-                    "%d files not found at SE close to %s, but have other replicas" % (len(notFoundReplicas), site)
+                    f"{len(notFoundReplicas)} files not found at SE close to {site}, but have other replicas"
                 )
         except Exception as e:
-            gLogger.always("%s" % e)
+            gLogger.always(f"{e}")
             pass
         finally:
             if not pbFound:
