@@ -13,12 +13,11 @@ import os
 import sys
 from time import time
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from DIRAC import exit, gLogger
 
     Script.registerSwitch("", "User=", "  User name")
@@ -102,7 +101,7 @@ def main():
     startTime = time()
     progressBar = ProgressBar(
         len(directories),
-        title="Changing %s%s to %d directories:" % (toChange, " recursively" if recursive else "", len(directories)),
+        title=f"Changing {toChange}{' recursively' if recursive else ''} to {len(directories)} directories:",
         chunk=1,
         interactive=True,
     )
@@ -123,7 +122,7 @@ def main():
                 continue
         res = chown(baseDir, user, group=group, mode=mode, recursive=recursive, fcClient=dfc)
         if not res["OK"]:
-            errors[baseDir] = res["Message"] + " executing %s: " % res["Action"]
+            errors[baseDir] = res["Message"] + f" executing {res['Action']}: "
         else:
             success += res["Value"]
 
@@ -141,7 +140,7 @@ def main():
         retCode = 1
         gLogger.notice("Errors:")
         for baseDir, error in errors.items():
-            gLogger.notice("\tDirectory %s - " % baseDir, error)
+            gLogger.notice(f"\tDirectory {baseDir} - ", error)
     elif len(directories) == 1:
         from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
         from LHCbDIRAC.DataManagementSystem.Client.ScriptExecutors import executeLfnMetadata
