@@ -11,23 +11,23 @@
 ###############################################################################
 """Retrieve a single file or list of files from Grid storage to the current directory."""
 import os
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
-    dmScript.registerNamespaceSwitches("download to (default = %s)" % os.path.realpath("."))
+    dmScript.registerNamespaceSwitches(f"download to (default = {os.path.realpath('.')})")
 
     Script.setUsageMessage(
         "\n".join(
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] [<LFN>] [<LFN>...] [SourceSE]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [<LFN>] [<LFN>...] [SourceSE]",
             ]
         )
     )
