@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Get the metadata of a (list of) LFNs from the FC."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -25,7 +26,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ... [LFN[,LFN2[,LFN3...]]]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [LFN[,LFN2[,LFN3...]]]",
                 "Arguments:",
                 "  LFN:      Logical File Name or file containing LFNs",
             ]
