@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Show replicas for a (set of) LFNs."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -29,7 +30,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] [<LFN>] [<LFN>...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [<LFN>] [<LFN>...]",
             ]
         )
     )
