@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Get the list of all the user files."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     days = 0
     months = 0
@@ -24,10 +25,10 @@ def main():
     wildcard = "*"
     dmScript = DMScript()
     dmScript.registerNamespaceSwitches()
-    Script.registerSwitch("", "Days=", "Match files older than number of days [%s]" % days)
-    Script.registerSwitch("", "Months=", "Match files older than number of months [%s]" % months)
-    Script.registerSwitch("", "Years=", "Match files older than number of years [%s]" % years)
-    Script.registerSwitch("", "Wildcard=", "Wildcard for matching filenames [%s]" % wildcard)
+    Script.registerSwitch("", "Days=", f"Match files older than number of days [{days}]")
+    Script.registerSwitch("", "Months=", f"Match files older than number of months [{months}]")
+    Script.registerSwitch("", "Years=", f"Match files older than number of years [{years}]")
+    Script.registerSwitch("", "Wildcard=", f"Wildcard for matching filenames [{wildcard}]")
     Script.registerSwitch("", "Output", "Write list to an output file")
     Script.registerSwitch("", "EmptyDirs", "Create a list of empty directories")
     Script.registerSwitch("", "Depth=", "Depth to which recursively browse (default = %d)" % depth)
@@ -40,7 +41,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
