@@ -12,12 +12,13 @@
 """Gets the metadata of a (list of) LHCb LFNs/PFNs given a valid DIRAC SE (or
 for all replicas) Only the LFN contained in the PFN is considered, unlike the
 DIRAC similar script."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -30,7 +31,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] ... [URL[,URL2[,URL3...]]] SE[ SE2...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [URL[,URL2[,URL3...]]] SE[ SE2...]",
                 "Arguments:",
                 "  URL:      Logical/Physical File Name or file containing URLs",
                 "  SE:       Valid DIRAC SE",
