@@ -11,12 +11,13 @@
 ###############################################################################
 """Remove the given file or a list of files from the File Catalog and from the
 storage."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerBKSwitches()
@@ -30,7 +31,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] [<LFN>] [<LFN>...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [<LFN>] [<LFN>...]",
             ]
         )
     )
