@@ -13,12 +13,13 @@
 
 It is possible to request a minimum of remaining replicas
 """
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -34,7 +35,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] ... [LFN[,LFN2[,LFN3...]]] SE[,SE2...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ... [LFN[,LFN2[,LFN3...]]] SE[,SE2...]",
                 "Arguments:",
                 "  LFN:      Logical File Name or file containing LFNs",
                 "  SE:       Valid DIRAC SE",
