@@ -10,12 +10,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Get statistics on number of replicas for a given directory or production."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerBKSwitches()
@@ -27,7 +28,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] [<LFN>] [<LFN>...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [<LFN>] [<LFN>...]",
             ]
         )
     )
