@@ -10,13 +10,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Script for scanning the popularity table."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     since = 30
     getAllDatasets = False
     Script.registerSwitch("", "Since=", "   Number of days to look for (default: %d)" % since)
@@ -26,7 +24,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile]",
             ]
         )
     )
