@@ -11,12 +11,13 @@
 ###############################################################################
 """Set a (set of) LFNs as problematic in the FC and in the BK and
 transformation system if all replicas are problematic."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -31,7 +32,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] [<LFN>] [<LFN>...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [<LFN>] [<LFN>...]",
             ]
         )
     )
