@@ -10,11 +10,9 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Get the storage usage summary for the given directories."""
-
 import DIRAC
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from DIRAC import gConfig, gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 seSvcClassDict = {}
 infoStringLength = 1
@@ -55,7 +53,7 @@ def printSEUsage(totalUsage, grandTotal, scaleFactor):
     """Nice printout of SE usage."""
     dashes = "-" * 48
     print(dashes)
-    print("%s %s %s" % ("DIRAC SE".ljust(20), ("Size (%s)" % unit).ljust(20), "Files".ljust(20)))
+    print(f"{'DIRAC SE'.ljust(20)} {('Size (%s)' % unit).ljust(20)} {'Files'.ljust(20)}")
     form = "%.1f"
     orderedSEs = orderSEs(totalUsage)
     for se in orderedSEs:
@@ -82,10 +80,10 @@ def printSEUsage(totalUsage, grandTotal, scaleFactor):
         size = usageDict["Size"] / scaleFactor
         sumFiles += files
         sumSize += size
-        print("%s %s %s" % (se.ljust(20), (form % (size)).ljust(20), str(files).ljust(20)))
+        print(f"{se.ljust(20)} {(form % size).ljust(20)} {str(files).ljust(20)}")
     if grandTotal:
         size = grandTotal["Size"] / scaleFactor
-        print("%s %s %s" % ("Total (disk)".ljust(20), (form % (size)).ljust(20), str(grandTotal["Files"]).ljust(20)))
+        print(f"{'Total (disk)'.ljust(20)} {(form % size).ljust(20)} {str(grandTotal['Files']).ljust(20)}")
     print(dashes)
 
 
@@ -114,7 +112,7 @@ def printBigTable(siteList, bigTable):
             for site in siteList:
                 if site in bigTableUsage:
                     grandTotal[site] = grandTotal.setdefault(site, 0) + bigTableUsage[site]
-                    prStr += ("%.3f" % bigTableUsage[site]).ljust(just[2])
+                    prStr += f"{bigTableUsage[site]:.3f}".ljust(just[2])
                 elif site == "Total":
                     prStr += "0".ljust(just[2])
                 else:
@@ -123,7 +121,7 @@ def printBigTable(siteList, bigTable):
     prStr = "\n" + "".ljust(just[0]) + "Grand-Total".ljust(just[1])
     for site in siteList:
         if site in grandTotal:
-            prStr += ("%.3f" % grandTotal[site]).ljust(just[2])
+            prStr += f"{grandTotal[site]:.3f}".ljust(just[2])
         else:
             prStr += "-".ljust(just[2])
     print(prStr)
@@ -146,11 +144,11 @@ def browseBK(bkQuery, ses, scaleFactor):
 
     bkPath = bkQuery.getPath()
     if not bkQuery.getConfiguration():
-        print("The Configuration should be specified in the --BKQuery option: %s" % bkPath)
+        print(f"The Configuration should be specified in the --BKQuery option: {bkPath}")
         return None
     conditions = bkQuery.getBKConditions()
     if not conditions:
-        print("No Conditions found for this Configuration %s" % bkPath)
+        print(f"No Conditions found for this Configuration {bkPath}")
         return None
     requestedEventTypes = bkQuery.getEventTypeList()
     requestedFileTypes = bkQuery.getFileTypeList()
@@ -159,7 +157,7 @@ def browseBK(bkQuery, ses, scaleFactor):
     bigTable = {}
     siteList = []
     for cond in conditions:
-        strCond = "Browsing conditions %s" % cond
+        strCond = f"Browsing conditions {cond}"
         writeInfo(strCond)
         bkQuery.setConditions(cond)
         eventTypesForPP = bkQuery.getBKProcessingPasses()
@@ -171,7 +169,7 @@ def browseBK(bkQuery, ses, scaleFactor):
                     continue
             else:
                 eventTypes = eventTypesForPP[processingPass]
-            strPP = " - ProcessingPass %s" % processingPass
+            strPP = f" - ProcessingPass {processingPass}"
             writeInfo(strCond + strPP)
             bkQuery.setProcessingPass(processingPass)
             totalUsage = {}
@@ -179,7 +177,7 @@ def browseBK(bkQuery, ses, scaleFactor):
             allProds = []
             # print eventTypes
             for eventType in eventTypes:
-                strEvtType = " - EventType %s" % str(eventType)
+                strEvtType = f" - EventType {str(eventType)}"
                 writeInfo(strCond + strPP + strEvtType)
                 bkQuery.setEventType(eventType)
                 fileTypes = bkQuery.getBKFileTypes()
@@ -189,7 +187,7 @@ def browseBK(bkQuery, ses, scaleFactor):
                     continue
                 prods = sorted(bkQuery.getBKProductions())
                 # print prods
-                strProds = " - FileTypes %s - Prods %s" % (str(fileTypes), str(prods))
+                strProds = f" - FileTypes {str(fileTypes)} - Prods {str(prods)}"
                 writeInfo(strCond + strPP + strEvtType + strProds)
                 info = bkQuery.getNumberOfLFNs()
                 nbFiles = info["NumberOfLFNs"]
@@ -311,9 +309,9 @@ def execute(unit, minimum, depth):
     ses += dmScript.getOption("SEs", [])
     sites = dmScript.getOption("Sites", [])
     for site in sites:
-        res = gConfig.getOptionsDict("/Resources/Sites/LCG/%s" % site)
+        res = gConfig.getOptionsDict(f"/Resources/Sites/LCG/{site}")
         if not res["OK"]:
-            print("Site %s not known" % site)
+            print(f"Site {site} not known")
             Script.showHelp()
         ses.extend(res["Value"]["SE"].replace(" ", "").split(","))
 
@@ -327,14 +325,14 @@ def execute(unit, minimum, depth):
     dirs = dmScript.getOption("Directory", [])
     if users:
         if users != "all":
-            dirs += ["/lhcb/user/%s/%s" % (user[0], user) for user in users]
+            dirs += [f"/lhcb/user/{user[0]}/{user}" for user in users]
             minimum = 0
         else:
             res = rpc.getStorageDirectories("/lhcb/user", None, None, None)
             if not res["OK"]:
                 print("Error getting directories in /lhcb/user:", res["Message"])
                 DIRAC.exit(2)
-            dirs += sorted(set(["/".join(d.split("/")[0:5]) for d in res["Value"]]))
+            dirs += sorted({"/".join(d.split("/")[0:5]) for d in res["Value"]})
             users = [user for user in [d.split("/")[-1] for d in dirs] if user]
     prods = None
     # print bkQuery
@@ -354,13 +352,13 @@ def execute(unit, minimum, depth):
             else:
                 prods = sorted(bkQuery.getBKProductions())
                 if not prods:
-                    print("No productions found for bkQuery %s" % str(bkQuery))
+                    print(f"No productions found for bkQuery {str(bkQuery)}")
                     DIRAC.exit(0)
                 # As storageSummary deals with directories and not real file types,
                 #    add DST in order to cope with old naming convention
                 if fileTypes and "FULL.DST" not in fileTypes and "DST" not in fileTypes:
                     fileTypes.append("DST")
-                print("Looking for %d productions:" % len(prods), prods)
+                print(f"Looking for {len(prods)} productions:", prods)
         elif fileTypes and fileTypes[0]:
             print("FileTypes:", fileTypes)
 
@@ -370,18 +368,18 @@ def execute(unit, minimum, depth):
         fileTypes = [""]
     prString = "Storage usage for "
     if sites:
-        prString += "Sites %s " % str(sites)
+        prString += f"Sites {str(sites)} "
     elif ses:
-        prString += "SEs %s " % str(ses)
+        prString += f"SEs {str(ses)} "
     if prods[0] != "":
-        prString += "productions %s " % str(prods)
+        prString += f"productions {str(prods)} "
     if fileTypes[0] not in ("", None):
-        prString += "file types %s " % str(fileTypes)
+        prString += f"file types {str(fileTypes)} "
     if dirs[0] != "":
         if fileTypes == ["RAW"]:
-            prString += "in %d directories" % len(dirs)
+            prString += f"in {len(dirs)} directories"
         else:
-            prString += "directories %s" % str(dirs)
+            prString += f"directories {str(dirs)}"
     if not users:
         if prString == "Storage usage for ":
             prString += "all SEs"
@@ -418,11 +416,11 @@ def execute(unit, minimum, depth):
             for dirName in dirs:
                 if users:
                     user = dirName.split("/")[-1]
-                    userRegistry = gConfig.getOptions("/Registry/Users/%s" % user)
+                    userRegistry = gConfig.getOptions(f"/Registry/Users/{user}")
                     if not userRegistry["OK"]:
                         quota = 0
                     else:
-                        quota = gConfig.getValue("/Registry/Users/%s/Quota" % user, 0)
+                        quota = gConfig.getValue(f"/Registry/Users/{user}/Quota", 0)
                         if not quota:
                             quota = gConfig.getValue("/Registry/DefaultStorageQuota", 0)
                     quota *= scaleDict["GB"] / scaleFactor
@@ -467,7 +465,7 @@ def execute(unit, minimum, depth):
                 if seStatus["DiskSE"]:
                     diskTotalFiles += files
                     diskTotalSize += size
-        print("%s %s %s" % ("Storage Type".ljust(20), ("Size (%s)" % unit).ljust(20), "Files".ljust(20)))
+        print(f"{'Storage Type'.ljust(20)} {('Size (%s)' % unit).ljust(20)} {'Files'.ljust(20)}")
         print("-" * 50)
         print(
             "%s %s %s"
@@ -504,7 +502,7 @@ def execute(unit, minimum, depth):
     DIRAC.exit(0)
 
 
-@DIRACScript()
+@Script()
 def main():
     global unit
     global dmScript
@@ -519,7 +517,7 @@ def main():
     unit = "TB"
     minimum = 0.1
     depth = 4
-    Script.registerSwitch("u:", "Unit=", "   Unit to use [%s] (MB,GB,TB,PB)" % unit)
+    Script.registerSwitch("u:", "Unit=", f"   Unit to use [{unit}] (MB,GB,TB,PB)")
     Script.registerSwitch("l", "LCG", "  Group results by tape and disk")
     Script.registerSwitch("", "Full", "  Output the directories matching selection")
     Script.registerSwitch("", "TopDirectories", "  Same as --Full but group by depth-%d directories" % depth)
@@ -528,7 +526,7 @@ def main():
     Script.registerSwitch("", "Users=", "   Get storage usage for a (list of) user(s)")
     Script.registerSwitch("", "Summary", "  Only print a summary for users")
     Script.registerSwitch(
-        "", "Minimum=", "   Don't print usage for users below that usage (same units, default %.1f" % minimum
+        "", "Minimum=", f"   Don't print usage for users below that usage (same units, default {minimum:.1f}"
     )
     Script.registerSwitch("", "UnknownSE=", "   Force using a non-existing SE name")
 
@@ -537,7 +535,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
