@@ -61,12 +61,11 @@ def translateBKPath(bkPath, procPassID=3):
 
 
 class DiracLHCb(Dirac):
-
     #############################################################################
     def __init__(self, withRepo=False, repoLocation="", operationsHelperIn=None):
         """Internal initialization of the DIRAC API."""
 
-        super(DiracLHCb, self).__init__(withRepo=withRepo, repoLocation=repoLocation)
+        super().__init__(withRepo=withRepo, repoLocation=repoLocation)
         self.tier1s = []
 
         if not operationsHelperIn:
@@ -110,15 +109,11 @@ class DiracLHCb(Dirac):
            @type printOutput: boolean
            @return: S_OK,S_ERROR
         """
-        return super(DiracLHCb, self).addFile(
-            lfn, fullPath, diracSE, fileGuid=makeGuid(fullPath)[fullPath], printOutput=printOutput
-        )
+        return super().addFile(lfn, fullPath, diracSE, fileGuid=makeGuid(fullPath)[fullPath], printOutput=printOutput)
 
     def addFile(self, lfn, fullPath, diracSE, printOutput=False):  # pylint: disable=arguments-differ
         """Copy of addRootFile."""
-        return super(DiracLHCb, self).addFile(
-            lfn, fullPath, diracSE, fileGuid=makeGuid(fullPath)[fullPath], printOutput=printOutput
-        )
+        return super().addFile(lfn, fullPath, diracSE, fileGuid=makeGuid(fullPath)[fullPath], printOutput=printOutput)
 
     def getBKAncestors(self, lfns, depth=1, replica=True):
         """This function allows to retrieve ancestor files from the Bookkeeping.
@@ -139,7 +134,7 @@ class DiracLHCb(Dirac):
         if not result["OK"]:
             self.log.error("Could not get ancestors", result["Message"])
             return result
-        ancestors = set(x["FileName"] for ancestors in result["Value"]["Successful"].values() for x in ancestors)
+        ancestors = {x["FileName"] for ancestors in result["Value"]["Successful"].values() for x in ancestors}
 
         return S_OK(lfns + list(ancestors))
 
@@ -194,7 +189,7 @@ class DiracLHCb(Dirac):
         """
         runSelection = ["Runs", "ProcessedRuns", "NotProcessed"]
         if selection not in runSelection:
-            return S_ERROR('Expected one of %s not "%s" for selection' % (", ".join(runSelection), selection))
+            return S_ERROR(f"Expected one of {', '.join(runSelection)} not \"{selection}\" for selection")
 
         if not isinstance(bkPath, str):
             return S_ERROR("Expected string for bkPath")
@@ -221,9 +216,9 @@ class DiracLHCb(Dirac):
         start = time.time()
         result = self._bkClient.getRunsForAGivenPeriod({"StartDate": startDate, "EndDate": endDate})
         rtime = time.time() - start
-        self.log.info("BK query time: %.2f sec" % rtime)
+        self.log.info(f"BK query time: {rtime:.2f} sec")
         if not result["OK"]:
-            self.log.info('Could not get runs with given dates from BK with result: "%s"' % result)
+            self.log.info(f'Could not get runs with given dates from BK with result: "{result}"')
             return result
 
         if not result["Value"]:
@@ -231,10 +226,10 @@ class DiracLHCb(Dirac):
             return result
 
         if selection not in result["Value"]:
-            return S_ERROR("No %s runs for specified dates" % (selection))
+            return S_ERROR(f"No {selection} runs for specified dates")
 
         runs = result["Value"][selection]
-        self.log.info("Found the following %s runs:\n%s" % (len(runs), ", ".join([str(i) for i in runs])))
+        self.log.info(f"Found the following {len(runs)} runs:\n{', '.join([str(i) for i in runs])}")
         # temporary until we can query for a discrete list of runs
         selectedData = []
         for run in runs:
@@ -251,15 +246,15 @@ class DiracLHCb(Dirac):
             start = time.time()
             result = self._bkClient.getVisibleFilesWithMetadata(query)
             rtime = time.time() - start
-            self.log.info("BK query time: %.2f sec" % rtime)
+            self.log.info(f"BK query time: {rtime:.2f} sec")
             self.log.verbose(result)
             if not result["OK"]:
                 return result
-            self.log.info("Selected %s files for run %s" % (len(result["Value"]), run))
+            self.log.info(f"Selected {len(result['Value'])} files for run {run}")
             if result["Value"]["LFNs"]:
                 selectedData += list(result["Value"]["LFNs"])
 
-        self.log.info("Total files selected = %s" % (len(selectedData)))
+        self.log.info(f"Total files selected = {len(selectedData)}")
         return S_OK(selectedData)
 
     #############################################################################
@@ -309,12 +304,12 @@ class DiracLHCb(Dirac):
         if "-" in runNumberString:
             runs = runNumberString.split("-")
             if len(runs) != 2:
-                return S_ERROR('Could not determine run range from "%s", try "<Run 1> - <Run2>"' % (runNumberString))
+                return S_ERROR(f'Could not determine run range from "{runNumberString}", try "<Run 1> - <Run2>"')
             try:
                 start = int(runs[0])
                 end = int(runs[1])
             except Exception:
-                return S_ERROR("Invalid run range: %s" % runNumberString)
+                return S_ERROR(f"Invalid run range: {runNumberString}")
             startRun = min(start, end)
             endRun = max(start, end)
         else:
@@ -322,7 +317,7 @@ class DiracLHCb(Dirac):
                 startRun = int(runNumberString)
                 endRun = startRun
             except Exception:
-                return S_ERROR("Invalid run number: %s" % runNumberString)
+                return S_ERROR(f"Invalid run number: {runNumberString}")
 
         query = self._bkQueryTemplate.copy()
         query["StartRun"] = startRun
@@ -392,7 +387,7 @@ class DiracLHCb(Dirac):
             query["DataQuality"] = dqFlag
 
         for key, val in list(query.items()):
-            if isinstance(val, six.string_types) and val.lower() == "all":
+            if isinstance(val, str) and val.lower() == "all":
                 query.pop(key)
         result = self.bkQuery(query)
         self.log.verbose(result)
@@ -542,7 +537,7 @@ class DiracLHCb(Dirac):
                 problematicFields.append(name)
 
         if problematicFields:
-            msg = "The following fields are not valid for a BK query: %s\nValid fields include: %s" % (
+            msg = "The following fields are not valid for a BK query: {}\nValid fields include: {}".format(
                 ", ".join(problematicFields),
                 ", ".join(self._bkQueryTemplate),
             )
@@ -584,16 +579,16 @@ class DiracLHCb(Dirac):
         result = self._bkClient.getVisibleFilesWithMetadata(bkQueryDict)
         #    result = bk.getFilesWithGivenDataSets(bkQueryDict)
         rtime = time.time() - start
-        self.log.info("BK query time: %.2f sec" % rtime)
+        self.log.info(f"BK query time: {rtime:.2f} sec")
 
         if not result["OK"]:
-            return S_ERROR('BK query returned an error: "%s"' % (result["Message"]))
+            return S_ERROR(f"BK query returned an error: \"{result['Message']}\"")
 
         if not result["Value"]:
             return self._errorReport("No BK files selected")
 
         returnedFiles = len(result["Value"])
-        self.log.verbose("%s files selected from the BK" % (returnedFiles))
+        self.log.verbose(f"{returnedFiles} files selected from the BK")
         return result
 
     #############################################################################
@@ -620,7 +615,7 @@ class DiracLHCb(Dirac):
             else:
                 flag = flag.upper()
                 if flag not in bkFlags["Value"]:
-                    msg = 'Specified DQ flag "%s" is not in allowed list: %s' % (flag, ", ".join(bkFlags["Value"]))
+                    msg = f"Specified DQ flag \"{flag}\" is not in allowed list: {', '.join(bkFlags['Value'])}"
                     self.log.error(msg)
                     return S_ERROR(msg)
                 else:
@@ -648,12 +643,12 @@ class DiracLHCb(Dirac):
         """
         result = self._bkClient.getAvailableDataQuality()
         if not result["OK"]:
-            self.log.error("Could not obtain possible DQ flags from BK with result:\n%s" % (result))
+            self.log.error(f"Could not obtain possible DQ flags from BK with result:\n{result}")
             return result
 
         if printOutput:
             flags = result["Value"]
-            self.log.info("Possible DQ flags from BK are: %s" % (", ".join(flags)))
+            self.log.info(f"Possible DQ flags from BK are: {', '.join(flags)}")
 
         return result
 
@@ -688,9 +683,9 @@ class DiracLHCb(Dirac):
         runDict = {}
         start = time.time()
         result = self._bkClient.getFileMetadata(lfns)
-        self.log.verbose("Obtained BK file metadata in %.2f seconds" % (time.time() - start))
+        self.log.verbose(f"Obtained BK file metadata in {time.time() - start:.2f} seconds")
         if not result["OK"]:
-            self.log.error('Failed to get bookkeeping metadata with result "%s"' % (result["Message"]))
+            self.log.error(f"Failed to get bookkeeping metadata with result \"{result['Message']}\"")
             return result
 
         for lfn, metadata in result["Value"]["Successful"].items():
@@ -698,7 +693,7 @@ class DiracLHCb(Dirac):
                 runNumber = metadata["RunNumber"]
                 runDict.setdefault(runNumber, []).append(lfn)
             else:
-                self.log.warn("Could not find run number from BK for %s" % (lfn))
+                self.log.warn(f"Could not find run number from BK for {lfn}")
 
         if printOutput:
             self.log.notice(self.pPrint.pformat(runDict))
@@ -734,9 +729,9 @@ class DiracLHCb(Dirac):
 
         start = time.time()
         result = self._bkClient.getFileMetadata(lfns)
-        self.log.verbose("Obtained BK file metadata in %.2f seconds" % (time.time() - start))
+        self.log.verbose(f"Obtained BK file metadata in {time.time() - start:.2f} seconds")
         if not result["OK"]:
-            self.log.error('Failed to get bookkeeping metadata with result "%s"' % (result["Message"]))
+            self.log.error(f"Failed to get bookkeeping metadata with result \"{result['Message']}\"")
             return result
 
         if printOutput:
@@ -748,7 +743,7 @@ class DiracLHCb(Dirac):
 
     def lhcbProxyInit(self, *args):  # pylint: disable=no-self-use
         """just calling the dirac-proxy-init script."""
-        os.system("dirac-proxy-init -o LogLevel=NOTICE -t --rfc %s" % "' '".join(args))
+        os.system("dirac-proxy-init -o LogLevel=NOTICE -t %s" % "' '".join(args))
 
     #############################################################################
 
@@ -778,8 +773,7 @@ class DiracLHCb(Dirac):
             return lcgSites
 
         for lcgSite in lcgSites["Value"]:
-
-            tier = gConfig.getValue("/Resources/Sites/LCG/%s/MoUTierLevel" % lcgSite, 2)
+            tier = gConfig.getValue(f"/Resources/Sites/LCG/{lcgSite}/MoUTierLevel", 2)
             if tier in (0, 1):
                 self.tier1s.append(lcgSite)
 
@@ -812,10 +806,8 @@ class DiracLHCb(Dirac):
         if printOutput:
             self.log.notice("========> Tier-1 status in DIRAC site and SE masks")
             for site in sorted(self.tier1s):
-                self.log.notice("\n====> %s is %s in site mask\n" % (site, tierInfo[site]["MaskStatus"]))
-                self.log.notice(
-                    "%s %s %s" % ("Storage Element".ljust(25), "Read Status".rjust(15), "Write Status".rjust(15))
-                )
+                self.log.notice(f"\n====> {site} is {tierInfo[site]['MaskStatus']} in site mask\n")
+                self.log.notice(f"{'Storage Element'.ljust(25)} {'Read Status'.rjust(15)} {'Write Status'.rjust(15)}")
                 for se in sorted(tierSEs[site]):
                     if se in tierInfo[site]:
                         self.log.notice(
@@ -835,7 +827,7 @@ class DiracLHCb(Dirac):
                     allowedSites.remove(site)
                 if site in bannedSites:
                     bannedSites.remove(site)
-            self.log.notice(" %s sites are in the site mask, %s are banned.\n" % (len(allowedSites), len(bannedSites)))
+            self.log.notice(f" {len(allowedSites)} sites are in the site mask, {len(bannedSites)} are banned.\n")
 
         summary = {"Sites": siteInfo, "SEs": seInfo, "Tier-1s": tierInfo}
         return S_OK(summary)
@@ -903,9 +895,7 @@ class DiracLHCb(Dirac):
             return res
 
         if printOutput:
-            self.log.notice(
-                "%s %s %s" % ("Storage Element".ljust(25), "Read Status".rjust(15), "Write Status".rjust(15))
-            )
+            self.log.notice(f"{'Storage Element'.ljust(25)} {'Read Status'.rjust(15)} {'Write Status'.rjust(15)}")
 
         seList = sorted(res["Value"])
         result = {}
@@ -913,13 +903,13 @@ class DiracLHCb(Dirac):
         for se in seList:
             res = rss.getElementStatus(se, "StorageElement")
             if not res["OK"]:
-                self.log.error("Failed to get StorageElement status for %s" % se)
+                self.log.error(f"Failed to get StorageElement status for {se}")
             else:
                 readState = res["Value"].get("ReadAccess", "Active")
                 writeState = res["Value"].get("WriteAccess", "Active")
                 result[se] = {"ReadStatus": readState, "WriteStatus": writeState}
                 if printOutput:
-                    self.log.notice("%s %s %s" % (se.ljust(25), readState.rjust(15), writeState.rjust(15)))
+                    self.log.notice(f"{se.ljust(25)} {readState.rjust(15)} {writeState.rjust(15)}")
 
         return S_OK(result)
 
@@ -970,9 +960,9 @@ class DiracLHCb(Dirac):
             )
         siteLfns = {}
         for lfn, reps in replicas.items():
-            possibleSites = set(
+            possibleSites = {
                 site for se in reps for site in sitesForSE.setdefault(se, getSitesForSE(se).get("Value", []))
-            )
+            }
             siteLfns.setdefault(",".join(sorted(possibleSites)), []).append(lfn)
 
         if "" in siteLfns:
@@ -982,9 +972,7 @@ class DiracLHCb(Dirac):
         metadataDict = self.getLfnMetadata(lfns, printOutput)
         if not metadataDict["OK"]:
             return metadataDict
-        fileSizes = dict(
-            (lfn, metadataDict["Value"]["Successful"].get(lfn, {}).get("Size", maxSizePerJob)) for lfn in lfns
-        )
+        fileSizes = {lfn: metadataDict["Value"]["Successful"].get(lfn, {}).get("Size", maxSizePerJob) for lfn in lfns}
 
         lfnGroups = []
         # maxSize is in GB
@@ -1035,7 +1023,7 @@ class DiracLHCb(Dirac):
         if not ret["OK"]:
             return ret
         lfn = ret["Value"]
-        if isinstance(lfn, six.string_types):
+        if isinstance(lfn, str):
             lfn = [lfn]
         results = getAccessURL(lfn, storageElement, protocol=protocol)
         if printOutput:
@@ -1051,8 +1039,8 @@ class DiracLHCb(Dirac):
         """
         inputData = parameters.get("InputData")
         if inputData:
-            self.log.debug("DiracLHCb._getLocalInputData. InputData: %s" % inputData)
-            if isinstance(inputData, six.string_types):
+            self.log.debug(f"DiracLHCb._getLocalInputData. InputData: {inputData}")
+            if isinstance(inputData, str):
                 inputData = inputData.split(";")
             inputData = [lfn.strip("LFN:") for lfn in inputData]
             ancestorsDepth = int(parameters.get("AncestorDepth", 0))
@@ -1065,7 +1053,7 @@ class DiracLHCb(Dirac):
                 ancestorsLFNs = []
                 for ancestorsLFN in res["Value"]["Successful"].values():
                     ancestorsLFNs += [i["FileName"] for i in ancestorsLFN]
-                self.log.info("DiracLHCb._getLocalInputData: adding %d ancestors" % len(ancestorsLFNs))
+                self.log.info(f"DiracLHCb._getLocalInputData: adding {len(ancestorsLFNs)} ancestors")
                 self.log.verbose("%s", ", ".join(ancestorsLFNs))
                 inputData += ancestorsLFNs
 
