@@ -19,7 +19,7 @@ import os
 import six
 
 from DIRAC import gLogger, S_OK, S_ERROR
-from DIRAC.Core.Utilities.Time import toString
+from DIRAC.Core.Utilities.TimeUtilities import toString
 from DIRAC.Core.Utilities.PromptUser import promptUser
 from DIRAC.WorkloadManagementSystem.Client.JobMonitoringClient import JobMonitoringClient
 
@@ -33,7 +33,7 @@ class DiracProduction(DiracLHCb):
     def __init__(self, tsClientIn=None):
         """Instantiates the Workflow object and some default parameters."""
 
-        super(DiracProduction, self).__init__()
+        super().__init__()
 
         if tsClientIn is None:
             self.transformationClient = TransformationClient()
@@ -74,7 +74,7 @@ class DiracProduction(DiracLHCb):
         Protects against
         LFN: being prepended and different types of production ID.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         result = self.transformationClient.getTransformation(int(productionID))
@@ -109,15 +109,15 @@ class DiracProduction(DiracLHCb):
         This includes the operation performed, any messages associated with
         the operation and the DN of the production manager performing it.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         result = self.transformationClient.getTransformationLogging(int(productionID))
         if not result["OK"]:
-            self.log.warn("Could not get transformation logging information for productionID %s" % (productionID))
+            self.log.warn(f"Could not get transformation logging information for productionID {productionID}")
             return result
         if not result["Value"]:
-            self.log.warn("No logging information found for productionID %s" % (productionID))
+            self.log.warn(f"No logging information found for productionID {productionID}")
             return result
 
         if not printOutput:
@@ -150,7 +150,7 @@ class DiracProduction(DiracLHCb):
         value. If printOutput is specified, the result is printed to the
         screen.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         result = self.transformationClient.getTransformationSummary()
@@ -169,7 +169,7 @@ class DiracProduction(DiracLHCb):
           the list of active productions is:\n%s"
                     % ", ".join(str(pID) for pID in result["Value"])
                 )
-                return S_ERROR("Production ID %s was not found" % (productionID))
+                return S_ERROR(f"Production ID {productionID} was not found")
 
         if printOutput:
             self._prettyPrint(result["Value"])
@@ -184,7 +184,7 @@ class DiracProduction(DiracLHCb):
         to-date snapshot of the application status combinations and
         associated WMS JobIDs.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         statusDict = self.getProdJobMetadata(productionID, status, minorStatus)
@@ -196,7 +196,7 @@ class DiracProduction(DiracLHCb):
         if not jobIDs:
             return S_ERROR("No JobIDs with matching conditions found")
 
-        self.log.verbose("Considering %s jobs with selected conditions" % (len(jobIDs)))
+        self.log.verbose(f"Considering {len(jobIDs)} jobs with selected conditions")
         # now need to get the application status information
         result = JobMonitoringClient().getJobsApplicationStatus(jobIDs)
         if not result["OK"]:
@@ -268,9 +268,9 @@ class DiracProduction(DiracLHCb):
         mStatAdj = int(2.0 * self.prodAdj)
         totalAdj = int(0.5 * self.prodAdj)
         exAdj = int(0.5 * self.prodAdj)
-        message = "\nJob Summary for ProductionID %s considering status %s" % (productionID, status)
+        message = f"\nJob Summary for ProductionID {productionID} considering status {status}"
         if minorStatus:
-            message += "and MinorStatus = %s" % (minorStatus)
+            message += f"and MinorStatus = {minorStatus}"
 
         message += ":\n\n"
         message += (
@@ -311,7 +311,7 @@ class DiracProduction(DiracLHCb):
 
         percSub = int(100 * submittedJobs / createdJobs)
         percDone = int(100 * doneJobs / createdJobs)
-        print("\nCurrent status of production %s:\n" % productionID)
+        print(f"\nCurrent status of production {productionID}:\n")
         print(
             "Submitted".ljust(12)
             + str(percSub).ljust(3)
@@ -344,7 +344,7 @@ class DiracProduction(DiracLHCb):
         to-date snapshot of the job status combinations and associated WMS
         JobIDs.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         statusDict = self.getProdJobMetadata(productionID, status, minorStatus)
@@ -391,11 +391,11 @@ class DiracProduction(DiracLHCb):
         mStatAdj = int(2.0 * self.prodAdj)
         totalAdj = int(0.5 * self.prodAdj)
         exAdj = int(0.5 * self.prodAdj)
-        message = "\nJob Summary for ProductionID %s considering" % (productionID)
+        message = f"\nJob Summary for ProductionID {productionID} considering"
         if status:
-            message += " Status = %s" % (status)
+            message += f" Status = {status}"
         if minorStatus:
-            message += " MinorStatus = %s" % (minorStatus)
+            message += f" MinorStatus = {minorStatus}"
         if not status and not minorStatus:
             message += " all status combinations"
 
@@ -434,7 +434,7 @@ class DiracProduction(DiracLHCb):
 
         percSub = int(100 * submittedJobs / createdJobs)
         percDone = int(100 * doneJobs / createdJobs)
-        print("\nCurrent status of production %s:\n" % productionID)
+        print(f"\nCurrent status of production {productionID}:\n")
         print(
             "Submitted".ljust(12)
             + str(percSub).ljust(3)
@@ -465,7 +465,7 @@ class DiracProduction(DiracLHCb):
         This queries the WMS for the given productionID and provides an up-
         to-date snapshot of the sites that jobs were submitted to.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         statusDict = self.getProdJobMetadata(productionID, None, None, site)
@@ -518,9 +518,9 @@ class DiracProduction(DiracLHCb):
         statAdj = int(0.5 * self.prodAdj)
         totalAdj = int(0.5 * self.prodAdj)
         exAdj = int(0.5 * self.prodAdj)
-        message = "\nSummary for ProductionID %s" % (productionID)
+        message = f"\nSummary for ProductionID {productionID}"
         if site:
-            message += " at Site %s" % (site)
+            message += f" at Site {site}"
         else:
             message += " at all Sites"
         message += ":\n\n"
@@ -553,7 +553,7 @@ class DiracProduction(DiracLHCb):
         percSub = int(100 * submittedJobs / createdJobs)
         percDone = int(100 * doneJobs / createdJobs)
         if not site:
-            print("\nCurrent status of production %s:\n" % productionID)
+            print(f"\nCurrent status of production {productionID}:\n")
             print(
                 "Submitted".ljust(12)
                 + str(percSub).ljust(3)
@@ -580,7 +580,7 @@ class DiracProduction(DiracLHCb):
     def getProductionProgress(self, productionID=None, printOutput=False):
         """Returns the status of jobs as seen by the production management
         infrastructure."""
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         productionID = int(productionID)
@@ -594,7 +594,7 @@ class DiracProduction(DiracLHCb):
             productionID = [productionID]
 
         productionID = [str(x) for x in productionID]
-        self.log.verbose("Will check progress for production(s):\n%s" % (", ".join(productionID)))
+        self.log.verbose(f"Will check progress for production(s):\n{', '.join(productionID)}")
         progress = {}
         for prod in productionID:
             # self._prettyPrint(result)
@@ -633,7 +633,7 @@ class DiracProduction(DiracLHCb):
                 status = prodDict["AgentType"]
                 currentProductions[prodID] = status
                 if status.lower() == "automatic":
-                    self.log.verbose("Found active production %s eligible to submit jobs" % prodID)
+                    self.log.verbose(f"Found active production {prodID} eligible to submit jobs")
 
         if printOutput:
             self._prettyPrint(currentProductions)
@@ -657,21 +657,19 @@ class DiracProduction(DiracLHCb):
         """
         commands = self.commands
 
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
         productionID = int(productionID)
         if not isinstance(command, str):
             return self._errorReport("Expected string, for command")
         if not command.lower() in commands:
-            return self._errorReport("Expected one of: %s for command string" % (", ".join(commands)))
+            return self._errorReport(f"Expected one of: {', '.join(commands)} for command string")
 
-        self.log.verbose(
-            'Requested to change production %s with command "%s"' % (productionID, command.lower().capitalize())
-        )
+        self.log.verbose(f'Requested to change production {productionID} with command "{command.lower().capitalize()}"')
         if not disableCheck:
             result = promptUser(
-                'Do you wish to change production %s with command "%s"? ' % (productionID, command.lower().capitalize())
+                f'Do you wish to change production {productionID} with command "{command.lower().capitalize()}"? '
             )
             if not result["OK"]:
                 self.log.info("Action cancelled")
@@ -687,15 +685,15 @@ class DiracProduction(DiracLHCb):
         )
         result = self.transformationClient.setTransformationParameter(int(productionID), "Status", actions[0])
         if not result["OK"]:
-            self.log.warn("Problem updating transformation status with result:\n%s" % result)
+            self.log.warn(f"Problem updating transformation status with result:\n{result}")
             return result
-        self.log.verbose("Setting transformation status to %s successful" % (actions[0]))
+        self.log.verbose(f"Setting transformation status to {actions[0]} successful")
         result = self.transformationClient.setTransformationParameter(int(productionID), "AgentType", actions[1])
         if not result["OK"]:
-            self.log.warn("Problem updating transformation agent type with result:\n%s" % result)
+            self.log.warn(f"Problem updating transformation agent type with result:\n{result}")
             return result
-        self.log.verbose("Setting transformation agent type to %s successful" % (actions[1]))
-        return S_OK("Production %s status updated" % productionID)
+        self.log.verbose(f"Setting transformation agent type to {actions[1]} successful")
+        return S_OK(f"Production {productionID} status updated")
 
     def productionFileSummary(
         self, productionID, selectStatus=None, outputFile=None, orderOutput=True, printSummary=False, printOutput=False
@@ -748,7 +746,7 @@ class DiracProduction(DiracLHCb):
                         print(record)
 
         if printSummary:
-            print("\nSummary for %s files in production %s\n" % (totalRecords, productionID))
+            print(f"\nSummary for {totalRecords} files in production {productionID}\n")
             print("Status".ljust(adj) + " " + "Total".ljust(adj) + "Percentage".ljust(adj) + "\n")
             for n, v in summary.items():
                 percentage = int(100 * int(v) / totalRecords)
@@ -756,7 +754,7 @@ class DiracProduction(DiracLHCb):
             print("\n")
 
         if selectStatus and not selected:
-            return S_ERROR('No files were selected for production %s and status "%s"' % (productionID, selectStatus))
+            return S_ERROR(f'No files were selected for production {productionID} and status "{selectStatus}"')
         elif selectStatus and selected:
             print(
                 '%s / %s files (%s percent) were found for production %s in status "%s"'
@@ -765,15 +763,15 @@ class DiracProduction(DiracLHCb):
 
         if outputFile:
             if os.path.exists(outputFile):
-                print("Requested output file %s already exists, please remove this file to continue" % outputFile)
+                print(f"Requested output file {outputFile} already exists, please remove this file to continue")
                 return fileSummary
 
             with open(outputFile, "w") as fopen:
                 fopen.write(toWrite)
             if not selectStatus:
-                print("Wrote %s lines to file %s" % (totalRecords, outputFile))
+                print(f"Wrote {totalRecords} lines to file {outputFile}")
             else:
-                print('Wrote %s lines to file %s for status "%s"' % (selected, outputFile, selectStatus))
+                print(f'Wrote {selected} lines to file {outputFile} for status "{selectStatus}"')
 
         return fileSummary
 
@@ -783,10 +781,10 @@ class DiracProduction(DiracLHCb):
         All productions are considered by default but can restrict to
         productionID.
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = lfns.replace("LFN:", "")
         elif isinstance(lfns, list):
             try:
@@ -826,7 +824,7 @@ class DiracProduction(DiracLHCb):
         if not res["OK"]:
             return res
         if not res["Value"]:
-            return S_ERROR("Job %s not found for production %s" % (jobID, productionID))
+            return S_ERROR(f"Job {jobID} not found for production {productionID}")
         jobInfo = res["Value"][0]
         if printOutput:
             self._prettyPrint(jobInfo)
@@ -841,7 +839,7 @@ class DiracProduction(DiracLHCb):
         date is the creation date of the production.
         """
         if not date:
-            self.log.verbose("No Date supplied, setting old date for production %s" % productionID)
+            self.log.verbose(f"No Date supplied, setting old date for production {productionID}")
             date = "2001-01-01"
         return self.selectJobs(status, minorStatus, applicationStatus, site, owner, str(productionID).zfill(8), date)
 
@@ -850,10 +848,10 @@ class DiracProduction(DiracLHCb):
 
         Usage: extendProduction <ProductionNameOrID> nJobs
         """
-        if not isinstance(productionID, (six.integer_types, six.string_types)):
+        if not isinstance(productionID, ((int,), (str,))):
             return self._errorReport("Expected string, long or int for production ID")
 
-        if isinstance(numberOfJobs, six.string_types):
+        if isinstance(numberOfJobs, str):
             try:
                 numberOfJobs = int(numberOfJobs)
             except Exception as x:
@@ -861,10 +859,10 @@ class DiracProduction(DiracLHCb):
 
         result = self.transformationClient.extendTransformation(int(productionID), numberOfJobs)
         if not result["OK"]:
-            return self._errorReport(result, "Could not extend production %s by %s jobs" % (productionID, numberOfJobs))
+            return self._errorReport(result, f"Could not extend production {productionID} by {numberOfJobs} jobs")
 
         if printOutput:
-            print("Extended production %s by %s jobs" % (productionID, numberOfJobs))
+            print(f"Extended production {productionID} by {numberOfJobs} jobs")
 
         return result
 
@@ -876,7 +874,7 @@ class DiracProduction(DiracLHCb):
         """
         result = self.transformationClient.getTransformationParameters(int(productionID), ["CreationDate"])
         if not result["OK"]:
-            self.log.warn("Problem getting production metadata for ID %s:\n%s" % (productionID, result))
+            self.log.warn(f"Problem getting production metadata for ID {productionID}:\n{result}")
             return result
 
         creationDate = toString(result["Value"]).split()[0]
@@ -884,7 +882,7 @@ class DiracProduction(DiracLHCb):
             productionID, status=status, minorStatus=minorStatus, site=site, date=creationDate
         )
         if not result["OK"]:
-            self.log.warn("Problem selecting production jobs for ID %s:\n%s" % (productionID, result))
+            self.log.warn(f"Problem selecting production jobs for ID {productionID}:\n{result}")
             return result
 
         jobsList = result["Value"]
@@ -906,16 +904,16 @@ class DiracProduction(DiracLHCb):
         result = prod.create(publish=publishFlag, requestID=requestID, reqUsed=tracking)
 
         if not result["OK"]:
-            gLogger.error("Error during prod creation:\n%s\ncheck that the wkf name is unique." % (result["Message"]))
+            gLogger.error(f"Error during prod creation:\n{result['Message']}\ncheck that the wkf name is unique.")
             return result
 
         if publishFlag:
             prodID = result["Value"]
-            msg = "Production %s successfully created " % (prodID)
+            msg = f"Production {prodID} successfully created "
 
             if extend:
                 self.extendProduction(prodID, extend, printOutput=True)
-                msg += ", extended by %s jobs" % extend
+                msg += f", extended by {extend} jobs"
             if MCsimflag:
                 self.production(prodID, "mctestmode")
                 msg = msg + " and started in mctestmode."
