@@ -59,7 +59,7 @@ class LHCbJob(Job):
 
     def __init__(self, script=None, stdout="std.out", stderr="std.err"):
         """Instantiates the Workflow object and some default parameters."""
-        super(LHCbJob, self).__init__(script, stdout, stderr)
+        super().__init__(script, stdout, stderr)
         self.stepCount = 0
         self.inputDataType = "DATA"  # Default, other options are MDF, ETC
         self.importLocation = "LHCbDIRAC.Workflow.Modules"
@@ -140,53 +140,53 @@ class LHCbJob(Job):
             "inputDataType": inputDataType,
             "logFile": logFile,
         }
-        if not isinstance(appName, six.string_types) or not isinstance(appVersion, six.string_types):
+        if not isinstance(appName, str) or not isinstance(appVersion, str):
             return self._reportError("Expected strings for application name and version", __name__, **kwargs)
 
         if logFile:
-            if isinstance(logFile, six.string_types):
+            if isinstance(logFile, str):
                 logName = logFile
             else:
                 return self._reportError("Expected string for log file name", __name__, **kwargs)
         else:
-            logName = "%s_%s.log" % (appName, appVersion)
+            logName = f"{appName}_{appVersion}.log"
 
         if not inputDataType:
             inputDataType = self.inputDataType
-        if not isinstance(inputDataType, six.string_types):
+        if not isinstance(inputDataType, str):
             return self._reportError("Expected string for input data type", __name__, **kwargs)
 
         optionsFile = None
         if not optionsFiles:
             return self._reportError("Expected string or list for optionsFiles", __name__, **kwargs)
-        if isinstance(optionsFiles, six.string_types):
+        if isinstance(optionsFiles, str):
             optionsFiles = [optionsFiles]
         if not isinstance(optionsFiles, list):
             return self._reportError("Expected string or list for optionsFiles", __name__, **kwargs)
         for optsFile in optionsFiles:
             if not optionsFile:
-                self.log.verbose("Found master options file %s" % optsFile)
+                self.log.verbose(f"Found master options file {optsFile}")
                 optionsFile = optsFile
             if os.path.exists(optsFile):
-                self.log.verbose("Found specified options file: %s" % optsFile)
+                self.log.verbose(f"Found specified options file: {optsFile}")
                 self.addToInputSandbox.append(optsFile)
-                optionsFile += ";%s" % optsFile
+                optionsFile += f";{optsFile}"
             elif re.search(r"\$", optsFile):
                 self.log.verbose(
-                    "Assuming %s is using an environment variable to be resolved during execution" % optsFile
+                    f"Assuming {optsFile} is using an environment variable to be resolved during execution"
                 )
                 if not optionsFile == optsFile:
-                    optionsFile += ";%s" % optsFile
+                    optionsFile += f";{optsFile}"
             else:
-                return self._reportError("Specified options file %s does not exist" % (optsFile), __name__, **kwargs)
+                return self._reportError(f"Specified options file {optsFile} does not exist", __name__, **kwargs)
 
         # ensure optionsFile list is unique:
         tmpList = optionsFile.split(";")
         optionsFile = ";".join(list(set(tmpList)))
-        self.log.verbose("Final options list is: %s" % optionsFile)
+        self.log.verbose(f"Final options list is: {optionsFile}")
 
         if inputData:
-            if isinstance(inputData, six.string_types):
+            if isinstance(inputData, str):
                 inputData = [inputData]
             if not isinstance(inputData, list):
                 return self._reportError(
@@ -200,7 +200,7 @@ class LHCbJob(Job):
                 self.addToInputData.append(inputDataStr)
 
         self.stepCount += 1
-        stepName = "%sStep%s" % (appName, self.stepCount)
+        stepName = f"{appName}Step{self.stepCount}"
 
         if not modulesNameList:
             modulesNameList = [
@@ -236,8 +236,8 @@ class LHCbJob(Job):
             parametersList=parametersList,
         )
 
-        logPrefix = "Step%s_" % (self.stepCount)
-        logName = "%s%s" % (logPrefix, logName)
+        logPrefix = f"Step{self.stepCount}_"
+        logName = f"{logPrefix}{logName}"
         self.addToOutputSandbox.append(logName)
 
         stepInstance = addStepToWorkflow(self.workflow, step, stepName)
@@ -283,7 +283,7 @@ class LHCbJob(Job):
         """
         kwargs = {"depth": depth}
         description = "Level at which ancestor files are retrieved from the bookkeeping"
-        if isinstance(depth, six.string_types):
+        if isinstance(depth, str):
             try:
                 self._addParameter(self.workflow, "AncestorDepth", "JDL", int(depth), description)
             except BaseException:
@@ -319,7 +319,7 @@ class LHCbJob(Job):
         :type inputDataType: String
         """
         description = "User specified input data type"
-        if not isinstance(inputDataType, six.string_types):
+        if not isinstance(inputDataType, str):
             try:
                 inputDataType = str(inputDataType)
             except TypeError:
@@ -396,7 +396,7 @@ class LHCbJob(Job):
             outputDataStr = ";".join(lfns)
             description = "List of output data files"
             self._addParameter(self.workflow, "UserOutputData", "JDL", outputDataStr, description)
-        elif isinstance(lfns, six.string_types):
+        elif isinstance(lfns, str):
             description = "Output data file"
             self._addParameter(self.workflow, "UserOutputData", "JDL", lfns, description)
         else:
@@ -404,7 +404,7 @@ class LHCbJob(Job):
 
         if OutputSE:
             description = "User specified Output SE"
-            if isinstance(OutputSE, six.string_types):
+            if isinstance(OutputSE, str):
                 OutputSE = [OutputSE]
             elif not isinstance(OutputSE, list):
                 return self._reportError("Expected string or list for OutputSE", **kwargs)
@@ -413,7 +413,7 @@ class LHCbJob(Job):
 
         if OutputPath:
             description = "User specified Output Path"
-            if not isinstance(OutputPath, six.string_types):
+            if not isinstance(OutputPath, str):
                 return self._reportError("Expected string for OutputPath", **kwargs)
             # Remove leading "/" that might cause problems with os.path.join
             while OutputPath[0] == "/":
@@ -464,13 +464,13 @@ class LHCbJob(Job):
            :type logFile: string
         """
         kwargs = {"executable": executable, "arguments": arguments, "applicationLog": logFile}
-        if not isinstance(executable, six.string_types):
+        if not isinstance(executable, str):
             return self._reportError("Expected strings for executable and arguments", **kwargs)
 
         if os.path.exists(executable):
-            self.log.verbose("Found script executable file %s" % (executable))
+            self.log.verbose(f"Found script executable file {executable}")
             self.addToInputSandbox.append(executable)
-            logName = "%s.log" % (os.path.basename(executable))
+            logName = f"{os.path.basename(executable)}.log"
             moduleName = os.path.basename(executable)
         else:
             self.log.verbose("Found executable code")
@@ -478,13 +478,13 @@ class LHCbJob(Job):
             moduleName = "CodeSegment"
 
         if logFile:
-            if isinstance(logFile, six.string_types):
+            if isinstance(logFile, str):
                 logName = str(logFile)
 
         self.stepCount += 1
 
         moduleName = moduleName.replace(".", "")
-        stepName = "ScriptStep%s" % (self.stepCount)
+        stepName = f"ScriptStep{self.stepCount}"
 
         if not modulesNameList:
             modulesNameList = ["CreateDataFile", "LHCbScript", "FileUsage", "UserJobFinalization"]
@@ -504,9 +504,9 @@ class LHCbJob(Job):
             parametersList=parametersList,
         )
 
-        stepName = "RunScriptStep%s" % (self.stepCount)
-        logPrefix = "Script%s_" % (self.stepCount)
-        logName = "%s%s" % (logPrefix, logName)
+        stepName = f"RunScriptStep{self.stepCount}"
+        logPrefix = f"Script{self.stepCount}_"
+        logName = f"{logPrefix}{logName}"
         self.addToOutputSandbox.append(logName)
 
         stepInstance = addStepToWorkflow(self.workflow, step, stepName)
@@ -548,7 +548,7 @@ class LHCbJob(Job):
         """
         kwargs = {"platform": platform}
 
-        if not isinstance(platform, six.string_types):
+        if not isinstance(platform, str):
             return self._reportError("Expected string for platform", **kwargs)
 
         if platform and platform.lower() != "any":
@@ -602,7 +602,7 @@ class LHCbJob(Job):
                 typeVersion = ""
 
             else:
-                self.log.verbose("Found file types %s for LFNs: %s" % (typeVersions.values(), list(typeVersions)))
+                self.log.verbose(f"Found file types {typeVersions.values()} for LFNs: {list(typeVersions)}")
                 typeVersionsList = list(set(typeVersions.values()))
                 if len(typeVersionsList) == 1:
                     typeVersion = typeVersionsList[0]
