@@ -12,8 +12,3 @@
 
 This contains the LHCb specific API plugins for DIRAC.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
