@@ -11,19 +11,17 @@
 ###############################################################################
 """Start or stop the production(s)"""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s <Production ID> |<Production ID>" % Script.scriptName,
+                f"  {Script.scriptName} <Production ID> |<Production ID>",
                 "Arguments:",
                 "  <Production ID>:      DIRAC Production Id",
             ]
@@ -73,7 +71,6 @@ def main():
         action = "stop"
 
     for prodID in args:
-
         result = diracProd.production(prodID, action, disableCheck=False)
         if "Message" in result:
             errorList.append((prodID, result["Message"]))
@@ -85,7 +82,7 @@ def main():
             exitCode = 0
 
     for error in errorList:
-        print("ERROR %s" % error)
+        print(f"ERROR {error}")
 
     DIRAC.exit(exitCode)
 
