@@ -10,20 +10,16 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <Production ID> <DIRAC Status>" % (Script.scriptName))
+    print(f"Usage: {Script.scriptName} <Production ID> <DIRAC Status>")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
 
@@ -39,7 +35,7 @@ def main():
     if result["OK"]:
         DIRAC.exit(0)
     elif "Message" in result:
-        print("Getting production application status summary failed with message:\n%s" % (result["Message"]))
+        print(f"Getting production application status summary failed with message:\n{result['Message']}")
         DIRAC.exit(2)
     else:
         print("Null result for getProductionApplicationSummary() call")
