@@ -9,30 +9,28 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
 
-    print("Usage: %s <Command> <Production ID> |<Production ID>" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <Command> <Production ID> |<Production ID>")
     commands = DiracProduction().getProductionCommands()["Value"]
-    print("\nCommands include: %s" % ", ".join(commands))
+    print(f"\nCommands include: {', '.join(commands)}")
     print("\nDescription:\n")
     for n, v in commands.items():
-        print("%s:" % n)
+        print(f"{n}:")
         for i, j in v.items():
-            print("     %s = %s" % (i, j))
+            print(f"     {i} = {j}")
 
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     args = Script.getPositionalArgs()
