@@ -9,8 +9,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
@@ -18,16 +19,12 @@ def usage():
 
     Prints script usage
     """
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <LFN> [<LFN>] [--ProductionID=<ID>] [Try -h,--help for more information]" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <LFN> [<LFN>] [--ProductionID=<ID>] [Try -h,--help for more information]")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch(
         "",
         "ProductionID=",
@@ -58,7 +55,7 @@ def main():
     exitCode = 0
     result = diracProd.checkFilesStatus(args, prodID, printOutput=False)
     if not result["OK"]:
-        print("ERROR %s" % (result["Message"]))
+        print(f"ERROR {result['Message']}")
         exitCode = 2
 
     DIRAC.exit(exitCode)
