@@ -9,8 +9,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def getBoolean(value):
@@ -28,16 +29,12 @@ def usage():
 
     Prints script usage
     """
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <ProductionID> <Options> [Try -h,--help for more information]" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <ProductionID> <Options> [Try -h,--help for more information]")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     # Default values
     status = None
     outFile = None
@@ -75,7 +72,7 @@ def main():
     try:
         productionID = int(productionID)
     except Exception as x:
-        print("Production ID must be an integer, not %s:\n%s" % (productionID, x))
+        print(f"Production ID must be an integer, not {productionID}:\n{x}")
         DIRAC.exit(2)
 
     result = diracProd.productionFileSummary(
@@ -86,7 +83,7 @@ def main():
         printOutput=printVerbose,
     )
     if not result["OK"]:
-        print("ERROR %s" % result["Message"])
+        print(f"ERROR {result['Message']}")
         exitCode = 2
 
     DIRAC.exit(exitCode)
