@@ -9,8 +9,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
@@ -18,16 +19,12 @@ def usage():
 
     Prints script usage
     """
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <WMS Job ID> [<WMS Job ID>]" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <WMS Job ID> [<WMS Job ID>]")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
