@@ -10,21 +10,17 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
     """usage Prints script usage."""
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <Production ID> <Production Job ID>" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <Production ID> <Production Job ID>")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
 
@@ -47,7 +43,7 @@ def main():
     if result["OK"]:
         DIRAC.exit(0)
     elif "Message" in result:
-        print("Getting production job info failed with message:\n%s" % (result["Message"]))
+        print(f"Getting production job info failed with message:\n{result['Message']}")
         DIRAC.exit(2)
     else:
         print("Null result for getProdJobInfo() call")
