@@ -9,8 +9,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
@@ -18,16 +19,12 @@ def usage():
 
     Prints script usage
     """
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <Production ID> [<DIRAC Status>]" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <Production ID> [<DIRAC Status>]")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
@@ -48,7 +45,7 @@ def main():
     if result["OK"]:
         DIRAC.exit(0)
     elif "Message" in result:
-        print("Getting production job summary failed with message:\n%s" % result["Message"])
+        print(f"Getting production job summary failed with message:\n{result['Message']}")
         DIRAC.exit(2)
     else:
         print("Null result for getProductionJobSummary() call")
