@@ -9,22 +9,19 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
     """usage Prints script usage."""
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s <Production ID> |<Production ID>" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} <Production ID> |<Production ID>")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
