@@ -9,13 +9,12 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     import DIRAC
@@ -29,7 +28,7 @@ def main():
     for prodID in args:
         result = diracProd.getProductionProgress(prodID, printOutput=True)
         if "Message" in result:
-            print("Listing production summary failed with message:\n%s" % result["Message"])
+            print(f"Listing production summary failed with message:\n{result['Message']}")
             exitCode = 2
         elif not result:
             print("Null result for getProduction() call", prodID)
@@ -40,7 +39,7 @@ def main():
     if not args:
         result = diracProd.getProductionProgress(printOutput=True)
         if "Message" in result:
-            print("Listing production summary failed with message:\n%s" % result["Message"])
+            print(f"Listing production summary failed with message:\n{result['Message']}")
             exitCode = 2
         elif not result:
             print("Null result for getProduction() call")
