@@ -12,19 +12,17 @@
 """Set the Agent Type for a(the) given transformation(s)"""
 import DIRAC
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s <Production ID> |<Production ID>" % Script.scriptName,
+                f"  {Script.scriptName} <Production ID> |<Production ID>",
                 "Arguments:",
                 "  <Production ID>:      DIRAC Production Id",
             ]
