@@ -10,7 +10,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def usage():
@@ -18,16 +18,12 @@ def usage():
 
     Prints script usage
     """
-    from DIRAC.Core.Base import Script
-
-    print("Usage: %s [<Production ID>]" % Script.scriptName)
+    print(f"Usage: {Script.scriptName} [<Production ID>]")
     DIRAC.exit(2)
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.parseCommandLine(ignoreErrors=True)
 
     from LHCbDIRAC.Interfaces.API.DiracProduction import DiracProduction
@@ -47,7 +43,7 @@ def main():
     if result["OK"]:
         DIRAC.exit(0)
     elif "Message" in result:
-        print("Listing production summary failed with message:\n%s" % result["Message"])
+        print(f"Listing production summary failed with message:\n{result['Message']}")
         DIRAC.exit(2)
     else:
         print("Null result for getProductionSummary() call")
