@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """DataProcessingProgressAgent."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import os
 import time
@@ -25,13 +21,10 @@ from DIRAC.Core.Base.AgentModule import AgentModule
 from LHCbDIRAC.ProductionManagementSystem.Client.ProcessingProgress import ProcessingProgress, HTMLProgressTable
 from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import BKQuery
 
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "ProductionManagement/DataProcessingProgressAgent"
 
 
 class DataProcessingProgressAgent(AgentModule):
-
     #############################################################################
     def initialize(self):
         """Sets default values."""
@@ -47,7 +40,7 @@ class DataProcessingProgressAgent(AgentModule):
         # Get back the loop number
         self.cacheFile = os.path.join(self.workDirectory, "cacheFile")
         try:
-            cfile = open(self.cacheFile, "r")
+            cfile = open(self.cacheFile)
             self.iterationNumber = int(cfile.read())
             cfile.close()
         except BaseException:
@@ -74,7 +67,7 @@ class DataProcessingProgressAgent(AgentModule):
                 bkPath = os.path.join(bkConfig, "*/Real Data", processingPass, str(eventType), fileType)
                 bkQuery = BKQuery(bkPath, visible=False)
                 if not bkQuery:
-                    self.log.error("Cannot build bkQuery for %s" % bkPath)
+                    self.log.error(f"Cannot build bkQuery for {bkPath}")
                 else:
                     report["BKQuery"].append(bkQuery)
             self.progressReports[reportName.replace(".", "/")] = report
@@ -82,14 +75,14 @@ class DataProcessingProgressAgent(AgentModule):
         self.log.info("List of progress reports:")
         self.previousProdStats = {}
         for reportName in self.progressReports:
-            printStr = "%s: " % reportName
+            printStr = f"{reportName}: "
             for key, value in self.progressReports[reportName].items():
                 if key != "BKQuery":
-                    printStr += ", %s : %s" % (key, str(value))
+                    printStr += f", {key} : {str(value)}"
                 else:
-                    printStr += ", %s :" % key
+                    printStr += f", {key} :"
                     for bkQuery in self.progressReports[reportName]["BKQuery"]:
-                        printStr += " - %s" % bkQuery.getPath()
+                        printStr += f" - {bkQuery.getPath()}"
             self.log.info(printStr)
         return S_OK()
 
@@ -99,11 +92,11 @@ class DataProcessingProgressAgent(AgentModule):
         for reportName in sorted(self.progressReports):
             htmlTable = HTMLProgressTable(reportName.replace(".", "/"))
             reportLen = len(reportName) + 4
-            self.log.info("\n%s\n* %s *\n%s" % (reportLen * "*", reportName, reportLen * "*"))
+            self.log.info(f"\n{reportLen * '*'}\n* {reportName} *\n{reportLen * '*'}")
             report = self.progressReports[reportName]
             # Skip all by each "frequency" loop
             if report["Frequency"] == 0 or (self.iterationNumber % report["Frequency"]) != 0:
-                self.log.info("Skipping this iteration for %s" % reportName)
+                self.log.info(f"Skipping this iteration for {reportName}")
                 continue
             self.statCollector.setClearCache(report["ClearCache"])
             summaryProdStats = []
@@ -151,7 +144,7 @@ class DataProcessingProgressAgent(AgentModule):
             self.statCollector.setPreviousStats(reportName, self.previousProdStats[reportName])
             try:
                 fOpen = open(outputHTML, "w")
-                fOpen.write("<head>\n<title>Progress of %s</title>\n</title>\n" % bkQuery.getProcessingPass())
+                fOpen.write(f"<head>\n<title>Progress of {bkQuery.getProcessingPass()}</title>\n</title>\n")
                 fOpen.write(str(htmlTable.getTable()))
                 fOpen.close()
                 print("Successfully wrote HTML file", outputHTML)
@@ -190,7 +183,7 @@ class DataProcessingProgressAgent(AgentModule):
             print("Failed to upload", htmlFile, "to", self.uploadDirectory)
 
     def am_getSection(self, section):
-        res = gConfig.getSections("%s/%s" % (self.am_getModuleParam("section"), section))
+        res = gConfig.getSections(f"{self.am_getModuleParam('section')}/{section}")
         if res["OK"]:
             return res["Value"]
         else:
