@@ -42,7 +42,7 @@ from concurrent.futures import ThreadPoolExecutor, wait
 import DIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Core.Base.AgentModule import AgentModule
-from DIRAC.Core.Utilities.Time import timeThis
+from DIRAC.Core.Utilities.TimeUtilities import timeThis
 from DIRAC.Interfaces.API.Dirac import Dirac
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 
@@ -222,10 +222,10 @@ class ProductionStatusAgent(AgentModule):
         if updatedT:
             self.log.info("Transformations updated this cycle:")
             for name, value in updatedT.items():
-                self.log.info("Transformations %s: %s => %s" % (name, value["from"], value["to"]))
+                self.log.info(f"Transformations {name}: {value['from']} => {value['to']}")
 
         if updatedPr:
-            self.log.info("Production Requests updated to Done status:", "%s" % (", ".join(str(i) for i in updatedPr)))
+            self.log.info("Production Requests updated to Done status:", f"{', '.join(str(i) for i in updatedPr)}")
 
         if gDoRealUpdate and not gSimulate:
             self._mailProdManager(updatedT, updatedPr)
@@ -246,7 +246,7 @@ class ProductionStatusAgent(AgentModule):
         self.log.verbose("Collecting old Production Request Progress...")
         result = self.prClient.getAllProductionProgress()
         if not result["OK"]:
-            return S_ERROR("Could not retrieve production progress summary: %s" % result["Message"])
+            return S_ERROR(f"Could not retrieve production progress summary: {result['Message']}")
         progressSummary = result["Value"]  # { <prID> : [ <prodId> : { 'Used', 'Events' } ] }
 
         for prID, summary in self.prSummary.items():
@@ -268,7 +268,7 @@ class ProductionStatusAgent(AgentModule):
         self.log.info("Collecting active production requests...")
         result = self.prClient.getProductionRequestList(0, "", "ASC", 0, 0, {"RequestState": "Active"})
         if not result["OK"]:
-            return S_ERROR("Could not retrieve active production requests: %s" % result["Message"])
+            return S_ERROR(f"Could not retrieve active production requests: {result['Message']}")
         activeMasters = result["Value"]["Rows"]
         for pr in activeMasters:
             prID = pr["RequestID"]
@@ -276,9 +276,7 @@ class ProductionStatusAgent(AgentModule):
                 self.prMasters[prID] = []
                 result = self.prClient.getProductionRequestList(prID, "", "ASC", 0, 0, {})
                 if not result["OK"]:
-                    return S_ERROR(
-                        "Could not get subrequests for production request %s: %s" % (prID, result["Message"])
-                    )
+                    return S_ERROR(f"Could not get subrequests for production request {prID}: {result['Message']}")
                 for subPr in result["Value"]["Rows"]:
                     subPrID = subPr["RequestID"]
                     self.prSummary[subPrID] = {
@@ -300,9 +298,7 @@ class ProductionStatusAgent(AgentModule):
         if not result["OK"]:
             return result
 
-        self.log.info(
-            "Will work with %s productions from %s Active (sub)requests" % (len(self.prProds), len(self.prSummary))
-        )
+        self.log.info(f"Will work with {len(self.prProds)} productions from {len(self.prSummary)} Active (sub)requests")
         self.log.verbose("Done with collecting Active production requests")
         return S_OK()
 
@@ -314,18 +310,16 @@ class ProductionStatusAgent(AgentModule):
         """
         res = self.tClient.getTransformationWithStatus(status)
         if not res["OK"]:
-            self.log.error("Failed to get transformations", "%s: %s" % (status, res["Message"]))
-            raise RuntimeError("Failed to get %s transformations: %s" % (status, res["Message"]))
+            self.log.error("Failed to get transformations", f"{status}: {res['Message']}")
+            raise RuntimeError(f"Failed to get {status} transformations: {res['Message']}")
         if not res["Value"]:
-            self.log.debug("No transformations in %s status" % status)
+            self.log.debug(f"No transformations in {status} status")
             return []
         if len(res["Value"]) > 20:
-            self.log.verbose(
-                "The following number of transformations are in %s status: %u" % (status, len(res["Value"]))
-            )
+            self.log.verbose(f"The following number of transformations are in {status} status: {len(res['Value'])}")
         else:
             valOutStr = ", ".join(str(i) for i in res["Value"])
-            self.log.verbose("The following transformations are in %s status: %s" % (status, valOutStr))
+            self.log.verbose(f"The following transformations are in {status} status: {valOutStr}")
         return res["Value"]
 
     @timeThis
@@ -381,7 +375,7 @@ class ProductionStatusAgent(AgentModule):
             totalColumnName = "Total"
         else:
             raise NotImplementedError(tableName)
-        self.log.verbose("Getting counters from for", "%s transformations" % len(transformationIDs))
+        self.log.verbose("Getting counters from for", f"{len(transformationIDs)} transformations")
         res = self.tClient.getCounters(
             tableName,
             ["TransformationID", statusKey],
@@ -413,7 +407,7 @@ class ProductionStatusAgent(AgentModule):
         :param list of str tIDs: The IDs to get cached data for
         :returns: transformations, taskStatuses, fileStatuses
         """
-        self.log.verbose("Filling _isIdleCache caches for", "%s transformations" % len(transIDs))
+        self.log.verbose("Filling _isIdleCache caches for", f"{len(transIDs)} transformations")
         result = self.tClient.getTransformations(condDict={"TransformationID": transIDs}, limit=1000)
         if not result["OK"]:
             self.log.error("Could not get transformations", result["Message"])
@@ -455,7 +449,7 @@ class ProductionStatusAgent(AgentModule):
             # other transformation type : go to Idle if
             # 0 assigned files, unused files number was not changing during the last cyclesTillIdle time
             # AND only failed and done tasks
-            self.log.debug("Files stats: %s" % str(filesStats))
+            self.log.debug(f"Files stats: {str(filesStats)}")
             unused = filesStats.get("Unused", 0)
             unusedInherited = filesStats.get("Unused-inherited", 0)
             oldUnused = self.filesUnused.setdefault(tID, {"Number": -1, "NotChanged": 0})
@@ -467,7 +461,7 @@ class ProductionStatusAgent(AgentModule):
             assigned = filesStats.get("Assigned", 0)
             isProcIdle = (assigned == 0) and ((unused == 0) or (oldUnused["NotChanged"] >= self.cyclesTillIdle))
             if isProcIdle:
-                self.log.debug("Tasks Stats: %s" % str(tStats))
+                self.log.debug(f"Tasks Stats: {str(tStats)}")
                 isProcIdle = all(tStats.get(status, 0) == 0 for status in KNOWN_TASK_STATES)
             isIdle = isProcIdle and (unused == 0) and (unusedInherited == 0)
         return (isIdle, isProcIdle, isSimulation)
@@ -536,7 +530,7 @@ class ProductionStatusAgent(AgentModule):
                     "Could not send update to the Production Request System", result["Message"]
                 )  # that is not critical
             else:
-                self.log.verbose("The progress of %s Production Requests is updated" % len(self.toUpdate))
+                self.log.verbose(f"The progress of {len(self.toUpdate)} Production Requests is updated")
         self.log.info("Production requests progress update is finished")
 
         # Get the status of the Analysis Productions input transformations
@@ -570,7 +564,7 @@ class ProductionStatusAgent(AgentModule):
                     if inputState not in ["Archived", "Completed", "Finished"]:
                         self.log.info(
                             "Marking hasActiveInput=True for",
-                            "%s (%s) as input %s has status %s" % (tID, prID, inputID, inputState),
+                            f"{tID} ({prID}) as input {inputID} has status {inputState}",
                         )
                         tInfo["hasActiveInput"] = True
 
@@ -588,13 +582,13 @@ class ProductionStatusAgent(AgentModule):
                 self.toUpdate.append({"ProductionID": tID, "BkEvents": nEvents})
                 tInfo["Events"] = nEvents
         else:
-            self.log.error("Progress is not updated", "%s : %s" % (tID, result["Message"]))
+            self.log.error("Progress is not updated", f"{tID} : {result['Message']}")
             return S_ERROR("Too dangerous to continue")
         # Find the transfromation ID for the input to each Analysis Production
         if self.prSummary[prID]["type"] == "AnalysisProduction":
             retVal = TransformationClient().getBookkeepingQuery(tID)
             if not retVal["OK"]:
-                self.log.error("Failed to call getBookkeepingQuery", "%s %s" % (tID, retVal["Message"]))
+                self.log.error("Failed to call getBookkeepingQuery", f"{tID} {retVal['Message']}")
                 return S_ERROR("Too dangerous to continue")
             inputBkQuery = retVal["Value"]
             if "ProductionID" in inputBkQuery:
@@ -605,7 +599,7 @@ class ProductionStatusAgent(AgentModule):
                     inputBkQuery["ConditionDescription"] = inputBkQuery["DataTakingConditions"]
                 retVal = BookkeepingClient().getProductions(inputBkQuery)
                 if not retVal["OK"]:
-                    self.log.error("Failed to call getProductions", "%s %s" % (tID, retVal["Message"]))
+                    self.log.error("Failed to call getProductions", f"{tID} {retVal['Message']}")
                     return S_ERROR("Too dangerous to continue")
                 tInfo["inputIDs"] = [x[0] for x in retVal["Value"]["Records"]]
 
@@ -627,7 +621,7 @@ class ProductionStatusAgent(AgentModule):
         Most importantly this method only allows status transitions based on
         what the original status should be.
         """
-        self.log.info("Changing status for transformation %s to %s" % (tID, status))
+        self.log.info(f"Changing status for transformation {tID} to {status}")
 
         if not gDoRealUpdate:
             updatedT[tID] = {"to": status, "from": origStatus}
@@ -635,7 +629,7 @@ class ProductionStatusAgent(AgentModule):
 
         result = self.tClient.setTransformationParameter(tID, "Status", status, currentStatus=origStatus)
         if not result["OK"]:
-            self.log.error("Failed to update status of transformation", "%s from %s to %s" % (tID, origStatus, status))
+            self.log.error("Failed to update status of transformation", f"{tID} from {origStatus} to {status}")
         else:
             updatedT[tID] = {"to": status, "from": origStatus}
 
@@ -647,9 +641,7 @@ class ProductionStatusAgent(AgentModule):
             return
 
         if self.notify:
-
             with sqlite3.connect(self.cacheFile) as conn:
-
                 try:
                     conn.execute(
                         """CREATE TABLE IF NOT EXISTS ProductionStatusAgentCache(
@@ -689,7 +681,7 @@ class ProductionStatusAgent(AgentModule):
 
     def __updateProductionRequestStatus(self, prID, status, updatedPr):
         """This method updates the production request status."""
-        self.log.info("Marking Production Request %s as %s" % (prID, status))
+        self.log.info(f"Marking Production Request {prID} as {status}")
 
         if not gDoRealUpdate:
             updatedPr.append(prID)
@@ -715,7 +707,7 @@ class ProductionStatusAgent(AgentModule):
             self.__updateTransformationStatus(tID, "RemovedFiles", "Completed", updatedT)
 
         self.log.info(
-            'Processing %s requests unrelated transformations in "Active" state' % len(self.notPrTrans["Active"])
+            f"Processing {len(self.notPrTrans['Active'])} requests unrelated transformations in \"Active\" state"
         )
         try:
             transformations, taskStatuses, fileStatuses = self._isIdleCache(self.notPrTrans["Active"])
@@ -729,7 +721,7 @@ class ProductionStatusAgent(AgentModule):
                 if isIdle:
                     self.__updateTransformationStatus(tID, "Active", "Idle", updatedT)
 
-        self.log.info('Processing %s requests unrelated transformations in "Idle" state' % len(self.notPrTrans["Idle"]))
+        self.log.info(f"Processing {len(self.notPrTrans['Idle'])} requests unrelated transformations in \"Idle\" state")
         try:
             transformations, taskStatuses, fileStatuses = self._isIdleCache(self.notPrTrans["Idle"])
         except RuntimeError:
@@ -804,7 +796,7 @@ class ProductionStatusAgent(AgentModule):
         """Check that this transformation has registered less events than it was
         requested."""
         if summary["prods"][tID]["Events"] < summary["prTotal"]:
-            self.log.verbose(" Transformation %s has produced less events, asking for extention " % tID)
+            self.log.verbose(f" Transformation {tID} has produced less events, asking for extention ")
             return True
         return False
 
@@ -881,9 +873,7 @@ class ProductionStatusAgent(AgentModule):
                     else:
                         self.__updateTransformationStatus(tID, "Idle", "Completed", updatedT)
                 elif tInfo["filesTotal"] == tInfo["filesProcessed"] + tInfo["filesMaxReset"]:
-                    self.log.warn(
-                        "Transformation has files in MaxReset", "ID=%s count=%s" % (tID, tInfo["filesMaxReset"])
-                    )
+                    self.log.warn("Transformation has files in MaxReset", f"ID={tID} count={tInfo['filesMaxReset']}")
 
     def _handleStateRemovedFiles(self, tID, tInfo, summary, updatedT):
         """Used by _applyProductionRequestsLogic"""
@@ -923,7 +913,7 @@ class ProductionStatusAgent(AgentModule):
             # isDone only uses the bookkeeping and therefore isn't useful
             self.__updateTransformationStatus(tID, "ValidatedOutput", "Completed", updatedT)
         else:
-            self.log.warn("Logical bug: transformation %s unexpectedly has 'ValidatedOutput'" % tID)
+            self.log.warn(f"Logical bug: transformation {tID} unexpectedly has 'ValidatedOutput'")
 
     def _handleStateValidatingInput(self, tID, tInfo, summary, updatedT):
         """Used by _applyProductionRequestsLogic"""
@@ -931,7 +921,7 @@ class ProductionStatusAgent(AgentModule):
             # for standard sim requests, all but the merge
             self.__updateTransformationStatus(tID, "ValidatingInput", "RemovingFiles", updatedT)
         else:
-            self.log.warn("Logical bug: transformation %s is unexpectedly 'ValidatingInput'" % tID)
+            self.log.warn(f"Logical bug: transformation {tID} is unexpectedly 'ValidatingInput'")
 
     def _handleStateTesting(self, tID, tInfo, summary, updatedT):
         """Used by _applyProductionRequestsLogic"""
