@@ -28,7 +28,7 @@ from LHCbDIRAC.Core.Utilities.HTML import Table, TableCell, TableRow
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
 
-class HTMLProgressTable(object):
+class HTMLProgressTable:
     def __init__(self, processingPass):
         """c'tor."""
         self.table = Table()
@@ -46,7 +46,7 @@ class HTMLProgressTable(object):
         titles = StatInfo().titles
         row1 = [TableCell("<b>" + str(title) + "</b>", align="left", attribs={"rowspan": 2})]
         row2 = []
-        for (head, subs) in titles:
+        for head, subs in titles:
             if isinstance(subs, list):
                 cols = len(subs)
             else:
@@ -118,7 +118,7 @@ class HTMLProgressTable(object):
         titleRow = self.__titleRow("Progress")
         self.table.rows.append([TableCell("", attribs={"colspan": self.htmlColumns})])
         self.table.rows.append(
-            [TableCell("Progress since %s" % previousTime, align="center", attribs={"colspan": self.htmlColumns})]
+            [TableCell(f"Progress since {previousTime}", align="center", attribs={"colspan": self.htmlColumns})]
         )
         self.table.rows += titleRow
         prodStats = self.__sumProdStats(summaryProdStats)
@@ -134,7 +134,7 @@ class HTMLProgressTable(object):
         # self.table.rows.append(row)
 
 
-class StatInfo(object):
+class StatInfo:
     def __init__(self, name="", info={}):
         self.name = name
         self.items = [
@@ -209,11 +209,11 @@ class StatInfo(object):
         if not val or abs(val) < 0.001:
             return "-"
         if item not in self.regularItems:
-            return "%.1f" % val
+            return f"{val:.1f}"
         if isinstance(val, int):
             return "%d" % val
         if isinstance(val, float):
-            return "%.3f" % val
+            return f"{val:.3f}"
         else:
             return str(val)
 
@@ -254,7 +254,7 @@ class StatInfo(object):
         thisName = self.name
         thatName = other.name
         if thisName != thatName:
-            print("Error substracting StatInfo for %s and %s" % (thisName, thatName))
+            print(f"Error substracting StatInfo for {thisName} and {thatName}")
             return StatInfo("")
         values = {}
         for item in self.items:
@@ -267,7 +267,7 @@ class StatInfo(object):
         return info
 
 
-class ProcessingProgress(object):
+class ProcessingProgress:
     def __init__(self, cacheFile=None):
         if not cacheFile:
             self.prodStatFile = os.path.join(os.environ["HOME"], ".dirac/work", "dirac-production-stats.pkl")
@@ -297,7 +297,7 @@ class ProcessingProgress(object):
     def getFullStats(self, bkQuery, printResult=False):
         processingPass = bkQuery.getProcessingPass()
         if printResult:
-            gLogger.info("\nStatistics for processing %s, condition %s\n" % (processingPass, bkQuery.getConditions()))
+            gLogger.info(f"\nStatistics for processing {processingPass}, condition {bkQuery.getConditions()}\n")
         prodStats = []
         processingPass = processingPass.split("/")
         if len(processingPass) != 4 or processingPass[1] != "Real Data":
@@ -315,7 +315,7 @@ class ProcessingProgress(object):
             if prodBKDict:
                 recoRunRanges[prod] = [prodBKDict.get("StartRun", 0), prodBKDict.get("EndRun", sys.maxsize)]
                 dqFlags = prodBKDict.get("DataQualityFlag", ["UNCHECKED", "EXPRESS_OK", "OK"])
-                if isinstance(dqFlags, six.string_types):
+                if isinstance(dqFlags, str):
                     dqFlags = dqFlags.split(",")
                 recoDQFlags += [fl for fl in dqFlags if fl not in recoDQFlags]
             else:
@@ -327,8 +327,8 @@ class ProcessingProgress(object):
             print("Exception in sorting productions:")
             for p in recoList:
                 print(p, recoRunRanges[p])
-        gLogger.verbose("Reconstruction productions found (%d): %s" % (len(recoList), str(sorted(recoList))))
-        gLogger.verbose("Reconstruction DQ flags: %s" % str(recoDQFlags))
+        gLogger.verbose(f"Reconstruction productions found ({len(recoList)}): {str(sorted(recoList))}")
+        gLogger.verbose(f"Reconstruction DQ flags: {str(recoDQFlags)}")
 
         # Get productions for merging
         mergeList = []
@@ -337,7 +337,7 @@ class ProcessingProgress(object):
         stripList = []
         for prod in bkQuery.getBKProductions(visible=False):
             prodBKDict = self.__getProdBkDict(prod)
-            gLogger.verbose("BK query for production %s: %s" % (prod, str(prodBKDict)))
+            gLogger.verbose(f"BK query for production {prod}: {str(prodBKDict)}")
             mergedTypes = prodBKDict.get("FileType")
             if not isinstance(mergedTypes, list):
                 mergedTypes = [mergedTypes]
@@ -352,7 +352,7 @@ class ProcessingProgress(object):
                 _msgTuple = (str(bkQuery.getFileTypeList()), prod, str(prodBKDict))
                 gLogger.verbose("Could not find production or filetype %s in BKquery of production %d (%s)" % _msgTuple)
         mergeList.sort(key=lambda x: int(mergeStripProds[x][0]))
-        gLogger.verbose("Merging productions found: %s" % str(mergeList))
+        gLogger.verbose(f"Merging productions found: {str(mergeList)}")
 
         # get list of stripping productions (from merging)
         stripRunRanges = {}
@@ -369,7 +369,7 @@ class ProcessingProgress(object):
             print("Error when sorting stripping productions:")
             for prodStrip in stripList:
                 print(prodStrip, stripRunRanges[prodStrip])
-        gLogger.verbose("Stripping productions found (%d): %s" % (len(stripList), str(sorted(stripList))))
+        gLogger.verbose(f"Stripping productions found ({len(stripList)}): {str(sorted(stripList))}")
 
         # Get all runs corresponding to the run range used by the Reco productions
         rawBKQuery = BKQuery(bkQuery)
@@ -377,7 +377,7 @@ class ProcessingProgress(object):
         rawBKQuery.setFileType("RAW")
         # get the list of runs (-prodNum)
         fullRunList = rawBKQuery.getBKRuns()
-        gLogger.verbose("Initial list of runs: %s" % str(fullRunList))
+        gLogger.verbose(f"Initial list of runs: {str(fullRunList)}")
         recoRunList = []
         openProd = False
         for prod in [p for p in recoList]:
@@ -390,7 +390,7 @@ class ProcessingProgress(object):
                 for p in [p for p in recoList if p != prod and recoRunRanges[prod] != recoRunRanges[p]]:
                     if recoRunRanges[prod][0] < recoRunRanges[p][1] and recoRunRanges[p][1] != sys.maxsize:
                         openProd = False
-                        gLogger.verbose("Production %s was removed as redundant..." % str(prod))
+                        gLogger.verbose(f"Production {str(prod)} was removed as redundant...")
                         recoList.remove(prod)
                         break
                 if not openProd:
@@ -400,7 +400,7 @@ class ProcessingProgress(object):
                 for run in fullRunList
                 if run not in recoRunList and run >= recoRunRanges[prod][0] and run <= recoRunRanges[prod][1]
             ]
-        gLogger.verbose("List of runs matching Reco (%d): %s" % (len(recoRunList), str(sorted(recoRunList))))
+        gLogger.verbose(f"List of runs matching Reco ({len(recoRunList)}): {str(sorted(recoRunList))}")
 
         restrictToStripping = True
         if restrictToStripping and not openProd and stripList:
@@ -413,22 +413,20 @@ class ProcessingProgress(object):
                 ]
         else:
             runList = recoRunList
-        gLogger.verbose(
-            "Final list of runs matching Reco and Stripping (%d): %s" % (len(runList), str(sorted(runList)))
-        )
+        gLogger.verbose(f"Final list of runs matching Reco and Stripping ({len(runList)}): {str(sorted(runList))}")
 
         # Now get statistics from the runs
         info, runInfo = self._getStatsFromRuns(int(bkQuery.getEventTypeList()[0]), runList, recoDQFlags)
         rawInfo = StatInfo(processingPass[1], info)
         prodStats.append(rawInfo)
         if printResult:
-            gLogger.info("%s - All runs in Reco productions" % processingPass[1])
+            gLogger.info(f"{processingPass[1]} - All runs in Reco productions")
             for fileInfo in runInfo:
                 if runInfo[fileInfo]:
-                    gLogger.info("%s runs (%d): %s" % (fileInfo, len(runInfo[fileInfo]), str(runInfo[fileInfo])))
-            summStr = "%s files, " % rawInfo.getItemAsString("Files")
-            summStr += "%s events in " % rawInfo.getItemAsString("Events")
-            summStr += "%s runs, luminosity (pb-1):All=%s, Bad=%s, OK=%s" % (
+                    gLogger.info(f"{fileInfo} runs ({len(runInfo[fileInfo])}): {str(runInfo[fileInfo])}")
+            summStr = f"{rawInfo.getItemAsString('Files')} files, "
+            summStr += f"{rawInfo.getItemAsString('Events')} events in "
+            summStr += "{} runs, luminosity (pb-1):All={}, Bad={}, OK={}".format(
                 rawInfo.getItemAsString("Runs"),
                 rawInfo.getItemAsString("Lumi"),
                 rawInfo.getItemAsString("BadLumi"),
@@ -462,7 +460,7 @@ class ProcessingProgress(object):
         )
         prodSets.append(
             {
-                "Name": "Merging (%s)" % fileType.split(".")[0],
+                "Name": f"Merging ({fileType.split('.')[0]})",
                 "FileType": fileType,
                 "List": mergeList,
                 "RunRange": None,
@@ -523,11 +521,11 @@ class ProcessingProgress(object):
                         summStr += "No run range specified"
                 motherProds = prodSet["MotherProds"]
                 if motherProds and prod in motherProds:
-                    summStr += " from productions %s" % motherProds[prod]
+                    summStr += f" from productions {motherProds[prod]}"
                 gLogger.info(summStr)
                 for inf in runInfo:
                     if runInfo[inf]:
-                        gLogger.info("%s runs (%d): %s" % (inf, len(runInfo[inf]), str(runInfo[inf])))
+                        gLogger.info(f"{inf} runs ({len(runInfo[inf])}): {str(runInfo[inf])}")
                 summStr = "%d files, " % info["Files"][""]
                 if info["Events"]:
                     summStr += "%d events in " % info["Events"][""]
@@ -551,7 +549,7 @@ class ProcessingProgress(object):
             if not info:
                 continue
             name = info.getName()
-            outputString += "\nSummary for %s\n" % name
+            outputString += f"\nSummary for {name}\n"
             outputString += "%d files, " % info.getItem("Files")
             if info.getItem("Events"):
                 outputString += "%d events in " % info.getItem("Events")
@@ -562,9 +560,9 @@ class ProcessingProgress(object):
             for prevInfo in prevStats:
                 name = prevInfo.getName()
                 if prevInfo.getItem("Runs") == 0:
-                    outputString += "From %s : - No runs...\n" % name
+                    outputString += f"From {name} : - No runs...\n"
                 else:
-                    outputString += "From %s : %.1f%% files, " % (
+                    outputString += "From {} : {:.1f}% files, ".format(
                         name,
                         100.0 * info.getItem("Files") / prevInfo.getItem("Files"),
                     )
@@ -572,7 +570,7 @@ class ProcessingProgress(object):
                         outputString += "%.1f%% events\n" % (
                             100.0 * info.getItem("Events") / prevInfo.getItem("Events")
                         )
-                    outputString += "%.1f%% runs, %.1f%% luminosity\n" % (
+                    outputString += "{:.1f}% runs, {:.1f}% luminosity\n".format(
                         100.0 * info.getItem("Runs") / prevInfo.getItem("Runs"),
                         100.0 * info.getItem("Lumi") / prevInfo.getItem("Lumi"),
                     )
@@ -634,7 +632,7 @@ class ProcessingProgress(object):
                     cachedLumi = val["luminosity"][ind]
                     cachedTime = val["RunStart"]
                 else:
-                    gLogger.error("Unable to get run information for run %s" % str(run))
+                    gLogger.error(f"Unable to get run information for run {str(run)}")
                     continue
                 dqFlag = runFlags[run]
             self.cachedInfo[run] = {
@@ -677,7 +675,7 @@ class ProcessingProgress(object):
     def __getLfnsMetadata(self, lfns):
         lfnDict = {}
         if len(lfns):
-            gLogger.verbose("Getting metadata for %d files" % len(lfns))
+            gLogger.verbose(f"Getting metadata for {len(lfns)} files")
             for lfnChunk in breakListIntoChunks(lfns, 1000):
                 while True:
                     res = self.bk.getFileMetadata(lfnChunk)
@@ -701,13 +699,13 @@ class ProcessingProgress(object):
         cached = self.cachedInfo.get(bkStr, {})
         cachedTime = cached.get("Time", None)
         cachedLfns = cached.get("Lfns", {})
-        if isinstance(fileType, six.string_types):
+        if isinstance(fileType, str):
             fileType = [fileType]
         if set(fileType).intersection(set(self.clearCache)):
             cachedTime = datetime.datetime.utcnow() - datetime.timedelta(days=8)
             cachedTime = None
             cachedLfns = {}
-            gLogger.verbose("Cleared cache for production %s, file type %s" % (str(prod), fileType))
+            gLogger.verbose(f"Cleared cache for production {str(prod)}, file type {fileType}")
         # Update if needed the cached information on LFNs
         if cachedLfns:
             lfns = [lfn for lfn in cachedLfns if cachedLfns[lfn].get("DQFlag") not in ("OK", "BAD")]
@@ -717,7 +715,7 @@ class ProcessingProgress(object):
                     res = self.bk.getFileMetadata(lfnChunk)
                     if not res["OK"]:
                         gLogger.error(
-                            "Error getting files metadata for cached files, bkQuery %s: %s" % (bkStr, res["Message"])
+                            f"Error getting files metadata for cached files, bkQuery {bkStr}: {res['Message']}"
                         )
                     else:
                         metadata = res["Value"]["Successful"]
@@ -728,10 +726,10 @@ class ProcessingProgress(object):
         # Now get the new files since last time...
         if cachedTime:
             bkQuery.setOption("StartDate", cachedTime.strftime("%Y-%m-%d %H:%M:%S"))
-        gLogger.verbose("Getting files for BKQuery %s" % str(bkQuery))
+        gLogger.verbose(f"Getting files for BKQuery {str(bkQuery)}")
         cachedTime = datetime.datetime.utcnow()
         lfns = [lfn for lfn in bkQuery.getLFNs(printOutput=False) if lfn not in cachedLfns]
-        gLogger.verbose("Returned %d files" % len(lfns))
+        gLogger.verbose(f"Returned {len(lfns)} files")
         cachedLfns.update(self.__getLfnsMetadata(lfns))
 
         self.cachedInfo[bkStr] = {"Time": cachedTime, "Lfns": cachedLfns}
@@ -796,7 +794,7 @@ class ProcessingProgress(object):
 
     def readCache(self):
         if not os.path.exists(self.prodStatFile):
-            gLogger.info("Created cached file %s" % self.prodStatFile)
+            gLogger.info(f"Created cached file {self.prodStatFile}")
             self.cachedInfo = {}
             self.saveCache()
             return
@@ -804,7 +802,7 @@ class ProcessingProgress(object):
         while not fileRead:
             try:
                 with FileLock(self.prodStatFile):
-                    lFile = open(self.prodStatFile, "r")
+                    lFile = open(self.prodStatFile)
                     cachedVersion = pickle.load(lFile)
                     startTime = time.time()
                     if cachedVersion == self.cacheVersion:
@@ -818,9 +816,9 @@ class ProcessingProgress(object):
                     lFile.close()
                     fileRead = True
             except FileLockException as error:
-                gLogger.error("Lock exception: %s while reading pickle file %s" % (error, self.prodStatFile))
+                gLogger.error(f"Lock exception: {error} while reading pickle file {self.prodStatFile}")
             except Exception:
-                gLogger.error("Could not read cache file %s" % self.prodStatFile)
+                gLogger.error(f"Could not read cache file {self.prodStatFile}")
                 self.cachedInfo = {}
                 DIRAC.exit(1)
 
@@ -830,23 +828,20 @@ class ProcessingProgress(object):
             fOpen = None
             startTime = time.time()
             try:
-                with FileLock(self.prodStatFile) as lock:
-                    fOpen = open(self.prodStatFile, "w")
-                    pickle.dump(self.cacheVersion, fOpen)
-                    pickle.dump(self.cachedInfo, fOpen)
-                    fOpen.close()
+                with FileLock(self.prodStatFile):
+                    with open(self.prodStatFile, "w") as fOpen:
+                        pickle.dump(self.cacheVersion, fOpen)
+                        pickle.dump(self.cachedInfo, fOpen)
+
                     _msgTuple = (self.prodStatFile, time.time() - startTime)
                     gLogger.verbose("Successfully wrote pickle file %s in %.3f seconds" % _msgTuple)
                     fileSaved = True
             except KeyboardInterrupt:
                 gLogger.info("<CTRL-C> hit while saving cache file, retry...")
-                lock.release()
-                if fOpen:
-                    fOpen.close()
             except FileLockException as error:
-                gLogger.error("Lock exception: %s while writing pickle file %s" % (error, self.prodStatFile))
+                gLogger.error(f"Lock exception: {error} while writing pickle file {self.prodStatFile}")
             except Exception:
-                gLogger.error("Unable to write pickle file %s" % self.prodStatFile)
+                gLogger.error(f"Unable to write pickle file {self.prodStatFile}")
 
 
 import errno
@@ -856,7 +851,7 @@ class FileLockException(Exception):
     pass
 
 
-class FileLock(object):
+class FileLock:
     """A file locking mechanism that has context-manager support so you can use
     it in a with statement.
 
@@ -871,7 +866,7 @@ class FileLock(object):
         delay between each attempt to lock.
         """
         self.is_locked = False
-        self.lockfile = os.path.join(os.getcwd(), "%s.lock" % file_name)
+        self.lockfile = os.path.join(os.getcwd(), f"{file_name}.lock")
         self.file_name = file_name
         self.timeout = timeout
         self.delay = delay
