@@ -39,7 +39,7 @@ from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import
 from LHCbDIRAC.TransformationSystem.Client.Transformation import Transformation
 
 
-class Production(object):
+class Production:
     """Production uses an LHCbJob object, as well as few clients."""
 
     #############################################################################
@@ -68,7 +68,7 @@ class Production(object):
         histoTypes = self.opsHelper.getValue(
             "Productions/HistogramTypes", ["HIST", "BRUNELHIST", "DAVINCIHIST", "GAUSSHIST"]
         )
-        self.outputSEs = dict((ht, histogramSE) for ht in histoTypes)
+        self.outputSEs = {ht: histogramSE for ht in histoTypes}
 
         if not script:
             self.__setDefaults()
@@ -123,14 +123,14 @@ class Production(object):
     def setParameter(self, name, parameterType, parameterValue, description):
         """Set parameters checking in CS in case some defaults need to be
         changed."""
-        proposedParam = self.opsHelper.getValue("Productions/%s" % name, "")
+        proposedParam = self.opsHelper.getValue(f"Productions/{name}", "")
         if proposedParam:
-            gLogger.debug("Setting %s from CS defaults = %s" % (name, proposedParam))
+            gLogger.debug(f"Setting {name} from CS defaults = {proposedParam}")
             self.LHCbJob._addParameter(
                 self.LHCbJob.workflow, name, parameterType, proposedParam, description
             )  # pylint: disable=protected-access
         else:
-            gLogger.debug("Setting parameter %s = %s" % (name, parameterValue))
+            gLogger.debug(f"Setting parameter {name} = {parameterValue}")
             self.LHCbJob._addParameter(
                 self.LHCbJob.workflow, name, parameterType, parameterValue, description
             )  # pylint: disable=protected-access
@@ -162,9 +162,9 @@ class Production(object):
                 optionsFile = [optionsFile]
 
         for package in extraPackages:
-            gLogger.verbose("Checking extra package: %s" % (package))
+            gLogger.verbose(f"Checking extra package: {package}")
             if not re.search(".", package):
-                raise TypeError("Must have extra packages in the following format 'Name.Version' not %s" % (package))
+                raise TypeError(f"Must have extra packages in the following format 'Name.Version' not {package}")
 
         gLogger.verbose("Extra packages and event type options are correctly specified")
         return S_OK()
@@ -225,29 +225,25 @@ class Production(object):
                 raise TypeError("extraPackages is not a string (nor a list)")
             if "," in extraPackages:
                 extraPackages = ";".join(extraPackages.split(","))
-            if "ProdConf" not in extraPackages:
-                extraPackages = extraPackages + ";ProdConf"
             extraPackages = extraPackages.replace(" ", "")
-        else:
-            extraPackages = "ProdConf"
 
         self.__checkArguments(extraPackages, optionsFile)
 
         try:
             if not dddbOpt.lower() == "global":
-                gLogger.verbose("Specific DDDBTag setting found for %s step, setting to: %s" % (appName, dddbOpt))
+                gLogger.verbose(f"Specific DDDBTag setting found for {appName} step, setting to: {dddbOpt}")
                 dddbOpt = dddbOpt.replace(" ", "")
         except AttributeError:
             pass
         try:
             if not conddbOpt.lower() == "global":
-                gLogger.verbose("Specific CondDBTag setting found for %s step, setting to: %s" % (appName, conddbOpt))
+                gLogger.verbose(f"Specific CondDBTag setting found for {appName} step, setting to: {conddbOpt}")
                 conddbOpt = conddbOpt.replace(" ", "")
         except AttributeError:
             pass
         try:
             if not dqOpt.lower() == "global":
-                gLogger.verbose("Specific DQTag setting found for %s step, setting to: %s" % (appName, dqOpt))
+                gLogger.verbose(f"Specific DQTag setting found for {appName} step, setting to: {dqOpt}")
                 dqOpt = dqOpt.replace(" ", "")
         except AttributeError:
             pass
@@ -256,8 +252,7 @@ class Production(object):
         self.LHCbJob.stepCount += 1
 
         if "Gaudi_App_Step" not in self.LHCbJob.workflow.step_definitions:
-
-            gLogger.debug("Determining the modules of the steps (modulesList = %s)" % modulesList)
+            gLogger.debug(f"Determining the modules of the steps (modulesList = {modulesList})")
             if modulesList is None:  # we assume it's a standard list of modules for Gaudi steps
                 gaudiPath = "Productions/GaudiStep_Modules"
                 modulesList = self.opsHelper.getValue(
@@ -298,7 +293,7 @@ class Production(object):
             self.LHCbJob.workflow.addStep(gaudiStepDef)
 
         # create the step instance add it to the wf, and return it
-        name = "%s_%s" % (appName, self.LHCbJob.stepCount)
+        name = f"{appName}_{self.LHCbJob.stepCount}"
         gaudiStepInstance = self.LHCbJob.workflow.createStepInstance("Gaudi_App_Step", name)
 
         valuesToSet = [
@@ -322,7 +317,7 @@ class Production(object):
             valuesToSet.append(["inputDataType", ";".join(ftIn.upper() for ftIn in fileTypesIn)])
 
         if inputData is None:
-            gLogger.verbose("%s step has no data requirement or is linked to the overall input data" % appName)
+            gLogger.verbose(f"{appName} step has no data requirement or is linked to the overall input data")
             gaudiStepInstance.setLink("inputData", "self", "InputData")
         elif inputData == "previousStep":
             gLogger.verbose("Taking input data as output from previous Gaudi step")
@@ -340,7 +335,7 @@ class Production(object):
         gaudiStepInstance.setValue("listoutput", (outputFilesList))
 
         # to construct the BK processing pass structure, starts from step '0'
-        stepIDInternal = "Step%s" % (self.LHCbJob.stepCount - 1)
+        stepIDInternal = f"Step{self.LHCbJob.stepCount - 1}"
         bkOptionsFile = optionsFile
 
         stepBKInfo = {
@@ -402,7 +397,6 @@ class Production(object):
             modulesList = ["UploadOutputData", "UploadLogFile", "UploadMC", "FailoverRequest"]
 
         if "Job_Finalization" not in self.LHCbJob.workflow.step_definitions:
-
             jobFinalizationStepDef = getStepDefinition(
                 "Job_Finalization", importLine="LHCbDIRAC.Workflow.Modules", modulesNameList=modulesList
             )
@@ -431,9 +425,9 @@ class Production(object):
         if not name:
             name = self.LHCbJob.workflow.getName()
         if not re.search("xml$", name):
-            name = "%s.xml" % name
+            name = f"{name}.xml"
         if os.path.exists(name):
-            shutil.move(name, "%s.backup" % name)
+            shutil.move(name, f"{name}.backup")
         name = name.replace("/", "").replace("\\", "")
         self.LHCbJob.workflow.toXMLFile(name)
 
@@ -478,7 +472,7 @@ class Production(object):
         ):
             try:
                 parameters[parameterName] = prodWorkflow.findParameter(parameterName).getValue()
-                info.append("%s: %s" % (parameterName, prodWorkflow.findParameter(parameterName).getValue()))
+                info.append(f"{parameterName}: {prodWorkflow.findParameter(parameterName).getValue()}")
             except AttributeError:
                 continue
 
@@ -516,7 +510,7 @@ class Production(object):
         del outputLFNs["BookkeepingLFNs"]  # since ProductionOutputData uses the file mask
         for i in outputLFNs.values():
             for j in i:
-                outputDir = "%s%s" % (j.split(str(prodID))[0], prodID)
+                outputDir = f"{j.split(str(prodID))[0]}{prodID}"
                 if outputDir not in outputDirectories:
                     outputDirectories.append(outputDir)
 
@@ -525,29 +519,27 @@ class Production(object):
         # Now for the steps of the workflow
         stepKeys = sorted(bkPassInfo)
         for step in stepKeys:
-            info.append(
-                "====> %s %s %s" % (bkPassInfo[step]["ApplicationName"], bkPassInfo[step]["ApplicationVersion"], step)
-            )
-            info.append("%s Option Files:" % (bkPassInfo[step]["ApplicationName"]))
+            info.append(f"====> {bkPassInfo[step]['ApplicationName']} {bkPassInfo[step]['ApplicationVersion']} {step}")
+            info.append(f"{bkPassInfo[step]['ApplicationName']} Option Files:")
             if optionsFiles := bkPassInfo[step]["OptionFiles"]:
                 if optionsFiles.startswith("{"):
                     info.append(pprint.pformat(json.loads(optionsFiles)))
                 else:
                     info.extend(optionsFiles.split(";"))
             if bkPassInfo[step]["ExtraPackages"]:
-                info.append("ExtraPackages: %s" % (bkPassInfo[step]["ExtraPackages"]))
+                info.append(f"ExtraPackages: {bkPassInfo[step]['ExtraPackages']}")
 
         try:
             if parameters["BkQuery"]:
                 info.append("\nBK Input Data Query:")
                 for bkn, bkv in parameters["BkQuery"].items():
-                    info.append("%s= %s" % (bkn, bkv))
+                    info.append(f"{bkn}= {bkv}")
         except KeyError:
             pass
 
         # BK output directories (very useful)
         bkPaths = []
-        bkOutputPath = "%s/%s/%s/%s/%s/%s" % (
+        bkOutputPath = "{}/{}/{}/{}/{}/{}".format(
             parameters["configName"],
             parameters["configVersion"],
             parameters["BKCondition"],
@@ -564,13 +556,13 @@ class Production(object):
             fileTypes.append("HIST")
 
         for ft in fileTypes:
-            bkPaths.append("%s/%s" % (bkOutputPath, ft))
+            bkPaths.append(f"{bkOutputPath}/{ft}")
         parameters["BKPaths"] = bkPaths
         info.append("\nBK Browsing Paths:\n%s" % ("\n".join(bkPaths)))
         infoString = "\n".join(info)
         parameters["DetailedInfo"] = infoString
 
-        gLogger.verbose("Parameters that will be added: %s" % parameters)
+        gLogger.verbose(f"Parameters that will be added: {parameters}")
 
         return parameters
 
@@ -599,17 +591,17 @@ class Production(object):
         # Add the BK conditions metadata / name
         simConds = self.bkkClient.getSimConditions()
         if not simConds["OK"]:
-            gLogger.error("Could not retrieve conditions data from BK:\n%s" % simConds)
+            gLogger.error(f"Could not retrieve conditions data from BK:\n{simConds}")
             return simConds
         simulationDescriptions = []
         for record in simConds["Value"]:
             simulationDescriptions.append(str(record[1]))
 
         if bkConditions not in simulationDescriptions:
-            gLogger.verbose("Assuming BK conditions %s are DataTakingConditions" % bkConditions)
+            gLogger.verbose(f"Assuming BK conditions {bkConditions} are DataTakingConditions")
             bkDictStep["DataTakingConditions"] = bkConditions
         else:
-            gLogger.verbose("Found simulation conditions for %s" % bkConditions)
+            gLogger.verbose(f"Found simulation conditions for {bkConditions}")
             bkDictStep["SimulationConditions"] = bkConditions
 
         descShort = self.LHCbJob.workflow.getDescrShort()
@@ -617,7 +609,6 @@ class Production(object):
 
         prodID = 0
         if publish:
-
             self.setParameter("ProcessingType", "JDL", str(self.prodGroup), "ProductionGroupOrType")
             self.setParameter("Priority", "JDL", str(self.priority), "UserPriority")
 
@@ -627,11 +618,11 @@ class Production(object):
                 gLogger.error(x)
                 return S_ERROR("Could not create workflow")
 
-            gLogger.verbose("Workflow XML file name is: %s" % fileName)
+            gLogger.verbose(f"Workflow XML file name is: {fileName}")
 
             workflowBody = ""
             if os.path.exists(fileName):
-                with open(fileName, "r") as fopen:
+                with open(fileName) as fopen:
                     workflowBody = fopen.read()
             else:
                 return S_ERROR("Could not get workflow body")
@@ -653,10 +644,10 @@ class Production(object):
             result = self.transformation.addTransformation()
 
             if not result["OK"]:
-                gLogger.error("Problem creating production:\n%s" % result)
+                gLogger.error(f"Problem creating production:\n{result}")
                 return result
             prodID = result["Value"]
-            gLogger.info("Production %s successfully created" % prodID)
+            gLogger.info(f"Production {prodID} successfully created")
 
             # All other parameters
             groupDesc = self.LHCbJob.workflow.findParameter("groupDescription").getValue()
@@ -740,7 +731,7 @@ class Production(object):
         bkDictStep["ConfigVersion"] = self.LHCbJob.workflow.findParameter("configVersion").getValue()
 
         if publish:
-            gLogger.verbose("Attempting to publish production %s to the BK" % (prodID))
+            gLogger.verbose(f"Attempting to publish production {prodID} to the BK")
             result = self.bkkClient.addProduction(bkDictStep)
             if not result["OK"]:
                 gLogger.error(result)
@@ -750,13 +741,11 @@ class Production(object):
             reqDict = {"ProductionID": int(prodID), "RequestID": requestID, "Used": reqUsed, "BkEvents": 0}
             result = ProductionRequestClient(timeout=120).addProductionToRequest(reqDict)
             if not result["OK"]:
-                gLogger.error(
-                    "Attempt to add production %s to request %s failed: %s " % (prodID, requestID, result["Message"])
-                )
-                gLogger.error("Dictionary below:\n%s" % reqDict)
+                gLogger.error(f"Attempt to add production {prodID} to request {requestID} failed: {result['Message']} ")
+                gLogger.error(f"Dictionary below:\n{reqDict}")
             else:
                 gLogger.info(
-                    "Successfully added production %s to request %s with flag set to %s" % (prodID, requestID, reqUsed)
+                    f"Successfully added production {prodID} to request {requestID} with flag set to {reqUsed}"
                 )
 
         return S_OK(prodID)
