@@ -27,7 +27,7 @@ from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
 
-class ProductionRequest(object):
+class ProductionRequest:
     """Production request class - objects are usually created starting from a production request"""
 
     def __init__(self, bkkClientIn=None, diracProdIn=None):
@@ -133,13 +133,12 @@ class ProductionRequest(object):
     def resolveSteps(self):
         """Given a list of steps in strings, some of which might be missing,
         resolve it into a list of dictionary of steps (self.stepsListDict)"""
-        outputVisFlag = dict(
-            [k, v] for el in self.outputVisFlag for k, v in el.items()
-        )  # Transform the list of dictionaries in a dictionary
-        specialOutputVisFlag = dict([k, v] for el in self.specialOutputVisFlag for k, v in el.items())
+        outputVisFlag = {
+            k: v for el in self.outputVisFlag for k, v in el.items()
+        }  # Transform the list of dictionaries in a dictionary
+        specialOutputVisFlag = {k: v for el in self.specialOutputVisFlag for k, v in el.items()}
         count = 0  # Needed to add correctly the optionFiles to the list of dictonaries of steps
         for stepID in self.stepsList:
-
             stepDict = self.bkkClient.getAvailableSteps({"StepId": stepID})
             if not stepDict["OK"]:
                 raise ValueError(stepDict["Message"])
@@ -263,7 +262,6 @@ class ProductionRequest(object):
         self.logger.debug(prodsDict)
         # now we build and launch each productions
         for prodIndex, prodDict in prodsDict.items():
-
             if self.prodsToLaunch:
                 if prodIndex not in self.prodsToLaunch:
                     continue
@@ -419,23 +417,24 @@ class ProductionRequest(object):
         prod.setParameter("numberOfEvents", "string", str(numberOfEvents), "Number of events to test")
 
         # add '1' to the stepMask and add GAUSSHIST to the fileMask
-        fileTypesOutLastStep = (
-            prod.LHCbJob.workflow.step_instances[-2].findParameter("listoutput").getValue()[0]["outputDataType"]
-        )
-        newFileMask = ["GAUSSHIST"] + [ftOut.upper() for ftOut in fileTypesOutLastStep.split(";")]
+        fileTypesOutLastStep = []
+        listOutputLastStep = prod.LHCbJob.workflow.step_instances[-2].findParameter("listoutput").getValue()
+        for ols in listOutputLastStep:
+            fileTypesOutLastStep.append(ols["outputDataType"])
+        newFileMask = ["GAUSSHIST"] + [ftOut.upper() for ftOut in fileTypesOutLastStep]
         stepMaskParameter = prod.LHCbJob.workflow.findParameter("outputDataStep")
         if stepMaskParameter:
             stepMask = stepMaskParameter.getValue().replace(" ", "").split(";")
-            newOutputFileStep = ";".join(sorted(list(set(["1"]).union(set(stepMask)))))
+            newOutputFileStep = ";".join(sorted(list({"1"}.union(set(stepMask)))))
         else:
             newOutputFileStep = "1"
         prod.setFileMask(newFileMask, newOutputFileStep)
 
         # find the file types out already built, append GAUSSHIST and set the new listoutput
-        fileTypesOut = (
-            prod.LHCbJob.workflow.step_instances[0].findParameter("listoutput").getValue()[0]["outputDataType"]
-        )
-        fileTypesOut = fileTypesOut.split(", ")
+        fileTypesOut = []
+        listOutput = prod.LHCbJob.workflow.step_instances[0].findParameter("listoutput").getValue()
+        for ls in listOutput:
+            fileTypesOut.append(ls["outputDataType"])
         fileTypesOut.append("GAUSSHIST")
         outputFilesList = prod._constructOutputFilesList(fileTypesOut)  # pylint: disable=protected-access
         prod.LHCbJob.workflow.step_instances[0].setValue("listoutput", outputFilesList)
@@ -466,7 +465,7 @@ class ProductionRequest(object):
             outputSEDict = {}
             if not self.fullListOfOutputFileTypes:
                 raise ValueError("No steps defined")
-            outputSEDict = dict([(fType, outputSE) for fType in self.fullListOfOutputFileTypes])
+            outputSEDict = {fType: outputSE for fType in self.fullListOfOutputFileTypes}
             if specialOutputSEs:
                 outputSEDict.update(specialOutputSEs)
             self.outputSEsPerFileType.append(outputSEDict)
@@ -671,7 +670,6 @@ class ProductionRequest(object):
             self.processors,
             self.ancestorDepths,
         ):
-
             if not self.parentRequestID and self.requestID:
                 transformationFamily = self.requestID
             else:
@@ -814,7 +812,7 @@ class ProductionRequest(object):
         if outputFileMask:
             outputFileMask = [m.lower() for m in outputFileMask.replace(" ", "").split(",")]
         if outputFileStep:
-            if isinstance(outputFileStep, six.string_types):
+            if isinstance(outputFileStep, str):
                 outputFileStep = [m.lower() for m in outputFileStep.replace(" ", "").split(",")]
         prod.setFileMask(outputFileMask, outputFileStep)
         if target:
@@ -849,7 +847,7 @@ class ProductionRequest(object):
             elif bkQuery.lower() == "frompreviousprod":
                 prod.inputBKSelection = self._getBKKQuery("frompreviousprod", fTypeIn, previousProdID)
 
-        self.logger.verbose("Launching with BK selection %s" % prod.inputBKSelection)
+        self.logger.verbose(f"Launching with BK selection {prod.inputBKSelection}")
 
         prod = self._addStepsToProd(prod, stepsInProd, removeInputData=removeInputData)
 
@@ -978,7 +976,7 @@ class ProductionRequest(object):
     stepsList = property(get_stepsList, set_stepsList)
 
     def set_startRun(self, value):
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = int(value)
         if value < 0:
             raise ValueError("startRun can not be negative")
@@ -990,7 +988,7 @@ class ProductionRequest(object):
     startRun = property(get_startRun, set_startRun)
 
     def set_endRun(self, value):
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = int(value)
         if value < 0:
             raise ValueError("endRun can not be negative")
@@ -1004,7 +1002,7 @@ class ProductionRequest(object):
     def set_requestID(self, value):
         if value == "":
             value = 0
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = int(value)
         if value < 0:
             raise ValueError("requestID can not be negative")
@@ -1018,7 +1016,7 @@ class ProductionRequest(object):
     def set_parentRequestID(self, value):
         if value == "":
             value = 0
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = int(value)
         if value < 0:
             raise ValueError("parentRequestID can not be negative")
