@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Module holding ProductionRequestClient class."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC.Core.Base.Client import Client, createClient
 
-__RCSID__ = "$Id$"
-
 
 @createClient("ProductionManagement/ProductionRequest")
 class ProductionRequestClient(Client):
@@ -27,7 +21,7 @@ class ProductionRequestClient(Client):
 
         :param str url: can specify a specific URL
         """
-        super(ProductionRequestClient, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.setServer("ProductionManagement/ProductionRequest")
         if url:
             self.setServer(url)
