@@ -12,7 +12,7 @@
 # pylint: disable=line-too-long,invalid-name,protected-access,missing-docstring
 
 import unittest
-from mock import Mock, MagicMock
+from unittest.mock import Mock, MagicMock
 
 from LHCbDIRAC.BookkeepingSystem.Client.test.mock_BookkeepingClient import (
     BookkeepingClientFake,
@@ -145,7 +145,6 @@ class ClientTestCase(unittest.TestCase):
     """Base class for the Client test cases."""
 
     def setUp(self):
-
         self.bkClientMock = Mock()
         self.diracProdIn = Mock()
         self.diracProdIn.launchProduction.return_value = {"OK": True, "Value": 321}
@@ -157,7 +156,6 @@ class ClientTestCase(unittest.TestCase):
 
 class ProductionRequestSuccess(ClientTestCase):
     def test__mcSpecialCase(self):
-
         # prepare the test case
         prod = Production()
         prod.setParameter("ProcessingType", "JDL", "Test", "ProductionGroupOrType")
@@ -243,7 +241,6 @@ class ProductionRequestSuccess(ClientTestCase):
                 self.assertEqual(par.value, "1")
 
     def test_resolveStepsSuccess(self):
-
         pr = ProductionRequest(self.bkClientFake, self.diracProdIn)
         pr.stepsList = ["123"]
         pr.outputVisFlag = [{"1": "N"}]
@@ -964,7 +961,6 @@ class ProductionRequestSuccess(ClientTestCase):
         )
 
     def test__applyOptionalCorrections(self):
-
         pr = ProductionRequest(self.bkClientFake, self.diracProdIn)
         pr.prodsTypeList = ["DataStripping", "Merge"]
         pr.plugins = ["ByRun", "BySize"]
@@ -1764,7 +1760,6 @@ class ProductionRequestSuccess(ClientTestCase):
         self.assertEqual(res, prodsDict)
 
     def test__addStepsToProd(self):
-
         stepsInProd = [
             {
                 "StepId": 123,
@@ -1898,7 +1893,6 @@ class ProductionRequestSuccess(ClientTestCase):
     #     )
 
     def test__getBKKQuery(self):
-
         pr = ProductionRequest(self.bkClientFake, self.diracProdIn)
         pr.dataTakingConditions = "dataTC"
         pr.processingPass = "procePass"
@@ -2023,7 +2017,6 @@ class ProductionRequestSuccess(ClientTestCase):
         self.assertEqual(res, resExpected)
 
     def test__splitIntoProductionSteps(self):
-
         r_p = _splitIntoProductionSteps(stepStripp)
         r_exp = [
             {
@@ -2125,7 +2118,6 @@ class ProductionRequestFailure(ClientTestCase):
 
 class ProductionRequestFullChain(ClientTestCase):
     def test_full(self):
-
         pr = ProductionRequest(self.bkClientFake, self.diracProdIn)
         pr.logger.setLevel("VERBOSE")
 
