@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_PMS_Client_ProcessingProgress."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 
-__RCSID__ = "$Id$"
-
 dummyResults = {}
 
 
