@@ -58,9 +58,9 @@ def inject_session(func):
 class AnalysisProductionsDB(DIRACDB):
     __engineCache = {}
 
-    def __init__(self, *, url=None):
+    def __init__(self, *, url=None, parentLogger=None):
         self.fullname = self.__class__.__name__
-        super().__init__()
+        super().__init__(parentLogger=parentLogger)
         if url is None:
             param = returnValueOrRaise(getDBParameters("ProductionManagement/AnalysisProductionsDB"))
             url = f"mysql://{param['User']}:{param['Password']}@{param['Host']}:{param['Port']}/{param['DBName']}"
@@ -202,7 +202,7 @@ class AnalysisProductionsDB(DIRACDB):
         if len(known_sample_ids) != len(sample_ids):
             raise ValueError(f"Some samples have already been archived {known_sample_ids - set(sample_ids)!r}")
         query = session.query(AP).filter(AP.sample_id.in_(sample_ids))
-        query.update({"validity_end": func.now()})
+        query.update({"validity_end": func.now()})  # pylint: disable=not-callable
 
     @inject_session
     def setState(self, newState: dict[str, dict], *, session: Session):
@@ -219,9 +219,9 @@ class AnalysisProductionsDB(DIRACDB):
         if set(oldTags) != set(newTags):
             raise ValueError("oldTags and newTags must contain the same keys")
         # Tags should always be lowercase in the database
-        oldTags = {i: {str(k).lower(): str(v).lower() for k, v in x.items()} for i, x in oldTags.items()}
-        newLengths = {i: len(x) for i, x in newTags.items()}
-        newTags = {i: {str(k).lower(): str(v).lower() for k, v in x.items()} for i, x in newTags.items()}
+        oldTags = {int(i): {str(k).lower(): str(v).lower() for k, v in x.items()} for i, x in oldTags.items()}
+        newLengths = {int(i): len(x) for i, x in newTags.items()}
+        newTags = {int(i): {str(k).lower(): str(v).lower() for k, v in x.items()} for i, x in newTags.items()}
         if newLengths != {i: len(x) for i, x in newTags.items()}:
             raise ValueError("newTags contains duplicate keys when converted to lowercase")
 
@@ -248,7 +248,7 @@ class AnalysisProductionsDB(DIRACDB):
         # Remove the old tags
         query = _filterForTime(session.query(Tag), Tag, at_time=None)
         query = query.filter(tuple_(Tag.sample_id, Tag.name).in_(toRemove))
-        query.update({"validity_end": func.now()})
+        query.update({"validity_end": func.now()})  # pylint: disable=not-callable
         # Add the new tag values
         for sample_id, name, value in toAdd:
             session.add(Tag(sample_id=sample_id, name=name, value=value))
