@@ -10,6 +10,7 @@
 ###############################################################################
 """ Module containing a front-end to the ElasticSearch-based ElasticApplicationSummaryDB.
 """
+
 from DIRAC import gConfig
 from DIRAC.ConfigurationSystem.Client.PathFinder import getDatabaseSection
 from DIRAC.ConfigurationSystem.Client.Helpers import CSGlobals
@@ -32,14 +33,12 @@ class ElasticApplicationSummaryDB(ElasticMCStatsDBBase):
         """Standard Constructor"""
 
         section = getDatabaseSection("ProductionManagement", "ElasticApplicationSummaryDB")
-        indexPrefix = gConfig.getValue("%s/IndexPrefix" % section, CSGlobals.getSetup()).lower()
+        indexPrefix = gConfig.getValue(f"{section}/IndexPrefix", CSGlobals.getSetup()).lower()
 
         # Connecting to the ES cluster
-        super(ElasticApplicationSummaryDB, self).__init__(
-            name, "ProductionManagement/ElasticApplicationSummaryDB", indexPrefix
-        )
+        super().__init__(name, "ProductionManagement/ElasticApplicationSummaryDB", indexPrefix)
 
-        self.indexName = "%s_%s" % (self.getIndexPrefix(), name.lower())
+        self.indexName = f"{self.getIndexPrefix()}_{name.lower()}"
         # Verifying if the index is there, and if not create it
         if not self.client.indices.exists(self.indexName):
             result = self.createIndex(self.indexName, mapping, period=None)
