@@ -8,29 +8,29 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-""" Module containing a front-end to the ElasticSearch-based ElasticMCGaussLogErrorsDB.
+""" Module containing a front-end to the ElasticSearch-based ElasticLogErrorsDB.
     This module interacts with one ES index: "ElasticMCLogErrors",
 
     Here we define a mapping which is taken from a list of log errors.
 """
+
 from DIRAC import S_OK, S_ERROR
 from DIRAC.Core.Base.ElasticDB import ElasticDB
+from DIRAC.Core.Utilities.ReturnValues import DReturnType
 
 
 class ElasticMCStatsDBBase(ElasticDB):
-    def set(self, data):
+    def set(self, data: list[dict]) -> DReturnType:
         """
-        Inserts data into ElasticJobParametersDB index
+        Inserts data into ElasticDB index
 
-        :param self: self reference
-        :param str value: data to be inserted
+        :param data: data to be inserted
 
         :returns: S_OK/S_ERROR as result of indexing
         """
-
         self.log.debug(
             self.__class__.__name__,
-            ".set(): inserting data in %s:%s" % (self.indexName, data),  # pylint: disable=no-member
+            f".set(): inserting data in {self.indexName}:{data}",  # pylint: disable=no-member
         )
 
         result = self.index(
@@ -42,30 +42,27 @@ class ElasticMCStatsDBBase(ElasticDB):
             self.log.error("ERROR: Couldn't insert data", result["Message"])
         return result
 
-    def get(self, productionID):
+    def get(self, productionID: int) -> DReturnType[list]:
         """Get docs per productionID. Basically here only for tests, right now
 
-        :param self: self reference
-        :param int productionID: production ID
-
-        :return: dict with all docs
+        :param productionID: production ID
+        :return: list with all docs
         """
-
-        self.log.debug(self.__class__.__name__ + ".get(): Getting for production %s" % str(productionID))
+        self.log.debug(self.__class__.__name__ + f".get(): Getting for production {productionID}")
 
         resultList = []
 
         """ the following should be equivalent to
-    {
-      "query": {
-        "bool": {
-          "filter": {  # no scoring
-            "term": {"ProductionID": productionID}  # term level query, does not pass through the analyzer
+        {
+          "query": {
+            "bool": {
+              "filter": {  # no scoring
+                "term": {"ProductionID": productionID}  # term level query, does not pass through the analyzer
+              }
+            }
           }
         }
-      }
-    }
-    """
+        """
 
         s = self.dslSearch.query("bool", filter=self._Q("term", ProductionID=productionID))  # pylint: disable=no-member
 
@@ -76,31 +73,28 @@ class ElasticMCStatsDBBase(ElasticDB):
             for name in hit:
                 hitDict[name] = getattr(hit, name)
             resultList.append(hitDict)
-
         return S_OK(resultList)
 
-    def remove(self, productionID):
+    def remove(self, productionID: int) -> DReturnType:
         """Remove docs per productionID. Basically here only for tests, right now
 
-        :param self: self reference
-        :param int productionID: production ID
-
+        :param productionID: production ID
         :return: S_OK/S_ERROR
         """
 
-        self.log.debug(self.__class__.__name__ + ".remove(): Removing documents of production %s" % str(productionID))
+        self.log.debug(self.__class__.__name__ + f".remove(): Removing documents of production {productionID}")
 
         """ the following should be equivalent to
-    {
-      "query": {
-        "bool": {
-          "filter": {  # no scoring
-            "term": {"ProductionID": productionID}  # term level query, does not pass through the analyzer
+        {
+          "query": {
+            "bool": {
+              "filter": {  # no scoring
+                "term": {"ProductionID": productionID}  # term level query, does not pass through the analyzer
+              }
+            }
           }
         }
-      }
-    }
-    """
+        """
 
         s = self.dslSearch.query("bool", filter=self._Q("term", ProductionID=productionID))  # pylint: disable=no-member
         try:
