@@ -10,6 +10,7 @@
 ###############################################################################
 """ Module containing a front-end to the ElasticSearch-based ElasticPrMonDB.
 """
+
 from DIRAC import gConfig
 from DIRAC.ConfigurationSystem.Client.PathFinder import getDatabaseSection
 from DIRAC.ConfigurationSystem.Client.Helpers import CSGlobals
@@ -84,12 +85,12 @@ class ElasticPrMonDB(ElasticMCStatsDBBase):
         """Standard Constructor"""
 
         section = getDatabaseSection("ProductionManagement", "ElasticPrMonDB")
-        indexPrefix = gConfig.getValue("%s/IndexPrefix" % section, CSGlobals.getSetup()).lower()
+        indexPrefix = gConfig.getValue(f"{section}/IndexPrefix", CSGlobals.getSetup()).lower()
 
         # Connecting to the ES cluster
-        super(ElasticPrMonDB, self).__init__(name, "ProductionManagement/ElasticPrMonDB", indexPrefix)
+        super().__init__(name, "ProductionManagement/ElasticPrMonDB", indexPrefix)
 
-        self.indexName = "%s_%s" % (self.getIndexPrefix(), name.lower())
+        self.indexName = f"{self.getIndexPrefix()}_{name.lower()}"
         # Verifying if the index is there, and if not create it
         if not self.client.indices.exists(self.indexName):
             result = self.createIndex(self.indexName, mapping, period=None)
