@@ -38,9 +38,9 @@ from LHCbDIRAC.ProductionManagementSystem.Utilities.Utils import informPeople
 class ProductionRequestDB(DB):
     """DB class for ProductionManagement/ProductionRequestDB."""
 
-    def __init__(self):
+    def __init__(self, parentLogger=None):
         """Constructor."""
-        DB.__init__(self, "ProductionRequestDB", "ProductionManagement/ProductionRequestDB")
+        DB.__init__(self, "ProductionRequestDB", "ProductionManagement/ProductionRequestDB", parentLogger=parentLogger)
         self.dateColumns = ["StartingDate", "FinalizationDate"]
         self.dateFormat = "%Y-%m-%d"
         self.lock = threading.Lock()
@@ -115,7 +115,7 @@ class ProductionRequestDB(DB):
             old = ""
         if not update.startswith(old) and not update.endswith(old):
             return update
-        prefix = "Comment by %s on %s: " % (user, time.strftime("%b %d, %Y"))
+        prefix = f"Comment by {user} on {time.strftime('%b %d, %Y')}: "
         if update.startswith(old):
             if old.rstrip():
                 old = old.rstrip() + "\n\n"
@@ -130,7 +130,7 @@ class ProductionRequestDB(DB):
         """
         inFields = ["RequestState", "ParentID", "MasterID", "RequestAuthor", "Inform", "IsModel"]
         result = self._query(
-            "SELECT %s " % ",".join(inFields) + "FROM ProductionRequests " + "WHERE RequestID=%s;" % iD, connection
+            f"SELECT {','.join(inFields)} " + "FROM ProductionRequests " + f"WHERE RequestID={iD};", conn=connection
         )
         if not result["OK"]:
             self.lock.release()
@@ -209,7 +209,7 @@ class ProductionRequestDB(DB):
 
         if rec["RequestState"]:
             if not rec["RequestState"] in ["New", "BK Check", "Submitted"]:
-                return S_ERROR("The request can't be created in '%s' state" % rec["RequestState"])
+                return S_ERROR(f"The request can't be created in '{rec['RequestState']}' state")
             if rec["RequestState"] != "New":
                 # !!! full information check must be here, but currently in the JS...
                 # so we only check EventType consistency
@@ -282,13 +282,13 @@ class ProductionRequestDB(DB):
             return result
 
         req = "INSERT INTO ProductionRequests ( " + ",".join(self.requestFields[1:-7])
-        req += " ) VALUES ( %s );" % ",".join(recls)
-        result = self._update(req, connection)
+        req += f" ) VALUES ( {','.join(recls)} );"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
         req = "SELECT LAST_INSERT_ID();"
-        result = self._query(req, connection)
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -299,8 +299,8 @@ class ProductionRequestDB(DB):
             result = self._update(
                 "INSERT INTO RequestHistory ("
                 + ",".join(self.historyFields[:-1])
-                + ") VALUES ( %s,'%s','%s')" % (requestID, str(rec["RequestState"]), str(rec["RequestAuthor"])),
-                connection,
+                + f") VALUES ( {requestID},'{str(rec['RequestState'])}','{str(rec['RequestAuthor'])}')",
+                conn=connection,
             )
             if not result["OK"]:
                 gLogger.error(result["Message"])
@@ -349,7 +349,7 @@ class ProductionRequestDB(DB):
         rQuery += "                   COALESCE(SUM(sr.RealNumberOfEvents),0)) AS SIGNED)"
         rQuery += "              AS bkSrTotal FROM "
         rQuery += "   (SELECT t.*, CAST(SUM(pp.BkEvents) AS SIGNED)"
-        rQuery += "                AS bk FROM (%s) as t " % req
+        rQuery += f"                AS bk FROM ({req}) as t "
         rQuery += "    LEFT JOIN ProductionProgress as pp ON (pp.RequestID=t.RequestID "
         rQuery += "    AND pp.Used=1) GROUP BY t.RequestID) as t "
         rQuery += "   LEFT JOIN ProductionRequests AS sr ON t.RequestID=sr.MasterID "
@@ -393,7 +393,7 @@ class ProductionRequestDB(DB):
                     if x == "RequestID":
                         # Collect also masters masters
                         req = "SELECT RequestID,MasterID FROM ProductionRequests "
-                        req += "WHERE RequestID IN %s" % val
+                        req += f"WHERE RequestID IN {val}"
                         result = self._query(req)
                         if not result["OK"]:
                             return result
@@ -407,7 +407,7 @@ class ProductionRequestDB(DB):
                             return S_OK({"Rows": [], "Total": 0})
                         val = "( " + ",".join(val) + ") "
                         idFilter = True
-                    sfilter.append(" t.%s IN %s " % (x, val))
+                    sfilter.append(f" t.{x} IN {val} ")
             sfilter = " AND ".join(sfilter)
         except Exception as e:
             return S_ERROR("Bad filter content " + str(e))
@@ -419,17 +419,17 @@ class ProductionRequestDB(DB):
                 sortOrder = "DESC"
 
         fields = ",".join(["t." + x for x in self.requestFields[:-7]])
-        req = "SELECT %s ,COUNT(sr.RequestID) AS HasSubrequest " % fields
+        req = f"SELECT {fields} ,COUNT(sr.RequestID) AS HasSubrequest "
         req += "FROM ProductionRequests as t "
         req += "LEFT JOIN ProductionRequests AS sr ON t.RequestID=sr.ParentID "
         req += "WHERE "
 
         if requestIDList:
             idlist = ",".join([str(x) for x in requestIDList])
-            where = "t.RequestID IN (%s)" % idlist
+            where = f"t.RequestID IN ({idlist})"
         else:
             if subrequestsFor:
-                where = "t.ParentID=%s" % subrequestsFor
+                where = f"t.ParentID={subrequestsFor}"
             else:
                 where = sfilter
                 if not idFilter:
@@ -442,10 +442,10 @@ class ProductionRequestDB(DB):
         order = ""
         if sortBy:
             # order have to be applyed twice: before LIMIT and at the end
-            order = " ORDER BY %s %s" % (sortBy, sortOrder)
+            order = f" ORDER BY {sortBy} {sortOrder}"
             req += order
         if limit and not subrequestsFor:
-            req += " LIMIT %s,%s" % (offset, limit)
+            req += f" LIMIT {offset},{limit}"
         result = self._query(self.__addMonitoring(req, order))
         if not result["OK"]:
             return result
@@ -453,7 +453,7 @@ class ProductionRequestDB(DB):
         rows = [dict(zip(self.requestFields, row)) for row in result["Value"]]
         total = len(rows)
         if limit:
-            result = self._query("SELECT COUNT(*) FROM ProductionRequests AS t WHERE %s" % where)
+            result = self._query(f"SELECT COUNT(*) FROM ProductionRequests AS t WHERE {where}")
             if not result["OK"]:
                 return result
             total = result["Value"][0][0]
@@ -484,7 +484,7 @@ class ProductionRequestDB(DB):
         hasSubreq = False
         if not old["MasterID"]:
             result = self._query(
-                "SELECT RequestID " + "FROM ProductionRequests " + "WHERE MasterID=%s" % requestID, connection
+                "SELECT RequestID " + "FROM ProductionRequests " + f"WHERE MasterID={requestID}", conn=connection
             )
             if not result["OK"]:
                 self.lock.release()
@@ -551,14 +551,14 @@ class ProductionRequestDB(DB):
                 return S_ERROR("Only admin can violate the system logic")
         else:
             self.lock.release()
-            return S_ERROR("The request is in unknown state '%s'" % requestState)
+            return S_ERROR(f"The request is in unknown state '{requestState}'")
 
         if old["MasterID"]:  # for subrequests it's simple
             if requestState == "New":
                 for x in update:
                     if x not in ["EventType", "NumberOfEvents", "RealNumberOfEvents", "Comments"]:
                         self.lock.release()
-                        return S_ERROR("%s is not allowed in subrequests" % x)
+                        return S_ERROR(f"{x} is not allowed in subrequests")
                     if x != "Comments" and not update[x]:
                         self.lock.release()
                         return S_ERROR("You must specify event type and number")
@@ -604,7 +604,7 @@ class ProductionRequestDB(DB):
                     "Extra",
                 ]:
                     self.lock.release()
-                    return S_ERROR("%s can't be modified during BK check" % x)
+                    return S_ERROR(f"{x} can't be modified during BK check")
             if "RequestState" not in update:
                 return S_OK(inform)
             if not update["RequestState"] in ["BK OK", "Rejected"]:
@@ -618,7 +618,7 @@ class ProductionRequestDB(DB):
             for x in update:
                 if x not in ["RequestState", "Comments", "Inform", "Extra"]:
                     self.lock.release()
-                    return S_ERROR("%s can't be modified after BK check" % x)
+                    return S_ERROR(f"{x} can't be modified after BK check")
             if "RequestState" not in update:
                 return S_OK(inform)
             if not update["RequestState"] in ["Submitted", "Rejected"]:
@@ -640,7 +640,7 @@ class ProductionRequestDB(DB):
                         "RetentionRate",
                     ):
                         self.lock.release()
-                        return S_ERROR("%s can't be modified during PPG signing" % x)
+                        return S_ERROR(f"{x} can't be modified during PPG signing")
                 if "RequestState" not in update:
                     return S_OK(inform)
                 if update["RequestState"] == "Accepted":
@@ -653,7 +653,7 @@ class ProductionRequestDB(DB):
                 for x in update:
                     if x not in ["RequestState", "Comments", "Inform", "ProPath", "ProID", "ProDetail", "Extra"]:
                         self.lock.release()
-                        return S_ERROR("%s can't be modified during Tech signing" % x)
+                        return S_ERROR(f"{x} can't be modified during Tech signing")
                 if "RequestState" not in update:
                     return S_OK(inform)
                 if update["RequestState"] == "Accepted":
@@ -670,7 +670,7 @@ class ProductionRequestDB(DB):
             for x in update:
                 if x not in ["RequestState", "Comments", "Inform", "ProPath", "ProID", "ProDetail", "Extra"]:
                     self.lock.release()
-                    return S_ERROR("%s can't be modified during Tech signing" % x)
+                    return S_ERROR(f"{x} can't be modified during Tech signing")
             if "RequestState" not in update:
                 return S_OK(inform)
             if update["RequestState"] == "Tech OK":
@@ -687,7 +687,7 @@ class ProductionRequestDB(DB):
             for x in update:
                 if x not in ["RequestState", "RequestWG", "Comments", "Inform", "RequestPriority", "Extra"]:
                     self.lock.release()
-                    return S_ERROR("%s can't be modified during PPG signing" % x)
+                    return S_ERROR(f"{x} can't be modified during PPG signing")
             if "RequestState" not in update:
                 return S_OK(inform)
             if update["RequestState"] == "PPG OK":
@@ -700,7 +700,7 @@ class ProductionRequestDB(DB):
             for x in update:
                 if x not in ["RequestState", "Comments", "Inform", "ProPath", "ProID", "ProDetail", "Extra"]:
                     self.lock.release()
-                    return S_ERROR("%s can't be modified during the progress" % x)
+                    return S_ERROR(f"{x} can't be modified during the progress")
             if "RequestState" not in update:
                 return S_OK(inform)
             if requestState == "Accepted":
@@ -748,10 +748,10 @@ class ProductionRequestDB(DB):
         connection = result["Value"]
 
         fields = ",".join(["t." + x for x in self.requestFields[:-7]])
-        req = "SELECT %s " % fields
+        req = f"SELECT {fields} "
         req += "FROM ProductionRequests as t "
-        req += "WHERE t.RequestID=%s" % requestID
-        result = self._query(req, connection)
+        req += f"WHERE t.RequestID={requestID}"
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -800,7 +800,7 @@ class ProductionRequestDB(DB):
             except ValueError:
                 pass
             except TypeError:
-                gLogger.warn("NumberOfEvents not defined for %s" % requestID)
+                gLogger.warn(f"NumberOfEvents not defined for {requestID}")
             update["RealNumberOfEvents"] = str(num)
 
         if "Comments" in update:
@@ -826,13 +826,13 @@ class ProductionRequestDB(DB):
             # the order is very important that's why we use recl_fields
             if dateValue in self.dateColumns and requestDict.get(dateValue):
                 recl_fields.append(dateValue)
-                updateValues.append("STR_TO_DATE('%s','%s')" % (requestDict.get(dateValue), self.dateFormat))
+                updateValues.append(f"STR_TO_DATE('{requestDict.get(dateValue)}','{self.dateFormat}')")
         updates = ",".join([x + "=" + y for x, y in zip(recl_fields, updateValues)])
 
         req = "UPDATE ProductionRequests "
-        req += "SET %s " % updates
-        req += "WHERE RequestID=%s" % requestID
-        result = self._update(req, connection)
+        req += f"SET {updates} "
+        req += f"WHERE RequestID={requestID}"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -841,8 +841,8 @@ class ProductionRequestDB(DB):
             result = self._update(
                 "INSERT INTO RequestHistory ("
                 + ",".join(self.historyFields[:-1])
-                + ") VALUES ( %s,'%s','%s')" % (requestID, str(update["RequestState"]), str(creds["User"])),
-                connection,
+                + f") VALUES ( {requestID},'{str(update['RequestState'])}','{str(creds['User'])}')",
+                conn=connection,
             )
             if not result["OK"]:
                 gLogger.error(result["Message"])
@@ -861,8 +861,8 @@ class ProductionRequestDB(DB):
         NOTE: it does self.lock.release() in case of errors
         """
         result = self._query(
-            "SELECT RequestID " + "FROM ProductionRequests " + "WHERE ParentID=%s and MasterID=%s" % (iD, master),
-            connection,
+            "SELECT RequestID " + "FROM ProductionRequests " + f"WHERE ParentID={iD} and MasterID={master}",
+            conn=connection,
         )
         if not result["OK"]:
             self.lock.release()
@@ -901,7 +901,7 @@ class ProductionRequestDB(DB):
         if creds["Group"] not in ["diracAdmin", "lhcb_admin"]:
             if requestAuthor != creds["User"] and not (isModel and creds["Group"] == "lhcb_tech"):
                 self.lock.release()
-                gLogger.error("%s can't remove %s request" % (creds["User"], requestAuthor))
+                gLogger.error(f"{creds['User']} can't remove {requestAuthor} request")
                 return S_ERROR("Only author can remove a request")
             if requestState != "New" and requestState != "Rejected":
                 self.lock.release()
@@ -921,7 +921,7 @@ class ProductionRequestDB(DB):
         req = ""
         if not masterID:  # this request is a master
             # delete history
-            result = self._update("DELETE FROM RequestHistory " + "WHERE RequestID=%s" % requestID)
+            result = self._update("DELETE FROM RequestHistory " + f"WHERE RequestID={requestID}")
             if not result["OK"]:
                 self.lock.release()
                 return result
@@ -930,15 +930,15 @@ class ProductionRequestDB(DB):
                 "DELETE FROM ProductionProgress "
                 + "WHERE RequestID IN "
                 + "(SELECT RequestID FROM ProductionRequests "
-                + "WHERE RequestID=%s OR MasterID=%s" % (requestID, requestID)
+                + f"WHERE RequestID={requestID} OR MasterID={requestID}"
                 + ")",
-                connection,
+                conn=connection,
             )
             if not result["OK"]:
                 self.lock.release()
                 return result
             req = "DELETE FROM ProductionRequests "
-            req += "WHERE MasterID=%s" % requestID
+            req += f"WHERE MasterID={requestID}"
         else:  # this request is subrequest
             result = self.__getSubrequestsList(requestID, masterID, connection)
             if not result["OK"]:
@@ -947,32 +947,32 @@ class ProductionRequestDB(DB):
             # delete tracking
             result = self._update(
                 "DELETE FROM ProductionProgress "
-                + "WHERE RequestID IN (%s)" % ",".join([str(x) for x in rlist] + [str(requestID)])
+                + f"WHERE RequestID IN ({','.join([str(x) for x in rlist] + [str(requestID)])})"
             )
             if not result["OK"]:
                 self.lock.release()
                 return result
             if len(rlist):
                 req = "DELETE FROM ProductionRequests "
-                req += "WHERE RequestID in (%s)" % ",".join([str(x) for x in rlist])
+                req += f"WHERE RequestID in ({','.join([str(x) for x in rlist])})"
         if req:
-            result = self._update(req, connection)
+            result = self._update(req, conn=connection)
             if not result["OK"]:
                 self.lock.release()
                 return result
 
         # move substructure
-        req = "UPDATE ProductionRequests SET ParentID=%s " % upperID
-        req += "WHERE ParentID=%s" % requestID
-        result = self._update(req, connection)
+        req = f"UPDATE ProductionRequests SET ParentID={upperID} "
+        req += f"WHERE ParentID={requestID}"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
 
         # finally delete us
         req = "DELETE FROM ProductionRequests "
-        req += "WHERE RequestID=%s" % requestID
-        result = self._update(req, connection)
+        req += f"WHERE RequestID={requestID}"
+        result = self._update(req, conn=connection)
 
         self.lock.release()
 
@@ -986,10 +986,10 @@ class ProductionRequestDB(DB):
         NOTE: unlock in case of errors
         """
         fields = ",".join(["t." + x for x in self.requestFields[:-7]])
-        req = "SELECT %s " % fields
+        req = f"SELECT {fields} "
         req += "FROM ProductionRequests as t "
-        req += "WHERE t.RequestID=%s" % requestID
-        result = self._query(req, connection)
+        req += f"WHERE t.RequestID={requestID}"
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -1042,7 +1042,7 @@ class ProductionRequestDB(DB):
         except ValueError:
             pass
         except TypeError:
-            gLogger.warn("NumberOfEvents is not defined for %s" % requestID)
+            gLogger.warn(f"NumberOfEvents is not defined for {requestID}")
         rec["RealNumberOfEvents"] = str(num)
 
         recl = [rec[x] for x in self.requestFields[1:-7]]
@@ -1054,13 +1054,13 @@ class ProductionRequestDB(DB):
         recls = result["Value"]
 
         req = "INSERT INTO ProductionRequests ( " + ",".join(self.requestFields[1:-7])
-        req += " ) VALUES ( %s );" % ",".join(recls)
-        result = self._update(req, connection)
+        req += f" ) VALUES ( {','.join(recls)} );"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
         req = "SELECT LAST_INSERT_ID();"
-        result = self._query(req, connection)
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -1071,8 +1071,8 @@ class ProductionRequestDB(DB):
             result = self._update(
                 "INSERT INTO RequestHistory ("
                 + ",".join(self.historyFields[:-1])
-                + ") VALUES ( %s,'%s','%s')" % (newRequestID, str(rec["RequestState"]), str(rec["RequestAuthor"])),
-                connection,
+                + f") VALUES ( {newRequestID},'{str(rec['RequestState'])}','{str(rec['RequestAuthor'])}')",
+                conn=connection,
             )
             if not result["OK"]:
                 gLogger.error(result["Message"])
@@ -1084,8 +1084,8 @@ class ProductionRequestDB(DB):
 
         req = "SELECT RequestID "
         req += "FROM ProductionRequests as t "
-        req += "WHERE t.ParentID=%s" % requestID
-        result = self._query(req, connection)
+        req += f"WHERE t.ParentID={requestID}"
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -1154,24 +1154,24 @@ class ProductionRequestDB(DB):
         """Update parent for this request if setParent is True and update master
         for this and all subrequests."""
         if setParent:
-            updates = "ParentID=%s,MasterID=%s" % (str(masterID), str(masterID))
+            updates = f"ParentID={str(masterID)},MasterID={str(masterID)}"
         req = "UPDATE ProductionRequests "
-        req += "SET %s " % updates
-        req += "WHERE RequestID=%s" % requestID
-        result = self._update(req, connection)
+        req += f"SET {updates} "
+        req += f"WHERE RequestID={requestID}"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             return result
         req = "SELECT RequestID,MasterID "
         req += "FROM ProductionRequests as t "
-        req += "WHERE t.ParentID=%s" % requestID
-        result = self._query(req, connection)
+        req += f"WHERE t.ParentID={requestID}"
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             return result
         for ch in result["Value"]:
             if ch[1]:
                 ret = self.__moveChildDeep(ch[0], masterID, False, connection)
                 if not ret["OK"]:
-                    gLogger.error("_moveChildDeep: can not move to %s: %s" % (str(masterID), ret["Message"]))
+                    gLogger.error(f"_moveChildDeep: can not move to {str(masterID)}: {ret['Message']}")
                 # !!! Failing that will leave both requests inconsistant !!!
                 # But since we have only one subrequest level now, it will never happened
         return S_OK()
@@ -1219,8 +1219,8 @@ class ProductionRequestDB(DB):
             return result
         req = "SELECT RequestID,MasterID "
         req += "FROM ProductionRequests as t "
-        req += "WHERE t.ParentID=%s" % requestID
-        result = self._query(req, connection)
+        req += f"WHERE t.ParentID={requestID}"
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -1246,13 +1246,13 @@ class ProductionRequestDB(DB):
             return result
         recls = result["Value"]
         req = "INSERT INTO ProductionRequests ( " + ",".join(self.requestFields[1:-7])
-        req += " ) VALUES ( %s );" % ",".join(recls)
-        result = self._update(req, connection)
+        req += f" ) VALUES ( {','.join(recls)} );"
+        result = self._update(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
         req = "SELECT LAST_INSERT_ID();"
-        result = self._query(req, connection)
+        result = self._query(req, conn=connection)
         if not result["OK"]:
             self.lock.release()
             return result
@@ -1266,20 +1266,18 @@ class ProductionRequestDB(DB):
         # If nothing could be moved, remove the master
         if not rsplitlist:
             req = "DELETE FROM ProductionRequests "
-            req += "WHERE RequestID=%s" % str(newRequestID)
-            result = self._update(req, connection)
+            req += f"WHERE RequestID={str(newRequestID)}"
+            result = self._update(req, conn=connection)
             self.lock.release()
             return S_ERROR("Could not move subrequests")
 
         # Copy the history (failures are not fatal since
         # it is hard to revert the previous changes...)
-        req = "SELECT " + ",".join(self.historyFields) + " FROM RequestHistory WHERE RequestID=%s " % requestID
+        req = "SELECT " + ",".join(self.historyFields) + f" FROM RequestHistory WHERE RequestID={requestID} "
         req += "ORDER BY TimeStamp"
-        result = self._query(req, connection)
+        result = self._query(req, conn=connection)
         if not result["OK"]:
-            gLogger.error(
-                "SplitProductionRequest: can not get history for %s: %s" % (str(requestID), result["Message"])
-            )
+            gLogger.error(f"SplitProductionRequest: can not get history for {str(requestID)}: {result['Message']}")
         else:
             for x in result["Value"]:
                 x = list(x)
@@ -1288,7 +1286,7 @@ class ProductionRequestDB(DB):
                     "INSERT INTO RequestHistory ("
                     + ",".join(self.historyFields)
                     + ") VALUES ( %s,'%s','%s','%s')" % tuple([str(y) for y in x]),
-                    connection,
+                    conn=connection,
                 )
             if not ret["OK"]:
                 gLogger.error("SplitProductionRequest: add history fail: %s", ["Message"])
@@ -1301,7 +1299,7 @@ class ProductionRequestDB(DB):
     def getProductionProgress(self, requestID):
         """return the list of associated productions requestID must be Long and
         already checked."""
-        req = "SELECT * FROM ProductionProgress WHERE RequestID=%s" % requestID
+        req = f"SELECT * FROM ProductionProgress WHERE RequestID={requestID}"
         result = self._query(req)
         if not result["OK"]:
             return result
@@ -1340,7 +1338,7 @@ class ProductionRequestDB(DB):
         req += " ) VALUES ( "
         req += ",".join([str(pdict[x]) for x in self.progressFields])
         req += " )"
-        result = self._update(req, connection)
+        result = self._update(req, conn=connection)
         self.lock.release()
         if not result["OK"]:
             return result
@@ -1349,7 +1347,7 @@ class ProductionRequestDB(DB):
     def removeProductionFromRequest(self, productionID):
         """Deassociate production."""
         req = "DELETE FROM ProductionProgress "
-        req += "WHERE ProductionID=%s" % str(productionID)
+        req += f"WHERE ProductionID={str(productionID)}"
         result = self._update(req)
         if not result["OK"]:
             return result
@@ -1359,8 +1357,8 @@ class ProductionRequestDB(DB):
         """Deassociate production."""
         used = int(used)
         req = "UPDATE ProductionProgress "
-        req += "SET Used=%s " % str(used)
-        req += "WHERE ProductionID=%s" % str(productionID)
+        req += f"SET Used={str(used)} "
+        req += f"WHERE ProductionID={str(productionID)}"
         result = self._update(req)
         if not result["OK"]:
             return result
@@ -1370,7 +1368,7 @@ class ProductionRequestDB(DB):
         """return the list of state changes for the requests requestID must be Long
         and already checked."""
         req = "SELECT " + ",".join(self.historyFields)
-        req += " FROM RequestHistory WHERE RequestID=%s " % requestID
+        req += f" FROM RequestHistory WHERE RequestID={requestID} "
         req += "ORDER BY TimeStamp"
         result = self._query(req)
         if not result["OK"]:
@@ -1385,9 +1383,9 @@ class ProductionRequestDB(DB):
         'Completed' state."""
         req1 = "SELECT RequestID FROM ProductionRequests WHERE RequestState in ('Active','Completed')"
         req2 = "SELECT RequestID FROM ProductionRequests WHERE RequestState in ('Active','Completed')"
-        req2 += " OR MasterID in (%s)" % req1
+        req2 += f" OR MasterID in ({req1})"
         req = "SELECT ProductionID FROM ProductionProgress WHERE RequestID "
-        req += "in (%s)" % req2
+        req += f"in ({req2})"
 
         result = self._query(req)
         if not result["OK"]:
@@ -1410,15 +1408,15 @@ class ProductionRequestDB(DB):
         for x in update:
             result = self._update(
                 "UPDATE ProductionProgress "
-                + "SET BkEvents=%s " % x["BkEvents"]
-                + "WHERE ProductionID=%s" % x["ProductionID"]
+                + f"SET BkEvents={x['BkEvents']} "
+                + f"WHERE ProductionID={x['ProductionID']}"
             )
             if not result["OK"]:
-                gLogger.info("Problem in updating progress. Not fatal: %s" % result["Message"])
+                gLogger.info(f"Problem in updating progress. Not fatal: {result['Message']}")
         return S_OK("")
 
     def __trackedInputSQL(self, fields):
-        req = "SELECT %s " % fields
+        req = f"SELECT {fields} "
         req += "FROM ProductionRequests as t WHERE"
         req += ' t.RequestState in ("Active","Completed")'
         req += " AND NumberOfEvents<0 "
@@ -1472,21 +1470,21 @@ class ProductionRequestDB(DB):
                 skiped.append(x["RequestID"])
                 continue
             req = "UPDATE ProductionRequests "
-            req += "SET RealNumberOfEvents=%s " % str(x["RealNumberOfEvents"])
-            req += "WHERE RequestID=%s" % str(x["RequestID"])
+            req += f"SET RealNumberOfEvents={str(x['RealNumberOfEvents'])} "
+            req += f"WHERE RequestID={str(x['RequestID'])}"
             result = self._update(req)
             if not result["OK"]:
                 skiped.append(x["RequestID"])
         if skiped:
-            return S_ERROR("updateTrackedInput has skiped requests %s" % ",".join(skiped))
+            return S_ERROR(f"updateTrackedInput has skiped requests {','.join(skiped)}")
         return S_OK("")
 
     def getProductionList(self, requestID):
         """return a list of all productions associated with the request or any its
         subrequest."""
-        req1 = "SELECT RequestID FROM ProductionRequests WHERE MasterID=%s" % requestID
+        req1 = f"SELECT RequestID FROM ProductionRequests WHERE MasterID={requestID}"
         req = "SELECT ProductionID FROM ProductionProgress WHERE RequestID "
-        req += "in (%s) OR RequestID=%s" % (req1, requestID)
+        req += f"in ({req1}) OR RequestID={requestID}"
 
         result = self._query(req)
         if not result["OK"]:
@@ -1501,11 +1499,11 @@ class ProductionRequestDB(DB):
         """return a dictionary containing a summary for each subrequest."""
         req = "SELECT RequestID,ParentID,RequestType,RequestState,NumberOfEvents FROM ProductionRequests"
         if status and rType:
-            req = "%s WHERE RequestState = '%s' AND RequestType = '%s'" % (req, status, rType)
+            req = f"{req} WHERE RequestState = '{status}' AND RequestType = '{rType}'"
         elif status:
-            req = "%s WHERE RequestState = '%s'" % (req, status)
+            req = f"{req} WHERE RequestState = '{status}'"
         elif rType:
-            req = "%s WHERE RequestType = '%s'" % (req, rType)
+            req = f"{req} WHERE RequestType = '{rType}'"
         res = self._query(req)
         if not res["OK"]:
             return res
@@ -1540,10 +1538,9 @@ class ProductionRequestDB(DB):
             ("EType", "EventType"),
             ("WG", "RequestWG"),
         ]:
-
-            req = "SELECT DISTINCT %s FROM ProductionRequests " % value
-            req += "WHERE %s IS NOT NULL " % value
-            req += "ORDER BY %s" % value
+            req = f"SELECT DISTINCT {value} FROM ProductionRequests "
+            req += f"WHERE {value} IS NOT NULL "
+            req += f"ORDER BY {value}"
             res = self._query(req)
             if not res["OK"]:
                 return res
