@@ -10,13 +10,10 @@
 ###############################################################################
 """ DIRAC service that expose access for MCStatsElasticDBs (several ElasticSearch DBs)
 """
-import six
-
 from DIRAC import S_OK
 from DIRAC.Core.DISET.RequestHandler import RequestHandler
 from LHCbDIRAC.ProductionManagementSystem.DB.ElasticApplicationSummaryDB import ElasticApplicationSummaryDB
-from LHCbDIRAC.ProductionManagementSystem.DB.ElasticMCBooleLogErrorsDB import ElasticMCBooleLogErrorsDB
-from LHCbDIRAC.ProductionManagementSystem.DB.ElasticMCGaussLogErrorsDB import ElasticMCGaussLogErrorsDB
+from LHCbDIRAC.ProductionManagementSystem.DB.ElasticLogErrorsDB import ElasticLogErrorsDB
 from LHCbDIRAC.ProductionManagementSystem.DB.ElasticPrMonDB import ElasticPrMonDB
 
 
@@ -26,36 +23,30 @@ class MCStatsElasticDBHandler(RequestHandler):
     @classmethod
     def initializeHandler(cls, serviceInfoDict):
         elasticApplicationSummaryDB = ElasticApplicationSummaryDB()
-        elasticMCBooleLogErrorsDB = ElasticMCBooleLogErrorsDB()
-        elasticMCGaussLogErrorsDB = ElasticMCGaussLogErrorsDB()
+        elasticLogErrorsDB = ElasticLogErrorsDB()
         elasticPrMonDB = ElasticPrMonDB()
 
         cls.db = {
             "XMLSummary": elasticApplicationSummaryDB,
-            "booleErrors": elasticMCBooleLogErrorsDB,
-            "gaussErrors": elasticMCGaussLogErrorsDB,
+            "errors": elasticLogErrorsDB,
             "prMon": elasticPrMonDB,
         }
 
         return S_OK()
 
-    types_set = [six.string_types, dict]
+    types_set = [str, (dict, list)]
 
     def export_set(self, typeName, data):
-
-        self.log.debug("Called set() with typeName = %s, data = %s" % (typeName, str(data)))
+        if isinstance(data, dict):
+            data = [data]
         return self.db[typeName].set(data)
 
-    types_get = [six.string_types, int]
+    types_get = [str, (str, int)]
 
     def export_get(self, typeName, productionID):
-
-        self.log.debug("Called get() with typeName = %s, productionID = %d" % (typeName, productionID))
         return self.db[typeName].get(productionID)
 
-    types_remove = [six.string_types, int]
+    types_remove = [str, (str, int)]
 
     def export_remove(self, typeName, productionID):
-
-        self.log.debug("Called remove() with typeName = %s, productionID = %d" % (typeName, productionID))
         return self.db[typeName].remove(productionID)
