@@ -10,7 +10,6 @@
 ###############################################################################
 """ProductionRequestHandler is the implementation of the Production Request
 service."""
-
 import importlib.resources
 import os
 import subprocess
@@ -68,11 +67,11 @@ class ProductionRequestHandler(RequestHandler):
         return S_OK(rows)
 
     types_getProductionRequestList = [
-        six.integer_types,
-        six.string_types,
-        six.string_types,
-        six.integer_types,
-        six.integer_types,
+        (int,),
+        (str,),
+        (str,),
+        (int,),
+        (int,),
         dict,
     ]
 
@@ -82,35 +81,35 @@ class ProductionRequestHandler(RequestHandler):
             [], subrequestFor, sortBy, sortOrder, offset, limit, rFilter
         )
 
-    types_updateProductionRequest = [six.integer_types, dict]
+    types_updateProductionRequest = [(int,), dict]
 
     def export_updateProductionRequest(self, requestID, requestDict):
         """Update production request specified by requestID."""
         creds = self.__clientCredentials()
         return self.productionRequestDB.updateProductionRequest(requestID, requestDict, creds)
 
-    types_duplicateProductionRequest = [six.integer_types, bool]
+    types_duplicateProductionRequest = [(int,), bool]
 
     def export_duplicateProductionRequest(self, requestID, clearpp):
         """Duplicate production request with subrequests."""
         creds = self.__clientCredentials()
         return self.productionRequestDB.duplicateProductionRequest(requestID, creds, clearpp)
 
-    types_deleteProductionRequest = [six.integer_types]
+    types_deleteProductionRequest = [(int,)]
 
     def export_deleteProductionRequest(self, requestID):
         """Delete production request specified by requestID."""
         creds = self.__clientCredentials()
         return self.productionRequestDB.deleteProductionRequest(requestID, creds)
 
-    types_splitProductionRequest = [six.integer_types, list]
+    types_splitProductionRequest = [(int,), list]
 
     def export_splitProductionRequest(self, requestID, splitList):
         """split production request."""
         creds = self.__clientCredentials()
         return self.productionRequestDB.splitProductionRequest(requestID, splitList, creds)
 
-    types_getProductionProgressList = [six.integer_types]
+    types_getProductionProgressList = [(int,)]
 
     def export_getProductionProgressList(self, requestID):
         """Return the list of associated with requestID productions."""
@@ -122,19 +121,19 @@ class ProductionRequestHandler(RequestHandler):
         """Associate production to request."""
         return self.productionRequestDB.addProductionToRequest(pdict)
 
-    types_removeProductionFromRequest = [six.integer_types]
+    types_removeProductionFromRequest = [(int,)]
 
     def export_removeProductionFromRequest(self, productionID):
         """Deassociate production."""
         return self.productionRequestDB.removeProductionFromRequest(productionID)
 
-    types_useProductionForRequest = [six.integer_types, bool]
+    types_useProductionForRequest = [(int,), bool]
 
     def export_useProductionForRequest(self, productionID, used):
         """Set Used flags for production."""
         return self.productionRequestDB.useProductionForRequest(productionID, used)
 
-    types_getRequestHistory = [six.integer_types]
+    types_getRequestHistory = [(int,)]
 
     def export_getRequestHistory(self, requestID):
         """Return the list of state changes for the request."""
@@ -203,7 +202,7 @@ class ProductionRequestHandler(RequestHandler):
         ]
         return S_OK(templates)
 
-    types_getProductionTemplate = [six.string_types]
+    types_getProductionTemplate = [(str,)]
 
     def export_getProductionTemplate(self, name):
         for path in self.__productionTemplatePaths():
@@ -212,7 +211,7 @@ class ProductionRequestHandler(RequestHandler):
         else:
             return S_ERROR(f"Template {name!r} doesn't exist")
 
-    types_execProductionScript = [six.string_types, six.string_types]
+    types_execProductionScript = [(str,), (str,)]
 
     def export_execProductionScript(self, script, workflow):
         creds = self.__clientCredentials()
@@ -252,7 +251,7 @@ class ProductionRequestHandler(RequestHandler):
         gLogger.error("Failed to execProductionScript", message)
         return S_ERROR(message)
 
-    types_execWizardScript = [six.string_types, dict]
+    types_execWizardScript = [(str,), dict]
 
     def export_execWizardScript(self, wizard, wizpar):
         """Execure wizard with parameters."""
@@ -281,10 +280,10 @@ class ProductionRequestHandler(RequestHandler):
             return S_ERROR(str(msg))
         setenv = "source /opt/dirac/bashrc"
         # #proxy = "X509_USER_PROXY=xxx"
-        proxy = "X509_USER_PROXY=%s" % proxyFile
-        cmd = "python %s" % (f[1])
+        proxy = f"X509_USER_PROXY={proxyFile}"
+        cmd = f"python {f[1]}"
         try:
-            res = shellCall(1800, ["/bin/bash -c '%s;%s %s'" % (setenv, proxy, cmd)])
+            res = shellCall(1800, [f"/bin/bash -c '{setenv};{proxy} {cmd}'"])
             if res["OK"]:
                 result = S_OK(str(res["Value"][1]) + str(res["Value"][2]))
             else:
@@ -292,29 +291,29 @@ class ProductionRequestHandler(RequestHandler):
                 result = res
         except Exception as msg:
             gLogger.error("During execution: " + str(msg))
-            result = S_ERROR("Failed to execute: %s" % str(msg))
+            result = S_ERROR(f"Failed to execute: {str(msg)}")
         os.remove(f[1])
         os.remove(proxyFile)
         return result
 
-    types_getProductionList = [six.integer_types]
+    types_getProductionList = [(int,)]
 
     def export_getProductionList(self, requestID):
         """Return the list of productions associated with request and its
         subrequests."""
         return self.productionRequestDB.getProductionList(requestID)
 
-    types_getProductionRequestSummary = [[six.string_types, list], [six.string_types, list]]
+    types_getProductionRequestSummary = [[(str,), list], [(str,), list]]
 
     def export_getProductionRequestSummary(self, status, requestType):
         """Method to retrieve the production / request relations for a given
         request status."""
-        if isinstance(requestType, six.string_types):
+        if isinstance(requestType, str):
             reqTypes = [requestType]
         elif isinstance(requestType, list):
             reqTypes = requestType
 
-        if isinstance(status, six.string_types):
+        if isinstance(status, str):
             selectStatus = [status]
         elif isinstance(status, list):
             selectStatus = status
@@ -329,22 +328,22 @@ class ProductionRequestHandler(RequestHandler):
         for req in requests["Rows"]:
             iD = int(req["RequestID"])
             if not req["RequestType"] in reqTypes:
-                gLogger.verbose("Skipping %s request ID %s..." % (req["RequestType"], iD))
+                gLogger.verbose(f"Skipping {req['RequestType']} request ID {iD}...")
                 continue
             if not req["RequestState"] in selectStatus:
-                gLogger.verbose("Skipping request ID %s in state %s" % (iD, req["RequestState"]))
+                gLogger.verbose(f"Skipping request ID {iD} in state {req['RequestState']}")
                 continue
             if req["HasSubrequest"]:
-                gLogger.verbose("Simulation request %s is a parent, getting subrequests..." % iD)
+                gLogger.verbose(f"Simulation request {iD} is a parent, getting subrequests...")
                 subReq = self.productionRequestDB.getProductionRequest([], int(iD))
                 if not subReq["OK"]:
-                    gLogger.error("Could not get production request for %s" % iD)
+                    gLogger.error(f"Could not get production request for {iD}")
                     return subReq
                 for sreq in subReq["Value"]["Rows"]:
                     sid = int(sreq["RequestID"])
                     resultDict[sid] = {"reqTotal": sreq["rqTotal"], "bkTotal": sreq["bkTotal"], "master": iD}
             else:
-                gLogger.verbose("Simulation request %s is a single request" % iD)
+                gLogger.verbose(f"Simulation request {iD} is a single request")
                 resultDict[iD] = {"reqTotal": req["rqTotal"], "bkTotal": req["bkTotal"], "master": 0}
 
         return S_OK(resultDict)
