@@ -24,11 +24,10 @@
       - for the MC: just set pr.prodsToLaunch = [1]
       - for the merge and/or stripping: set pr.prodsToLaunch, then set pr.previousProdID
 """
-from six.moves import range
 
 import ast
 
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 
 Script.parseCommandLine()
 
@@ -44,7 +43,6 @@ from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import Produc
 
 
 def modifyCompression(dict1, dict2, default):
-
     compression = []
 
     combinedVis = dict1.copy()
@@ -66,11 +64,10 @@ def modifyCompression(dict1, dict2, default):
 
 
 def fillVisList(vdict, num):
-
     # Assuming that, if there's only one element in the list of output visibility flags, every step will catch that flag
     if len(vdict) == 1:
         val = vdict[list(vdict)[0]]
-        vdict = dict([(str(i), val) for i in range(int(list(vdict)[0]), int(list(vdict)[0]) + num)])
+        vdict = {str(i): val for i in range(int(list(vdict)[0]), int(list(vdict)[0]) + num)}
     # Another assumption: if the number of steps is bigger than that of vis flags,
     # then extend the list with the last flag available
     # to fill the "holes"
@@ -361,7 +358,7 @@ if validationFlag:
 
 res = pr.buildAndLaunchRequest()
 if not res["OK"]:
-    gLogger.error("Errors with submission: %s" % res["Message"])
+    gLogger.error(f"Errors with submission: {res['Message']}")
     DIRACexit(2)
 else:
-    gLogger.always("Submitted %s" % str(res["Value"]))
+    gLogger.always(f"Submitted {str(res['Value'])}")
