@@ -24,11 +24,10 @@
       - for the MC: just set pr.prodsToLaunch = [1]
       - for the merge and/or stripping: set pr.prodsToLaunch, then set pr.previousProdID
 """
-from six.moves import range
 
 import ast
 
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 
 Script.parseCommandLine()
 
@@ -217,7 +216,7 @@ numberOfSteps = len(pr.stepsList)
 pr.compressionLvl = ["LOW"] * numberOfSteps
 pr.compressionLvl[-1] = "HIGH"
 
-vis = dict([str(i), "N"] for i in range(1, numberOfSteps))
+vis = {str(i): "N" for i in range(1, numberOfSteps)}
 vis[str(numberOfSteps)] = "Y"
 
 pr.outputVisFlag = [vis]
@@ -247,7 +246,7 @@ if validationFlag:
 
 res = pr.buildAndLaunchRequest()
 if not res["OK"]:
-    gLogger.error("Errors with submission: %s" % res["Message"])
+    gLogger.error(f"Errors with submission: {res['Message']}")
     DIRACexit(2)
 else:
-    gLogger.always("Submitted %s" % str(res["Value"]))
+    gLogger.always(f"Submitted {str(res['Value'])}")
