@@ -22,11 +22,10 @@ Exotic things you might want to do:
   pre: remember to check if your input file is online, if not use lcg-bringonline <PFN>
 * run only part of the request on the Grid:
 """
-from six.moves import range
 
 import ast
 
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 
 Script.parseCommandLine()
 
