@@ -11,7 +11,7 @@
 """Moving toward a templates-less system."""
 import ast
 
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 
 Script.parseCommandLine()
 
@@ -127,7 +127,7 @@ numberOfSteps = len(pr.stepsList)
 pr.compressionLvl = ["LOW"] * numberOfSteps
 pr.compressionLvl[-1] = "HIGH"
 
-vis = dict([str(i), "N"] for i in range(1, numberOfSteps))
+vis = {str(i): "N" for i in range(1, numberOfSteps)}
 vis[str(numberOfSteps)] = "Y"
 
 pr.outputVisFlag = [vis]
