@@ -9,11 +9,10 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Moving toward a templates-less system."""
-from six.moves import range
 
 import ast
 
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 
 Script.parseCommandLine()
 
@@ -22,11 +21,10 @@ from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import Produc
 
 
 def fillVisList(vdict, num):
-
     # Assuming that, if there's only one element in the list of output visibility flags, every step will catch that flag
     if len(vdict) == 1:
         val = vdict[list(vdict)[0]]
-        vdict = dict([(str(i), val) for i in range(int(list(vdict)[0]), int(list(vdict)[0]) + num)])
+        vdict = {str(i): val for i in range(int(list(vdict)[0]), int(list(vdict)[0]) + num)}
     # Another assumption: if the number of steps is bigger than that of vis flags,
     # then extend the list with the last flag available
     # to fill the "holes"
