@@ -9,10 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Just couple utilities."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
+import json
 import os
 import sqlite3
 
@@ -22,8 +19,6 @@ from DIRAC.ConfigurationSystem.Client.Helpers.Registry import getUserOption, get
 from DIRAC.FrameworkSystem.Client.NotificationClient import NotificationClient
 from DIRAC.ConfigurationSystem.Client import PathFinder
 
-__RCSID__ = "$Id$"
-
 
 def _getMemberMails(group):
     """get members mails."""
@@ -41,7 +36,6 @@ def _aggregate(reqId, reqType, reqWG, reqName, SimCondition, ProPath, groups, in
     cacheFile = os.path.join(DIRAC.rootPath, "work/ProductionManagement/cache.db")
 
     with sqlite3.connect(cacheFile) as conn:
-
         try:
             conn.execute(
                 """CREATE TABLE IF NOT EXISTS ProductionManagementCache(
@@ -82,11 +76,11 @@ def informPeople(rec, oldstate, state, author, inform):
         gLogger.error("No ProductionRequest section in configuration")
         return
 
-    fromAddress = gConfig.getValue("%s/fromAddress" % csS, "")
+    fromAddress = gConfig.getValue(f"{csS}/fromAddress", "")
     if not fromAddress:
-        gLogger.error("No fromAddress is defined in CS path %s/fromAddress" % csS)
+        gLogger.error(f"No fromAddress is defined in CS path {csS}/fromAddress")
         return
-    sendNotifications = gConfig.getValue("%s/sendNotifications" % csS, "Yes")
+    sendNotifications = gConfig.getValue(f"{csS}/sendNotifications", "Yes")
     if sendNotifications != "Yes":
         gLogger.info("No notifications will be sent")
         return
@@ -94,23 +88,23 @@ def informPeople(rec, oldstate, state, author, inform):
     footer = "\n\nNOTE: This is an automated notification."
     footer += " Please do not reply.\n"
 
-    footer += "DIRAC Web portal: https://lhcb-portal-dirac.cern.ch/DIRAC/s:%s/g:" % PathFinder.getDIRACSetup()
+    footer += f"DIRAC Web portal: https://lhcb-portal-dirac.cern.ch/DIRAC/s:{PathFinder.getDIRACSetup()}/g:"
 
     ppath = "/?view=tabs&url_state=1|*LHCbDIRAC.ProductionRequestManager.classes.ProductionRequestManager:,\n\n"
 
     ppath += "The request details:\n"
-    ppath += "  Type: %s" % str(rec["RequestType"])
-    ppath += "  Name: %s\n" % str(rec["RequestName"])
-    ppath += "  Conditions: %s\n" % str(rec["SimCondition"])
-    ppath += "  Processing pass: %s\n" % str(rec["ProPath"])
+    ppath += f"  Type: {str(rec['RequestType'])}"
+    ppath += f"  Name: {str(rec['RequestName'])}\n"
+    ppath += f"  Conditions: {str(rec['SimCondition'])}\n"
+    ppath += f"  Processing pass: {str(rec['ProPath'])}\n"
 
-    gLogger.info(".... %s ...." % ppath)
+    gLogger.info(f".... {ppath} ....")
 
     authorMail = getUserOption(author, "Email")
     if authorMail:
         if state not in ["BK Check", "Submitted"]:
             if state == "BK OK":
-                subj = "DIRAC: please resign your Production Request %s" % reqId
+                subj = f"DIRAC: please resign your Production Request {reqId}"
                 body = "\n".join(
                     [
                         "Customized Simulation Conditions in your request was registered. ",
@@ -119,7 +113,7 @@ def informPeople(rec, oldstate, state, author, inform):
                     ]
                 )
             else:
-                subj = "DIRAC: the state of Production Request %s is changed to '%s'; %s;%s" % (
+                subj = "DIRAC: the state of Production Request {} is changed to '{}'; {};{}".format(
                     reqId,
                     state,
                     rec.get("RequestWG", ""),
@@ -129,10 +123,10 @@ def informPeople(rec, oldstate, state, author, inform):
             notification = NotificationClient()
             res = notification.sendMail(authorMail, subj, body + footer + "lhcb_user" + ppath, fromAddress, True)
             if not res["OK"]:
-                gLogger.error("_inform_people: can't send email: %s" % res["Message"])
+                gLogger.error(f"_inform_people: can't send email: {res['Message']}")
 
     if inform:
-        subj = "DIRAC: the state of %s Production Request %s is changed to '%s'; %s;%s" % (
+        subj = "DIRAC: the state of {} Production Request {} is changed to '{}'; {};{}".format(
             rec["RequestType"],
             reqId,
             state,
@@ -150,10 +144,10 @@ def informPeople(rec, oldstate, state, author, inform):
                     notification = NotificationClient()
                     res = notification.sendMail(eMail, subj, body + footer + "lhcb_user" + ppath, fromAddress, True)
                     if not res["OK"]:
-                        gLogger.error("_inform_people: can't send email: %s" % res["Message"])
+                        gLogger.error(f"_inform_people: can't send email: {res['Message']}")
 
     if state == "Accepted":
-        subj = "DIRAC: the Production Request %s is accepted; %s;%s" % (
+        subj = "DIRAC: the Production Request {} is accepted; {};{}".format(
             reqId,
             rec.get("RequestWG", ""),
             rec.get("RequestName", ""),
@@ -168,10 +162,10 @@ def informPeople(rec, oldstate, state, author, inform):
                 notification = NotificationClient()
                 res = notification.sendMail(man, subj, body % group + footer + group + ppath, fromAddress, True)
                 if not res["OK"]:
-                    gLogger.error("_inform_people: can't send email: %s" % res["Message"])
+                    gLogger.error(f"_inform_people: can't send email: {res['Message']}")
 
     elif state == "PPG OK" and oldstate == "Accepted":
-        subj = "DIRAC: returned Production Request %s; %s;%s" % (
+        subj = "DIRAC: returned Production Request {}; {};{}".format(
             reqId,
             rec.get("RequestWG", ""),
             rec.get("RequestName", ""),
@@ -193,10 +187,9 @@ def informPeople(rec, oldstate, state, author, inform):
                 notification = NotificationClient()
                 res = notification.sendMail(man, subj, body % group + footer + group + ppath, fromAddress, True)
                 if not res["OK"]:
-                    gLogger.error("_inform_people: can't send email: %s" % res["Message"])
+                    gLogger.error(f"_inform_people: can't send email: {res['Message']}")
 
     elif state == "BK Check":
-
         groups = ["lhcb_bk"]
 
         _aggregate(
@@ -211,7 +204,6 @@ def informPeople(rec, oldstate, state, author, inform):
         )
 
     elif state == "Submitted":
-
         groups = ["lhcb_ppg", "lhcb_tech"]
         _aggregate(
             reqId,
@@ -226,3 +218,10 @@ def informPeople(rec, oldstate, state, author, inform):
 
     else:
         return
+
+
+def unpackOptionFile(optionsFile):
+    if optionsFile.startswith("{"):
+        return json.loads(optionsFile)
+    else:
+        return optionsFile.split(";")
