@@ -31,17 +31,17 @@ The following switches and options are provided.
 - omitMerge     : omit all merge production
 - noFiles       : do not request file information
 """
+
 from datetime import datetime
 import sys
 
 from DIRAC import exit as DIRACExit
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def doParse():
     """Function that contains all the switches definition and isolates the rest
     of the module from parseCommandLine."""
-    from DIRAC.Core.Base import Script
 
     # Switch description
     Script.registerSwitch("i:", "requestID=", "ID of the request")
@@ -91,7 +91,6 @@ def doParse():
     mergeAction, noFiles, sortKey = None, False, "RequestID"
 
     for switch in Script.getUnprocessedSwitches():
-
         if switch[0].lower() in ("i", "requestid"):
             params["RequestID"] = switch[1]
         elif switch[0].lower() in ("r", "requeststate"):
@@ -145,7 +144,6 @@ def getRequests(parsedInput, sortKey):
     parsedRequests = []
 
     for request in sortedRequests:
-
         parsedRequests.append(
             {
                 "requestID": request["RequestID"],
@@ -173,7 +171,6 @@ def getTransformations(transClient, requestID, noFiles):
     parsedTransformations = {}
 
     for transformation in transformations:
-
         transformationID = transformation["TransformationID"]
 
         if not noFiles:
@@ -209,7 +206,7 @@ def getFiles(transClient, transformationID):
     # This gets the interesting values
     recordsResult = ts.getTransformationSummaryWeb({"TransformationID": transformationID}, [], 0, 1000000)
     if not recordsResult["OK"]:
-        print("TransID %s: %s" % (transformationID, recordsResult["Message"]))
+        print(f"TransID {transformationID}: {recordsResult['Message']}")
         filesDict["Total"] = -1
         return filesDict
     records = recordsResult["Value"]
@@ -218,14 +215,14 @@ def getFiles(transClient, transformationID):
     path = ts.getTransformationParameters(transformationID, ["DetailedInfo"])
 
     if not path["OK"]:
-        print("TransID %s: %s" % (transformationID, path["Message"]))
+        print(f"TransID {transformationID}: {path['Message']}")
         filesDict["Total"] = -1
         return filesDict
     path = path["Value"]
     path = path.split("BK Browsing Paths:\n", 1)[1]
 
     if not files["OK"]:
-        print("TransID %s: %s" % (transformationID, files["Message"]))
+        print(f"TransID {transformationID}: {files['Message']}")
         filesDict["Total"] = -1
         return filesDict
     files = files["Value"]
@@ -255,18 +252,18 @@ def printSelection(parsedInput, mergeAction, noFiles, sortKey):
 
     print("\n")
     print("-" * 60)
-    print("                REQUESTS at %s" % datetime.now().replace(microsecond=0))
+    print(f"                REQUESTS at {datetime.now().replace(microsecond=0)}")
     print("-" * 60)
 
     print("  Selection parameters:")
 
     for key, value in parsedInput.items():
-        print("    %s : %s" % (key.ljust(25, " "), value))
+        print(f"    {key.ljust(25, ' ')} : {value}")
 
     print("  Display parameters:")
     print("    display merge transformations: %s" % ((1 and mergeAction) or "all"))
     print("    get files information        : %s" % (not noFiles))
-    print("    sort key                     : %s" % (sortKey))
+    print(f"    sort key                     : {sortKey}")
 
     print("-" * 60)
     print("\n")
@@ -316,7 +313,6 @@ def printResults(request, mergeAction):
             continue
 
         if mergeAction == "group" and transformation["transformationType"] in ["Merge", "MCMerge"]:
-
             groupedMerge["Merged"] += 1
             if groupedMerge["Merged"] == 1:
                 groupedMerge["Path"] = filesDict["Path"]
@@ -324,7 +320,6 @@ def printResults(request, mergeAction):
                 groupedMerge["Path"] = "Multiple"
 
             if filesDict["Total"] > 0:
-
                 groupedMerge["Processed"] += filesDict["Processed"]
                 groupedMerge["Total"] += filesDict["Total"]
                 groupedMerge["Running"] += filesDict["Running"]
@@ -339,7 +334,6 @@ def printResults(request, mergeAction):
         # prints only the HOT production
         if mergeAction == "hot":
             if filesDict["Total"] > 0 and filesDict["Hot"] == 1:
-
                 printTransformation(request["requestID"], transformationID, transformation, filesDict)
 
             continue
@@ -347,9 +341,8 @@ def printResults(request, mergeAction):
         printTransformation(request["requestID"], transformationID, transformation, filesDict)
 
     if mergeAction == "group" and groupedMerge["Merged"]:
-
         if groupedMerge["Merged"] > 1:
-            groupMsg = "%s merge prod(s) grouped" % groupedMerge["Merged"]
+            groupMsg = f"{groupedMerge['Merged']} merge prod(s) grouped"
             printTransformation(request["requestID"], None, None, groupedMerge, groupMsg=groupMsg)
         else:
             printTransformation(request["requestID"], transformationID, transformation, groupedMerge)
@@ -370,7 +363,7 @@ def printTransformation(requestID, transformationID, transformation, filesDict,
       transformationID and transformation can be set to None.
     """
     if not noFiles and filesDict["Path"] is not None:
-        print("BK Browsing Path: [%s]" % filesDict["Path"])
+        print(f"BK Browsing Path: [{filesDict['Path']}]")
     if noFiles:
         filesMsg = ""
     elif filesDict["Total"] == -1:
@@ -420,7 +413,7 @@ def printTransformation(requestID, transformationID, transformation, filesDict,
 def printRequestsInfo(requests):
     """Prints the number of requests."""
 
-    print(" found %s requests \n" % len(requests))
+    print(f" found {len(requests)} requests \n")
     printNow()
 
 
@@ -431,7 +424,7 @@ def printNow():
     sys.stdout.flush()
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
