@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """LHCbDIRAC/ResourceStatusSystem/Agent/LHCbPRProxyAgent.py."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 # First, pythonic stuff
 import os
 import stat
@@ -45,7 +39,6 @@ class LHCbPRProxyAgent(AgentModule):
         """
 
         try:
-
             self.am_setOption("shifterProxy", "LHCbPR")
             return S_OK()
 
