@@ -13,15 +13,9 @@
 JobWebSummaryEfficiencyPolicy.__bases__:
   DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase.PolicyBase
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK
 from DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase import PolicyBase
 
-__RCSID__ = "$Id$"
-
 
 class JobWebSummaryEfficiencyPolicy(PolicyBase):
     """The JobEfficiencyPolicy class is a policy that checks the efficiency of
@@ -84,9 +78,9 @@ class JobWebSummaryEfficiencyPolicy(PolicyBase):
             result["Status"] = "Banned"
         else:
             result["Status"] = "Error"
-            result["Reason"] = 'Unknown status "%s"' % status
+            result["Reason"] = f'Unknown status "{status}"'
             return S_OK(result)
 
-        result["Reason"] = "Jobs Efficiency: %s with status %s" % (efficiency, status)
+        result["Reason"] = f"Jobs Efficiency: {efficiency} with status {status}"
 
         return S_OK(result)
