@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_RSS_Policy_TransferQualityPolicy."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 
 import LHCbDIRAC.ResourceStatusSystem.Policy.TransferQualityPolicy as moduleTested
