@@ -12,7 +12,7 @@
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
 
 import unittest
-import mock
+from unittest import mock
 
 import six
 
