@@ -18,7 +18,7 @@ import os
 import time
 import datetime
 import pickle
-from six.moves import queue as Queue
+import queue as Queue
 import six
 
 from DIRAC import S_OK
@@ -26,7 +26,6 @@ from DIRAC.Core.Base.AgentModule import AgentModule
 from DIRAC.Core.Utilities.ThreadPool import ThreadPool
 from DIRAC.Core.Utilities.ThreadSafe import Synchronizer
 from DIRAC.Core.Utilities.List import breakListIntoChunks
-from DIRAC.FrameworkSystem.Client.MonitoringClient import gMonitor
 from DIRAC.TransformationSystem.Agent.TransformationAgentsUtilities import TransformationAgentsUtilities
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
@@ -89,7 +88,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
 
         self._logInfo("Full Update Period: %d seconds" % self.fullUpdatePeriod)
         self._logInfo("BK update latency : %d seconds" % self.bkUpdateLatency)
-        self._logInfo("Plugins with run info: %s" % ", ".join(self.pluginsWithRunInfo))
+        self._logInfo(f"Plugins with run info: {', '.join(self.pluginsWithRunInfo)}")
 
         self.transClient = TransformationClient()
         self.bkClient = BookkeepingClient()
@@ -100,7 +99,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                 self.fullTimeLog = pickle.load(pf)
                 self.bkQueries = pickle.load(pf)
             self._logInfo("successfully loaded Log from", self.pickleFile, "initialize")
-        except (EOFError, IOError):
+        except (EOFError, OSError):
             self._logInfo("failed loading Log from", self.pickleFile, "initialize")
             self.timeLog = {}
             self.fullTimeLog = {}
@@ -112,7 +111,6 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
         for i in range(maxNumberOfThreads):
             threadPool.generateJobAndQueueIt(self._execute, [i])
 
-        gMonitor.registerActivity("Iteration", "Agent Loops", AGENT_NAME, "Loops/min", gMonitor.OP_SUM)
         return S_OK()
 
     @gSynchro
@@ -124,13 +122,13 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                     pickle.dump(self.timeLog, pf)
                     pickle.dump(self.fullTimeLog, pf)
                     pickle.dump(self.bkQueries, pf)
-                self._logVerbose("successfully dumped Log into %s" % self.pickleFile)
-            except IOError as e:
-                self._logError("fail to open %s: %s" % (self.pickleFile, e))
+                self._logVerbose(f"successfully dumped Log into {self.pickleFile}")
+            except OSError as e:
+                self._logError(f"fail to open {self.pickleFile}: {e}")
             except pickle.PickleError as e:
-                self._logError("fail to dump %s: %s" % (self.pickleFile, e))
+                self._logError(f"fail to dump {self.pickleFile}: {e}")
             except ValueError as e:
-                self._logError("fail to close %s: %s" % (self.pickleFile, e))
+                self._logError(f"fail to close {self.pickleFile}: {e}")
 
     ################################################################################
 
@@ -140,7 +138,6 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
         Just fills a list, and a queue, with BKKQueries ID.
         """
 
-        gMonitor.addMark("Iteration", 1)
         # Get all the transformations
         result = self.transClient.getTransformations(condDict={"Status": ["Active", "Idle"]})
         if not result["OK"]:
@@ -174,16 +171,14 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
         """
 
         while True:  # not self.bkQueriesToBeChecked.empty():
-
             transID = None
-
+            startTime = None
             try:
-
                 transID = self.bkQueriesToBeChecked.get()
                 self.transInThread[transID] = " [Thread%d] [%s] " % (threadID, str(transID))
 
                 startTime = time.time()
-                self._logInfo("Processing transformation %s." % transID, transID=transID)
+                self._logInfo(f"Processing transformation {transID}.", transID=transID)
 
                 res = self.transClient.getTransformation(transID, extraParams=False)
                 if not res["OK"]:
@@ -207,7 +202,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                     # In case we failed a full query, we should retry full query until successful
                     if "StartDate" not in bkQuery:
                         self.bkQueries.pop(transID, None)
-                    self._logError("Failed to get response from the Bookkeeping: %s" % e, "", "__getFiles", transID)
+                    self._logError(f"Failed to get response from the Bookkeeping: {e}", "", "__getFiles", transID)
                     continue
 
                 runDict = {}
@@ -216,12 +211,10 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                 for lfnChunk in breakListIntoChunks(files, self.chunkSize):
                     start = time.time()
                     res = self.bkClient.getFileMetadata(lfnChunk)
-                    self._logVerbose(
-                        "Got metadata from BK for %d files" % len(lfnChunk), transID=transID, reftime=start
-                    )
+                    self._logVerbose(f"Got metadata from BK for {len(lfnChunk)} files", transID=transID, reftime=start)
                     if not res["OK"]:
                         self._logError(
-                            "Failed to get BK metadata for %d files" % len(lfnChunk), res["Message"], transID=transID
+                            f"Failed to get BK metadata for {len(lfnChunk)} files", res["Message"], transID=transID
                         )
                         # No need to return as we only consider files that are successful...
                     else:
@@ -240,7 +233,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                 if transPlugin in self.pluginsWithRunInfo:
                     for lfn, metadata in filesMetadata.items():  # can be an iterator
                         runID = metadata.get("RunNumber", None)
-                        if isinstance(runID, (six.string_types, six.integer_types)):
+                        if isinstance(runID, ((str,), (int,))):
                             runDict.setdefault(int(runID), []).append(lfn)
                     try:
                         self.__addRunsMetadata(transID, list(runDict))
@@ -258,11 +251,11 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                     lfnChunks = [lfnList] if runID else breakListIntoChunks(lfnList, self.chunkSize)
                     for lfnChunk in lfnChunks:
                         # Add the files to the transformation
-                        self._logVerbose("Adding %d lfns for transformation" % len(lfnChunk), transID=transID)
+                        self._logVerbose(f"Adding {len(lfnChunk)} lfns for transformation", transID=transID)
                         result = self.transClient.addFilesToTransformation(transID, lfnChunk)
                         if not result["OK"]:
                             self._logError(
-                                "Failed to add %d lfns to transformation" % len(lfnChunk),
+                                f"Failed to add {len(lfnChunk)} lfns to transformation",
                                 result["Message"],
                                 transID=transID,
                             )
@@ -281,16 +274,13 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                             ]  # can be an iterator
                             if addedLfns:
                                 # Add files metadata: size and file type
-                                lfnDict = dict(
-                                    (
-                                        lfn,
-                                        {
-                                            "Size": filesMetadata[lfn]["FileSize"],
-                                            "FileType": filesMetadata[lfn]["FileType"],
-                                        },
-                                    )
+                                lfnDict = {
+                                    lfn: {
+                                        "Size": filesMetadata[lfn]["FileSize"],
+                                        "FileType": filesMetadata[lfn]["FileType"],
+                                    }
                                     for lfn in addedLfns
-                                )
+                                }
                                 res = self.transClient.setParameterToTransformationFiles(transID, lfnDict)
                                 if not res["OK"]:
                                     self._logError(
@@ -316,7 +306,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
                                         )
                                         continue
                                 else:
-                                    self._logInfo("Added %d files to transformation" % len(addedLfns), transID=transID)
+                                    self._logInfo(f"Added {len(addedLfns)} files to transformation", transID=transID)
 
             except Exception as x:  # pylint: disable=broad-except
                 self._logException(
@@ -353,16 +343,16 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
 
     def __getFiles(self, transID, bkQuery, now):
         """Perform the query to the Bookkeeping."""
-        self._logInfo("Using BK query for transformation: %s" % str(bkQuery), transID=transID)
+        self._logInfo(f"Using BK query for transformation: {str(bkQuery)}", transID=transID)
         start = time.time()
         result = self.bkClient.getFiles(bkQuery)
-        self._logVerbose("BK query time: %.2f seconds." % (time.time() - start), transID=transID)
+        self._logVerbose(f"BK query time: {time.time() - start:.2f} seconds.", transID=transID)
         if not result["OK"]:
             raise RuntimeError(result["Message"])
         else:
             self.__updateTimeStamp(transID, now)
             if result["Value"]:
-                self._logInfo("Obtained %d files from BK" % len(result["Value"]), transID=transID)
+                self._logInfo(f"Obtained {len(result['Value'])} files from BK", transID=transID)
             return result["Value"]
 
     @gSynchro
@@ -377,7 +367,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
             raise RuntimeError(runsInCache["Message"])
         newRuns = list(set(runsList) - set(runsInCache["Value"]))
         if newRuns:
-            self._logVerbose("Associating run metadata to %d runs" % len(newRuns), transID=transID)
+            self._logVerbose(f"Associating run metadata to {len(newRuns)} runs", transID=transID)
             res = self.bkClient.getRunInformation({"RunNumber": newRuns, "Fields": ["TCK", "CondDb", "DDDB"]})
             if not res["OK"]:
                 raise RuntimeError(res["Message"])
@@ -392,7 +382,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
             raise RuntimeError(runsInCache["Message"])
         newRuns = list(set(runsList) - set(runsInCache["Value"]))
         if newRuns:
-            self._logVerbose("Associating run duration to %d runs" % len(newRuns), transID=transID)
+            self._logVerbose(f"Associating run duration to {len(newRuns)} runs", transID=transID)
             res = self.bkClient.getRunInformation({"RunNumber": newRuns, "Fields": ["JobStart", "JobEnd"]})
             if not res["OK"]:
                 raise RuntimeError(res["Message"])
@@ -406,9 +396,7 @@ class BookkeepingWatchAgent(AgentModule, TransformationAgentsUtilities):
     def finalize(self):
         """Gracious finalization."""
         if self.bkQueriesInCheck:
-            self._logInfo(
-                "Wait for queue to get empty before terminating the agent (%d tasks)" % len(self.transInThread)
-            )
+            self._logInfo(f"Wait for queue to get empty before terminating the agent ({len(self.transInThread)} tasks)")
             self.bkQueriesInCheck = []
             while self.transInThread:
                 time.sleep(2)
