@@ -29,14 +29,13 @@ For files in MaxReset and Assigned:
   o wait until all are treated before proceeding
 - Check that none of the job input data has BK descendants for the current production
   o if the data has a replica flag it means all was uploaded successfully - should be investigated by hand
-  o if there is no replica flag can proceed with file removal from LFC / storage (can be disabled by flag)
+  o if there is no replica flag can proceed with file removal from FC / storage (can be disabled by flag)
 - Mark the recovered input file status as 'Unused' in the ProductionDB if they were not in MaxReset
 """
 import datetime
 
 from DIRAC import S_OK
 from DIRAC.Core.Base.AgentModule import AgentModule
-from DIRAC.Core.Utilities.Time import dateTime
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from DIRAC.RequestManagementSystem.Client.ReqClient import ReqClient
 
@@ -82,7 +81,7 @@ class DataRecoveryAgent(AgentModule):
         """The main execution method."""
         # Configuration settings
         self.enableFlag = self.am_getOption("EnableFlag", True)
-        self.log.verbose("Enable flag is %s" % self.enableFlag)
+        self.log.verbose(f"Enable flag is {self.enableFlag}")
         if not self.transformationTypes:
             self.log.warn("No transformation types to look for... aborting")
             return S_OK()
@@ -101,7 +100,8 @@ class DataRecoveryAgent(AgentModule):
             result = self.__getEligibleTransformations(transStatus, self.transformationTypes)
             if not result["OK"]:
                 self.log.error(
-                    "Could not obtain eligible transformations", "Status '%s': %s" % (transStatus, result["Message"])
+                    "Could not obtain eligible transformations",
+                    f"Status '{transStatus}': {result['Message']}",
                 )
                 return result
 
@@ -115,16 +115,16 @@ class DataRecoveryAgent(AgentModule):
             transformationDict.update(result["Value"])
 
         self.log.info(
-            "Selected %d transformations of types %s" % (len(transformationDict), ", ".join(self.transformationTypes))
+            f"Selected {len(transformationDict)} transformations of types {', '.join(self.transformationTypes)}"
         )
-        self.log.verbose("Transformations selected:\n%s" % (", ".join(transformationDict)))
+        self.log.verbose(f"Transformations selected:\n{', '.join(transformationDict)}")
 
         for transformation, typeName in transformationDict.items():
-            self.transLogger = self.log.getSubLogger("Trans-%s" % transformation)
+            self.transLogger = self.log.getSubLogger(f"Trans-{transformation}")
             result = self.__selectTransformationFiles(transformation, fileSelectionStatus)
             if not result["OK"]:
                 self.transLogger.error(
-                    "Could not select files for transformation", "%s: %s" % (transformation, result["Message"])
+                    "Could not select files for transformation", f"{transformation}: {result['Message']}"
                 )
                 continue
             fileDict = result["Value"]
@@ -135,25 +135,25 @@ class DataRecoveryAgent(AgentModule):
                 )
                 continue
 
-            title = "Looking at transformation %s, type %s " % (transformation, typeName)
+            title = f"Looking at transformation {transformation}, type {typeName} "
             self.transLogger.info("=" * len(title))
             self.transLogger.info(title)
 
-            self.transLogger.info("Selected %d files with status %s" % (len(fileDict), ",".join(fileSelectionStatus)))
+            self.transLogger.info(f"Selected {len(fileDict)} files with status {','.join(fileSelectionStatus)}")
             result = self.__obtainWMSJobIDs(transformation, fileDict, selectDelay, wmsStatusList)
             if not result["OK"]:
                 self.transLogger.error("Could not obtain jobs for files of transformation", result["Message"])
                 continue
             jobFileDict = result["Value"]
             if not jobFileDict:
-                self.transLogger.info("No %s jobs found for selected files" % " or ".join(wmsStatusList))
+                self.transLogger.info(f"No {' or '.join(wmsStatusList)} jobs found for selected files")
                 continue
 
-            self.transLogger.verbose("Looking at WMS jobs %s" % ",".join(str(jobID) for jobID in jobFileDict))
+            self.transLogger.verbose(f"Looking at WMS jobs {','.join(str(jobID) for jobID in jobFileDict)}")
 
             fileCount = sum(len(lfnList) for lfnList in jobFileDict.values())
             self.transLogger.verbose(
-                "%s files are selected after examining WMS jobs" % (str(fileCount) if fileCount else "No")
+                f"{str(fileCount) if fileCount else 'No'} files are selected after examining WMS jobs"
             )
             if not fileCount:
                 continue
@@ -176,11 +176,11 @@ class DataRecoveryAgent(AgentModule):
                 continue
 
             jobsThatDidntProduceOutputs, jobsThatProducedOutputs = self.__checkdescendants(transformation, jobFileDict)
-            title = "======== Transformation %s: results ========" % transformation
+            title = f"======== Transformation {transformation}: results ========"
             self.transLogger.info(title)
-            self.transLogger.info("\tTotal jobs that can be updated now: %d" % len(jobsThatDidntProduceOutputs))
+            self.transLogger.info(f"\tTotal jobs that can be updated now: {len(jobsThatDidntProduceOutputs)}")
             if jobsThatProducedOutputs:
-                self.transLogger.info("\t%d jobs have descendants" % len(jobsThatProducedOutputs))
+                self.transLogger.info(f"\t{len(jobsThatProducedOutputs)} jobs have descendants")
             else:
                 self.transLogger.info("\tNo jobs have descendants")
 
@@ -189,14 +189,14 @@ class DataRecoveryAgent(AgentModule):
             filesWithDescendants = []
             for job, fileList in jobFileDict.items():
                 if job in jobsThatDidntProduceOutputs:
-                    recoverableFiles = set(lfn for lfn in fileList if fileDict[lfn][1] not in unrecoverableStatus)
+                    recoverableFiles = {lfn for lfn in fileList if fileDict[lfn][1] not in unrecoverableStatus}
                     filesToUpdate += list(recoverableFiles)
                     filesMaxReset += list(set(fileList) - recoverableFiles)
                 elif job in jobsThatProducedOutputs:
                     filesWithDescendants += fileList
 
             if filesToUpdate:
-                self.transLogger.info("\tUpdating %d files to '%s'" % (len(filesToUpdate), updateStatus))
+                self.transLogger.info(f"\tUpdating {len(filesToUpdate)} files to '{updateStatus}'")
                 result = self.__updateFileStatus(transformation, filesToUpdate, updateStatus)
                 if not result["OK"]:
                     self.transLogger.error("\tRecoverable files were not updated", result["Message"])
@@ -212,7 +212,7 @@ class DataRecoveryAgent(AgentModule):
                     "\t!!!!!!!! Transformation has descendants for files that are not marked as processed !!!!!!!!"
                 )
                 self.transLogger.warn("\tFiles with descendants:", ",".join(filesWithDescendants))
-                self.transLogger.info("\tUpdating %d files to '%s'" % (len(filesWithDescendants), "Processed"))
+                self.transLogger.info(f"\tUpdating {len(filesWithDescendants)} files to '{'Processed'}'")
                 result = self.__updateFileStatus(transformation, filesWithDescendants, "Processed")
                 if not result["OK"]:
                     self.transLogger.error("\tRecovered files were not updated", result["Message"])
@@ -225,7 +225,7 @@ class DataRecoveryAgent(AgentModule):
         res = self.transClient.getTransformations(condDict={"Status": status, "Type": typeList})
         if not res["OK"]:
             return res
-        transformations = dict((str(prod["TransformationID"]), prod["Type"]) for prod in res["Value"])
+        transformations = {str(prod["TransformationID"]): prod["Type"] for prod in res["Value"]}
         return S_OK(transformations)
 
     #############################################################################
@@ -245,7 +245,7 @@ class DataRecoveryAgent(AgentModule):
             missingKeys = mandatoryKeys - set(fileDict)
             if missingKeys:
                 for key in missingKeys:
-                    self.transLogger.warn("%s is mandatory, but missing for:\n\t%s" % (key, str(fileDict)))
+                    self.transLogger.warn(f"{key} is mandatory, but missing for:\n\t{str(fileDict)}")
             else:
                 resDict[fileDict["LFN"]] = (fileDict["TaskID"], fileDict["Status"])
         return S_OK(resDict)
@@ -261,14 +261,14 @@ class DataRecoveryAgent(AgentModule):
         in Unused status (not Processed for example) that will not be
         touched.
         """
-        taskIDList = sorted(set(taskID for taskID, _status in fileDict.values()))
+        taskIDList = sorted({taskID for taskID, _status in fileDict.values()})
         self.transLogger.verbose(
             "The following %d task IDs correspond to the selected files:\n%s"
             % (len(taskIDList), ", ".join(str(taskID) for taskID in taskIDList))
         )
 
         jobFileDict = {}
-        olderThan = dateTime() - datetime.timedelta(hours=selectDelay)
+        olderThan = datetime.datetime.utcnow() - datetime.timedelta(hours=selectDelay)
 
         res = self.transClient.getTransformationTasks(
             condDict={"TransformationID": transformation, "TaskID": taskIDList},
@@ -276,7 +276,7 @@ class DataRecoveryAgent(AgentModule):
             timeStamp="LastUpdateTime",
         )
         if not res["OK"]:
-            self.transLogger.error("getTransformationTasks returned an error", "%s" % res["Message"])
+            self.transLogger.error("getTransformationTasks returned an error", f"{res['Message']}")
             return res
 
         mandatoryKeys = {"TaskID", "ExternalID", "LastUpdateTime", "ExternalStatus"}
@@ -284,7 +284,7 @@ class DataRecoveryAgent(AgentModule):
             missingKey = mandatoryKeys - set(taskDict)
             if missingKey:
                 for key in missingKey:
-                    self.transLogger.warn("Missing key %s for job dictionary:\n\t%s" % (key, str(taskDict)))
+                    self.transLogger.warn(f"Missing key {key} for job dictionary:\n\t{str(taskDict)}")
                 continue
 
             taskID = taskDict["TaskID"]
@@ -293,7 +293,7 @@ class DataRecoveryAgent(AgentModule):
 
             if not int(wmsID):
                 self.transLogger.verbose(
-                    "TaskID %s: status is %s (jobID = %s) so will not recheck with WMS" % (taskID, wmsStatus, wmsID)
+                    f"TaskID {taskID}: status is {wmsStatus} (jobID = {wmsID}) so will not recheck with WMS"
                 )
                 continue
 
@@ -336,11 +336,11 @@ class DataRecoveryAgent(AgentModule):
         for jobID, requestID in result["Value"]["Successful"].items():
             res = self.reqClient.getRequestStatus(requestID)
             if not res["OK"]:
-                self.transLogger.error("Failed to get Status for Request", "%s:%s" % (requestID, res["Message"]))
+                self.transLogger.error("Failed to get Status for Request", f"{requestID}:{res['Message']}")
             elif res["Value"] != "Done":
                 # If we fail to get the Status or it is not Done, we must wait, so remove the job from the list.
                 del jobFileDict[str(jobID)]
-                self.transLogger.verbose("Removing jobID %s from consideration until requests are completed" % (jobID))
+                self.transLogger.verbose(f"Removing jobID {jobID} from consideration until requests are completed")
 
         return S_OK()
 
