@@ -15,6 +15,7 @@ from the results of the test phase and emailed to the Production Manager.
 
 Author: Simon Bidwell
 """
+
 from DIRAC import S_OK, S_ERROR
 
 from DIRAC.Core.Base.AgentModule import AgentModule
@@ -68,8 +69,8 @@ class MCSimulationTestingAgent(AgentModule):
         if res["OK"]:
             idleTransformations = res["Value"]
             idleTransformations = [d.get("TransformationID") for d in idleTransformations]
-            self.log.verbose("Found %d Idle MC transformations" % len(idleTransformations))
-            self.log.debug("Idle transformations found: %s" % ",".join([str(it) for it in idleTransformations]))
+            self.log.verbose(f"Found {len(idleTransformations)} Idle MC transformations")
+            self.log.debug(f"Idle transformations found: {','.join([str(it) for it in idleTransformations])}")
         else:
             self.log.error("Call to Transformation Client service failed", res["Message"])
             return res
@@ -79,7 +80,7 @@ class MCSimulationTestingAgent(AgentModule):
         if res["OK"]:
             testingSimulations = res["Value"]
             testingSimulations = [pair[0] for pair in testingSimulations]
-            self.log.verbose("Found %d MC transformations undergoing a testing phase" % len(testingSimulations))
+            self.log.verbose(f"Found {len(testingSimulations)} MC transformations undergoing a testing phase")
             self.log.debug(
                 "MC transformations found undergoing a testing phase: %s"
                 % ",".join([str(ts) for ts in testingSimulations])
@@ -238,7 +239,7 @@ class MCSimulationTestingAgent(AgentModule):
             self.log.error("Error calling bkClient", res["Message"])
             return S_ERROR(res["Message"])
         successful = res["Value"]["Successful"]
-        self.log.debug("Successful tasks: %s" % str(successful))
+        self.log.debug(f"Successful tasks: {str(successful)}")
         if not successful:
             self.log.error("There are no successful tasks")
             return S_ERROR("There are no successful tasks")
@@ -315,7 +316,7 @@ class MCSimulationTestingAgent(AgentModule):
                 if not res["OK"]:
                     self.log.error("Call to removeStoredJobDescription failed", res["Message"])
                     return res
-                self.log.info("Transformation %s has an updated body and Status set to active" % transID)
+                self.log.info(f"Transformation {transID} has an updated body and Status set to active")
                 return S_OK()
             else:
                 self.log.error(
