@@ -10,6 +10,7 @@
 ###############################################################################
 """TransformationAgent is and LHCb class just for overwriting some of the DIRAC
 methods."""
+
 from DIRAC import gLogger, S_OK, S_ERROR
 from DIRAC.ResourceStatusSystem.Client.ResourceManagementClient import ResourceManagementClient
 from DIRAC.TransformationSystem.Agent.TransformationAgent import TransformationAgent as DIRACTransformationAgent
@@ -58,18 +59,18 @@ class TransformationAgent(DIRACTransformationAgent):
         try:
             plugModule = __import__(self.pluginLocation, globals(), locals(), ["TransformationPlugin"])
         except ImportError as x:
-            gLogger.exception("%s.__generatePluginObject: Failed to import 'TransformationPlugin'" % AGENT_NAME, "", x)
+            gLogger.exception(f"{AGENT_NAME}.__generatePluginObject: Failed to import 'TransformationPlugin'", "", x)
             return S_ERROR()
         try:
             oPlugin = getattr(plugModule, "TransformationPlugin")(
-                "%s" % plugin,
+                f"{plugin}",
                 dataManager=clients["DataManager"],
                 transClient=clients["TransformationClient"],
                 bkClient=clients["BookkeepingClient"],
                 rmClient=clients["ResourceManagementClient"],
             )
         except Exception as x:  # pylint: disable=broad-except
-            gLogger.exception("%s.__generatePluginObject: Failed to create %s()." % (AGENT_NAME, plugin), "", x)
+            gLogger.exception(f"{AGENT_NAME}.__generatePluginObject: Failed to create {plugin}().", "", x)
             return S_ERROR()
         oPlugin.workDirectory = self.workDirectory
         oPlugin.pluginCallback = self.pluginCallback
