@@ -9,6 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Simple extension of base class."""
+
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 from DIRAC.TransformationSystem.Agent.ValidateOutputDataAgent import (
@@ -50,7 +51,7 @@ class ValidateOutputDataAgent(DIRACValidateOutputDataAgent):
     def checkTransformationIntegrity(self, prodID):
         """This method contains the real work."""
         gLogger.info("-" * 40)
-        gLogger.info("Checking the integrity of production %s" % prodID)
+        gLogger.info(f"Checking the integrity of production {prodID}")
         gLogger.info("-" * 40)
 
         res = self.getTransformationDirectories(prodID)
@@ -85,7 +86,7 @@ class ValidateOutputDataAgent(DIRACValidateOutputDataAgent):
             gLogger.error(res["Message"])
             return res
         for directory, error in res["Value"]["Failed"]:
-            gLogger.error("Failed to determine existance of directory", "%s %s" % (directory, error))
+            gLogger.error("Failed to determine existance of directory", f"{directory} {error}")
         if res["Value"]["Failed"]:
             return S_ERROR("Failed to determine the existance of directories")
         directoryExists = res["Value"]["Successful"]
