@@ -9,16 +9,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit test for the MCExtensionAgent."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import copy
 import importlib
 import unittest
 
-from mock import Mock, MagicMock
+from unittest.mock import Mock, MagicMock
 from DIRAC import S_OK, S_ERROR, gLogger
 
 from LHCbDIRAC.TransformationSystem.Agent.MCExtensionAgent import MCExtensionAgent
