@@ -9,14 +9,10 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test class for the MCSimulationTestingAgent."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import importlib
 import unittest
-from mock import MagicMock, patch
+from unittest.mock import MagicMock, patch
 
 from LHCbDIRAC.TransformationSystem.Agent.MCSimulationTestingAgent import MCSimulationTestingAgent
 from LHCbDIRAC.ProductionManagementSystem.Client.Production import Production
@@ -26,7 +22,7 @@ from DIRAC import gLogger
 try:
     with open("./src/LHCbDIRAC/TransformationSystem/Agent/test/testWF.xml") as fd:
         storedJobDescription = fd.read()
-except IOError:
+except OSError:
     with open("./TransformationSystem/Agent/test/testWF.xml") as fd:
         storedJobDescription = fd.read()
 
