@@ -9,14 +9,10 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test class for plugins."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # imports
 import unittest
 import importlib
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 from DIRAC import gLogger
 
