@@ -10,6 +10,7 @@
 ###############################################################################
 """Client module to deal with transformations, but mostly dedicated to
 DataManipulation (e.g.: replications)"""
+
 from DIRAC import gLogger, S_OK, S_ERROR
 from DIRAC.TransformationSystem.Client.Transformation import Transformation as DIRACTransformation
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
@@ -37,7 +38,7 @@ class Transformation(DIRACTransformation):
         else:
             self.transClient = transClientIn
 
-        super(Transformation, self).__init__(transID=transID, transClient=self.transClient)
+        super().__init__(transID=transID, transClient=self.transClient)
 
     #############################################################################
 
@@ -50,7 +51,7 @@ class Transformation(DIRACTransformation):
         res = bkClient.getFiles(bkQuery)
         if not res["OK"]:
             return self._errorReport(res, "Failed to perform BK query")
-        gLogger.info("The supplied query returned %d files" % len(res["Value"]))
+        gLogger.info(f"The supplied query returned {len(res['Value'])} files")
         if printOutput:
             self._prettyPrint(res)
         return S_OK(res["Value"])
@@ -102,7 +103,7 @@ class Transformation(DIRACTransformation):
 
     def addTransformation(self, addFiles=True, printOutput=False):
         """Add a transformation, using TransformationClient()"""
-        res = super(Transformation, self).addTransformation(addFiles, printOutput)
+        res = super().addTransformation(addFiles, printOutput)
         if res["OK"]:
             transID = res["Value"]
         else:
@@ -132,5 +133,5 @@ class Transformation(DIRACTransformation):
             return S_OK()
         if resolveSEGroup(seList):
             return S_OK()
-        gLogger.error("Some SEs are unknown in %s" % ",".join(seList))
+        gLogger.error(f"Some SEs are unknown in {','.join(seList)}")
         return S_ERROR("Some StorageElements not known")
