@@ -13,6 +13,7 @@
 This is a very simple extension to the DIRAC one
 """
 from DIRAC import S_OK, gLogger
+from DIRAC.Core.Utilities.JEncode import strToIntDict
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient as DIRACTransformationClient
 from LHCbDIRAC.ProductionManagementSystem.Utilities.StateMachine import ProductionsStateMachine
@@ -59,7 +60,7 @@ class TransformationClient(DIRACTransformationClient):
         bkQuery=None,
         timeout=1800,
     ):
-        res = super(TransformationClient, self).addTransformation(
+        res = super().addTransformation(
             transName,
             description,
             longDescription,
@@ -84,10 +85,16 @@ class TransformationClient(DIRACTransformationClient):
         if bkQuery:
             res = self._getRPC().addBookkeepingQuery(transID, bkQuery)
             if not res["OK"]:
-                gLogger.error("Failed to publish BKQuery for transformation", "%s %s" % (transID, res["Message"]))
+                gLogger.error("Failed to publish BKQuery for transformation", f"{transID} {res['Message']}")
                 return res
         return S_OK(transID)
 
+    def getDestinationForRun(self, runIDs):
+        retVal = self._getRPC().getDestinationForRun(runIDs)
+        if not retVal["OK"]:
+            return retVal
+        return S_OK(strToIntDict(retVal["Value"]))
+
     def _applyTransformationStatusStateMachine(self, transIDAsDict, dictOfProposedstatus, force):
         """Performs a state machine check for productions when asked to change the
         status."""
