@@ -29,10 +29,10 @@ from DIRAC.Core.Utilities.List import intListToString, breakListIntoChunks
 class TransformationDB(DIRACTransformationDB):
     """Extension of the DIRAC Transformation DB."""
 
-    def __init__(self, dbname=None, dbconfig=None, dbIn=None):
+    def __init__(self, dbname=None, dbconfig=None, dbIn=None, parentLogger=None):
         """The standard constructor takes the database name (dbname) and the name
         of the configuration section (dbconfig)"""
-        DIRACTransformationDB.__init__(self, dbname, dbconfig, dbIn)
+        DIRACTransformationDB.__init__(self, dbname, dbconfig, dbIn, parentLogger=parentLogger)
         self.lock = threading.Lock()
         self.queryFields = (
             "SimulationConditions",
@@ -74,17 +74,17 @@ class TransformationDB(DIRACTransformationDB):
         connection = res["Value"]["Connection"]
 
         # deleting runs metadata
-        req = "SELECT DISTINCT RunNumber FROM TransformationRuns WHERE TransformationID = %s" % transID
+        req = f"SELECT DISTINCT RunNumber FROM TransformationRuns WHERE TransformationID = {transID}"
         res = self._query(req)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         runsMaybeToDelete = [r[0] for r in res["Value"]]
 
-        req = "SELECT DISTINCT RunNumber FROM TransformationRuns WHERE TransformationID != %s" % transID
+        req = f"SELECT DISTINCT RunNumber FROM TransformationRuns WHERE TransformationID != {transID}"
         res = self._query(req)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         runsToKeep = [r[0] for r in res["Value"]]
 
@@ -145,7 +145,7 @@ class TransformationDB(DIRACTransformationDB):
         """Simply set the hot flag."""
         connection = self.__getConnection(connection)
         return self._update(
-            "UPDATE Transformations SET Hot = %s WHERE TransformationID = %d" % (flag, int(transID)), connection
+            "UPDATE Transformations SET Hot = %s WHERE TransformationID = %d" % (flag, int(transID)), conn=connection
         )
 
     #############################################################################
@@ -155,7 +155,7 @@ class TransformationDB(DIRACTransformationDB):
     def deleteBookkeepingQuery(self, transID, connection=False):
         """Delete the specified query from the database."""
         connection = self.__getConnection(connection)
-        return self._update("DELETE FROM BkQueriesNew WHERE TransformationID=%d" % int(transID), connection)
+        return self._update("DELETE FROM BkQueriesNew WHERE TransformationID=%d" % int(transID), conn=connection)
 
     def setBookkeepingQueryEndRun(self, transID, runNumber, connection=False):
         """Set the EndRun for the supplied transformation."""
@@ -177,7 +177,7 @@ class TransformationDB(DIRACTransformationDB):
     ON DUPLICATE KEY UPDATE ParameterValue = %d"
             % (transID, runNumber, runNumber)
         )
-        return self._update(req, connection)
+        return self._update(req, conn=connection)
 
     def setBookkeepingQueryStartRun(self, transID, runNumber, connection=False):
         """Set the StartRun for the supplied transformation."""
@@ -199,7 +199,7 @@ class TransformationDB(DIRACTransformationDB):
     ON DUPLICATE KEY UPDATE ParameterValue = %d"
             % (transID, runNumber, runNumber)
         )
-        return self._update(req, connection)
+        return self._update(req, conn=connection)
 
     def addBookkeepingQueryRunList(self, transID, runList, connection=False):
         """Adds the list of runs."""
@@ -218,12 +218,12 @@ class TransformationDB(DIRACTransformationDB):
             if runNumbers != "All":
                 if not isinstance(runNumbers, list):
                     runNumbers = [runNumbers]
-                runsInQuery = set(int(run) for run in runNumbers)
+                runsInQuery = {int(run) for run in runNumbers}
             else:
                 return S_ERROR("Cannot add runs to 'All'")
-            runsInQuery |= set(int(run) for run in runList)
+            runsInQuery |= {int(run) for run in runList}
         except ValueError as e:
-            return S_ERROR("RunList invalid: %s" % repr(e))
+            return S_ERROR(f"RunList invalid: {repr(e)}")
         if len(runsInQuery) > 999:
             return S_ERROR("RunList bigger the 1000 not allowed because of Oracle limitations!!!")
         value = ";;;".join(str(x) for x in sorted(runsInQuery))
@@ -231,7 +231,7 @@ class TransformationDB(DIRACTransformationDB):
             "UPDATE BkQueriesNew SET ParameterValue='%s' WHERE TransformationID = %d AND ParameterName='RunNumbers'"
             % (value, transID)
         )
-        self._update(req, connection)
+        self._update(req, conn=connection)
         return S_OK()
 
     def addBookkeepingQuery(self, transID, queryDict, connection=False):
@@ -247,7 +247,7 @@ class TransformationDB(DIRACTransformationDB):
             else:
                 value = queryDict[field]
 
-                if isinstance(value, six.integer_types + (float,)):
+                if isinstance(value, (int,) + (float,)):
                     value = str(value)
                 if isinstance(value, (list, tuple)):
                     value = ";;;".join(str(x) for x in value)
@@ -259,7 +259,7 @@ class TransformationDB(DIRACTransformationDB):
             req += "(%d,'%s','%s'), " % (transID, field, value)
         req = req.strip().rstrip(",")
 
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             return res
         return S_OK(transID)
@@ -269,8 +269,8 @@ class TransformationDB(DIRACTransformationDB):
         connection = self.__getConnection(connection)
         req = "SELECT DISTINCT TransformationID FROM BkQueriesNew"
         if transIDs:
-            req = req + " WHERE TransformationID IN (%s)" % (", ".join(str(t) for t in transIDs))
-        res = self._query(req, connection)
+            req = req + f" WHERE TransformationID IN ({', '.join(str(t) for t in transIDs)})"
+        res = self._query(req, conn=connection)
         if res["OK"]:
             res = S_OK([tID[0] for tID in res["Value"]])
         return res
@@ -279,7 +279,7 @@ class TransformationDB(DIRACTransformationDB):
         """Get the bookkeeping query parameters."""
         connection = self.__getConnection(connection)
         req = "SELECT * FROM BkQueriesNew WHERE TransformationID=%d" % (int(transID))
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
             return res
         if not res["Value"]:
@@ -305,11 +305,11 @@ class TransformationDB(DIRACTransformationDB):
         """extends DIRAC.__insertExistingTransformationFiles Does not add userSE
         and adds runNumber."""
 
-        gLogger.info("Inserting %d files in TransformationFiles" % len(fileTuplesList))
+        gLogger.info(f"Inserting {len(fileTuplesList)} files in TransformationFiles")
         # splitting in various chunks, in case it is too big
         for fileTuples in breakListIntoChunks(fileTuplesList, 10000):
             gLogger.verbose(
-                "Adding first %d files in TransformationFiles (out of %d)" % (len(fileTuples), len(fileTuplesList))
+                f"Adding first {len(fileTuples)} files in TransformationFiles (out of {len(fileTuplesList)})"
             )
             req = "INSERT INTO TransformationFiles (TransformationID,Status,TaskID,FileID, \
       TargetSE,LastUpdate,RunNumber,Size,FileType,RAWAncestors) VALUES"
@@ -335,7 +335,7 @@ class TransformationDB(DIRACTransformationDB):
                 if status not in ("Removed",):
                     candidates = True
                     if not re.search("-", status):
-                        status = "%s-inherited" % status
+                        status = f"{status}-inherited"
                         if taskID:
                             taskID = 1000000 * int(originalID) + int(taskID)
                     req = "%s (%d,'%s',%s,%d,'%s',UTC_TIMESTAMP(),%s,%s,'%s',%s)," % (
@@ -353,7 +353,7 @@ class TransformationDB(DIRACTransformationDB):
             if not candidates:
                 continue
             req = req.rstrip(",")
-            res = self._update(req, connection)
+            res = self._update(req, conn=connection)
             if not res["OK"]:
                 return res
 
@@ -404,7 +404,7 @@ class TransformationDB(DIRACTransformationDB):
                     foundLfns.add(lfn)
                 else:
                     gLogger.error(
-                        "Supplied file not in %s status but %s" % (self.allowedStatusForTasks, fileDict["Status"]), lfn
+                        f"Supplied file not in {self.allowedStatusForTasks} status but {fileDict['Status']}", lfn
                     )
             unavailableLfns = set(lfns) - foundLfns
             if unavailableLfns:
@@ -418,20 +418,16 @@ class TransformationDB(DIRACTransformationDB):
      (%d,'%s','%d','%s', UTC_TIMESTAMP(), UTC_TIMESTAMP(),%d);"
             % (transID, "Created", 0, se, runID)
         )
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             self.lock.release()
             gLogger.error("Failed to publish task for transformation", res["Message"])
             return res
 
-        # The second command is ok for the MyISAM schema, but it doesn't work with InnoDB schema.
-        # With InnoDB, TaskID is computed by a trigger, which sets the local variable @last (per connection)
+        # TaskID is computed by a trigger, which sets the local variable @last (per connection)
         # @last is the last insert TaskID. With multi-row inserts, will be the first new TaskID inserted.
         # The trigger TaskID_Generator must be present with the InnoDB schema (defined in TransformationDB.sql)
-        if self.isTransformationTasksInnoDB:
-            res = self._query("SELECT @last;", connection)
-        else:
-            res = self._query("SELECT LAST_INSERT_ID();", connection)
+        res = self._query("SELECT @last;", conn=connection)
 
         self.lock.release()
         if not res["OK"]:
@@ -473,13 +469,13 @@ class TransformationDB(DIRACTransformationDB):
             for key, val in condDict.items():
                 if key in self.transRunParams:
                     selectDict[key] = val
-        req = "SELECT %s FROM TransformationRuns %s" % (
+        req = "SELECT {} FROM TransformationRuns {}".format(
             intListToString(self.transRunParams),
             self.buildCondition(
                 selectDict, older=older, newer=newer, timeStamp=timeStamp, orderAttribute=orderAttribute, limit=limit
             ),
         )
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
             return res
         webList = []
@@ -490,7 +486,7 @@ class TransformationDB(DIRACTransformationDB):
             transDict = {}
             for param, item in zip(self.transRunParams, row):
                 transDict[param] = item
-                rList.append(item if isinstance(item, six.integer_types) else str(item))
+                rList.append(item if isinstance(item, int) else str(item))
             webList.append(rList)
             resultList.append(transDict)
         result = S_OK(resultList)
@@ -537,7 +533,7 @@ class TransformationDB(DIRACTransformationDB):
     WHERE TransformationID = %d and RunNumber = %d"
             % (transID, runID)
         )
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             gLogger.error("Failed to update TransformationRuns table with LastUpdate", res["Message"])
         elif not res["Value"]:
@@ -557,10 +553,10 @@ class TransformationDB(DIRACTransformationDB):
         fileIDs = res["Value"][0]
         rDict = {fileID: lfnsDict[lfn] for fileID, lfn in fileIDs.items()}
         for fID, param in rDict.items():
-            values = ",".join("`%s` = NULL" % k if v is None else "`%s` = '%s'" % (k, v) for k, v in param.items())
+            values = ",".join(f"`{k}` = NULL" if v is None else f"`{k}` = '{v}'" for k, v in param.items())
             query = "UPDATE TransformationFiles SET %s WHERE TransformationID = %d AND FileID = %d"
             query %= (values, transID, fID)
-            res = self._update(query, connection)
+            res = self._update(query, conn=connection)
             if not res["OK"]:
                 gLogger.error("Failed to update TransformationFiles table", res["Message"])
                 return res
@@ -581,7 +577,7 @@ class TransformationDB(DIRACTransformationDB):
     WHERE TransformationID = %d and RunNumber in (%s)"
             % (status, transID, intListToString(runIDs))
         )
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             gLogger.error("Failed to update TransformationRuns table with Status", res["Message"])
         return res
@@ -597,7 +593,7 @@ class TransformationDB(DIRACTransformationDB):
     WHERE TransformationID = %d and RunNumber = %d"
             % (selectedSite, transID, runID)
         )
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             gLogger.error("Failed to update TransformationRuns table with SelectedSite", res["Message"])
         elif not res["Value"]:
@@ -620,16 +616,16 @@ class TransformationDB(DIRACTransformationDB):
       VALUES (%d,%d,'%s',UTC_TIMESTAMP())"
                 % (transID, runID, status)
             )
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             gLogger.error("Failed to insert to TransformationRuns table", res["Message"])
         return res
 
     def __cleanTransformationRuns(self, transID, connection=False):
-        req = "DELETE  FROM TransformationRuns WHERE TransformationID = %s" % transID
-        res = self._update(req, connection)
+        req = f"DELETE  FROM TransformationRuns WHERE TransformationID = {transID}"
+        res = self._update(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
         return res
 
     #############################################################################
@@ -659,10 +655,10 @@ class TransformationDB(DIRACTransformationDB):
         if isinstance(runID, str):
             runID = int(runID)
         req = "INSERT INTO RunsMetadata (RunNumber, Name, Value) VALUES(%d, '%s', '%s')" % (runID, name, value)
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             if "1062: Duplicate entry" in res["Message"]:
-                gLogger.debug("Failed to insert to RunsMetadata table: %s" % res["Message"])
+                gLogger.debug(f"Failed to insert to RunsMetadata table: {res['Message']}")
                 return S_OK()
             else:
                 gLogger.error("Failed to insert to RunsMetadata table", res["Message"])
@@ -674,7 +670,7 @@ class TransformationDB(DIRACTransformationDB):
         if isinstance(runID, str):
             runID = int(runID)
         req = "UPDATE RunsMetadata SET Value = %s WHERE RunNumber = %d AND Name = '%s'" % (value, runID, name)
-        res = self._update(req, connection)
+        res = self._update(req, conn=connection)
         if not res["OK"]:
             gLogger.error("Failed to update RunsMetadata table", res["Message"])
             return res
@@ -695,10 +691,10 @@ class TransformationDB(DIRACTransformationDB):
         except ValueError as e:
             gLogger.exception("Invalid run number", lException=e)
             return S_ERROR("Invalid run number")
-        req = "SELECT RunNumber, Name, Value FROM RunsMetadata WHERE RunNumber IN (%s)" % runIDs
-        res = self._query(req, connection)
+        req = f"SELECT RunNumber, Name, Value FROM RunsMetadata WHERE RunNumber IN ({runIDs})"
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             dictOfNameValue = {}
@@ -712,20 +708,20 @@ class TransformationDB(DIRACTransformationDB):
         RunIDs can be a list.
         """
         connection = self.__getConnection(connection)
-        req = "DELETE FROM RunsMetadata %s" % self.buildCondition(condDict)
-        res = self._update(req, connection)
+        req = f"DELETE FROM RunsMetadata {self.buildCondition(condDict)}"
+        res = self._update(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         return S_OK()
 
     def getRunsInCache(self, condDict=None, connection=False):
         """get which runNumnber are cached."""
         connection = self.__getConnection(connection)
-        req = "SELECT DISTINCT RunNumber FROM RunsMetadata %s" % self.buildCondition(condDict)
-        res = self._query(req, connection)
+        req = f"SELECT DISTINCT RunNumber FROM RunsMetadata {self.buildCondition(condDict)}"
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             return S_OK([run[0] for run in res["Value"]])
@@ -738,10 +734,10 @@ class TransformationDB(DIRACTransformationDB):
     def getDestinationForRun(self, runIDs, connection=False):
         """get destination of a run or a list of runs."""
         connection = self.__getConnection(connection)
-        req = "SELECT * FROM RunDestination WHERE RunNumber IN (%s)" % (", ".join(str(runID) for runID in runIDs))
-        res = self._query(req, connection)
+        req = f"SELECT * FROM RunDestination WHERE RunNumber IN ({', '.join(str(runID) for runID in runIDs)})"
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         return S_OK(dict(res["Value"]) if res["Value"] else {})
 
@@ -749,9 +745,9 @@ class TransformationDB(DIRACTransformationDB):
         """set destination of a run."""
         connection = self.__getConnection(connection)
         req = "INSERT INTO RunDestination (RunNumber, Destination) VALUES (%d, '%s')" % (runID, destination)
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
         return res
 
     #############################################################################
@@ -770,9 +766,9 @@ class TransformationDB(DIRACTransformationDB):
             transformationID,
             jobDescription,
         )
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             return S_OK()
@@ -781,9 +777,9 @@ class TransformationDB(DIRACTransformationDB):
         """get the job description for transformationID."""
         connection = self.__getConnection(connection)
         req = "SELECT * FROM StoredJobDescription WHERE TransformationID = %d" % transformationID
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             return S_OK(res["Value"])
@@ -792,9 +788,9 @@ class TransformationDB(DIRACTransformationDB):
         """remove the job description for transformationID."""
         connection = self.__getConnection(connection)
         req = "DELETE FROM StoredJobDescription WHERE TransformationID = %d" % transformationID
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             return S_OK()
@@ -803,9 +799,9 @@ class TransformationDB(DIRACTransformationDB):
         """gets a list of all the stored job description transformationIDs."""
         connection = self.__getConnection(connection)
         req = "SELECT TransformationID FROM StoredJobDescription"
-        res = self._query(req, connection)
+        res = self._query(req, conn=connection)
         if not res["OK"]:
-            gLogger.error("Failure executing %s" % str(req))
+            gLogger.error(f"Failure executing {str(req)}")
             return res
         else:
             return S_OK(res["Value"])
