@@ -9,77 +9,70 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """DISET request handler for the LHCbDIRAC/TransformationDB."""
-import six
 
 from DIRAC import S_OK, S_ERROR
 from DIRAC.TransformationSystem.Service.TransformationManagerHandler import TransformationManagerHandler as TManagerBase
-from LHCbDIRAC.TransformationSystem.DB.TransformationDB import TransformationDB
 
 
-class TransformationManagerHandler(TManagerBase):
-    types_deleteTransformation = [six.integer_types]
-
-    @classmethod
-    def initializeHandler(cls, serviceInfoDict):
-        cls.database = TransformationDB("TransformationDB", "Transformation/TransformationDB")
-        return S_OK()
+class TransformationManagerHandlerMixin:
+    types_deleteTransformation = [int]
 
     def export_deleteTransformation(self, transID):
         rc = self.getRemoteCredentials()
         author = rc.get("DN", rc.get("CN"))
-        return self.database.deleteTransformation(transID, author=author)
+        return self.transformationDB.deleteTransformation(transID, author=author)
 
-    types_setHotFlag = [six.integer_types, bool]
+    types_setHotFlag = [int, bool]
 
     def export_setHotFlag(self, transID, hotFlag):
-        return self.database.setHotFlag(transID, hotFlag)
+        return self.transformationDB.setHotFlag(transID, hotFlag)
 
     #############################################################################
     #
     # Managing the BkQueries table
     #
 
-    types_addBookkeepingQuery = [six.integer_types, dict]
+    types_addBookkeepingQuery = [int, dict]
 
     @classmethod
     def export_addBookkeepingQuery(self, transID, queryDict):
-        return self.database.addBookkeepingQuery(transID, queryDict)
+        return self.transformationDB.addBookkeepingQuery(transID, queryDict)
 
-    types_deleteBookkeepingQuery = [six.integer_types]
+    types_deleteBookkeepingQuery = [int]
 
     @classmethod
     def export_deleteBookkeepingQuery(self, transID):
-        return self.database.deleteBookkeepingQuery(transID)
+        return self.transformationDB.deleteBookkeepingQuery(transID)
 
-    types_getBookkeepingQuery = [six.integer_types]
+    types_getBookkeepingQuery = [int]
 
     @classmethod
     def export_getBookkeepingQuery(self, transID):
-        return self.database.getBookkeepingQuery(transID)
+        return self.transformationDB.getBookkeepingQuery(transID)
 
     types_getTransformationsWithBkQueries = [list]
 
     @classmethod
     def export_getTransformationsWithBkQueries(self, transIDs):
-        return self.database.getTransformationsWithBkQueries(transIDs)
+        return self.transformationDB.getTransformationsWithBkQueries(transIDs)
 
-    types_setBookkeepingQueryEndRun = [six.integer_types, six.integer_types]
+    types_setBookkeepingQueryEndRun = [int, int]
 
     @classmethod
     def export_setBookkeepingQueryEndRun(self, transID, runNumber):
-        return self.database.setBookkeepingQueryEndRun(transID, runNumber)
+        return self.transformationDB.setBookkeepingQueryEndRun(transID, runNumber)
 
-    types_setBookkeepingQueryStartRun = [six.integer_types, six.integer_types]
+    types_setBookkeepingQueryStartRun = [int, int]
 
     @classmethod
     def export_setBookkeepingQueryStartRun(self, transID, runNumber):
-        return self.database.setBookkeepingQueryStartRun(transID, runNumber)
+        return self.transformationDB.setBookkeepingQueryStartRun(transID, runNumber)
 
-    types_addBookkeepingQueryRunList = [six.integer_types, [list]]
+    types_addBookkeepingQueryRunList = [int, [list]]
 
     @classmethod
     def export_addBookkeepingQueryRunList(self, transID, runList):
-        return self.database.addBookkeepingQueryRunList(transID, runList)
+        return self.transformationDB.addBookkeepingQueryRunList(transID, runList)
 
     #############################################################################
     #
@@ -90,45 +83,45 @@ class TransformationManagerHandler(TManagerBase):
 
     @classmethod
     def export_getTransformationRuns(self, condDict={}, orderAttribute=None, limit=None):
-        return self.database.getTransformationRuns(condDict, orderAttribute=orderAttribute, limit=limit)
+        return self.transformationDB.getTransformationRuns(condDict, orderAttribute=orderAttribute, limit=limit)
 
-    types_insertTransformationRun = [six.integer_types, six.integer_types, six.string_types]
+    types_insertTransformationRun = [int, int, str]
 
     @classmethod
     def export_insertTransformationRun(self, transID, runID, selectedSite=""):
-        return self.database.insertTransformationRun(transID, runID, selectedSite="")
+        return self.transformationDB.insertTransformationRun(transID, runID, selectedSite="")
 
-    types_getTransformationRunStats = [[six.integer_types, list]]
+    types_getTransformationRunStats = [[int, list]]
 
     @classmethod
     def export_getTransformationRunStats(self, transIDs):
-        if isinstance(transIDs, six.integer_types):
+        if isinstance(transIDs, int):
             transIDs = [transIDs]
-        return self.database.getTransformationRunStats(transIDs)
+        return self.transformationDB.getTransformationRunStats(transIDs)
 
-    types_addTransformationRunFiles = [six.integer_types, six.integer_types, list]
+    types_addTransformationRunFiles = [int, int, list]
 
     @classmethod
     def export_addTransformationRunFiles(self, transID, runID, lfns):
-        return self.database.addTransformationRunFiles(transID, runID, lfns)
+        return self.transformationDB.addTransformationRunFiles(transID, runID, lfns)
 
-    types_setParameterToTransformationFiles = [six.integer_types, dict]
+    types_setParameterToTransformationFiles = [int, dict]
 
     @classmethod
     def export_setParameterToTransformationFiles(self, transID, lfnsDict):
-        return self.database.setParameterToTransformationFiles(transID, lfnsDict)
+        return self.transformationDB.setParameterToTransformationFiles(transID, lfnsDict)
 
-    types_setTransformationRunStatus = [six.integer_types, [six.integer_types, list], six.string_types]
+    types_setTransformationRunStatus = [int, [int, list], str]
 
     @classmethod
     def export_setTransformationRunStatus(self, transID, runID, status):
-        return self.database.setTransformationRunStatus(transID, runID, status)
+        return self.transformationDB.setTransformationRunStatus(transID, runID, status)
 
-    types_setTransformationRunsSite = [six.integer_types, six.integer_types, six.string_types]
+    types_setTransformationRunsSite = [int, int, str]
 
     @classmethod
     def export_setTransformationRunsSite(self, transID, runID, assignedSE):
-        return self.database.setTransformationRunsSite(transID, runID, assignedSE)
+        return self.transformationDB.setTransformationRunsSite(transID, runID, assignedSE)
 
     types_getTransformationRunsSummaryWeb = [dict, list, int, int]
 
@@ -155,7 +148,7 @@ class TransformationManagerHandler(TManagerBase):
             orderAttribute = None
 
         # Get the transformations that match the selection
-        res = self.database.getTransformationRuns(
+        res = self.transformationDB.getTransformationRuns(
             condDict=selectDict, older=toDate, newer=fromDate, orderAttribute=orderAttribute
         )
         if not res["OK"]:
@@ -208,7 +201,7 @@ class TransformationManagerHandler(TManagerBase):
             transID = int(transRunDict["TransformationID"])
             if transID not in transIDs:
                 transIDs.append(transID)
-        res = self.database.getTransformationRunStats(transIDs)
+        res = self.transformationDB.getTransformationRunStats(transIDs)
         if not res["OK"]:
             return res
         transRunStatusDict = res["Value"]
@@ -233,7 +226,7 @@ class TransformationManagerHandler(TManagerBase):
                 fileDict["PercentProcessed"] = 0
             else:
                 processed = fileDict.get("Processed", 0)
-                fileDict["PercentProcessed"] = "%.1f" % (int(processed * 1000.0 / fileDict["Total"]) / 10.0)
+                fileDict["PercentProcessed"] = f"{int(processed * 1000.0 / fileDict['Total']) / 10.0:.1f}"
             for state in fileStateNames:
                 if fileDict and state in fileDict:
                     transRun.append(fileDict[state])
@@ -260,90 +253,94 @@ class TransformationManagerHandler(TManagerBase):
     # Managing the RunsMetadata table
     #
 
-    types_addRunsMetadata = [six.integer_types, dict]
+    types_addRunsMetadata = [int, dict]
 
     @classmethod
     def export_addRunsMetadata(self, runID, metadataDict):
         """insert run metadata."""
-        return self.database.setRunsMetadata(runID, metadataDict)
+        return self.transformationDB.setRunsMetadata(runID, metadataDict)
 
-    types_updateRunsMetadata = [six.integer_types, dict]
+    types_updateRunsMetadata = [int, dict]
 
     @classmethod
     def export_updateRunsMetadata(self, runID, metadataDict):
         """insert run metadata."""
-        return self.database.updateRunsMetadata(runID, metadataDict)
+        return self.transformationDB.updateRunsMetadata(runID, metadataDict)
 
-    types_getRunsMetadata = [[list, six.integer_types]]
+    types_getRunsMetadata = [[list, int]]
 
     @classmethod
     def export_getRunsMetadata(self, runID):
         """retrieve run metadata."""
-        return self.database.getRunsMetadata(runID)
+        return self.transformationDB.getRunsMetadata(runID)
 
-    types_deleteRunsMetadata = [six.integer_types]
+    types_deleteRunsMetadata = [int]
 
     @classmethod
     def export_deleteRunsMetadata(self, runID):
         """delete run metadata."""
-        return self.database.deleteRunsMetadata(runID)
+        return self.transformationDB.deleteRunsMetadata(runID)
 
     types_getRunsInCache = [dict]
 
     @classmethod
     def export_getRunsInCache(self, condDict):
         """gets what's in."""
-        return self.database.getRunsInCache(condDict)
+        return self.transformationDB.getRunsInCache(condDict)
 
     #############################################################################
     #
     # Managing the RunDestination table
     #
 
-    types_getDestinationForRun = [[six.integer_types, six.string_types, list]]
+    types_getDestinationForRun = [[int, str, list]]
 
     @classmethod
     def export_getDestinationForRun(self, runIDs):
         """retrieve run destination for a single run or a list of runs."""
-        if isinstance(runIDs, six.integer_types):
+        if isinstance(runIDs, int):
             runIDs = [runIDs]
         if isinstance(runIDs, str):
             runIDs = [int(runIDs)]
         # expecting a list of long integers
-        return self.database.getDestinationForRun(runIDs)
+        return self.transformationDB.getDestinationForRun(runIDs)
 
-    types_setDestinationForRun = [six.integer_types, six.string_types]
+    types_setDestinationForRun = [int, str]
 
     @classmethod
     def export_setDestinationForRun(self, runID, destination):
         """set run destination."""
-        return self.database.setDestinationForRun(runID, destination)
+        return self.transformationDB.setDestinationForRun(runID, destination)
 
     #############################################################################
     #
     # Managing the StoredJobDescription table
     #
 
-    types_addStoredJobDescription = [six.integer_types, six.string_types]
+    types_addStoredJobDescription = [int, str]
 
     @classmethod
     def export_addStoredJobDescription(self, transformationID, jobDescription):
-        return self.database.addStoredJobDescription(transformationID, jobDescription)
+        return self.transformationDB.addStoredJobDescription(transformationID, jobDescription)
 
-    types_getStoredJobDescription = [six.integer_types]
+    types_getStoredJobDescription = [int]
 
     @classmethod
     def export_getStoredJobDescription(self, transformationID):
-        return self.database.getStoredJobDescription(transformationID)
+        return self.transformationDB.getStoredJobDescription(transformationID)
 
-    types_removeStoredJobDescription = [six.integer_types]
+    types_removeStoredJobDescription = [int]
 
     @classmethod
     def export_removeStoredJobDescription(self, transformationID):
-        return self.database.removeStoredJobDescription(transformationID)
+        return self.transformationDB.removeStoredJobDescription(transformationID)
 
     types_getStoredJobDescriptionIDs = []
 
     @classmethod
     def export_getStoredJobDescriptionIDs(self):
-        return self.database.getStoredJobDescriptionIDs()
+        return self.transformationDB.getStoredJobDescriptionIDs()
+
+
+class TransformationManagerHandler(TransformationManagerHandlerMixin, TManagerBase):
+    pass
