@@ -11,13 +11,13 @@
 """PluginScript module holds PluginScript class, which is an extension of
 DMScript class."""
 from DIRAC import S_OK, gLogger
-from DIRAC.Core.Base import Script
+from DIRAC.Core.Base.Script import Script
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
 
 from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
 
-class Setter(object):
+class Setter:
     """Class used for setting an option: use setOption() method as a script
     setter."""
 
@@ -42,7 +42,7 @@ class PluginScript(DMScript):
     """Scripts utilities class."""
 
     def __init__(self):
-        super(PluginScript, self).__init__()
+        super().__init__()
         self.pluginParameters = {
             "Plugin=": "   Plugin name (mandatory)",
             "Type=": "   Transformation type [Replication] (Removal automatic)",
@@ -102,9 +102,9 @@ class PluginScript(DMScript):
         else:
             params = {}
         # print self.options
-        for key in set(self.options) & set(
+        for key in set(self.options) & {
             param if not param.endswith("=") else param[:-1] for param in self.additionalParameters
-        ):
+        }:
             params[key] = self.options[key]
         return params
 
