@@ -16,12 +16,13 @@ import datetime
 import random
 import time
 import sys
+import pickle
 import six
 
 from DIRAC import gConfig, gLogger, S_OK, S_ERROR
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 
-# from DIRAC.Core.Utilities.Time import timeThis
+# from DIRAC.Core.Utilities.TimeUtilities import timeThis
 from DIRAC.Core.Utilities.File import mkDir
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import DMSHelpers, resolveSEGroup
@@ -36,6 +37,7 @@ from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import BKQuery, makeBKPath
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 from LHCbDIRAC.DataManagementSystem.Client.DMScript import ProgressBar
 from LHCbDIRAC.DataManagementSystem.Client.StorageUsageClient import StorageUsageClient
+from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import getFileDescendents
 
 
 def _stripNumDirectory(dirName):
@@ -84,7 +86,7 @@ class PluginUtilities(DIRACPluginUtilities):
         else:
             self.rmClient = rmClient
 
-        super(PluginUtilities, self).__init__(
+        super().__init__(
             plugin=plugin, transClient=self.transClient, dataManager=dataManager, fc=fc, debug=debug, transID=transID
         )
 
@@ -166,15 +168,15 @@ class PluginUtilities(DIRACPluginUtilities):
         normCounters = normaliseShares(counters) if counters else {}
 
         if self.shareMetrics:
-            title += " (metrics is %s)" % self.shareMetrics
+            title += f" (metrics is {self.shareMetrics})"
         log(title)
         for se in sorted(shares):
-            if isinstance(shares[se], six.integer_types):
+            if isinstance(shares[se], int):
                 infoStr = "%s: %d " % (se.rjust(15), shares[se])
             else:
-                infoStr = "%s: %4.1f " % (se.rjust(15), shares[se])
+                infoStr = f"{se.rjust(15)}: {shares[se]:4.1f} "
             if se in counters:
-                infoStr += "| %4.1f %%" % normCounters[se]
+                infoStr += f"| {normCounters[se]:4.1f} %"
             log(infoStr)
 
     def getPluginShares(self, section=None, backupSE=None, log=None, counters=True):
@@ -197,12 +199,11 @@ class PluginUtilities(DIRACPluginUtilities):
             if not res["OK"]:
                 self.logError("Cannot get information on transformation")
                 return res
-            else:
-                transType = res["Value"]["Type"]
+            transType = res["Value"]["Type"]
             section = sharesSections.get(transType, "CPUforRAW")
         res = getShares(section)
         if not res["OK"]:
-            self.logError("There is no CS section %s" % section, res["Message"])
+            self.logError(f"There is no CS section {section}", res["Message"])
             return res
         rawFraction = {}
         if backupSE:
@@ -211,20 +212,20 @@ class PluginUtilities(DIRACPluginUtilities):
             result = getShares("RAW", normalise=True)
             if result["OK"]:
                 rawShares = result["Value"]
-                shares = dict((se, rawShares[se] * rawFraction[se]) for se in set(rawShares) & set(rawFraction))
+                shares = {se: rawShares[se] * rawFraction[se] for se in set(rawShares) & set(rawFraction)}
                 tier1Fraction = sum(shares.values())
                 shares[backupSE] = 100.0 - tier1Fraction
             else:
                 return res
-            rawPercentage = dict((se, 100.0 * val) for se, val in rawFraction.items())  # can be an iterator
+            rawPercentage = {se: 100.0 * val for se, val in rawFraction.items()}  # can be an iterator
             self.printShares(
-                "Fraction of RAW (%s) to be processed at each SE (%%):" % section, rawPercentage, counters=[], log=log
+                f"Fraction of RAW ({section}) to be processed at each SE (%):", rawPercentage, counters=[], log=log
             )
         else:
             shares = normaliseShares(res["Value"])
             log("Obtained the following target distribution shares (%):")
             for se in sorted(shares):
-                log("%s: %.1f" % (se.ljust(15), shares[se]))
+                log(f"{se.ljust(15)}: {shares[se]:.1f}")
 
         # If counters are not requested, return only shares
         if not counters:
@@ -240,13 +241,9 @@ class PluginUtilities(DIRACPluginUtilities):
         if not res["OK"]:
             self.logError("Failed to get used share", res["Message"])
             return res
-        else:
-            existingCount = res["Value"]
-            self.printShares("Target shares and usage for production (%):", shares, counters=existingCount, log=log)
-        if rawFraction:
-            return S_OK((rawFraction, shares))
-        else:
-            return S_OK((existingCount, shares))
+        existingCount = res["Value"]
+        self.printShares("Target shares and usage for production (%):", shares, counters=existingCount, log=log)
+        return S_OK((rawFraction if rawFraction else existingCount, shares))
 
     def __getRunDuration(self, runID):
         """Get the run duration."""
@@ -323,7 +320,7 @@ class PluginUtilities(DIRACPluginUtilities):
                     for ov in overlap:
                         seDict[ov] = seDict.setdefault(ov, 0) + count
                 else:
-                    self.logWarn("%s is in counters but not in required list" % se)
+                    self.logWarn(f"{se} is in counters but not in required list")
             usageDict = seDict
         if normalise:
             usageDict = normaliseShares(usageDict)
@@ -331,7 +328,7 @@ class PluginUtilities(DIRACPluginUtilities):
 
     def getMetadataFromTSorBK(self, lfns, param):
         """Get BK parameters from BK unless they are already present in the TS."""
-        if isinstance(lfns, six.string_types):
+        if isinstance(lfns, str):
             lfns = [lfns]
         filesParam = {}
         # For parameters that are in the TS files DB, no need to go to BK
@@ -346,9 +343,7 @@ class PluginUtilities(DIRACPluginUtilities):
                         filesParam[lfn] = value
 
             lfnsLeft = set(lfns) - set(filesParam)
-            self.logVerbose(
-                "Found parameter %s in transFiles for %d files, %d left" % (param, len(filesParam), len(lfnsLeft))
-            )
+            self.logVerbose(f"Found parameter {param} in transFiles for {len(filesParam)} files, {len(lfnsLeft)} left")
         else:
             lfnsLeft = lfns
 
@@ -360,7 +355,7 @@ class PluginUtilities(DIRACPluginUtilities):
                     res = self.bkClient.getFileMetadata(chunk)
                     if res["OK"]:
                         success = res["Value"]["Successful"]
-                        filesParam.update(dict((lfn, success[lfn].get(param)) for lfn in success))
+                        filesParam.update({lfn: success[lfn].get(param) for lfn in success})
                         break
                     if not loggedError:
                         self.logError("Error getting BK file metadata", res["Message"])
@@ -371,21 +366,24 @@ class PluginUtilities(DIRACPluginUtilities):
             for fileDict in self.transFiles:
                 lfn = fileDict["LFN"]
                 if lfn in success:
-                    for param in self.tsParams:
-                        par = param if param != "FileSize" else "Size"
+                    for par in self.tsParams:
+                        if par == "FileSize":
+                            par = "Size"
                         if fileDict.get(par) is None:
-                            lfnDict.setdefault(lfn, {}).update({par: success[lfn][param]})
+                            lfnDict.setdefault(lfn, {}).update({par: success[lfn][par]})
             if lfnDict:
                 res = self.transClient.setParameterToTransformationFiles(self.transID, lfnDict)
                 self.logVerbose(
-                    "Updated files metadata in TS for %d files: %s" % (len(lfnDict), "OK" if res["OK"] else "Failed")
+                    f"Updated files metadata in TS for {len(lfnDict)} files: {'OK' if res['OK'] else 'Failed'}"
                 )
 
         return filesParam
 
     def getProductions(self, processingPasses, transStatus):
         """Get the list of productions matching a given list of processing
-        passes."""
+        passes.
+        This is currently used only in _RemoveReplicasWhenProcessed, so very tailored
+        """
         # Get information about the current transformation
         transQuery = self.getTransQuery(self.transReplicas)
         if transQuery is None:
@@ -402,14 +400,15 @@ class PluginUtilities(DIRACPluginUtilities):
         bkPathList = {}
         if fullBKPaths:
             # We were given full BK paths, use them
-            bkQuery = BKQuery(bkPath, visible="All")
-            eventType = bkQuery.getEventTypeList()
-            bkPathList.update(
-                dict(
-                    (bkPath.replace("RealData", "Real Data"), bkQuery.getQueryDict()["ProcessingPass"])
-                    for bkPath in fullBKPaths
+            for bkPath in fullBKPaths:
+                bkQuery = BKQuery(bkPath, visible="All")
+                eventType = bkQuery.getEventTypeList()
+                bkPathList.update(
+                    {
+                        bkPath.replace("RealData", "Real Data"): bkQuery.getQueryDict()["ProcessingPass"]
+                        for bkPath in fullBKPaths
+                    }
                 )
-            )
 
         if relBKPaths:
             for procPass in relBKPaths:
@@ -448,9 +447,9 @@ class PluginUtilities(DIRACPluginUtilities):
             if (
                 transStatus != "Flush"
                 and not self.getCachedTimeExceeded()
-                and (now - productions["LastCall_%s" % self.transID]) < datetime.timedelta(hours=period)
+                and (now - productions[f"LastCall_{self.transID}"]) < datetime.timedelta(hours=period)
             ):
-                self.logInfo("Skip this loop (less than %s hours since last call)" % period)
+                self.logInfo(f"Skip this loop (less than {period} hours since last call)")
                 return S_OK()
         else:
             productions.setdefault("List", {})
@@ -461,13 +460,13 @@ class PluginUtilities(DIRACPluginUtilities):
                 bkQuery.setOption("ReplicaFlag", "All")
                 prods = bkQuery.getBKProductions()
                 if not prods:
-                    self.logVerbose("For bkPath %s, found no productions, wait next time" % (bkPath))
+                    self.logVerbose(f"For bkPath {bkPath}, found no productions, wait next time")
                     return S_OK()
                 productions["List"][bkPath] = []
                 for prod in prods:
                     res = self.transClient.getTransformation(prod)
                     if not res["OK"]:
-                        self.logError("Error getting transformation %s" % prod, res["Message"])
+                        self.logError(f"Error getting transformation {prod}", res["Message"])
                     else:
                         if res["Value"]["Status"] != "Cleaned":
                             productions["List"][bkPath].append(int(prod))
@@ -478,7 +477,7 @@ class PluginUtilities(DIRACPluginUtilities):
             productions["CacheTime"] = now
 
         # Record time of last call and update the cache
-        productions["LastCall_%s" % self.transID] = now
+        productions[f"LastCall_{self.transID}"] = now
         self.setCachedProductions(productions)
         # Return the list of BK paths (with their processing passes),
         #   the list of productions and the depth of current processing pass
@@ -507,14 +506,14 @@ get from BK"
                         self.filesParam[lfn] = paramValue
                         nCached += 1
             self.logVerbose("Obtained %s of %d files from disk cache" % (param, nCached))
-        filesParam = dict((lfn, self.filesParam[lfn]) for lfn in lfns & set(self.filesParam))
+        filesParam = {lfn: self.filesParam[lfn] for lfn in lfns & set(self.filesParam)}
         # Get parameter for LFNs not cached yet
         lfns = lfns - set(filesParam)
         if lfns:
             resDict = self.getMetadataFromTSorBK(list(lfns), param)
             filesParam.update(resDict)
             self.filesParam.update(resDict)
-            self.logVerbose("Obtained %s of %d files from TS or BK" % (param, len(resDict)))
+            self.logVerbose(f"Obtained {param} of {len(resDict)} files from TS or BK")
         return filesParam
 
     def getStorageFreeSpace(self, candSEs):
@@ -522,7 +521,7 @@ get from BK"
         weight = {}
         for se in candSEs:
             weight[se] = self.getRMFreeSpace(se)
-        self.logVerbose("Free space from RSS: %s" % weight)
+        self.logVerbose(f"Free space from RSS: {weight}")
         return weight
 
     def getRMFreeSpace(self, se):
@@ -538,7 +537,7 @@ get from BK"
         if not (se in self.freeSpace) or self.freeSpace[se]["LastCheckTime"] < cacheLimit:
             res = self.rmClient.selectSpaceTokenOccupancyCache(token=se)
             if not res["OK"] or not res["Value"]:
-                self.logError("Error when getting space for SE %s" % (se,), res["Message"])
+                self.logError(f"Error when getting space for SE {se}", res["Message"])
                 return 0
 
             self.freeSpace[se] = dict(zip(res["Columns"], res["Value"][0]))
@@ -568,13 +567,13 @@ get from BK"
                     weights[se] = total
                     orderedSEs.append(se)
                 rand = random.uniform(0.0, total)
-                self.logDebug("List of ordered SEs (random number is %.1f out of %.1f)" % (rand, total))
+                self.logDebug(f"List of ordered SEs (random number is {rand:.1f} out of {total:.1f})")
                 for se in orderedSEs:
-                    self.logDebug("%s: %.1f" % (se, weights[se]))
+                    self.logDebug(f"{se}: {weights[se]:.1f}")
                 for se in orderedSEs:
                     if rand <= weights[se]:
                         break
-            self.logDebug("Selected SE is %s" % se)
+            self.logDebug(f"Selected SE is {se}")
             rankedSEs.append(se)
             weightForSEs.pop(se)
         return rankedSEs
@@ -603,7 +602,7 @@ get from BK"
             archiveActiveSEs = [se for se in archiveActiveSEs if se not in archiveExisting]
             # Set existing archive SEs first, then other archives (check against all archives)
             candidateSEs = self.selectSEs(archiveExisting + self.rankSEs(archiveActiveSEs), nbArchive, existingSEs)
-            self.logVerbose("Selected ArchiveSEs: %s" % candidateSEs)
+            self.logVerbose(f"Selected ArchiveSEs: {candidateSEs}")
             if len(candidateSEs) < nbArchive:
                 self.logError("Cannot select enough archive SEs")
                 return None
@@ -628,7 +627,7 @@ get from BK"
         ]
         # 4. Select the proper number of SEs in the candidate ordered list
         candidateSEs = self.selectSEs(candidateSEs, numberOfCopies, existingSEs)
-        self.logVerbose("Selected SecondarySEs: %s" % candidateSEs)
+        self.logVerbose(f"Selected SecondarySEs: {candidateSEs}")
         if len(candidateSEs) < numberOfCopies:
             self.logError("Can not select enough Active SEs as SecondarySE")
             return None
@@ -637,7 +636,7 @@ get from BK"
         # Remove existing SEs if requested
         if exclusiveSEs:
             targetSEs = [se for se in targetSEs if se not in existingSEs]
-        self.logVerbose("Selected target SEs: %s" % targetSEs)
+        self.logVerbose(f"Selected target SEs: {targetSEs}")
         return ",".join(sorted(targetSEs))
 
     def selectSEs(self, candSEs, needToCopy, existingSEs):
@@ -686,9 +685,8 @@ get from BK"
     def getProcessedFiles(self, lfns):
         """Check which files have been processed by a given production, i.e. have a
         meaningful descendant."""
-        from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import getFileDescendants
 
-        return getFileDescendants(self.transID, lfns, transClient=self.transClient, dm=self.dm, bkClient=self.bkClient)
+        return getFileDescendents(self.transID, lfns, transClient=self.transClient, dm=self.dm, bkClient=self.bkClient)
 
     # @timeThis
     def getRAWAncestorsForRun(self, runID, param=None, paramValue=None, getFiles=False):
@@ -703,7 +701,7 @@ get from BK"
         if not lfns:
             res = self.getTransformationFiles(runID=runID)
             if not res["OK"]:
-                self.logError("Cannot get transformation files for run %s: %s" % (str(runID), res["Message"]))
+                self.logError(f"Cannot get transformation files for run {str(runID)}: {res['Message']}")
                 return 0
             lfns = [fileDict["LFN"] for fileDict in res["Value"] if fileDict["Status"] not in self.excludedStatuses]
             self.transRunFiles[runID] = lfns
@@ -732,9 +730,7 @@ get from BK"
         # Get number of ancestors for known files
         cachedLfns = self.cachedLFNAncestors.get(runID, {})
         # If we cached a number, clean the cache
-        if cachedLfns and True in set(
-            isinstance(val, six.integer_types) for val in cachedLfns.values()
-        ):  # can be an iterator
+        if cachedLfns and True in {isinstance(val, int) for val in cachedLfns.values()}:  # can be an iterator
             cachedLfns = {}
         setLfns = set(lfns)
         hitLfns = setLfns & set(cachedLfns)
@@ -750,10 +746,10 @@ get from BK"
             if res["OK"]:
                 ancestorDict = res["Value"]["Successful"]
             else:
-                self.logError("Error getting ancestors: %s" % res["Message"])
+                self.logError(f"Error getting ancestors: {res['Message']}")
                 ancestorDict = {}
             for lfn in ancestorDict:
-                ancFiles = set(os.path.basename(f["FileName"]) for f in ancestorDict[lfn] if f["FileType"] == "RAW")
+                ancFiles = {os.path.basename(f["FileName"]) for f in ancestorDict[lfn] if f["FileType"] == "RAW"}
                 ancestorFiles.update(ancFiles)
                 self.cachedLFNAncestors.setdefault(runID, {})[lfn] = ancFiles
 
@@ -795,21 +791,21 @@ get from BK"
                     if fullDst:
                         ancestorFullDST = fullDst[0]
                 else:
-                    self.logError("Error getting ancestors of %s" % lfnToCheck, res["Message"])
+                    self.logError(f"Error getting ancestors of {lfnToCheck}", res["Message"])
         if ancestorFullDST:
-            self.logDebug("Ancestor %s found: %s" % (self.__recoType, ancestorFullDST))
+            self.logDebug(f"Ancestor {self.__recoType} found: {ancestorFullDST}")
             res = self.bkClient.getJobInfo(ancestorFullDST)
             if res["OK"]:
                 try:
                     recoProduction = res["Value"][0][18]
                     self.logVerbose("Reconstruction production is %d" % recoProduction)
                 except IndexError as e:
-                    self.logException("Exception extracting reco production from %s" % str(res["Value"]), lException=e)
+                    self.logException(f"Exception extracting reco production from {str(res['Value'])}", lException=e)
                     recoProduction = None
             else:
                 self.logError("Error getting job information", res["Message"])
         else:
-            self.logVerbose("No ancestor %s file found" % self.__recoType)
+            self.logVerbose(f"No ancestor {self.__recoType} file found")
         if recoProduction:
             res = self.transClient.getTransformationFiles({"TransformationID": recoProduction, "RunNumber": runID})
             if res["OK"]:
@@ -842,14 +838,13 @@ get from BK"
             return _clearTaskLFNs(taskLfns)
         ancestors = ancestors["Value"]["Successful"]
         ancLfns = [anc["FileName"] for ancList in ancestors.values() for anc in ancList]  # can be an iterator
-        self.logVerbose("Checking ancestors presence at %s for %d files" % (",".join(sorted(seList)), len(ancLfns)))
+        self.logVerbose(f"Checking ancestors presence at {','.join(sorted(seList))} for {len(ancLfns)} files")
         res = self.dm.getReplicasForJobs(ancLfns, getUrl=False)
         if not res["OK"]:
             self.logError("Error getting replicas of ancestors", res["Message"])
             # Fake no replicas for all files
             return _clearTaskLFNs(taskLfns)
-        else:
-            success = res["Value"]["Successful"]
+        success = res["Value"]["Successful"]
         for lfn, ancList in ancestors.items():  # can be an iterator
             for anc in ancList:
                 if not seList & set(success[anc["FileName"]]):
@@ -876,14 +871,14 @@ get from BK"
         condDict = {"TransformationID": transID}
         if isinstance(runs, (dict, list, tuple, set)):
             condDict["RunNumber"] = list(runs)
-        elif isinstance(runs, six.integer_types):
+        elif isinstance(runs, int):
             runs = [runs]
             condDict["RunNumber"] = runs
         result = self.transClient.getTransformationRuns(condDict)
         if not result["OK"]:
             return result
         # Check that all runs are there, if not add them
-        runsFound = set(run["RunNumber"] for run in result["Value"])
+        runsFound = {run["RunNumber"] for run in result["Value"]}
         if runs:
             missingRuns = set(runs) - runsFound
             if missingRuns:
@@ -934,7 +929,7 @@ get from BK"
             self.logInfo("Set run number for %d files with run #0, which means it was not set yet" % nZero)
 
         if param:
-            self.logVerbose("Grouped %d files by run and %s" % (len(files), param))
+            self.logVerbose(f"Grouped {len(files)} files by run and {param}")
         return runDict
 
     def getFilesGroupedByRun(self, lfns=None):
@@ -959,7 +954,7 @@ get from BK"
                 runGroups.setdefault(newRun, []).extend(runLFNs)
                 nZero += len(runLFNs)
             self.logInfo("Set run number for %d files with run #0, which means it was not set yet" % nZero)
-        self.logVerbose("Obtained %d runs" % len(runGroups))
+        self.logVerbose(f"Obtained {len(runGroups)} runs")
         return runGroups
 
     def createTasks(self, storageElementGroups, chunkSize=None):
@@ -971,12 +966,11 @@ get from BK"
             stringTargetLFNs = storageElementGroups[stringTargetSEs]
             for lfnGroup in breakListIntoChunks(sorted(stringTargetLFNs), chunkSize):
                 tasks.append((stringTargetSEs, lfnGroup))
-        self.logVerbose("%d tasks created" % len(tasks))
+        self.logVerbose(f"{len(tasks)} tasks created")
         return tasks
 
     def readCacheFile(self, workDirectory):
         """Utility function."""
-        import pickle
 
         # Now try and get the cached information
         tmpDir = os.environ.get("TMPDIR", "/tmp")
@@ -990,13 +984,13 @@ get from BK"
                 ),
             ),
         )
-        for (cacheFile, prefixes) in cacheFiles:
+        for cacheFile, prefixes in cacheFiles:
             if not cacheFile:
                 continue
             for node in prefixes:
                 cacheFile = os.path.join(cacheFile, node)
                 mkDir(cacheFile)
-            cacheFile = os.path.join(cacheFile, "Transformation_%s.pkl" % (str(self.transID)))
+            cacheFile = os.path.join(cacheFile, f"Transformation_{str(self.transID)}.pkl")
             if not self.cacheFile:
                 self.cacheFile = cacheFile
             try:
@@ -1010,11 +1004,11 @@ get from BK"
                     self.cachedLastRun = pickle.load(cacheFile_o)
                     self.cachedLFNProcessedPath = pickle.load(cacheFile_o)
                     self.lastCall = pickle.load(cacheFile_o)
-                self.logVerbose("Cache file %s successfully loaded" % cacheFile)
+                self.logVerbose(f"Cache file {cacheFile} successfully loaded")
                 # print '*****'
                 # print '\n'.join( ['%s %s' % ( key, val ) for key, val in self.cachedLFNProcessedPath.items()] )
                 break
-            except (IOError, LookupError) as e:
+            except (OSError, LookupError) as e:
                 self.logException("Cache file could not be loaded", cacheFile, lException=e)
 
     def getCachedRunLFNs(self, runID, paramValue):
@@ -1062,7 +1056,6 @@ get from BK"
 
     def writeCacheFile(self):
         """Utility function."""
-        import pickle
 
         if self.cacheFile:
             try:
@@ -1075,7 +1068,7 @@ get from BK"
                     pickle.dump(self.cachedLastRun, cacheFile_o)
                     pickle.dump(self.cachedLFNProcessedPath, cacheFile_o)
                     pickle.dump(self.lastCall, cacheFile_o)
-                self.logVerbose("Cache file %s successfully written" % self.cacheFile)
+                self.logVerbose(f"Cache file {self.cacheFile} successfully written")
             except Exception as e:
                 self.logException("Could not write cache file", self.cacheFile, lException=e)
 
@@ -1103,7 +1096,7 @@ get from BK"
                     )
                     runFiles.pop(run)
         else:
-            self.logError("Error getting metadata for %d files" % len(lfns), res["Message"])
+            self.logError(f"Error getting metadata for {len(lfns)} files", res["Message"])
         return runFiles
 
     def getTransQuery(self, transReplicas):
@@ -1131,7 +1124,7 @@ get from BK"
         """Remove from transFiles all files without a replica and set their
         status."""
         noReplicaFiles = []
-        for fileDict in [fileDict for fileDict in transFiles]:
+        for fileDict in list(transFiles):
             if fileDict["LFN"] not in transReplicas:
                 noReplicaFiles.append(fileDict["LFN"])
                 transFiles.remove(fileDict)
@@ -1141,9 +1134,9 @@ get from BK"
             info = "without replicas" if status == "Problematic" else "already processed"
             res = self.transClient.setFileStatusForTransformation(self.transID, status, noReplicaFiles)
             if not res["OK"]:
-                self.logError("Error setting file status for %d files" % len(noReplicaFiles), res["Message"])
+                self.logError(f"Error setting file status for {len(noReplicaFiles)} files", res["Message"])
             else:
-                self.logInfo("Found %d files %s, status set to %s" % (len(noReplicaFiles), info, status))
+                self.logInfo(f"Found {len(noReplicaFiles)} files {info}, status set to {status}")
 
     def __getRunDestinations(self, runIDList):
         """Get the site destination for a set of runs and cache this information in
@@ -1187,7 +1180,7 @@ get from BK"
             self.logError("Error getting transformation files", res["Message"])
             return {}
         fDictList = res["Value"]
-        unProcessedLfns = set(fDict["LFN"] for fDict in fDictList if fDict["Status"] != "Processed")
+        unProcessedLfns = {fDict["LFN"] for fDict in fDictList if fDict["Status"] != "Processed"}
         procLfns = lfns - unProcessedLfns
         prodLfns = {}
         processedLfns = set()
@@ -1227,7 +1220,7 @@ get from BK"
             % (len(lfnSet), ",".join(str(prod) for prod in prodList), depth)
         )
         excludeTypes = ("LOG", "BRUNELHIST", "DAVINCIHIST", "GAUSSHIST", "HIST", "INDEX.ROOT")
-        if isinstance(lfnSet, six.string_types):
+        if isinstance(lfnSet, str):
             lfnSet = {lfnSet}
         elif isinstance(lfnSet, list):
             lfnSet = set(lfnSet)
@@ -1251,17 +1244,17 @@ get from BK"
             for lfnChunk in breakListIntoChunks(lfns, chunkSize):
                 progressBar.loop()
                 # prod is a long and server expects an int!
-                res = self.bkClient.getFileDescendants(lfnChunk, depth=1, production=int(prod), checkreplica=False)
+                res = self.bkClient.getFileDescendents(lfnChunk, depth=1, production=int(prod), checkreplica=False)
                 if not res["OK"]:
                     return res
                 for lfn, descDict in res["Value"]["WithMetadata"].items():  # can be an iterator
                     # Only keep the file type as metadata in teh dict
                     success.setdefault(lfn, {}).update(
-                        dict(
-                            (desc, {"FileType": metadata["FileType"], "GotReplica": metadata["GotReplica"]})
+                        {
+                            desc: {"FileType": metadata["FileType"], "GotReplica": metadata["GotReplica"]}
                             for desc, metadata in descDict.items()  # can be an iterator
                             if metadata["FileType"] not in excludeTypes
-                        )
+                        }
                     )
                     # Record information about which production created each descendant
                     for desc in descDict:
@@ -1270,9 +1263,9 @@ get from BK"
 
         # Get set of file types
         fileTypes = sorted(
-            set(metadata["FileType"] for descendants in success.values() for metadata in descendants.values())
+            {metadata["FileType"] for descendants in success.values() for metadata in descendants.values()}
         )  # can be an iterator
-        self.logVerbose("Will check file type%s %s" % ("s" if len(fileTypes) > 1 else "", ",".join(fileTypes)))
+        self.logVerbose(f"Will check file type{'s' if len(fileTypes) > 1 else ''} {','.join(fileTypes)}")
 
         # Try and find descendants for each file type in turn as this is sufficient
         for fileType in fileTypes:
@@ -1301,16 +1294,16 @@ get from BK"
                 else:
                     # Sort remaining descendants in productions
                     prodDesc.setdefault(prod, set()).add(desc)
-            for prod in foundProds:
+            for prod, found in foundProds.items():
                 self.logVerbose(
                     "Found %s descendants with replicas for %d files (out of %d) in production %d at depth %d"
-                    % (fileType, len(foundProds[prod]), len(lfnSet), prod, depth + 1)
+                    % (fileType, len(found), len(lfnSet), prod, depth + 1)
                 )
 
             # Check descendants without replicas in reverse order of productions
             for prod in sorted(prodDesc, reverse=True):
                 # Check descendants whose parent was not yet found processed
-                toCheckInProd = set(desc for desc in prodDesc[prod] if not descToCheck[desc] & finalResult)
+                toCheckInProd = {desc for desc in prodDesc[prod] if not descToCheck[desc] & finalResult}
                 if toCheckInProd:
                     self.logVerbose(
                         "Found %d %s descendants without replicas in production %d at depth %d,"
@@ -1381,12 +1374,12 @@ get from BK"
         period = self.getPluginParam("Period", 0)
         now = datetime.datetime.utcnow()
         if self.lastCall and (now - self.lastCall) < datetime.timedelta(hours=period):
-            self.logInfo("Skip this loop (less than %s hours since last call)" % period)
+            self.logInfo(f"Skip this loop (less than {period} hours since last call)")
             return S_OK(None)
         self.lastCall = now
         self.writeCacheFile()
         self.logVerbose(
-            "Checking how many files can be sent to %s\n\t for directories %s" % (",".join(destSEs), ",".join(dirList))
+            f"Checking how many files can be sent to {','.join(destSEs)}\n\t for directories {','.join(dirList)}"
         )
 
         # Get current storage usage per SE
@@ -1498,7 +1491,7 @@ get from BK"
         now = datetime.datetime.utcnow()
         period = self.getPluginParam("Period", 6)
         if self.lastCall and (now - self.lastCall) < datetime.timedelta(hours=period):
-            self.logInfo("Skip this loop (less than %s hours since last call)" % period)
+            self.logInfo(f"Skip this loop (less than {period} hours since last call)")
             return S_OK(None)
         self.lastCall = now
         self.writeCacheFile()
@@ -1518,10 +1511,8 @@ get from BK"
             transTable = "Tasks"
             cond["ExternalStatus"] = ["Waiting", "Received", "Checking", "Created", "Staging", "Submitted"]
             item = "TargetSE"
-        self.logVerbose(
-            "Get number of %s by %s" % (transTable, item), "for %s transformations %s" % (transType, str(transList))
-        )
-        res = self.transClient.getCounters("Transformation%s" % transTable, [item], cond)
+        self.logVerbose(f"Get number of {transTable} by {item}", f"for {transType} transformations {str(transList)}")
+        res = self.transClient.getCounters(f"Transformation{transTable}", [item], cond)
         if not res["OK"]:
             return res
         # Count number of pending tasks as TargetSE can be multiple
@@ -1582,7 +1573,7 @@ get from BK"
                     pendingTasksPerSE[se] += 1
         self.logVerbose("Throttled files per TargetSE", str(dict(removedFiles)))
         if acceptedRuns or suppressedRuns:
-            self.logVerbose("Throttled %d runs" % len(suppressedRuns), ", accepted %d runs" % len(acceptedRuns))
+            self.logVerbose(f"Throttled {len(suppressedRuns)} runs", f", accepted {len(acceptedRuns)} runs")
 
     def checkRunForFlush(self, runID, runStatus, forceFlush, param, paramValue, paramStr, evtType):
         """
@@ -1748,14 +1739,14 @@ def getReplicationPlugins():
 def getShares(sType, normalise=False):
     """Get the shares from the Operations section of the CS If not found, look in
     the Resources section."""
-    optionPath = "Shares/%s" % sType
+    optionPath = f"Shares/{sType}"
     res = Operations().getOptionsDict(optionPath)
     if not res["OK"]:
         res = gConfig.getOptionsDict(os.path.join("/Resources", optionPath))
     if not res["OK"]:
         return res
     if not res["Value"]:
-        return S_ERROR("/Resources/%s option contains no shares" % optionPath)
+        return S_ERROR(f"/Resources/{optionPath} option contains no shares")
     shares = res["Value"]
     for site, value in shares.items():  # can be an iterator
         shares[site] = float(value)
@@ -1804,16 +1795,16 @@ def addFilesToTransformation(transID, lfns, addRunInfo=True, resetPresentFiles=F
     is not present."""
     transClient = TransformationClient()
     bk = BookkeepingClient()
-    gLogger.info("Adding %d files to transformation %s" % (len(lfns), transID))
+    gLogger.info(f"Adding {len(lfns)} files to transformation {transID}")
     res = transClient.getTransformation(transID)
     if not res["OK"]:
         return res
     transPlugin = res["Value"]["Plugin"]
     pluginsWithRunInfo = Operations().getValue("TransformationPlugins/PluginsWithRunInfo", [])
     addRunInfo = addRunInfo and transPlugin in pluginsWithRunInfo
-    addedLfns = dict()
+    addedLfns = {}
     presentLfns = set()
-    failedLfns = dict()
+    failedLfns = {}
     for lfnChunk in breakListIntoChunks(lfns, 1000):
         runDict = {}
         if addRunInfo:
@@ -1834,7 +1825,7 @@ def addFilesToTransformation(transID, lfns, addRunInfo=True, resetPresentFiles=F
             if not res["OK"]:
                 if not errorLogged:
                     errorLogged = True
-                    gLogger.error("Error adding %d files to transformation, retry..." % len(lfnChunk), res["Message"])
+                    gLogger.error(f"Error adding {len(lfnChunk)} files to transformation, retry...", res["Message"])
                 time.sleep(1)
                 retries -= 1
             else:
@@ -1842,16 +1833,14 @@ def addFilesToTransformation(transID, lfns, addRunInfo=True, resetPresentFiles=F
         if not retries:
             failedLfns.update(dict.fromkeys(lfnChunk, res["Message"]))
             continue
-        added = set(
-            lfn for (lfn, status) in res["Value"]["Successful"].items() if status == "Added"
-        )  # can be an iterator
-        present = set(
+        added = {lfn for (lfn, status) in res["Value"]["Successful"].items() if status == "Added"}  # can be an iterator
+        present = {
             lfn for (lfn, status) in res["Value"]["Successful"].items() if status == "Present"
-        )  # can be an iterator
+        }  # can be an iterator
         addedLfns.update(dict.fromkeys(added, "Added"))
         presentLfns.update(present)
         if addRunInfo:
-            gLogger.info("Add information for %d runs to transformation %s" % (len(runDict), transID))
+            gLogger.info(f"Add information for {len(runDict)} runs to transformation {transID}")
             for runID, runLfns in runDict.items():  # can be an iterator
                 runLfns &= added
                 if runLfns:
@@ -1859,7 +1848,7 @@ def addFilesToTransformation(transID, lfns, addRunInfo=True, resetPresentFiles=F
                     if not res["OK"]:
                         gLogger.error(
                             "Error adding files to run",
-                            "for %d files to run %s: %s" % (len(runLfns), runID, res["Message"]),
+                            f"for {len(runLfns)} files to run {runID}: {res['Message']}",
                         )
             # Add run metadata if not present in TS
             res = transClient.getRunsMetadata(list(runDict))
@@ -1880,13 +1869,13 @@ def addFilesToTransformation(transID, lfns, addRunInfo=True, resetPresentFiles=F
                         if not res["OK"]:
                             gLogger.error("Error setting run metadata in TS", res["Message"])
 
-    gLogger.info("%d files successfully added to transformation" % len(addedLfns))
+    gLogger.info(f"{len(addedLfns)} files successfully added to transformation")
     resetLfns = 0
     if resetPresentFiles and presentLfns:
         for lfnChunk in breakListIntoChunks(presentLfns, 1000):
             res = transClient.setFileStatusForTransformation(transID, "Unused", lfnChunk, force=True)
             if not res["OK"]:
-                gLogger.error("Error resetting files Unused", "for %d files: %s" % (len(lfnChunk), res["Message"]))
+                gLogger.error("Error resetting files Unused", f"for {len(lfnChunk)} files: {res['Message']}")
                 failedLfns.update(dict.fromkeys(lfnChunk, res["Message"]))
             else:
                 resetLfns += len(lfnChunk)
@@ -1899,6 +1888,6 @@ def stripDirectory(files, depth=None):
     """Return set of directories for a list of LFNs, and directory for a single LFN."""
     if depth is None:
         depth = 4
-    if isinstance(files, six.string_types):
+    if isinstance(files, str):
         return os.path.sep + os.path.join(*files.split(os.path.sep)[: depth + 1])
-    return set(os.path.sep + os.path.join(*lfn.split(os.path.sep)[: depth + 1]) for lfn in files)
+    return {os.path.sep + os.path.join(*lfn.split(os.path.sep)[: depth + 1]) for lfn in files}
