@@ -8,7 +8,8 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from mock import Mock
+
+from unittest.mock import Mock
 import unittest
 
 from LHCbDIRAC.TransformationSystem.Utilities.StateMachine import TransformationFilesStateMachine
