@@ -12,7 +12,7 @@
 """Gets a list of files from BK and checks if they have common ancestors."""
 import time
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 fixIt = None
 
@@ -25,7 +25,7 @@ def removeFile(lfns, transClient, dm, bkClient):
         gLogger.always("Files were made invisible in BK")
     else:
         gLogger.always("Error making files invisible in BK", res["Message"])
-    gLogger.always("Removing %d files from disk" % len(lfns))
+    gLogger.always(f"Removing {len(lfns)} files from disk")
     res = dm.getReplicas(lfns)
     success = res.get("Value", {}).get("Successful", [])
     failed = res.get("Value", {}).get("Failed", lfns)
@@ -41,23 +41,21 @@ def removeFile(lfns, transClient, dm, bkClient):
                     if lfn in removeFiles:
                         removeFiles.remove(lfn)
         if removeFiles:
-            gLogger.always("Removing completely %d files" % len(removeFiles))
+            gLogger.always(f"Removing completely {len(removeFiles)} files")
             res = dm.removeFile(removeFiles)
             if not res["OK"]:
-                gLogger.fatal("Error removing %d files" % len(removeFiles), res["Message"])
+                gLogger.fatal(f"Error removing {len(removeFiles)} files", res["Message"])
             else:
                 success = res["Value"]["Successful"]
                 failed = res["Value"]["Failed"]
-                gLogger.always(
-                    "Successfully fully removed %d files that only had the duplicate ancestors" % len(success)
-                )
+                gLogger.always(f"Successfully fully removed {len(success)} files that only had the duplicate ancestors")
                 if failed:
                     errors = {}
                     for lfn, reason in failed.items():
                         errors.setdefault(reason, []).append(lfn)
                     gLogger.error(
-                        "Failed to remove %d files" % len(failed),
-                        "\n".join("%s: %s" % (reason, errors[reason]) for reason in errors),
+                        f"Failed to remove {len(failed)} files",
+                        "\n".join(f"{reason}: {errors[reason]}" for reason in errors),
                     )
         success = []
         failed = {}
@@ -73,16 +71,14 @@ def removeFile(lfns, transClient, dm, bkClient):
                         failed[se] = res["Value"]["Failed"]
         if success:
             gLogger.always(
-                "Successfully removed %d replicas of files that only had the duplicate ancestors" % len(success)
+                f"Successfully removed {len(success)} replicas of files that only had the duplicate ancestors"
             )
         if failed:
             errors = {}
             for se in failed:
                 for lfn, reason in failed[se].items():
-                    errors.setdefault(reason + " @%s" % se, []).append(lfn)
-            gLogger.error(
-                "Failed to remove replicas\n", "\n".join("%s: %s" % (reason, errors[reason]) for reason in errors)
-            )
+                    errors.setdefault(reason + f" @{se}", []).append(lfn)
+            gLogger.error("Failed to remove replicas\n", "\n".join(f"{reason}: {errors[reason]}" for reason in errors))
         elif not success and not removeFiles:
             gLogger.always("None of the files had replicas left on disk...")
         if not success:
@@ -112,14 +108,12 @@ def removeFile(lfns, transClient, dm, bkClient):
                     )
     elif failed:
         gLogger.fatal(
-            "Failed to get replicas for %d files:\n" % len(failed),
+            f"Failed to get replicas for {len(failed)} files:\n",
             res.get("Message", "\n".join(sorted(set(failed.values if isinstance(failed, type({})) else [])))),
         )
         gLogger.info(
             "\n".join(
-                ("%s: %s" % (lfn, failed[lfn]) for lfn in sorted(failed))
-                if isinstance(failed, dict)
-                else sorted(failed)
+                (f"{lfn}: {failed[lfn]}" for lfn in sorted(failed)) if isinstance(failed, dict) else sorted(failed)
             )
         )
 
@@ -137,14 +131,14 @@ def analyzeAncestors(commonAncestors, ancestors, transClient, dm, bkClient):
     for lfnStr, anc in commonAncestors.items():
         lfns = lfnStr.split(",")
         run = lfnRuns.get(lfns[0], "Unknown")
-        gLogger.always("\n%s (run %s):\n\t%s" % ("\n".join(lfns), str(run), "\n\t".join(anc)))
+        gLogger.always("\n{} (run {}):\n\t{}".format("\n".join(lfns), str(run), "\n\t".join(anc)))
         # Now check if one of the files only has those common ancestors
         for lfn in sorted(lfns, reverse=True):
             if anc == ancestors[lfn]:
                 if not fixIt:
-                    gLogger.always("%s only has those as ancestors. Use --FixIt to remove the file" % lfn)
+                    gLogger.always(f"{lfn} only has those as ancestors. Use --FixIt to remove the file")
                 else:
-                    gLogger.always("%s only has those as ancestors. We shall remove the file" % lfn)
+                    gLogger.always(f"{lfn} only has those as ancestors. We shall remove the file")
                     lfnsToRemove.add(lfn)
                     lfns.remove(lfn)
                     if len(lfns) == 1:
@@ -153,11 +147,10 @@ def analyzeAncestors(commonAncestors, ancestors, transClient, dm, bkClient):
         removeFile(list(lfnsToRemove), transClient=transClient, dm=dm, bkClient=bkClient)
 
 
-@DIRACScript()
+@Script()
 def main():
     global fixIt
 
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -173,7 +166,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile]",
             ]
         )
     )
@@ -208,12 +201,12 @@ def main():
     cc.checkAncestors()
 
     # Print out the results
-    gLogger.always("\nResults (%.1f seconds):" % (time.time() - startTime))
+    gLogger.always(f"\nResults ({time.time() - startTime:.1f} seconds):")
 
     if not cc.commonAncestors:
         gLogger.always("No files found with common ancestors ==> OK")
     else:
-        gLogger.always("Found %d sets of files with common ancestors ==> ERROR" % len(cc.commonAncestors))
+        gLogger.always(f"Found {len(cc.commonAncestors)} sets of files with common ancestors ==> ERROR")
         analyzeAncestors(cc.commonAncestors, cc.ancestors, transClient=transClient, dm=dm, bkClient=bkClient)
 
 
