@@ -16,12 +16,11 @@ import time
 
 import DIRAC
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -33,7 +32,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] [ProdIDs]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] [ProdIDs]",
             ]
         )
     )
@@ -42,7 +41,7 @@ def main():
         "", "ActiveRunsProduction=", "   Specify the production from which the runs should be derived"
     )
     Script.registerSwitch("", "FileType=", "S   pecify the descendants file type")
-    Script.registerSwitch("", "NoFC", "   Trust the BK replica flag, no LFC check")
+    Script.registerSwitch("", "NoFC", "   Trust the BK replica flag, no FC check")
     Script.registerSwitch("", "FixIt", "   Fix the files in transformation table")
     Script.registerSwitch("", "Verbose", "   Print full list of files with error")
     Script.registerSwitch("", "Status=", "   Select files with a given status in the production")
@@ -90,7 +89,7 @@ def main():
             try:
                 fromProd = int(switch[1])
             except ValueError as e:
-                gLogger.exception("Wrong production number: %s" % switch[1], lException=e)
+                gLogger.exception(f"Wrong production number: {switch[1]}", lException=e)
                 DIRAC.exit(0)
 
     args = Script.getPositionalArgs()
@@ -109,7 +108,7 @@ def main():
                 else:
                     prodList.append(int(eval(r[0])))
         except (ValueError, NameError) as e:
-            gLogger.exception("Bad production list: %s" % args[0], lException=e)
+            gLogger.exception(f"Bad production list: {args[0]}", lException=e)
     # In case the user asked for specific LFNs
     if not status:
         lfnList = dmScript.getOption("LFNs", [])
@@ -150,7 +149,7 @@ def main():
         if not fileType:
             bkQuery = BKQuery({"Production": prod, "FileType": "ALL", "Visible": "All"})
             cc.fileType = bkQuery.getBKFileTypes()
-            gLogger.notice("Looking for descendants of type %s" % str(cc.fileType))
+            gLogger.notice(f"Looking for descendants of type {str(cc.fileType)}")
             notAllFileTypes = False
         else:
             cc.fileType = fileType
@@ -170,7 +169,7 @@ def main():
         suffix = ""
         n = 0
         while True:
-            fileName = "CheckDescendantsResults_%s%s.txt" % (str(cc.prod), suffix)
+            fileName = f"CheckDescendantsResults_{str(cc.prod)}{suffix}.txt"
             if not os.path.exists(fileName):
                 break
             n += 1
@@ -178,7 +177,7 @@ def main():
         fp = None
         if cc.inFCNotInBK:
             lfns = cc.inFCNotInBK
-            gLogger.notice("%d descendants were found in FC but don't have replica flag in BK" % len(lfns))
+            gLogger.notice(f"{len(lfns)} descendants were found in FC but don't have replica flag in BK")
             if not fp:
                 fp = open(fileName, "w")
             fp.write("\nInFCNotInBK ".join([""] + lfns))
@@ -193,7 +192,7 @@ def main():
 
         if cc.inFailover:
             lfns = cc.inFailover
-            gLogger.notice("%d descendants were found in Failover and have no replica flag in BK" % len(lfns))
+            gLogger.notice(f"{len(lfns)} descendants were found in Failover and have no replica flag in BK")
             if not fp:
                 fp = open(fileName, "w")
             fp.write("\nInFailover ".join([""] + lfns))
@@ -205,11 +204,11 @@ def main():
                 "You should check whether they are in a failover request by looking "
                 "at their job status and in the RMS..."
             )
-            gLogger.notice("To list them:     grep InFailover %s" % fileName)
+            gLogger.notice(f"To list them:     grep InFailover {fileName}")
 
         if cc.inBKNotInFC:
             lfns = cc.inBKNotInFC
-            gLogger.notice("%d descendants were found with replica flag in BK but not in FC" % len(lfns))
+            gLogger.notice(f"{len(lfns)} descendants were found with replica flag in BK but not in FC")
             if not fp:
                 fp = open(fileName, "w")
             fp.write("\nInBKNotInFC ".join([""] + lfns))
@@ -217,7 +216,7 @@ def main():
                 "First %d files:" % nMax if not verbose and len(lfns) > nMax else "All files:",
                 "\n".join([""] + lfns[0:nMax]),
             )
-            gLogger.notice("To try and fix this:    grep InBKNotInFC %s | dirac-dms-check-bkk2fc" % fileName)
+            gLogger.notice(f"To try and fix this:    grep InBKNotInFC {fileName} | dirac-dms-check-bkk2fc")
 
         if cc.removedFiles:
             from DIRAC.Core.Utilities.List import breakListIntoChunks
@@ -249,7 +248,7 @@ def main():
 
         if cc.prcdWithMultDesc:
             lfns = sorted(cc.prcdWithMultDesc)
-            gLogger.notice("Processed LFNs with multiple descendants (%d) -> ERROR" % len(lfns))
+            gLogger.notice(f"Processed LFNs with multiple descendants ({len(lfns)}) -> ERROR")
             gLogger.notice(
                 "First %d files:" % nMax if not verbose and len(lfns) > nMax else "All files:",
                 "\n".join([""] + lfns[0:nMax]),
@@ -257,9 +256,7 @@ def main():
             if not fp:
                 fp = open(fileName, "w")
             fp.write(
-                "\nProcMultDesc ".join(
-                    [""] + ["%s: %s" % (lfn, str(multi)) for lfn, multi in cc.prcdWithMultDesc.items()]
-                )
+                "\nProcMultDesc ".join([""] + [f"{lfn}: {str(multi)}" for lfn, multi in cc.prcdWithMultDesc.items()])
             )
             gLogger.notice("I'm not doing anything for them, neither with the 'FixIt' option")
         else:
@@ -272,11 +269,9 @@ def main():
             badLfns = set()
             if res["OK"]:
                 # Check the DQ flag of these files
-                badLfns = set(
-                    lfn for lfn, meta in res["Value"]["Successful"].items() if meta["DataqualityFlag"] == "BAD"
-                )
+                badLfns = {lfn for lfn, meta in res["Value"]["Successful"].items() if meta["DataqualityFlag"] == "BAD"}
             if badLfns:
-                gLogger.notice("Processed LFNs without descendants (%d)" % len(lfns))
+                gLogger.notice(f"Processed LFNs without descendants ({len(lfns)})")
                 gLogger.notice(
                     "WARNING: %d of these files have a BAD data quality flag and thus may have been removed"
                     % len(badLfns)
@@ -284,7 +279,7 @@ def main():
                 lfns -= badLfns
             if fixIt and lfns:
                 fixIt = False
-                gLogger.notice("Processed LFNs without descendants (%d) -> ERROR!" % len(lfns))
+                gLogger.notice(f"Processed LFNs without descendants ({len(lfns)}) -> ERROR!")
                 gLogger.notice("Resetting them 'Unused'")
                 res = cc.transClient.setFileStatusForTransformation(prod, "Unused", list(lfns), force=True)
                 if not res["OK"]:
@@ -296,10 +291,10 @@ def main():
                 if badLfns:
                     fp.write("\nProcButBAD ".join([""] + sorted(badLfns)))
                     gLogger.notice("BAD files processed without descendants can be checked using:")
-                    gLogger.notice("     grep ProcButBAD %s" % fileName)
+                    gLogger.notice(f"     grep ProcButBAD {fileName}")
                 if lfns:
                     lfns = sorted(lfns)
-                    gLogger.notice("Processed LFNs without descendants (%d) -> ERROR!" % len(lfns))
+                    gLogger.notice(f"Processed LFNs without descendants ({len(lfns)}) -> ERROR!")
                     gLogger.notice(
                         "First %d files:" % nMax if not verbose and len(lfns) > nMax else "All files:",
                         "\n".join([""] + lfns[0:nMax]),
@@ -330,7 +325,7 @@ def main():
 
         if cc.nonPrcdWithMultDesc:
             lfns = sorted(cc.nonPrcdWithMultDesc)
-            gLogger.notice("Non processed LFNs with multiple descendants (%d) -> ERROR" % len(lfns))
+            gLogger.notice(f"Non processed LFNs with multiple descendants ({len(lfns)}) -> ERROR")
             if not fp:
                 fp = open(fileName, "w")
             fp.write("\nNotProcMultDesc ".join([""] + lfns))
@@ -345,7 +340,7 @@ def main():
         # fixing, if requested
         if cc.nonPrcdWithDesc:
             lfns = sorted(cc.nonPrcdWithDesc)
-            gLogger.notice("There are %d LFNs not marked Processed but that have descendants -> ERROR" % len(lfns))
+            gLogger.notice(f"There are {len(lfns)} LFNs not marked Processed but that have descendants -> ERROR")
             gLogger.notice(
                 "First %d files:" % nMax if not verbose and len(lfns) > nMax else "All files:",
                 "\n".join([""] + lfns[0:nMax]),
@@ -362,12 +357,12 @@ def main():
                     gLogger.notice("Use --FixIt for setting files Processed in TS")
                 else:
                     gLogger.notice("To get the list of files and check them again:")
-                    gLogger.notice("     grep NotProcWithDesc %s | dirac-production-check-descendants" % fileName)
+                    gLogger.notice(f"     grep NotProcWithDesc {fileName} | dirac-production-check-descendants")
         else:
             gLogger.notice("No non processed LFNs with descendants found -> OK!")
         if fp:
             fp.close()
-            gLogger.notice("Complete list of files is in %s" % fileName)
+            gLogger.notice(f"Complete list of files is in {fileName}")
         gLogger.notice("Processed production %d in %.1f seconds" % (cc.prod, time.time() - startTime))
 
 
