@@ -12,10 +12,10 @@
 """remove output of production."""
 import sys
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC.Core.Base.Script import parseCommandLine
 
@@ -52,7 +52,7 @@ def main():
             continue
         status = res["Value"]
         if status not in ["RemovingFiles", "RemovingOutput", "ValidatingInput", "Active"]:
-            gLogger.error("The transformation is in %s status and the outputs cannot be removed" % status)
+            gLogger.error(f"The transformation is in {status} status and the outputs cannot be removed")
             continue
         agent.removeTransformationOutput(transID)
 
