@@ -23,16 +23,12 @@ import os
 import shutil
 import ssl
 
-if sys.version_info < (3,):
-    from urllib2 import urlopen as url_library_urlopen  # pylint: disable=no-name-in-module,import-error
-    from urllib2 import URLError as url_library_URLError  # pylint: disable=no-name-in-module,import-error
-else:
-    from urllib.request import urlopen as url_library_urlopen  # pylint: disable=no-name-in-module,import-error
-    from urllib.error import URLError as url_library_URLError  # pylint: disable=no-name-in-module,import-error
+from urllib.request import urlopen as url_library_urlopen  # pylint: disable=no-name-in-module,import-error
+from urllib.error import URLError as url_library_URLError  # pylint: disable=no-name-in-module,import-error
 
 from DIRAC import S_OK
 from DIRAC.Core.Utilities.File import mkDir
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def __runSystemDefaults(jobID=None):
@@ -137,10 +133,8 @@ def __runJobLocally(jobID, basepath):
     localJob.runLocal()
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
-
     Script.registerSwitch("D:", "Download=", "Defines data acquisition as DownloadInputData")
     Script.registerSwitch("P:", "Protocol=", "Defines data acquisition as InputDataByProtocol")
     Script.parseCommandLine(ignoreErrors=False)
