@@ -20,33 +20,32 @@ Examples of Usage :
   dirac-production-set-run 1234 --StartRun 99000 (change startrun.)
 """
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC import gLogger
-    from DIRAC.Core.Base import Script
 
     Script.setUsageMessage(
-        __doc__
-        + "\n".join(
-            [
-                "Usage:",
-                "  %s [option|cfgfile] ... Prod -Option [RunNumber|RunList]" % Script.scriptName,
-                "Arguments:",
-                "  Prod:      DIRAC Production Id",
-                "  RunNumber: New Start or End run",
-                "  RunList: List of Runs to be added",
-                "Examples:\n",
-                "dirac-production-set-run.py 92 --List                        (show the list of runs for transformation 92)\n",
-                "dirac-production-set-run.py 92 --AddRuns 98200,98201             (add some discrete run to transformation 92)\n",
-                "dirac-production-set-run.py 92 --AddRuns 98200,98201,99000:99100 (add some discrete run and\
-         a range of runs to transformation 92)\n",
-                "dirac-production-set-run.py 92 --StartRun 98200                 (change the start run for transformation 92)\n",
-                "dirac-production-set-run.py 92 --EndRun   98200                 (change the end run  for transformation 92)\n",
-            ]
-        )
+        f"{__doc__}"
+        f"Usage:\n"
+        f"  {Script.scriptName} [option|cfgfile] ... Prod -Option [RunNumber|RunList]\n"
+        "Arguments:\n"
+        "  Prod:      DIRAC Production Id\n"
+        "  RunNumber: New Start or End run\n"
+        "  RunList: List of Runs to be added\n"
+        "Examples:\n"
+        "  # show the list of runs for transformation 92\n"
+        "  dirac-production-set-run.py 92 --List\n"
+        "  # add some discrete run to transformation 92\n"
+        "  dirac-production-set-run.py 92 --AddRuns 98200,98201\n"
+        "  # add some discrete run and a range of runs to transformation 92\n"
+        "  dirac-production-set-run.py 92 --AddRuns 98200,98201,99000:99100\n"
+        "  # change the start run for transformation 92\n"
+        "  dirac-production-set-run.py 92 --StartRun 98200\n"
+        "  # change the end run  for transformation 92\n"
+        "  dirac-production-set-run.py 92 --EndRun   98200\n"
     )
 
     Script.registerSwitch("", "EndRun=", "Specify endrun for the transformation")
@@ -56,7 +55,7 @@ def main():
 
     Script.parseCommandLine(ignoreErrors=True)
 
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
 
     transList = getTransformations(Script.getPositionalArgs())
 
@@ -87,7 +86,7 @@ def main():
     for prodId in transList:
         res = client.getBookkeepingQuery(prodId)
         if not res["OK"]:
-            gLogger.error("Error retrieving BKQuery for transformation %s" % prodId, res["Message"])
+            gLogger.error(f"Error retrieving BKQuery for transformation {prodId}", res["Message"])
             DIRAC.exit(2)
         bkDict = res["Value"]
         startRun = bkDict.get("StartRun", 0)
@@ -143,14 +142,14 @@ def main():
         if "List" in settings:
             gLogger.notice("%sRun selection settings for transformation %d:" % ("\n" if changed else "", prodId))
             if runNumbers:
-                gLogger.notice("List of runs: %s" % ",".join([str(run) for run in sorted(runNumbers)]))
+                gLogger.notice(f"List of runs: {','.join([str(run) for run in sorted(runNumbers)])}")
             else:
                 if startRun:
-                    gLogger.notice("Start run is %s" % startRun)
+                    gLogger.notice(f"Start run is {startRun}")
                 else:
                     gLogger.notice("No start run defined ")
                 if endRun:
-                    gLogger.notice("End run is %s" % endRun)
+                    gLogger.notice(f"End run is {endRun}")
                 else:
                     gLogger.notice("No end run defined ")
 
