@@ -9,10 +9,11 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC.Core.Base.Script import parseCommandLine
 
@@ -27,9 +28,6 @@ def main():
         transIDs = [int(arg) for arg in sys.argv[1:]]
 
     from LHCbDIRAC.TransformationSystem.Agent.ValidateOutputDataAgent import ValidateOutputDataAgent
-    from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
-    from DIRAC import gLogger
-    import DIRAC
 
     agent = ValidateOutputDataAgent(
         "Transformation/ValidateOutputDataAgent",
@@ -38,7 +36,6 @@ def main():
     )
     agent.initialize()
 
-    client = TransformationClient()
     for transID in transIDs:
         agent.checkTransformationIntegrity(transID)
 
