@@ -12,13 +12,12 @@
 """
  Test a plugin
 """
-
 import DIRAC
 from DIRAC import S_OK
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-class FakeClient(object):
+class FakeClient:
     def __init__(self, trans, transID, lfns, asIfProd):
         self.trans = trans
         self.transID = transID
@@ -36,7 +35,7 @@ class FakeClient(object):
         (self.transFiles, self.transReplicas) = self.prepareForPlugin(lfns)
 
     def addFilesToTransformation(self, transID, lfns):
-        return S_OK({"Failed": {}, "Successful": dict([(lfn, "Added") for lfn in lfns])})
+        return S_OK({"Failed": {}, "Successful": {lfn: "Added" for lfn in lfns}})
 
     def getTransformation(self, transID, extraParams=False):
         if transID == self.transID and self.asIfProd:
@@ -96,7 +95,7 @@ class FakeClient(object):
                 res = self.bk.getFileMetadata([fileDict["LFN"] for fileDict in self.transFiles])
                 if not res["OK"]:
                     return res
-                runs = list(set(meta["RunNumber"] for meta in res["Value"]["Successful"].values()))
+                runs = list({meta["RunNumber"] for meta in res["Value"]["Successful"].values()})
             for run in runs:
                 transRuns.append({"RunNumber": run, "Status": "Active", "SelectedSite": None})
             return DIRAC.S_OK(transRuns)
@@ -203,7 +202,7 @@ class FakeClient(object):
     def prepareForPlugin(self, lfns):
         import time
 
-        print("Preparing the plugin input data (%d files)" % len(lfns))
+        print(f"Preparing the plugin input data ({len(lfns)} files)")
         type = self.trans.getType()["Value"]
         if not lfns:
             return (None, None)
@@ -233,8 +232,8 @@ class FakeClient(object):
                     if ses:
                         replicas[lfn] = sorted(ses)
             else:
-                print("Error getting replicas of %d files:" % len(lfns), res["Message"])
-        print("Obtained replicas of %d files in %.3f seconds" % (len(lfns), time.time() - startTime))
+                print(f"Error getting replicas of {len(lfns)} files:", res["Message"])
+        print(f"Obtained replicas of {len(lfns)} files in {time.time() - startTime:.3f} seconds")
         return (files, replicas)
 
 
@@ -254,10 +253,9 @@ def printFinalSEs(transType, location, targets):
         print("    Final SEs:", total)
 
 
-@DIRACScript()
+@Script()
 def main():
     import DIRAC
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.TransformationSystem.Utilities.PluginScript import PluginScript
 
     pluginScript = PluginScript()
@@ -274,7 +272,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
@@ -309,9 +307,9 @@ def main():
             gLogger.fatal("No plugin specified")
             DIRAC.exit(1)
         # Get default options from CS
-        res = Operations().getOptionsDict("TransformationPlugins/%s" % plugin)
+        res = Operations().getOptionsDict(f"TransformationPlugins/{plugin}")
         if res["OK"]:
-            gLogger.notice("Parameters for plugin %s (*<param> means it is a generic parameter)" % plugin)
+            gLogger.notice(f"Parameters for plugin {plugin} (*<param> means it is a generic parameter)")
             options = res["Value"]
             # Get default options for all plugins
             res = Operations().getOptionsDict("TransformationPlugins")
@@ -322,10 +320,10 @@ def main():
                         options["*" + opt] = allOptions[opt]
             # SE options first
             for opt in [opt for opt in sorted(options) if "SEs" in opt]:
-                gLogger.notice("\t%s : %s" % (opt, options[opt]))
+                gLogger.notice(f"\t{opt} : {options[opt]}")
             # Other options
             for opt in [opt for opt in sorted(options) if "SEs" not in opt]:
-                gLogger.notice("\t%s : %s" % (opt, options[opt]))
+                gLogger.notice(f"\t{opt} : {options[opt]}")
             DIRAC.exit(0)
         else:
             gLogger.error("Plugin has no specific parameters")
@@ -394,7 +392,7 @@ def main():
 
     print("Transformation type:", transType)
     if requestedLFNs:
-        print("%d requested LFNs" % len(requestedLFNs))
+        print(f"{len(requestedLFNs)} requested LFNs")
     else:
         print("BK Query:", bkQueryDict)
     print("Plugin:", plugin)
@@ -420,7 +418,7 @@ def main():
         if not checkReplica:
             bkQuery.setOption("ReplicaFlag", "No")
             lfns += bkQuery.getLFNs(printSEUsage=False, printOutput=False, visible=visible)
-            print("%d files in directories:" % len(lfns))
+            print(f"{len(lfns)} files in directories:")
             directories = {}
             import os
 
@@ -437,7 +435,7 @@ def main():
         print("No plugin to be tested...")
         DIRAC.exit(0)
 
-    print("\nNow testing the %s plugin %s" % (transType.lower(), plugin))
+    print(f"\nNow testing the {transType.lower()} plugin {plugin}")
     transformation.setPlugin(plugin)
     transformation.setBkQuery(bkQueryDict)
 
@@ -470,7 +468,7 @@ def main():
 
     startTime = time.time()
     res = oplugin.run()
-    print("Plugin took %.1f seconds" % (time.time() - startTime))
+    print(f"Plugin took {time.time() - startTime:.1f} seconds")
     print("")
     if res["OK"]:
         print(len(res["Value"]), "tasks created")
@@ -516,7 +514,7 @@ def main():
                     "- Target SEs:", previousTask["SEs"], "- 1 file", " - Current locations:", previousTask["Location"]
                     printFinalSEs(transType, previousTask["Location"], previousTask["SEs"])
                     previousTask = {"First": 0, "SEs": None, "Location": None, "Tasks": 0}
-                print(i, "- Target SEs:", task[0], "- %d files" % len(task[1]), " - Current locations:", location)
+                print(i, "- Target SEs:", task[0], f"- {len(task[1])} files", " - Current locations:", location)
                 printFinalSEs(transType, location, task[0])
         if previousTask["Tasks"]:
             i += 1
