@@ -10,17 +10,16 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Add files to a transformation."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
-
     import os
     import DIRAC
-    from DIRAC import gLogger
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
+
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -30,13 +29,15 @@ def main():
     Script.registerSwitch("", "Chown=", "   Give user/group for chown of the directories of files in the FC")
 
     Script.parseCommandLine(ignoreErrors=True)
+    from DIRAC import gLogger
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
 
     Script.setUsageMessage(
         "\n".join(
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
@@ -82,7 +83,7 @@ def main():
         DIRAC.exit(0)
 
     if userGroup:
-        directories = set([os.path.dirname(lfn) for lfn in requestedLFNs])
+        directories = {os.path.dirname(lfn) for lfn in requestedLFNs}
         res = chown(directories, user=userGroup[0], group=userGroup[1])
         if not res["OK"]:
             gLogger.fatal("Error changing ownership", res["Message"])
