@@ -12,10 +12,10 @@
 
 import sys
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC.Core.Base.Script import parseCommandLine
 
@@ -23,7 +23,7 @@ def main():
 
     import DIRAC
     from LHCbDIRAC.TransformationSystem.Agent.TransformationCleaningAgent import TransformationCleaningAgent
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
 
     if len(sys.argv) < 2:
         print("Usage: dirac-transformation-archive transID [transID] [transID]")
