@@ -11,13 +11,13 @@
 ###############################################################################
 """Debug files status for a (list of) transformations It is possible to do
 minor fixes to those files, using options."""
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
-    from DIRAC.Core.Base import Script
 
     infoList = ("files", "runs", "tasks", "jobs", "alltasks", "flush", "log")
     statusList = (
@@ -34,8 +34,8 @@ def main():
     )
     dmScript = DMScript()
     dmScript.registerFileSwitches()
-    Script.registerSwitch("", "Info=", "Specify what to print out from %s" % str(infoList))
-    Script.registerSwitch("", "Status=", "Select files with a given status from %s" % str(statusList))
+    Script.registerSwitch("", "Info=", f"Specify what to print out from {str(infoList)}")
+    Script.registerSwitch("", "Status=", f"Select files with a given status from {str(statusList)}")
     Script.registerSwitch("", "Runs=", "Specify a (list of) runs")
     Script.registerSwitch(
         "", "ExceptActiveRunsFromProduction=", "Do not consider runs with active files from these prods"
