@@ -11,16 +11,14 @@
 ###############################################################################
 """In a transformation, flush a list of runs or runs that are flushed in the
 transformation used in BKQuery."""
-
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
     from DIRAC import gLogger
-    from DIRAC.Core.Base import Script
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
 
     Script.registerSwitch("", "Runs=", "   list of runs to flush (comma separated, ranges r1:r2)")
     Script.registerSwitch("", "NoAction", "   No action taken, just give stats")
@@ -30,7 +28,7 @@ def main():
             [
                 __doc__,
                 "Usage:",
-                "  %s [option|cfgfile] <TransID>[,<TransID2>...]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] <TransID>[,<TransID2>...]",
             ]
         )
     )
@@ -67,7 +65,7 @@ def main():
     for transID in transList:
         res = transClient.getTransformationRuns({"TransformationID": transID})
         if not res["OK"]:
-            gLogger.fatal("Error getting runs for transformation %s" % transID, res["Message"])
+            gLogger.fatal(f"Error getting runs for transformation {transID}", res["Message"])
             DIRAC.exit(1)
         runs = res["Value"]
         runs.sort(key=lambda x: int(x["RunNumber"]))
@@ -80,7 +78,7 @@ def main():
                 # Get transformationID used in the BK query, to find out which runs are flushed in there
                 res = transClient.getBookkeepingQuery(transID)
                 if not res["OK"]:
-                    gLogger.fatal("Error getting BK query for transformation %s" % transID, res["Message"])
+                    gLogger.fatal(f"Error getting BK query for transformation {transID}", res["Message"])
                     DIRAC.exit(1)
                 queryProd = res["Value"].get("ProductionID")
                 if not queryProd:
@@ -89,7 +87,7 @@ def main():
 
                 res = transClient.getTransformationRuns({"TransformationID": queryProd})
                 if not res["OK"]:
-                    gLogger.fatal("Error getting runs for transformation %s" % queryProd, res["Message"])
+                    gLogger.fatal(f"Error getting runs for transformation {queryProd}", res["Message"])
                     DIRAC.exit(1)
                 queryRuns = res["Value"]
                 # Get the list of runs flushed in the parent production
@@ -114,17 +112,17 @@ def main():
                             toBeFlushed.append(run)
 
         else:
-            toBeFlushed = sorted(set(runList) & set([run["RunNumber"] for run in runs]))
+            toBeFlushed = sorted(set(runList) & {run["RunNumber"] for run in runs})
 
         ok = 0
         gLogger.always(
-            "Runs %s flushed in transformation %s:" % ("being" if action else "to be", transID),
+            f"Runs {'being' if action else 'to be'} flushed in transformation {transID}:",
             ",".join([str(run) for run in toBeFlushed]),
         )
         for run in toBeFlushed:
             res = transClient.setTransformationRunStatus(transID, run, "Flush") if action else {"OK": True}
             if not res["OK"]:
-                gLogger.fatal("Error setting run %s to Flush in transformation %s" % (run, transID), res["Message"])
+                gLogger.fatal(f"Error setting run {run} to Flush in transformation {transID}", res["Message"])
             else:
                 ok += 1
         gLogger.always("%d runs set to Flush in transformation %d" % (ok, transID))
