@@ -11,15 +11,14 @@
 ###############################################################################
 """Set files Removed in a transformation."""
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
-from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+from DIRAC.Core.Base.Script import Script
+from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
 
 
-@DIRACScript()
+@Script()
 def main():
     import DIRAC
     from DIRAC import gLogger
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -33,7 +32,7 @@ def main():
                 __doc__,
                 "Usage:",
                 "Set files as Removed in a (set of) transformations",
-                "  %s [option|cfgfile] ..." % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] ...",
             ]
         )
     )
