@@ -13,16 +13,12 @@
 <Status> of Transformation <TransID>"""
 import DIRAC
 
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
-    from DIRAC.Core.Utilities.List import breakListIntoChunks
-
-    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript, Script
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+    from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
     dmScript.registerFileSwitches()
@@ -40,31 +36,35 @@ def main():
         "Removed",
         "ProbInFC",
     )
-    Script.registerSwitch("", "Status=", "Select files with a given status from %s" % str(statusList))
-    Script.registerSwitch("", "NewStatus=", "New status to be set (default: %s)" % newStatus)
+    Script.registerSwitch("", "Status=", f"Select files with a given status from {str(statusList)}")
+    Script.registerSwitch("", "NewStatus=", f"New status to be set (default: {newStatus})")
     Script.setUsageMessage(
         __doc__
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile] <TransID> <Status>" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile] <TransID> <Status>",
             ]
         )
     )
     Script.parseCommandLine()
 
+    from DIRAC.Core.Utilities.List import breakListIntoChunks
+    from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+
     switches = Script.getUnprocessedSwitches()
     status = None
     for opt, val in switches:
         if opt == "Status":
             val = set(val.split(","))
             if val & set(statusList) != val:
-                print("Unknown status %s... Select in %s" % (",".join(val), str(statusList)))
+                print(f"Unknown status {','.join(val)}... Select in {str(statusList)}")
                 Script.showHelp(exitCode=1)
             status = list(val)
         elif opt == "NewStatus":
             if val not in statusList:
-                print("Unknown status %s... Select in %s" % (val, str(statusList)))
+                print(f"Unknown status {val}... Select in {str(statusList)}")
                 Script.showHelp()
                 DIRAC.exit(1)
             newStatus = val
@@ -87,18 +87,18 @@ def main():
         if not lfns:
             res = transClient.getTransformation(transID)
             if not res["OK"]:
-                print("Failed to get transformation information: %s" % res["Message"])
+                print(f"Failed to get transformation information: {res['Message']}")
                 DIRAC.exit(2)
 
             selectDict = {"TransformationID": res["Value"]["TransformationID"], "Status": status}
             res = transClient.getTransformationFiles(condDict=selectDict)
             if not res["OK"]:
-                print("Failed to get files: %s" % res["Message"])
+                print(f"Failed to get files: {res['Message']}")
                 DIRAC.exit(2)
 
             lfns = [d["LFN"] for d in res["Value"]]
             if not lfns:
-                print("No files found in transformation %s, status %s" % (transID, status))
+                print(f"No files found in transformation {transID}, status {status}")
 
         if not lfns:
             print("No files to be set in transformation", transID)
@@ -121,7 +121,7 @@ def main():
             print("%d files were set %s in transformation %s" % (resetFiles, newStatus, transID))
             if failed:
                 for reason in failed:
-                    print("Failed for %d files: %s" % (len(failed[reason]), reason))
+                    print(f"Failed for {len(failed[reason])} files: {reason}")
     DIRAC.exit(0)
 
 
