@@ -12,12 +12,12 @@
 """Adds a parameter to an existing transformation"""
 
 from DIRAC import gLogger
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
-@DIRACScript()
+@Script()
 def main():
-    from LHCbDIRAC.TransformationSystem.Utilities.PluginScript import PluginScript, Script
+    from LHCbDIRAC.TransformationSystem.Utilities.PluginScript import PluginScript
 
     pluginScript = PluginScript()
     pluginScript.registerPluginSEParameters()
@@ -27,10 +27,11 @@ def main():
 
     Script.parseCommandLine(ignoreErrors=True)
 
-    from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
-    from LHCbDIRAC.TransformationSystem.Client.Transformation import Transformation
+    from DIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+
     from LHCbDIRAC.DataManagementSystem.Client.AddTransformation import getTransformationName
-    from LHCbDIRAC.TransformationSystem.Utilities.ScriptUtilities import getTransformations
+    from LHCbDIRAC.TransformationSystem.Client.Transformation import Transformation
+    from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
     transList = getTransformations(Script.getPositionalArgs())
 
@@ -55,20 +56,24 @@ def main():
             if tName:
                 res = transformation.setTransformationName(tName)
                 if not res["OK"]:
-                    gLogger.error("Error setting transformation name", "as %s : %s" % (tName, res["Message"]))
+                    gLogger.error("Error setting transformation name", f"as {tName} : {res['Message']}")
                 else:
-                    gLogger.notice("Successfully set transformation name", "as %s" % tName)
+                    gLogger.notice("Successfully set transformation name", f"as {tName}")
             else:
-                gLogger.error("Cannot set transformation name", "as %s" % transName)
+                gLogger.error("Cannot set transformation name", f"as {transName}")
         for key, val in pluginSEParams.items():
             res = transformation.setSEParam(key, val)
             if not res["OK"]:
-                gLogger.error("Error setting SE parameter", "%s = %s : %s" % (key, val, res["Message"]))
+                gLogger.error("Error setting SE parameter", f"{key} = {val} : {res['Message']}")
             else:
-                gLogger.notice("Successfully set parameter", "%s = %s" % (key, val))
+                gLogger.notice("Successfully set parameter", f"{key} = {val}")
         for key, val in pluginParams.items():
             res = transformation.setAdditionalParam(key, val)
             if not res["OK"]:
-                gLogger.error("Error setting additional parameter", "%s = %s : %s" % (key, val, res["Message"]))
+                gLogger.error("Error setting additional parameter", f"{key} = {val} : {res['Message']}")
             else:
-                gLogger.notice("Successfully set parameter", "%s = %s" % (key, val))
+                gLogger.notice("Successfully set parameter", f"{key} = {val}")
+
+
+if __name__ == "__main__":
+    main()
