@@ -12,7 +12,7 @@
 """Set the destination for a set of runs, based on the majority of reco
 output."""
 import DIRAC
-from DIRAC.Core.Utilities.DIRACScript import DIRACScript
+from DIRAC.Core.Base.Script import Script
 
 
 def execute(dmScript):
@@ -48,7 +48,7 @@ def execute(dmScript):
     if "ParameterNames" in res.get("Value", {}):
         parameterNames = res["Value"]["ParameterNames"]
         info = res["Value"]["Records"]
-        progressBar.endLoop("Obtained %d files" % len(info))
+        progressBar.endLoop(f"Obtained {len(info)} files")
     else:
         gLogger.error("\nNo metadata found")
         DIRAC.exit(3)
@@ -61,7 +61,7 @@ def execute(dmScript):
         runLFNs.setdefault(metadata["RunNumber"], []).append(lfn)
 
     chunkSize = 1000
-    progressBar = ProgressBar(len(lfns), title="Getting replicas of %d files" % len(lfns), chunk=chunkSize)
+    progressBar = ProgressBar(len(lfns), title=f"Getting replicas of {len(lfns)} files", chunk=chunkSize)
     replicas = {}
     errors = {}
     for lfnChunk in breakListIntoChunks(lfns, chunkSize):
@@ -75,12 +75,12 @@ def execute(dmScript):
                 errors.setdefault(error, []).append(lfn)
     progressBar.endLoop()
     for error, lfns in errors.items():
-        gLogger.error(error, "for %d files" % len(lfns))
+        gLogger.error(error, f"for {len(lfns)} files")
 
     tier1RDST = set(resolveSEGroup("Tier1-RDST"))
     setOK = 0
     errors = {}
-    progressBar = ProgressBar(len(runLFNs), title="Defining destination for %d runs" % len(runLFNs), step=10)
+    progressBar = ProgressBar(len(runLFNs), title=f"Defining destination for {len(runLFNs)} runs", step=10)
     for run, lfns in runLFNs.items():
         progressBar.loop()
         res = tr.getDestinationForRun(run)
@@ -113,12 +113,11 @@ def execute(dmScript):
                 setOK += 1
     progressBar.endLoop("Successfully set destination for %d runs" % setOK)
     for error, runs in errors.items():
-        gLogger.error(error, "for runs %s" % ",".join(runs))
+        gLogger.error(error, f"for runs {','.join(runs)}")
 
 
-@DIRACScript()
+@Script()
 def main():
-    from DIRAC.Core.Base import Script
     from LHCbDIRAC.DataManagementSystem.Client.DMScript import DMScript
 
     dmScript = DMScript()
@@ -129,7 +128,7 @@ def main():
         + "\n".join(
             [
                 "Usage:",
-                "  %s [option|cfgfile]" % Script.scriptName,
+                f"  {Script.scriptName} [option|cfgfile]",
             ]
         )
     )
