@@ -11,9 +11,9 @@
 """ Analyse XMLSummary module and PoolCatalog in order to monitor the files access
     We send data to the accounting (Site -> SE : fail/success)
 """
+
 from collections import defaultdict
 
-import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.AccountingSystem.Client.Types.DataOperation import DataOperation
 from DIRAC.Resources.Catalog.PoolXMLCatalog import PoolXMLCatalog
@@ -28,9 +28,8 @@ class AnalyseFileAccess(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("AnalyseFileAccess")
-        super(AnalyseFileAccess, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = LHCbDIRAC.version
         self.XMLSummary = ""
         self.XMLSummary_o = None
         self.poolXMLCatName = ""
@@ -40,8 +39,8 @@ class AnalyseFileAccess(ModuleBase):
     def _resolveInputVariables(self):
         """By convention any workflow parameters are resolved here."""
 
-        super(AnalyseFileAccess, self)._resolveInputVariables()
-        super(AnalyseFileAccess, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
         self.XMLSummary_o = XMLSummary(self.XMLSummary, log=self.log)
         self.dsc = self.workflow_commons["AccountingReport"]
@@ -65,8 +64,7 @@ class AnalyseFileAccess(ModuleBase):
         """
 
         try:
-            super(AnalyseFileAccess, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -87,7 +85,7 @@ class AnalyseFileAccess(ModuleBase):
                 else:
                     raise e
 
-            self.log.info("Analyzing root access from %s and %s" % (self.XMLSummary, self.poolXMLCatName))
+            self.log.info(f"Analyzing root access from {self.XMLSummary} and {self.poolXMLCatName}")
 
             accessAttempts = self._checkFileAccess(self.poolXMLCatName_o, self.XMLSummary_o)
 
@@ -107,7 +105,7 @@ class AnalyseFileAccess(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(AnalyseFileAccess, self).finalize(self.version)
+            super().finalize()
 
     @staticmethod
     def _checkFileAccess(xmlCatalog, xmlSummary):
