@@ -11,7 +11,6 @@
 """Analyse XMLSummary module."""
 import os
 
-import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Resources.Catalog.PoolXMLFile import getGUID
 from DIRAC.FrameworkSystem.Client.NotificationClient import NotificationClient
@@ -28,9 +27,8 @@ class AnalyseXMLSummary(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("AnalyseXMLSummary")
-        super(AnalyseXMLSummary, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = LHCbDIRAC.version
         self.nc = NotificationClient()
         self.XMLSummary = ""
         self.XMLSummary_o = None
@@ -38,8 +36,8 @@ class AnalyseXMLSummary(ModuleBase):
     def _resolveInputVariables(self):
         """By convention any workflow parameters are resolved here."""
 
-        super(AnalyseXMLSummary, self)._resolveInputVariables()
-        super(AnalyseXMLSummary, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
         self.XMLSummary_o = XMLSummary(self.XMLSummary, log=self.log)
 
@@ -62,8 +60,7 @@ class AnalyseXMLSummary(ModuleBase):
         """
 
         try:
-            super(AnalyseXMLSummary, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -77,7 +74,7 @@ class AnalyseXMLSummary(ModuleBase):
 
             self._resolveInputVariables()
 
-            self.log.info("Performing XML summary analysis for %s" % (self.XMLSummary))
+            self.log.info(f"Performing XML summary analysis for {self.XMLSummary}")
             # Resolve the step and job input data
 
             self.step_commons["XMLSummary_o"] = self.XMLSummary_o
@@ -106,8 +103,8 @@ class AnalyseXMLSummary(ModuleBase):
             if not self.stepStatus["OK"]:
                 return S_OK()
 
-            self.log.info("XML summary %s" % self.XMLSummary)
-            self.setApplicationStatus("%s Step OK" % self.applicationName)
+            self.log.info(f"XML summary {self.XMLSummary}")
+            self.setApplicationStatus(f"{self.applicationName} Step OK")
             return S_OK()
 
         except Exception as e:  # pylint:disable=broad-except
@@ -116,7 +113,7 @@ class AnalyseXMLSummary(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(AnalyseXMLSummary, self).finalize(self.version)
+            super().finalize()
 
     def _basicSuccess(self):
         """Treats basic success, meaning the outputs and the status of the XML
@@ -133,20 +130,20 @@ class AnalyseXMLSummary(ModuleBase):
             else:
                 # report to FileReport
                 filesInPart = [x[0].strip("LFN:") for x in self.XMLSummary_o.inputStatus if x[1] == "part"]
-                self.log.error("Files %s are in status 'part'" % ";".join(filesInPart))
+                self.log.error(f"Files {';'.join(filesInPart)} are in status 'part'")
                 for fileInPart in filesInPart:
                     if fileInPart in self.inputDataList:
-                        self.log.error("Reporting %s as 'Problematic'" % fileInPart)
+                        self.log.error(f"Reporting {fileInPart} as 'Problematic'")
                         self.fileReport.setFileStatus(int(self.production_id), fileInPart, "Problematic")
                         failTheJob = True
 
         if self.XMLSummary_o.inputFileStats["fail"]:
             # report to FileReport
             filesInFail = [x[0].strip("LFN:") for x in self.XMLSummary_o.inputStatus if x[1] == "fail"]
-            self.log.error("Files %s are in status 'fail'" % ";".join(filesInFail))
+            self.log.error(f"Files {';'.join(filesInFail)} are in status 'fail'")
             for fileInFail in filesInFail:
                 if fileInFail in self.inputDataList:
-                    self.log.error("Reporting %s as 'Problematic'" % fileInFail)
+                    self.log.error(f"Reporting {fileInFail} as 'Problematic'")
                     self.fileReport.setFileStatus(int(self.production_id), fileInFail, "Problematic")
                     failTheJob = True
 
@@ -167,11 +164,11 @@ class AnalyseXMLSummary(ModuleBase):
         result = constructProductionLFNs(self.workflow_commons, self.bkClient)
 
         if not result["OK"]:
-            self.log.error('Could not create production LFNs with message "%s"' % (result["Message"]))
+            self.log.error(f"Could not create production LFNs with message \"{result['Message']}\"")
             raise Exception(result["Message"])
 
         if "DebugLFNs" not in result["Value"]:
-            self.log.error("No debug LFNs found after creating production LFNs, result was:%s" % result)
+            self.log.error(f"No debug LFNs found after creating production LFNs, result was:{result}")
             raise Exception("DebugLFNs Not Found")
 
         debugLFNs = result["Value"]["DebugLFNs"]
@@ -210,7 +207,7 @@ class AnalyseXMLSummary(ModuleBase):
 
             guidInput = ""
             if not guidResult["OK"]:
-                self.log.error("Could not find GUID for %s with message" % (fname), guidResult["Message"])
+                self.log.error(f"Could not find GUID for {fname} with message", guidResult["Message"])
             elif guidResult["generated"]:
                 self.log.info(
                     "PoolXMLFile generated GUID(s) for the following files ", ", ".join(guidResult["generated"])
@@ -228,7 +225,7 @@ class AnalyseXMLSummary(ModuleBase):
                 self.log.info(result)
                 if not result["OK"]:
                     self.log.error("Could not save INPUT data file with result", str(result["Message"]))
-                    msg += "Could not save intermediate data file %s with result\n%s\n" % (fname, result["Message"])
+                    msg += f"Could not save intermediate data file {fname} with result\n{result['Message']}\n"
                 else:
                     msg = msg + lfn + "\n" + str(result) + "\n"
             else:
@@ -239,11 +236,11 @@ class AnalyseXMLSummary(ModuleBase):
 
         if not self._WMSJob():
             self.log.info(
-                "JOBID is null, *NOT* sending mail, for information the mail was:\n====>Start\n%s\n<====End" % (msg)
+                f"JOBID is null, *NOT* sending mail, for information the mail was:\n====>Start\n{msg}\n<====End"
             )
         else:
             mailAddress = self.opsH.getValue("EMail/JobFailures", "lhcb-datacrash@cern.ch")
-            self.log.info("Sending crash mail for job to %s" % (mailAddress))
+            self.log.info(f"Sending crash mail for job to {mailAddress}")
 
             res = self.nc.sendMail(mailAddress, subject, msg, "joel.closier@cern.ch", localAttempt=False)
             if not res["OK"]:
