@@ -10,6 +10,7 @@
 ###############################################################################
 """Bookkeeping Reporting module (just prepare the files, do not send them
 (which is done in the uploadOutput)"""
+
 import os
 import re
 import shlex
@@ -36,9 +37,7 @@ class BookkeepingReport(ModuleBase):
 
         self.log = gLogger.getSubLogger("BookkeepingReport")
 
-        super(BookkeepingReport, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.simDescription = "NoSimConditions"
         self.eventType = ""
@@ -72,9 +71,7 @@ class BookkeepingReport(ModuleBase):
     ):
         """Usual executor."""
         try:
-
-            super(BookkeepingReport, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -108,7 +105,7 @@ class BookkeepingReport(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(BookkeepingReport, self).finalize(self.version)
+            super().finalize()
 
     ################################################################################
     # AUXILIAR FUNCTIONS
@@ -117,8 +114,8 @@ class BookkeepingReport(ModuleBase):
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
 
-        super(BookkeepingReport, self)._resolveInputVariables()
-        super(BookkeepingReport, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
         self.stepOutputs, _sot, _hist = self._determineOutputs()
 
@@ -136,7 +133,6 @@ class BookkeepingReport(ModuleBase):
             and "LogFilePath" in self.workflow_commons
             and "ProductionOutputData" in self.workflow_commons
         ):
-
             logFilePath = self.workflow_commons["LogFilePath"]
             bkLFNs = self.workflow_commons["BookkeepingLFNs"]
 
@@ -169,27 +165,27 @@ class BookkeepingReport(ModuleBase):
                 xmlSummaryFile = self.step_commons["XMLSummary"]
             except KeyError:
                 self.log.warn("XML Summary file name not found, will try to guess it")
-                xmlSummaryFile = "summary%s_%s_%s_%s.xml" % (
+                xmlSummaryFile = "summary{}_{}_{}_{}.xml".format(
                     self.applicationName,
                     self.production_id,
                     self.prod_job_id,
                     self.step_number,
                 )
-                self.log.warn("Trying %s" % xmlSummaryFile)
+                self.log.warn(f"Trying {xmlSummaryFile}")
                 if xmlSummaryFile not in os.listdir("."):
-                    self.log.warn("XML Summary file %s not found, will try to guess a second time" % xmlSummaryFile)
-                    xmlSummaryFile = "summary%s_%s.xml" % (self.applicationName, self.step_id)
-                    self.log.warn("Trying %s" % xmlSummaryFile)
+                    self.log.warn(f"XML Summary file {xmlSummaryFile} not found, will try to guess a second time")
+                    xmlSummaryFile = f"summary{self.applicationName}_{self.step_id}.xml"
+                    self.log.warn(f"Trying {xmlSummaryFile}")
                     if xmlSummaryFile not in os.listdir("."):
                         self.log.warn(
-                            "XML Summary file %s not found, will try to guess a third and last time" % xmlSummaryFile
+                            f"XML Summary file {xmlSummaryFile} not found, will try to guess a third and last time"
                         )
-                        xmlSummaryFile = "summary%s_%s.xml" % (self.applicationName, self.step_number)
-                        self.log.warn("Trying %s" % xmlSummaryFile)
+                        xmlSummaryFile = f"summary{self.applicationName}_{self.step_number}.xml"
+                        self.log.warn(f"Trying {xmlSummaryFile}")
             try:
                 self.xf_o = XMLSummary(xmlSummaryFile)
             except XMLSummaryError as e:
-                self.log.warn("No XML summary available", "%s" % repr(e))
+                self.log.warn("No XML summary available", f"{repr(e)}")
                 self.xf_o = None
 
         return bkLFNs, logFilePath
@@ -358,7 +354,7 @@ class BookkeepingReport(ModuleBase):
                 out = self.step_commons["md5"][output]
 
             if status:
-                self.log.info("Failed to get md5sum of %s" % str(output))
+                self.log.info(f"Failed to get md5sum of {str(output)}")
                 self.log.info(str(out))
                 md5sum = "000000000000000000000000000000000000"
             else:
@@ -368,7 +364,7 @@ class BookkeepingReport(ModuleBase):
                 guidResult = getGUID(output)
                 guid = ""
                 if not guidResult["OK"]:
-                    self.log.error("Could not find GUID", "for %s with message %s" % (output, guidResult["Message"]))
+                    self.log.error("Could not find GUID", f"for {output} with message {guidResult['Message']}")
                 elif guidResult["generated"]:
                     self.log.warn(
                         "PoolXMLFile generated GUID(s) for the following files ", ", ".join(guidResult["generated"])
@@ -376,12 +372,12 @@ class BookkeepingReport(ModuleBase):
                     guid = guidResult["Value"][output]
                 else:
                     guid = guidResult["Value"][output]
-                    self.log.info("Setting POOL XML catalog GUID", "for %s to %s" % (output, guid))
+                    self.log.info("Setting POOL XML catalog GUID", f"for {output} to {guid}")
             else:
                 guid = self.step_commons["guid"][output]
 
             if not guid:
-                self.log.error("No GUID found", "for %s" % output)
+                self.log.error("No GUID found", f"for {output}")
                 raise NameError("No GUID found")
 
             # find the constructed lfn
@@ -393,7 +389,7 @@ class BookkeepingReport(ModuleBase):
                         lfn = outputLFN
                         break
                 else:
-                    self.log.error("Could not find LFN", "for %s" % output)
+                    self.log.error("Could not find LFN", f"for {output}")
                     raise NameError("Could not find LFN of output file")
 
             oldTypeName = None
@@ -402,7 +398,7 @@ class BookkeepingReport(ModuleBase):
 
             # PROTECTION for old production XMLs
             if typeName.upper() == "HIST":
-                typeName = "%sHIST" % (self.applicationName.upper())
+                typeName = f"{self.applicationName.upper()}HIST"
 
             # Add Output to the XML file
             outputFile = BookkeepingJobInfo.OutputFile(
@@ -458,13 +454,13 @@ class BookkeepingReport(ModuleBase):
                 if output.lower() == outputFileInXML.lower():
                     self.log.info(
                         "Found output LFN in XML summary object with different case",
-                        "%s -> %s" % (output, outputFileInXML),
+                        f"{output} -> {outputFileInXML}",
                     )
                     return str(self.xf_o.outputsEvents[outputFileInXML]), outputFileInXML
 
             if ("hist" in outputtype.lower()) or (".root" in outputtype.lower()):
                 self.log.warn(
-                    "HIST file not found in XML summary, event stats set to 'Unknown'", "HIST not found = %s" % output
+                    "HIST file not found in XML summary, event stats set to 'Unknown'", f"HIST not found = {output}"
                 )
                 return "Unknown", output
 
