@@ -10,9 +10,9 @@
 ###############################################################################
 """Prepare a file (data.py) which is consumed by Ganga, containing the input
 files as resolved in the workflow."""
+
 from DIRAC import S_OK, S_ERROR, gLogger
 
-import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Core.Utilities.GangaDataFile import GangaDataFile
 
@@ -25,18 +25,17 @@ class CreateDataFile(ModuleBase):
 
         self.log = gLogger.getSubLogger("CreateDataFile")
 
-        super(CreateDataFile, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.gangaFileName = "data.py"
         self.poolXMLCatName = "pool_xml_catalog.xml"
         self.persistency = ""
-        self.version = LHCbDIRAC.version
 
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
 
-        super(CreateDataFile, self)._resolveInputVariables()
-        super(CreateDataFile, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
     def execute(
         self,
@@ -54,9 +53,7 @@ class CreateDataFile(ModuleBase):
         """Just calls GangaDataFile with some parameter."""
 
         try:
-
-            super(CreateDataFile, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -88,4 +85,4 @@ class CreateDataFile(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(CreateDataFile, self).finalize(self.version)
+            super().finalize()
