@@ -19,22 +19,19 @@ import os
 
 from DIRAC import S_OK, S_ERROR, gLogger
 
-import LHCbDIRAC
 import LHCbDIRAC.Core.Utilities.LogErr as LogErr
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
 
 class ErrorLogging(ModuleBase):
-
     #############################################################################
 
     def __init__(self):
         """c'tor."""
 
         self.log = gLogger.getSubLogger("ErrorLogging")
-        super(ErrorLogging, self).__init__(self.log)
+        super().__init__(self.log)
 
-        self.version = LHCbDIRAC.version
         # Internal parameters
         self.errorLogNameHTML = ""
         self.errorLogNamejson = ""
@@ -43,8 +40,8 @@ class ErrorLogging(ModuleBase):
 
     def _resolveInputVariables(self):
         """By convention the module input parameters are resolved here."""
-        super(ErrorLogging, self)._resolveInputVariables()
-        super(ErrorLogging, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
         self.errorLogNamejson = "%d_Errors_%s.json" % (self.jobID, self.applicationName)
 
@@ -69,9 +66,7 @@ class ErrorLogging(ModuleBase):
         """
 
         try:
-
-            super(ErrorLogging, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -94,22 +89,18 @@ class ErrorLogging(ModuleBase):
                 % (self.applicationName, self.applicationVersion, self.applicationLog)
             )
             if not os.path.exists(self.applicationLog):
-                self.log.info("Application log file from previous module not found locally: %s" % self.applicationLog)
+                self.log.info(f"Application log file from previous module not found locally: {self.applicationLog}")
                 return S_OK()
 
             # Now really running
             # self.step_commons['extraPackages'] is something like 'AppConfig.v3r360;TurboStreamProd.v4r2p9;ProdConf'
-            appConfigVersion = [
-                x.split(".")[1] for x in self.step_commons["extraPackages"].split(";") if "AppConfig" in x
-            ][0]
             result = LogErr.readLogFile(
                 logFile=self.applicationLog,
-                project=self.applicationName,
-                version=self.applicationVersion,
-                appConfigVersion=appConfigVersion,
                 jobID=self.prod_job_id,
                 prodID=self.production_id,
                 wmsID=self.jobID,
+                application=self.applicationName,
+                applicationVersion=self.applicationVersion,
                 name=self.errorLogNamejson,
             )
 
@@ -122,9 +113,7 @@ class ErrorLogging(ModuleBase):
                 return S_OK()
 
             if not os.path.exists(self.errorLogNamejson):
-                self.log.error(
-                    "%s not found locally, exiting without affecting workflow status" % self.errorLogNamejson
-                )
+                self.log.error(f"{self.errorLogNamejson} not found locally, exiting without affecting workflow status")
                 return S_OK()
 
             self.log.info(
@@ -139,4 +128,4 @@ class ErrorLogging(ModuleBase):
             return S_ERROR("Error in ErrorLogging module")
 
         finally:
-            super(ErrorLogging, self).finalize(self.version)
+            super().finalize()
