@@ -16,28 +16,24 @@ request (for failover)
 """
 from DIRAC import S_OK, S_ERROR, gLogger
 
-import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
 
 class FailoverRequest(ModuleBase):
-
     #############################################################################
 
     def __init__(self, bkClient=None, dm=None):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("FailoverRequest")
-        super(FailoverRequest, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
     #############################################################################
 
     def _resolveInputVariables(self):
         """By convention the module input parameters are resolved here."""
-        super(FailoverRequest, self)._resolveInputVariables()
-        super(FailoverRequest, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
     #############################################################################
 
@@ -56,9 +52,7 @@ class FailoverRequest(ModuleBase):
         """Main execution function."""
 
         try:
-
-            super(FailoverRequest, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -114,9 +108,7 @@ class FailoverRequest(ModuleBase):
                 # This will try a second time a commit, before generating a SetFileStatus operation
                 result = self.fileReport.generateForwardDISET()
                 if not result["OK"]:
-                    self.log.warn(
-                        "Could not generate Operation for file report", "with result:\n%s" % (result["Message"])
-                    )
+                    self.log.warn("Could not generate Operation for file report", f"with result:\n{result['Message']}")
                 else:
                     if result["Value"] is None:  # Means the FileReport managed to report, no need for a new operation
                         self.log.info("On second attempt, files correctly reported to TransformationDB")
@@ -143,7 +135,7 @@ class FailoverRequest(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(FailoverRequest, self).finalize(self.version)
+            super().finalize()
 
 
 # EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#
