@@ -12,7 +12,6 @@
 defined in the user workflow."""
 import os
 
-import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger, gConfig
 from DIRAC.Core.Utilities import DEncode
 from DIRAC.RequestManagementSystem.Client.Request import Operation
@@ -21,21 +20,19 @@ from LHCbDIRAC.DataManagementSystem.Client.DataUsageClient import DataUsageClien
 
 
 class FileUsage(ModuleBase):
-
     #############################################################################
 
     def __init__(self, bkClient=None, dm=None):
         """Module initialization."""
         self.log = gLogger.getSubLogger("FileUsage")
-        super(FileUsage, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
         self.dataUsageClient = DataUsageClient()
 
     #############################################################################
 
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
-        super(FileUsage, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
         dirDict = {}
         if self.inputDataList:
@@ -68,9 +65,7 @@ class FileUsage(ModuleBase):
         """Main execution function."""
 
         try:
-
-            super(FileUsage, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -108,7 +103,7 @@ class FileUsage(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(FileUsage, self).finalize(self.version)
+            super().finalize()
 
     #############################################################################
 
@@ -119,13 +114,13 @@ class FileUsage(ModuleBase):
         """
         self.log.verbose("Reporting input file usage:")
         for entry in dirDict:
-            self.log.verbose("%s:%s" % (entry, dirDict[entry]))
+            self.log.verbose(f"{entry}:{dirDict[entry]}")
         localSite = gConfig.getValue("/LocalSite/Site", "UNKNOWN")
         try:
             localSite = localSite.split(".")[1]
         except BaseException:
             pass
-        self.log.verbose("Using Site Name: %s" % (localSite))
+        self.log.verbose(f"Using Site Name: {localSite}")
 
         if self._enableModule():
             usageStatus = self.dataUsageClient.sendDataUsageReport(localSite, dirDict)
@@ -138,7 +133,7 @@ class FileUsage(ModuleBase):
                 self.request.addOperation(forwardDISETOp)
                 self.workflow_commons["Request"] = self.request
         else:
-            self.log.info("Would have attempted to report %s at %s" % (dirDict, localSite))
+            self.log.info(f"Would have attempted to report {dirDict} at {localSite}")
             return S_OK()
 
         return S_OK()
