@@ -19,7 +19,6 @@ import os
 from DIRAC import S_OK, S_ERROR, gLogger, gConfig
 from DIRAC.Core.Utilities import DErrno
 
-import LHCbDIRAC
 from LHCbDIRAC.Core.Utilities.ProductionOptions import getDataOptions, getModuleOptions
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Core.Utilities.RunApplication import RunApplication, LbRunError, LHCbApplicationError, LHCbDIRACError
@@ -32,7 +31,7 @@ class GaudiApplication(ModuleBase):
         """Usual init for LHCb workflow modules."""
 
         self.log = gLogger.getSubLogger("GaudiApplication")
-        super(GaudiApplication, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.systemConfig = ""
         self.stdError = ""
@@ -48,8 +47,8 @@ class GaudiApplication(ModuleBase):
     def _resolveInputVariables(self):
         """Resolve all input variables for the module here."""
 
-        super(GaudiApplication, self)._resolveInputVariables()
-        super(GaudiApplication, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
     def execute(
         self,
@@ -71,8 +70,7 @@ class GaudiApplication(ModuleBase):
         """
 
         try:
-            super(GaudiApplication, self).execute(
-                LHCbDIRAC.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -104,7 +102,7 @@ class GaudiApplication(ModuleBase):
                 commandOptions = []
                 if self.optionsFile and self.optionsFile != "None":
                     commandOptions += self.optionsFile.split(";")
-                self.log.info("Final options files: %s" % (", ".join(commandOptions)))
+                self.log.info("Final options files:", ", ".join(commandOptions))
 
             runNumberGauss = 0
             firstEventNumberGauss = 0
@@ -157,9 +155,7 @@ class GaudiApplication(ModuleBase):
                 )[
                     "Value"
                 ]  # always OK
-                self.log.info(
-                    "Extra options generated for %s %s step:" % (self.applicationName, self.applicationVersion)
-                )
+                self.log.info(f"Extra options generated for {self.applicationName} {self.applicationVersion} step:")
                 print(
                     projectOpts
                 )  # Always useful to see in the logs (don't use gLogger as we often want to cut n' paste)
@@ -180,16 +176,16 @@ class GaudiApplication(ModuleBase):
             )
 
             # Now really running
-            self.setApplicationStatus("%s step %s" % (self.applicationName, self.step_number))
+            self.setApplicationStatus(f"{self.applicationName} step {self.step_number}")
             ra.run()  # This would trigger an exception in case of failure, or application status != 0
 
-            self.log.info("Going to manage %s output" % self.applicationName)
+            self.log.info(f"Going to manage {self.applicationName} output")
             self._manageAppOutput(stepOutputs)
 
             # Still have to set the application status e.g. user job case.
-            self.setApplicationStatus("%s %s Successful" % (self.applicationName, self.applicationVersion))
+            self.setApplicationStatus(f"{self.applicationName} {self.applicationVersion} Successful")
 
-            return S_OK("%s %s Successful" % (self.applicationName, self.applicationVersion))
+            return S_OK(f"{self.applicationName} {self.applicationVersion} Successful")
 
         except LbRunError as lbre:  # This is the case for lb-run/environment errors
             self.setApplicationStatus(repr(lbre))
@@ -205,4 +201,4 @@ class GaudiApplication(ModuleBase):
             self.setApplicationStatus("Error in GaudiApplication module")
             return S_ERROR(str(exc))
         finally:
-            super(GaudiApplication, self).finalize(LHCbDIRAC.version)
+            super().finalize()
