@@ -26,9 +26,7 @@ class MergeMDF(ModuleBase):
     def __init__(self, bkClient=None, dm=None):
         """Module initialization."""
         self.log = gLogger.getSubLogger("MergeMDF")
-        super(MergeMDF, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.outputLFN = ""
         # List all input parameters here
@@ -40,8 +38,8 @@ class MergeMDF(ModuleBase):
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
 
-        super(MergeMDF, self)._resolveInputVariables()
-        super(MergeMDF, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
     #############################################################################
 
@@ -60,9 +58,7 @@ class MergeMDF(ModuleBase):
         """Main execution function."""
 
         try:
-
-            super(MergeMDF, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -80,17 +76,17 @@ class MergeMDF(ModuleBase):
 
             stepOutputs, stepOutputTypes, _histogram = self._determineOutputs()
 
-            logLines = ["#" * len(self.version), self.version, "#" * len(self.version)]
+            logLines = ["#" * len(LHCbDIRAC.version), LHCbDIRAC.version, "#" * len(LHCbDIRAC.version)]
 
             localInputs = [str(list(poolCat.getPfnsByLfn(x)["Replicas"].values())[0]) for x in self.stepInputData]
             inputs = " ".join(localInputs)
-            cmd = "cat %s > %s" % (inputs, self.outputFilePrefix + "." + stepOutputTypes[0])
+            cmd = f"cat {inputs} > {self.outputFilePrefix + '.' + stepOutputTypes[0]}"
             logLines.append("\nExecuting merge operation...")
-            self.log.info('Executing "%s"' % cmd)
+            self.log.info(f'Executing "{cmd}"')
             result = systemCall(timeout=600, cmdSeq=shlex.split(cmd))
             if not result["OK"]:
                 self.log.error(result)
-                logLines.append("Merge operation failed with result:\n%s" % result)
+                logLines.append(f"Merge operation failed with result:\n{result}")
                 return S_ERROR("Problem Executing Application")
 
             status = result["Value"][0]
@@ -101,16 +97,16 @@ class MergeMDF(ModuleBase):
                 self.log.error(stderr)
 
             if status:
-                msg = 'Non-zero status %s while executing "%s"' % (status, cmd)
+                msg = f'Non-zero status {status} while executing "{cmd}"'
                 self.log.info(msg)
                 logLines.append(msg)
                 return S_ERROR("Problem Executing Application")
 
-            self.log.info("Going to manage %s output" % self.applicationName)
+            self.log.info(f"Going to manage {self.applicationName} output")
             self._manageAppOutput(stepOutputs)
 
             # Still have to set the application status e.g. user job case.
-            self.setApplicationStatus("%s %s Successful" % (self.applicationName, self.applicationVersion))
+            self.setApplicationStatus(f"{self.applicationName} {self.applicationVersion} Successful")
 
             # Write to log file
             msg = "Produced merged MDF file"
@@ -121,14 +117,14 @@ class MergeMDF(ModuleBase):
             with open(self.applicationLog, "w") as fopen:
                 fopen.write("\n".join(logLines) + "\n")
 
-            return S_OK("%s %s Successful" % (self.applicationName, self.applicationVersion))
+            return S_OK(f"{self.applicationName} {self.applicationVersion} Successful")
 
         except Exception as e:  # pylint:disable=broad-except
             self.log.exception("Failure in MergeMDF execute module", lException=e)
             return S_ERROR(str(e))
 
         finally:
-            super(MergeMDF, self).finalize(self.version)
+            super().finalize()
 
 
 # EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#EOF#
