@@ -29,12 +29,13 @@ from DIRAC.RequestManagementSystem.Client.File import File
 from DIRAC.RequestManagementSystem.private.RequestValidator import RequestValidator
 from DIRAC.DataManagementSystem.Client.DataManager import DataManager
 
+import LHCbDIRAC
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 from LHCbDIRAC.Core.Utilities.ProductionData import getLogPath, constructProductionLFNs
 from LHCbDIRAC.Workflow.Modules.ModulesUtilities import getNumberOfProcessorsToUse
 
 
-class ModuleBase(object):
+class ModuleBase:
     """Base class for Modules - works only within DIRAC workflows"""
 
     #############################################################################
@@ -125,7 +126,7 @@ class ModuleBase(object):
         self.simDescription = ""
         self.siteName = None
         self.stepName = None
-        self.stepInputData = None
+        self.stepInputData = []
         self.XMLSummary = ""  # name of the file, not the object
         self.stepProcPass = None
         self.outputFilePrefix = ""
@@ -134,7 +135,6 @@ class ModuleBase(object):
 
     def execute(
         self,
-        version=None,
         production_id=None,
         prod_job_id=None,
         wms_job_id=None,
@@ -146,11 +146,9 @@ class ModuleBase(object):
         step_id=None,
     ):
         """Function called by all super classes."""
+        self.log.info(f"===== Executing {LHCbDIRAC.version} ===== ")
 
-        if version:
-            self.log.info("===== Executing " + version + " ===== ")
-
-        self.log.verbose("Executing directory for job is %s" % os.getcwd())
+        self.log.verbose(f"Executing directory for job is {os.getcwd()}")
 
         if production_id:
             self.production_id = production_id
@@ -188,17 +186,14 @@ class ModuleBase(object):
         if step_id:
             self.step_id = step_id
         else:
-            self.step_id = "%s_%s_%s" % (self.production_id, self.prod_job_id, self.step_number)
+            self.step_id = f"{self.production_id}_{self.prod_job_id}_{self.step_number}"
 
         self.siteName = siteName()
 
     #############################################################################
 
-    def finalize(self, version=None):
-        """Just finalizing."""
-
-        if version:
-            self.log.info("===== Terminating " + version + " ===== ")
+    def finalize(self):
+        self.log.info(f"===== Terminating {LHCbDIRAC.version} ===== ")
 
     #############################################################################
 
@@ -285,7 +280,7 @@ class ModuleBase(object):
             if not (self.onlineDDDBTag and self.onlineCondDBTag and self.TCK):
                 self.log.error(
                     "Missing normally required Run Metadata",
-                    "DDDB=%s, CondDb=%s, TCK=%s" % (self.onlineDDDBTag, self.onlineCondDBTag, self.TCK),
+                    f"DDDB={self.onlineDDDBTag}, CondDb={self.onlineCondDBTag}, TCK={self.TCK}",
                 )
 
         if "outputDataFileMask" in self.workflow_commons:
@@ -337,7 +332,7 @@ class ModuleBase(object):
             histoTypes = self.opsH.getValue(
                 "Productions/HistogramTypes", ["HIST", "BRUNELHIST", "DAVINCIHIST", "GAUSSHIST"]
             )
-            self.outputSEs = dict((ht, histogramSE) for ht in histoTypes)
+            self.outputSEs = {ht: histogramSE for ht in histoTypes}
         # for older productions we construct it based on what should be found in the steps
         if "listoutput" in self.step_commons:
             listOutputStep = self.step_commons["listoutput"]
@@ -373,7 +368,7 @@ class ModuleBase(object):
 
         # this is only for production jobs and for application steps
         if prodID and jobID and stepInstanceNumber and "listoutput" in self.step_commons:
-            self.outputFilePrefix = "%s_%s_%s" % (prodID, jobID, stepInstanceNumber)
+            self.outputFilePrefix = f"{prodID}_{jobID}_{stepInstanceNumber}"
             self.applicationLog = self.applicationName + "_" + self.outputFilePrefix + ".log"
             self.XMLSummary = "summary" + self.applicationName + "_" + self.outputFilePrefix + ".xml"
             self.histoName = self.applicationName + "_" + self.outputFilePrefix + ".Hist.root"
@@ -405,7 +400,7 @@ class ModuleBase(object):
         if "extraPackages" in self.step_commons:
             self.extraPackages = self.step_commons["extraPackages"]
             if self.extraPackages:
-                if isinstance(self.extraPackages, six.string_types):
+                if isinstance(self.extraPackages, str):
                     eps = self.extraPackages.split(";")  # pylint: disable=no-member
                     epList = []
                     for ep in eps:
@@ -506,7 +501,7 @@ class ModuleBase(object):
 
                 outputTypes = list(outputTypes)
                 if len(outputTypes) > 1:
-                    raise ValueError("Not all input files have the same type (%s)" % ",".join(outputTypes))
+                    raise ValueError(f"Not all input files have the same type ({','.join(outputTypes)})")
                 outputType = outputTypes[0].lower()
                 stepOutTypes = [outputType.lower()]
                 stepOutputs = [
@@ -603,21 +598,19 @@ class ModuleBase(object):
             if os.path.basename(lfn).lower() in list(fi.lower() for fi in fileInfo):
                 try:
                     fileInfo[os.path.basename(lfn)]["lfn"] = lfn
-                    self.log.verbose("Found LFN for file", "%s -> %s" % (lfn, os.path.basename(lfn)))
+                    self.log.verbose("Found LFN for file", f"{lfn} -> {os.path.basename(lfn)}")
                 except KeyError:
                     fileInfo[os.path.basename(lfn).lower()]["lfn"] = lfn
-                    self.log.verbose("Found LFN for file", "%s -> %s" % (lfn, os.path.basename(lfn).lower()))
+                    self.log.verbose("Found LFN for file", f"{lfn} -> {os.path.basename(lfn).lower()}")
             elif os.path.basename(lfn).split("_")[-1].lower() in list(fi.lower() for fi in fileInfo):
                 try:
                     fileInfo[os.path.basename(lfn).split("_")[-1]]["lfn"] = lfn
-                    self.log.verbose("Found LFN for file", " %s -> %s" % (lfn, os.path.basename(lfn).split("_")[-1]))
+                    self.log.verbose("Found LFN for file", f" {lfn} -> {os.path.basename(lfn).split('_')[-1]}")
                 except KeyError:
                     fileInfo[os.path.basename(lfn).split("_")[-1].lower()]["lfn"] = lfn
-                    self.log.verbose(
-                        "Found LFN for file", " %s -> %s" % (lfn, os.path.basename(lfn).split("_")[-1].lower())
-                    )
+                    self.log.verbose("Found LFN for file", f" {lfn} -> {os.path.basename(lfn).split('_')[-1].lower()}")
             else:
-                self.log.warn("LFN not recognized", "for LFN %s" % lfn)
+                self.log.warn("LFN not recognized", f"for LFN {lfn}")
 
         # check local existance
         fileList = self._checkLocalExistance(list(fileInfo))
@@ -661,11 +654,11 @@ class ModuleBase(object):
         filesOnDisk = set(os.listdir("."))
         diff = set(fileList).difference(filesOnDisk)
         if diff:
-            self.log.warn("Not all files found", "set of what's on the disk: %s" % filesOnDisk)
+            self.log.warn("Not all files found", f"set of what's on the disk: {filesOnDisk}")
             self.log.warn("Looking for files with different case")
-            diffCI = set(fx.lower() for fx in fileList).difference(set(fod.lower() for fod in filesOnDisk))
+            diffCI = {fx.lower() for fx in fileList}.difference({fod.lower() for fod in filesOnDisk})
             if diffCI:
-                self.log.error("Output data not found", "File list %s does not exist locally" % notPresentFiles)
+                self.log.error("Output data not found", f"File list {notPresentFiles} does not exist locally")
                 raise os.error("Output data not found")
 
             # now checking what's the actual filename case that's written
@@ -748,7 +741,7 @@ class ModuleBase(object):
 
         if notPresentKeys:
             for fileName_keys in notPresentKeys:
-                self.log.error("File %s has missing %s" % (fileName_keys[0], fileName_keys[1]))
+                self.log.error(f"File {fileName_keys[0]} has missing {fileName_keys[1]}")
             raise ValueError("Missing requested fileName keys")
 
     #############################################################################
@@ -772,7 +765,7 @@ class ModuleBase(object):
         this also assumes the files are in the current working directory.
         """
         # Retrieve the POOL File GUID(s) for any final output files
-        self.log.info("Will search for POOL GUIDs for: %s" % (", ".join(candidateFiles)))
+        self.log.info(f"Will search for POOL GUIDs for: {', '.join(candidateFiles)}")
         pfnGUID = getGUID(list(candidateFiles))
         if not pfnGUID["OK"]:
             self.log.error(
@@ -785,7 +778,7 @@ class ModuleBase(object):
         elif pfnGUID["generated"]:
             self.log.warn("PoolXMLFile generated GUID(s) for the following files ", ", ".join(pfnGUID["generated"]))
         else:
-            self.log.info("GUIDs found for all specified POOL files: %s" % (", ".join(candidateFiles)))
+            self.log.info(f"GUIDs found for all specified POOL files: {', '.join(candidateFiles)}")
 
         for pfn, guid in pfnGUID["Value"].items():
             candidateFiles[pfn]["guid"] = guid
@@ -803,14 +796,14 @@ class ModuleBase(object):
 
             final[fileName] = metadata
             final[fileName]["filedict"] = fileDict
-            final[fileName]["localpath"] = "%s/%s" % (os.getcwd(), fileName)
+            final[fileName]["localpath"] = f"{os.getcwd()}/{fileName}"
 
         # Sanity check all final candidate metadata keys are present (return S_ERROR if not)
         mandatoryKeys = ["guid", "filedict"]  # filedict is used for requests (this method adds guid and filedict)
         for fileName, metadata in final.items():
             for key in mandatoryKeys:
                 if key not in metadata:
-                    raise RuntimeError("File %s has missing %s" % (fileName, key))
+                    raise RuntimeError(f"File {fileName} has missing {key}")
 
         return final
 
@@ -831,7 +824,7 @@ class ModuleBase(object):
                     ):
                         stepInputData.append(outputF["outputDataName"])
                 except KeyError:
-                    raise RuntimeError("Can't find output of step %s" % previousStep)
+                    raise RuntimeError(f"Can't find output of step {previousStep}")
 
             # outputDataName is always lower case but the job output can vary
             # Fix it if the file only exists in the current directory with mixed case
@@ -865,7 +858,7 @@ class ModuleBase(object):
         else:
             finalOutputs, _bkFileTypes = self._findOutputs(outputs)
 
-        self.log.info("Final step outputs are: %s" % (finalOutputs))
+        self.log.info(f"Final step outputs are: {finalOutputs}")
         self.step_commons["listoutput"] = finalOutputs
 
         if "outputList" in self.workflow_commons:
@@ -879,7 +872,7 @@ class ModuleBase(object):
             self.log.info("Attempting to recreate the production output LFNs...")
             result = constructProductionLFNs(self.workflow_commons, self.bkClient)
             if not result["OK"]:
-                raise IOError("Could not create production LFNs: %s" % result["Message"])
+                raise OSError(f"Could not create production LFNs: {result['Message']}")
             self.workflow_commons["BookkeepingLFNs"] = result["Value"]["BookkeepingLFNs"]
             self.workflow_commons["LogFilePath"] = result["Value"]["LogFilePath"]
             self.workflow_commons["ProductionOutputData"] = result["Value"]["ProductionOutputData"]
@@ -907,7 +900,6 @@ class ModuleBase(object):
         filesFound = []
 
         for output in stepOutput:
-
             found = False
             fileOnDisk = None
 
@@ -919,13 +911,13 @@ class ModuleBase(object):
             if found and fileOnDisk:
                 self.log.info(
                     "Found output file (case is not considered)",
-                    "%s matching %s " % (fileOnDisk, output["outputDataName"]),
+                    f"{fileOnDisk} matching {output['outputDataName']} ",
                 )
                 output["outputDataName"] = fileOnDisk
                 filesFound.append(output)
             else:
                 self.log.error("Output not found", output["outputDataName"])
-                raise IOError("OutputData not found")
+                raise OSError("OutputData not found")
 
         for fileFound in filesFound:
             bkFileTypes.append(fileFound["outputDataType"].upper())
@@ -944,7 +936,7 @@ class ModuleBase(object):
 
     def _WMSJob(self):
         """Check if this job is running via WMS."""
-        return True if self.jobID else False
+        return bool(self.jobID)
 
     #############################################################################
 
@@ -975,7 +967,7 @@ class ModuleBase(object):
         """just writes a file to disable the watchdog."""
         self.log.info("Creating DISABLE_WATCHDOG_CPU_WALLCLOCK_CHECK in order to disable the Watchdog")
         with open("DISABLE_WATCHDOG_CPU_WALLCLOCK_CHECK", "w") as fopen:
-            fopen.write("%s" % time.asctime())
+            fopen.write(f"{time.asctime()}")
 
     #############################################################################
 
@@ -985,7 +977,7 @@ class ModuleBase(object):
         reportRequest = None
         result = self.jobReport.generateForwardDISET()
         if not result["OK"]:
-            self.log.warn("Could not generate Operation for job report", "with result:\n%s" % (result))
+            self.log.warn("Could not generate Operation for job report", f"with result:\n{result}")
         else:
             reportRequest = result["Value"]
         if reportRequest:
@@ -1002,7 +994,7 @@ class ModuleBase(object):
                 self.log.error("Not failing the job because of that, keep going")
             isValid = self.requestValidator.validate(self.request)
             if not isValid["OK"]:
-                raise RuntimeError("Failover request is not valid: %s" % isValid["Message"])
+                raise RuntimeError(f"Failover request is not valid: {isValid['Message']}")
             else:
                 requestJSON = self.request.toJSON()
                 if requestJSON["OK"]:
@@ -1010,7 +1002,7 @@ class ModuleBase(object):
                     request_string = str(requestJSON["Value"])
                     self.log.debug(request_string)
                     # Write out the request string
-                    fname = "%s_%s_request.json" % (self.production_id, self.prod_job_id)
+                    fname = f"{self.production_id}_{self.prod_job_id}_request.json"
                     with open(fname, "w") as jsonFile:
                         jsonFile.write(request_string)
                     self.log.info("Created file containing failover request", fname)
@@ -1018,7 +1010,7 @@ class ModuleBase(object):
                     if result["OK"]:
                         self.log.info("Digest of the request", result["Value"])
                     else:
-                        self.log.warn("No digest? That's not sooo important", "anyway: %s" % result["Message"])
+                        self.log.warn("No digest? That's not sooo important", f"anyway: {result['Message']}")
                 else:
                     raise RuntimeError(requestJSON["Message"])
 
@@ -1029,7 +1021,7 @@ class ModuleBase(object):
             result = accountingReport.commit()
             if not result["OK"]:
                 self.log.error("!!! Both accounting and RequestDB are down? !!!")
-                self.log.error("accountingReport result: %s" % result["Message"])
+                self.log.error(f"accountingReport result: {result['Message']}")
                 self.log.error(
                     'Anyway, the job won\'t fail for this reason, because this is "just" the accounting report'
                 )
@@ -1044,9 +1036,9 @@ class ModuleBase(object):
         Uses the global request object (self.request).
         """
         if error:
-            self.log.info('BK registration for %s failed with message: "%s" setting failover request' % (lfn, error))
+            self.log.info(f'BK registration for {lfn} failed with message: "{error}" setting failover request')
         else:
-            self.log.info("Setting BK registration request for %s" % (lfn))
+            self.log.info(f"Setting BK registration request for {lfn}")
 
         regFile = Operation()
         regFile.Type = "RegisterFile"
