@@ -13,7 +13,6 @@
 Initially written for use after merged outputs have been successfully
 uploaded to an SE.
 """
-import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.RequestManagementSystem.Client.Operation import Operation
 from DIRAC.RequestManagementSystem.Client.File import File
@@ -21,16 +20,13 @@ from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
 
 class RemoveInputData(ModuleBase):
-
     #############################################################################
 
     def __init__(self, bkClient=None, dm=None):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("RemoveInputData")
-        super(RemoveInputData, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         # List all parameters here
         self.inputDataList = []
@@ -40,7 +36,7 @@ class RemoveInputData(ModuleBase):
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
 
-        super(RemoveInputData, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
     #############################################################################
 
@@ -59,9 +55,7 @@ class RemoveInputData(ModuleBase):
         """Main execution function."""
 
         try:
-
-            super(RemoveInputData, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -83,7 +77,7 @@ class RemoveInputData(ModuleBase):
 
             # Try to remove the file list with failover if necessary
             failover = []
-            self.log.info('Attempting dm.removeFile("%s")' % (self.inputDataList))
+            self.log.info(f'Attempting dm.removeFile("{self.inputDataList}")')
             result = self.dataManager.removeFile(self.inputDataList)
             self.log.verbose(result)
             if not result["OK"]:
@@ -98,11 +92,11 @@ class RemoveInputData(ModuleBase):
                     failureDict = result["Value"]["Failed"]
                     if failureDict:
                         self.log.info(
-                            'Not all files were successfully removed, see "LFN : reason" below\n%s' % (failureDict)
+                            f'Not all files were successfully removed, see "LFN : reason" below\n{failureDict}'
                         )
                     failover = list(failureDict)
             except KeyError:
-                self.log.error("Setting files for removal request to be the input data: %s" % self.inputDataList)
+                self.log.error(f"Setting files for removal request to be the input data: {self.inputDataList}")
                 failover = self.inputDataList
 
             for lfn in failover:
@@ -116,13 +110,13 @@ class RemoveInputData(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(RemoveInputData, self).finalize(self.version)
+            super().finalize()
 
     #############################################################################
 
     def __setFileRemovalRequest(self, lfn):
         """Sets a removal request for a file including all replicas."""
-        self.log.info("Setting file removal request for %s" % lfn)
+        self.log.info(f"Setting file removal request for {lfn}")
         removeFile = Operation()
         removeFile.Type = "RemoveFile"
         rmFile = File()
