@@ -10,11 +10,11 @@
 ###############################################################################
 """StepAccounting module performs several common operations at the end of a
 workflow step, in particular prepares and sends the step accounting data."""
+import datetime
+
 from DIRAC import S_OK, S_ERROR, gConfig, gLogger
-from DIRAC.Core.Utilities import Time
 from DIRAC.Workflow.Utilities.Utils import getStepCPUTimes
 
-import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.AccountingSystem.Client.Types.JobStep import JobStep
 
@@ -23,22 +23,19 @@ class StepAccounting(ModuleBase):
     """StepAccounting class."""
 
     def __init__(self, bkClient=None, dm=None):
-
         self.log = gLogger.getSubLogger("StepAccounting")
-        super(StepAccounting, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.dsc = None
         self.stepStat = None
 
-        self.version = LHCbDIRAC.version
-
     ########################################################################
 
     def _resolveInputVariables(self, dsc=None):
         """By convention all workflow parameters are resolved here."""
 
-        super(StepAccounting, self)._resolveInputVariables()
-        super(StepAccounting, self)._resolveInputStep()
+        super()._resolveInputVariables()
+        super()._resolveInputStep()
 
         if dsc is not None:
             self.dsc = dsc
@@ -67,10 +64,8 @@ class StepAccounting(ModuleBase):
         xf_o=None,
         dsc=None,
     ):
-
         try:
-            super(StepAccounting, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -109,7 +104,7 @@ class StepAccounting(ModuleBase):
 
             self._resolveInputVariables(dsc)
 
-            now = Time.dateTime()
+            now = datetime.datetime.utcnow()
             jobStep.setStartTime(now)
             jobStep.setEndTime(now)
 
@@ -138,7 +133,7 @@ class StepAccounting(ModuleBase):
                 return S_ERROR("Values for StepAccounting are wrong")
 
             if not self._enableModule():
-                self.log.info("Not enabled, would have accounted for %s" % dataDict)
+                self.log.info(f"Not enabled, would have accounted for {dataDict}")
                 return S_OK()
 
             self.dsc.addRegister(jobStep)
@@ -150,4 +145,4 @@ class StepAccounting(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(StepAccounting, self).finalize(self.version)
+            super().finalize()
