@@ -26,7 +26,6 @@ from DIRAC.RequestManagementSystem.Client.File import File
 from DIRAC.Resources.Storage.StorageElement import StorageElement
 from DIRAC.Core.Utilities.ReturnValues import returnSingleResult
 
-import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Workflow.Modules.ModulesUtilities import zipFiles
 from LHCbDIRAC.Core.Utilities.ProductionData import getLogPath
@@ -42,9 +41,7 @@ class UploadLogFile(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("UploadLogFile")
-        super(UploadLogFile, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
         self.logSE = self.opsH.getValue("LogStorage/LogSE", "LogSE")
         self.logSizeLimit = self.opsH.getValue("LogFiles/SizeLimit", 1 * 1024 * 1024)
@@ -58,8 +55,7 @@ class UploadLogFile(ModuleBase):
     ######################################################################
 
     def _resolveInputVariables(self):
-
-        super(UploadLogFile, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
         if "LogTargetPath" in self.workflow_commons:
             self.logLFNPath = self.workflow_commons["LogTargetPath"]
@@ -91,9 +87,7 @@ class UploadLogFile(ModuleBase):
         """Main executon method."""
 
         try:
-
-            super(UploadLogFile, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -118,9 +112,9 @@ class UploadLogFile(ModuleBase):
             else:
                 self.log.error("Failed to list the log directory", str(res["Value"][2]))
 
-            self.log.debug("PRODUCTION_ID = %s, JOB_ID = %s " % (self.production_id, self.prod_job_id))
-            self.logdir = os.path.realpath("./job/log/%s/%s" % (self.production_id, self.prod_job_id))
-            self.log.info("Selected log files will be temporarily stored", "in %s" % self.logdir)
+            self.log.debug(f"PRODUCTION_ID = {self.production_id}, JOB_ID = {self.prod_job_id} ")
+            self.logdir = os.path.realpath(f"./job/log/{self.production_id}/{self.prod_job_id}")
+            self.log.info("Selected log files will be temporarily stored", f"in {self.logdir}")
 
             ##########################################
             # First determine the files which should be saved
@@ -140,15 +134,13 @@ class UploadLogFile(ModuleBase):
                 self.log.error("Completely failed to populate temporary log file directory.", res["Message"])
                 self.setApplicationStatus("Failed To Populate Log Dir")
                 return S_OK()
-            self.log.debug("%s populated with log files." % self.logdir)
+            self.log.debug(f"{self.logdir} populated with log files.")
 
             #########################################
             # Make sure all the files in the log directory have the correct permissions
             result = self.__setLogFilePermissions(self.logdir)
             if not result["OK"]:
-                self.log.error(
-                    "Could not set permissions of log files to 0755", "with message:\n%s" % (result["Message"])
-                )
+                self.log.error("Could not set permissions of log files to 0755", f"with message:\n{result['Message']}")
 
             # zip all files
             zipFileName = os.path.basename(str(self.prod_job_id) + ".zip")
@@ -159,7 +151,7 @@ class UploadLogFile(ModuleBase):
                     self.setApplicationStatus("Failed to create zip of log files")
                     # We do not fail the job for this case
                     return S_OK()
-            except IOError:
+            except OSError:
                 self.log.error("Failed to create zip of log files", res["Message"])
                 self.setApplicationStatus("Failed to create zip of log files")
                 # We do not fail the job for this case
@@ -170,40 +162,38 @@ class UploadLogFile(ModuleBase):
                 self.failoverTransfer = FailoverTransfer(self.request)
 
             # Attempt to uplaod the zippped logs to the LogSE
-            self.log.info("Transferring zipped log files", "to the %s" % self.logSE)
+            self.log.info("Transferring zipped log files", f"to the {self.logSE}")
 
             if not self._enableModule():
                 self.log.info("Would have attempted to upload the zipped log files, but there's not JobID")
                 return S_OK()
 
-            # self.logFilePath is something like /lhcb/MC/2016/LOG/00095376/0000/00000381
+            # self.logFilePath is something like /lhcb/MC/2016/LOG/00095376/0000/
             # the zipFileName should have the same name, e.g. 00000381.zip
             zipPath = os.path.join(self.logFilePath, zipFileName)
             res = returnSingleResult(StorageElement(self.logSE).getURL(zipPath, protocol="https"))
             if not res["OK"]:
                 self.log.warn("Could not get dynamic URL for log", res)
-                logHttpsURL = "https://lhcb-dirac-logse.web.cern.ch/lhcb-dirac-logse/%s" % zipPath
+                # The rule for interpreting what is to be deflated can be found in /eos/lhcb/grid/prod/lhcb/logSE/.htaccess
+                logHttpsURL = f"https://lhcb-dirac-logse.web.cern.ch/lhcb-dirac-logse/{zipPath}"
             else:
                 logHttpsURL = res["Value"]
 
-            self.log.info("putFile", "%s to %s" % (zipFileName, self.logSE))
-            # What is uploaded should be something like /lhcb/MC/2016/LOG/00095376/0000/00000381.zip
-            # (so, removing the last directory, that is the same same of the .zip file)
-            # The rule for interpreting what is to be deflated can be found in /eos/lhcb/grid/prod/lhcb/logSE/.htaccess
-            uploadPath = os.path.join(os.path.dirname(self.logFilePath.rstrip("/")), zipFileName)
-            res = returnSingleResult(StorageElement(self.logSE).putFile({uploadPath: zipFileName}))
+            self.log.info("putFile", f"{zipFileName} to {self.logSE}")
+
+            res = returnSingleResult(StorageElement(self.logSE).putFile({zipPath: zipFileName}))
             if res["OK"]:
-                self.log.info("Successfully upload log file", "to %s" % self.logSE)
-                self.log.info("Logs for this job may be retrieved", "from %s" % logHttpsURL)
+                self.log.info("Successfully upload log file", f"to {self.logSE}")
+                self.log.info("Logs for this job may be retrieved", f"from {logHttpsURL}")
             else:
                 self.log.error(
-                    "Failed to upload log files", "with message '%s', now uploading to failover SE" % res["Message"]
+                    "Failed to upload log files", f"with message '{res['Message']}', now uploading to failover SE"
                 )
                 self._uploadLogToFailoverSE(zipFileName)
 
             # While it's the zip file that is uploaded, we set in job parameters its directory,
             # as the .zip is deflated automatically
-            self.setJobParameter("Log URL", '<a href="%s">Log file directory</a>' % logHttpsURL.rstrip(zipFileName))
+            self.setJobParameter("Log URL", f"<a href=\"{logHttpsURL.replace('.zip','/')}\">Log file directory</a>")
 
             self.workflow_commons["Request"] = self.request
 
@@ -214,7 +204,7 @@ class UploadLogFile(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(UploadLogFile, self).finalize(self.version)
+            super().finalize()
 
     #############################################################################
 
@@ -225,7 +215,7 @@ class UploadLogFile(ModuleBase):
         self.failoverSEs = getDestinationSEList("Tier1-Failover", self.siteName, outputmode="Any")
         random.shuffle(self.failoverSEs)
         self.log.info(
-            "Attempting to store file", "%s to the following SE(s):\n%s" % (zipFileName, ", ".join(self.failoverSEs))
+            "Attempting to store file", f"{zipFileName} to the following SE(s):\n{', '.join(self.failoverSEs)}"
         )
 
         fileDict = {zipFileName: {"lfn": self.logLFNPath, "workflowSE": self.failoverSEs}}
@@ -240,7 +230,7 @@ class UploadLogFile(ModuleBase):
 
         result = self.failoverTransfer.transferAndRegisterFile(
             fileName=zipFileName,
-            localPath="%s/%s" % (os.getcwd(), zipFileName),
+            localPath=f"{os.getcwd()}/{zipFileName}",
             lfn=self.logLFNPath,
             destinationSEList=self.failoverSEs,
             fileMetaDict=fileMetaDict,
@@ -280,18 +270,18 @@ class UploadLogFile(ModuleBase):
             "prodConf*.json",
         ]  # '*.root',
         if self.logExtensions:
-            self.log.debug("Using list of log extensions from CS:\n%s" % (", ".join(self.logExtensions)))
+            self.log.debug(f"Using list of log extensions from CS:\n{', '.join(self.logExtensions)}")
             logFileExtensions = self.logExtensions
         else:
-            self.log.debug("Using default list of log extensions:\n%s" % (", ".join(logFileExtensions)))
+            self.log.debug(f"Using default list of log extensions:\n{', '.join(logFileExtensions)}")
 
         candidateFiles = []
         for ext in logFileExtensions:
-            self.log.debug("Looking at log file wildcard: %s" % ext)
+            self.log.debug(f"Looking at log file wildcard: {ext}")
             globList = glob.glob(ext)
             for check in globList:
                 if os.path.isfile(check):
-                    self.log.debug("Found locally existing log file: %s" % check)
+                    self.log.debug(f"Found locally existing log file: {check}")
                     candidateFiles.append(check)
 
         return S_OK(candidateFiles)
@@ -311,15 +301,15 @@ class UploadLogFile(ModuleBase):
         try:
             os.chmod(self.logdir, stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP | stat.S_IROTH + stat.S_IXOTH)
         except OSError as x:
-            self.log.error("Could not set logdir permissions to 0755:", "%s (%s)" % (self.logdir, str(x)))
+            self.log.error("Could not set logdir permissions to 0755:", f"{self.logdir} ({str(x)})")
         # Populate the temporary directory
         try:
             for fileS in selectedFiles:
-                destinationFile = "%s/%s" % (self.logdir, os.path.basename(fileS))
+                destinationFile = f"{self.logdir}/{os.path.basename(fileS)}"
                 shutil.copy(fileS, destinationFile)
         except shutil.Error:
             self.log.warn("src and dst are the same")
-        except IOError as x:
+        except OSError as x:
             self.log.exception("Exception while trying to copy file.", str(fileS) + str(x))
             self.log.info("The following files will be skipped and can be considered lost", str(fileS))
 
@@ -329,14 +319,14 @@ class UploadLogFile(ModuleBase):
             self.log.info("Failed to copy any files to the target directory.")
             return S_ERROR()
 
-        self.log.debug("Prepared %s files in the temporary directory." % self.logdir)
+        self.log.debug(f"Prepared {self.logdir} files in the temporary directory.")
         return S_OK()
 
     #############################################################################
 
     def __createLogUploadRequest(self, targetSE, logFileLFN, uploadedSE):
         """Set a request to upload job log files from the output sandbox."""
-        self.log.info("Setting log upload request", "for %s at %s" % (logFileLFN, targetSE))
+        self.log.info("Setting log upload request", f"for {logFileLFN} at {targetSE}")
 
         logUpload = Operation()
         logUpload.Type = "LogUpload"
@@ -362,10 +352,10 @@ class UploadLogFile(ModuleBase):
         they are readable."""
         try:
             for toChange in os.listdir(logDir):
-                if not os.path.islink("%s/%s" % (logDir, toChange)):
-                    self.log.debug("Changing permissions of %s/%s to 0755" % (logDir, toChange))
+                if not os.path.islink(f"{logDir}/{toChange}"):
+                    self.log.debug(f"Changing permissions of {logDir}/{toChange} to 0755")
                     os.chmod(
-                        "%s/%s" % (logDir, toChange),
+                        f"{logDir}/{toChange}",
                         stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP | stat.S_IROTH + stat.S_IXOTH,
                     )
         except OSError as x:
