@@ -16,7 +16,6 @@ import json
 import six
 from DIRAC import S_OK, S_ERROR, gLogger
 
-import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.ProductionManagementSystem.Client.MCStatsClient import MCStatsClient
 from LHCbDIRAC.Core.Utilities.XMLSummaries import XMLSummary
@@ -30,14 +29,12 @@ class UploadMC(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("UploadMC")
-        super(UploadMC, self).__init__(self.log)
-
-        self.version = LHCbDIRAC.version
+        super().__init__(self.log)
 
     def _resolveInputVariables(self):
         """standard method for resolving the input variables."""
 
-        super(UploadMC, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
     def execute(
         self,
@@ -57,17 +54,14 @@ class UploadMC(ModuleBase):
         All these uploads are controlled by flags that can be found in
         'Operations/<setup>/Productions/'
 
-        1) Gauss errors => /Operations/<setup>/Productions/UploadES_GaussErrors (default: True)
-        2) Boole errors => /Operations/<setup>/Productions/UploadES_BooleErrors (default: True)
-        3) Summary.xml -> JSON => /Operations/<setup>/Productions/UploadES_XMLSummary (default: False)
-        4) GeneratorLog.xml -> JSON => /Operations/<setup>/Productions/UploadES_GeneratorLog (default: False)
-        5) PRMon => /Operations/<setup>/Productions/UploadES_PrMon (default: False)
+        1) errors => /Operations/<setup>/Productions/UploadES_errors (default: True)
+        2) Summary.xml -> JSON => /Operations/<setup>/Productions/UploadES_XMLSummary (default: False)
+        3) GeneratorLog.xml -> JSON => /Operations/<setup>/Productions/UploadES_GeneratorLog (default: False)
+        4) PRMon => /Operations/<setup>/Productions/UploadES_PrMon (default: False)
 
         """
         try:
-
-            super(UploadMC, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -86,102 +80,73 @@ class UploadMC(ModuleBase):
             # DBs list
             # db = {
             #     'XMLSummary': elasticApplicationSummaryDB,
-            #     'booleErrors': elasticMCBooleLogErrorsDB,
-            #     'gaussErrors': elasticMCGaussLogErrorsDB,
+            #     'errors': ElasticLogErrorsDB,
             #     'generatorLog': elasticMCGeneratorLogDB,
             #     'prMon': elasticMCGeneratorLogDB,
             # }
 
-            # 1) MC Gauss errors
+            # 1) MC errors
             # looking for json files that are 'self.jobID_Errors_Gauss.json'
-            fn = "%s_Errors_Gauss.json" % (self.jobID)
+            # TODO: it could be extended to at least Boole
+            fn = f"{self.jobID}_Errors_Gauss.json"
             if os.path.exists(fn):
-                with io.open(fn) as fd:
+                with open(fn) as fd:
                     try:
                         jsonData = json.load(fd)
-                        self.log.verbose("Content of JSON file", "%s: %s" % (fn, jsonData))
-                        if self._enableModule() and self.opsH.getValue("Productions/UploadES_GaussErrors", True):
-                            res = mcStatsClient.set("gaussErrors", jsonData)
+                        self.log.verbose("Content of JSON file", f"{fn}: {jsonData}")
+                        errorList = []  # Fill this list to send the data in a bulk
+                        for i, error in jsonData.items():
+                            errorList.append(error)
+                        if self._enableModule() and self.opsH.getValue("Productions/UploadES_errors", True):
+                            res = mcStatsClient.set("errors", errorList)
                             if not res["OK"]:
                                 self.log.error(
                                     "MC Error data not set, exiting without affecting workflow status",
-                                    "%s: %s" % (str(jsonData), res["Message"]),
+                                    f"{str(errorList)}: {res['Message']}",
                                 )
                         else:
                             # At this point we can see exactly what the module would have uploaded
-                            self.log.info(
-                                "Module disabled", "would have attempted to upload the following file %s" % fn
-                            )
+                            self.log.info("Module disabled", f"would have attempted to upload the following file {fn}")
                     except Exception as ve:
                         self.log.error(repr(ve))
-                        self.log.verbose("Exception loading the JSON file: content of %s follows" % fn)
+                        self.log.verbose(f"Exception loading the JSON file: content of {fn} follows")
                         self.log.verbose(fd.read)
                         # do not fail the job for this
                         # raise
             else:
                 self.log.info("Gauss errors JSON file not found", fn)
 
-            # 2) MC Boole errors
-            # looking for json files that are 'self.jobID_Errors_Boole.json'
-            fn = "%s_Errors_Boole.json" % (self.jobID)
-            if os.path.exists(fn):
-                with io.open(fn) as fd:
-                    try:
-                        jsonData = json.load(fd)
-                        self.log.verbose("Content of JSON file", "%s: %s" % (fn, jsonData))
-                        if self._enableModule() and self.opsH.getValue("Productions/UploadES_BooleErrors", True):
-                            res = mcStatsClient.set("booleErrors", jsonData)
-                            if not res["OK"]:
-                                self.log.error(
-                                    "MC Error data not set, exiting without affecting workflow status",
-                                    "%s: %s" % (str(jsonData), res["Message"]),
-                                )
-                        else:
-                            # At this point we can see exactly what the module would have uploaded
-                            self.log.info(
-                                "Module disabled", "would have attempted to upload the following file %s" % fn
-                            )
-                    except Exception as ve:
-                        self.log.error(repr(ve))
-                        self.log.verbose("Exception loading the JSON file: content of %s follows" % fn)
-                        self.log.verbose(fd.read)
-                        # do not fail the job for this
-                        # raise
-            else:
-                self.log.info("Boole errors JSON file not found", fn)
-
-            # 3) summary JSON files
+            # 2) summary JSON files
             # looking for xml files that are 'summaryGauss_self.production_id_self.prod_job_id_1.xml'
-            xmlfl = "summaryGauss_%s_%s_1.xml" % (self.production_id, self.prod_job_id)
+            xmlfl = f"summaryGauss_{self.production_id}_{self.prod_job_id}_1.xml"
             if os.path.exists(xmlfl):
-
                 try:
                     xmlData = XMLSummary(xmlfl)
                     xmlData.xmltojson()
                     # At this point 'summaryGauss_self.production_id_self.prod_job_id_1.json' should have been created
-                    jsonfl = "summaryGauss_%s_%s_1.json" % (self.production_id, self.prod_job_id)
-                    with io.open(jsonfl) as JS:
+                    jsonfl = f"summaryGauss_{self.production_id}_{self.prod_job_id}_1.json"
+                    with open(jsonfl) as JS:
                         jsonData = json.load(JS)
                         ids = dict()
                         ids["JobID"] = self.jobID
                         ids["ProductionID"] = self.production_id
                         ids["prod_job_id"] = self.prod_job_id
                         jsonData["Counters"]["ID"] = ids
-                        with io.open(jsonfl, "w", encoding="utf-8") as output:
-                            output.write(six.text_type(json.dumps(jsonData, indent=2)))
+                        with open(jsonfl, "w", encoding="utf-8") as output:
+                            output.write(str(json.dumps(jsonData, indent=2)))
 
-                        self.log.verbose("Content of JSON file", "%s: %s" % (jsonfl, jsonData))
+                        self.log.verbose("Content of JSON file", f"{jsonfl}: {jsonData}")
                         if self._enableModule() and self.opsH.getValue("Productions/UploadES_XMLSummary", False):
                             res = mcStatsClient.set("XMLSummary", jsonData)
                             if not res["OK"]:
                                 self.log.error(
                                     "Gauss Summaries data not set, exiting without affecting workflow status",
-                                    "%s: %s" % (str(jsonData), res["Message"]),
+                                    f"{str(jsonData)}: {res['Message']}",
                                 )
                         else:
                             # At this point we can see exactly what the module would have uploaded
                             self.log.info(
-                                "Module disabled", "would have attempted to upload the following file %s" % jsonfl
+                                "Module disabled", f"would have attempted to upload the following file {jsonfl}"
                             )
 
                 except Exception:
@@ -191,38 +156,37 @@ class UploadMC(ModuleBase):
             else:
                 self.log.info("XML Gauss summary file not found", xmlfl)
 
-            # 4) Generator logs
+            # 3) Generator logs
             # looking for xml files that are 'GeneratorLog.xml'
             xmlfile = "GeneratorLog.xml"
             if os.path.exists(xmlfile):
-
                 try:
-                    jsonfile = "GeneratorLog_%s_%s.json" % (self.production_id, self.prod_job_id)
+                    jsonfile = f"GeneratorLog_{self.production_id}_{self.prod_job_id}.json"
                     xmlData = GeneratorLog()
                     xmlData.generatorLogJson(jsonfile)
                     # At this point 'GeneratorLog_self.production_id_self.prod_job_id.json' should have been created
-                    with io.open(jsonfile) as JS:
+                    with open(jsonfile) as JS:
                         jsonData = json.load(JS)
                         ids = dict()
                         ids["JobID"] = self.jobID
                         ids["ProductionID"] = self.production_id
                         ids["prod_job_id"] = self.prod_job_id
                         jsonData["generatorCounters"]["ID"] = ids
-                        with io.open(jsonfile, "w", encoding="utf-8") as output:
-                            output.write(six.text_type(json.dumps(jsonData)))
+                        with open(jsonfile, "w", encoding="utf-8") as output:
+                            output.write(str(json.dumps(jsonData)))
 
-                        self.log.verbose("Content of JSON file", "%s: %s" % (jsonfile, jsonData))
+                        self.log.verbose("Content of JSON file", f"{jsonfile}: {jsonData}")
                         if self._enableModule() and self.opsH.getValue("Productions/UploadES_GeneratorLog", False):
                             res = mcStatsClient.set("generatorLog", jsonData)
                             if not res["OK"]:
                                 self.log.error(
                                     "Generator Log data not set, exiting without affecting workflow status",
-                                    "%s: %s" % (str(jsonData), res["Message"]),
+                                    f"{str(jsonData)}: {res['Message']}",
                                 )
                         else:
                             # At this point we can see exactly what the module would have uploaded
                             self.log.info(
-                                "Module disabled", "would have attempted to upload the following file %s" % jsonfile
+                                "Module disabled", f"would have attempted to upload the following file {jsonfile}"
                             )
 
                 except Exception:
@@ -232,32 +196,32 @@ class UploadMC(ModuleBase):
             else:
                 self.log.info("XML GeneratorLog file not found", xmlfile)
 
-            # 5) PRmon JSON files (only for Gauss)
+            # 4) PRmon JSON files (only for Gauss)
             # looking for prmon files that are 'prmon_Gauss.json'
             prmonFile = "prmon_Gauss.json"
             if os.path.exists(prmonFile):
-                with io.open(prmonFile) as JS:
+                with open(prmonFile) as JS:
                     try:
                         jsonData = json.load(JS)
                         jsonData["JobID"] = self.jobID
                         jsonData["ProductionID"] = self.production_id
                         jsonData["prod_job_id"] = self.prod_job_id
-                        self.log.verbose("Content of JSON file", "%s: %s" % (prmonFile, jsonData))
+                        self.log.verbose("Content of JSON file", f"{prmonFile}: {jsonData}")
                         if self._enableModule() and self.opsH.getValue("Productions/UploadES_PrMon", False):
                             res = mcStatsClient.set("prMon", jsonData)
                             if not res["OK"]:
                                 self.log.error(
                                     "prmon Metrics data not set, exiting without affecting workflow status",
-                                    "%s: %s" % (str(jsonData), res["Message"]),
+                                    f"{str(jsonData)}: {res['Message']}",
                                 )
                         else:
                             # At this point we can see exactly what the module would have uploaded
                             self.log.info(
-                                "Module disabled", "would have attempted to upload the following file %s" % prmonFile
+                                "Module disabled", f"would have attempted to upload the following file {prmonFile}"
                             )
                     except Exception as ve:
                         self.log.error(repr(ve))
-                        self.log.verbose("Exception loading the JSON file: content of %s follows" % prmonFile)
+                        self.log.verbose(f"Exception loading the JSON file: content of {prmonFile} follows")
                         self.log.verbose(JS.read())
                         # do not fail the job for this
                         # raise
@@ -271,4 +235,4 @@ class UploadMC(ModuleBase):
             return S_ERROR(repr(e))
 
         finally:
-            super(UploadMC, self).finalize(self.version)
+            super().finalize()
