@@ -24,10 +24,9 @@ from DIRAC.RequestManagementSystem.Client.Operation import Operation
 from DIRAC.RequestManagementSystem.Client.File import File
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 
-import LHCbDIRAC
 from LHCbDIRAC.Core.Utilities.ResolveSE import getDestinationSEList
 from LHCbDIRAC.Core.Utilities.ProductionData import constructProductionLFNs
-from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import getFileDescendants
+from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import getFileDescendents
 
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
@@ -41,9 +40,8 @@ class UploadOutputData(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("UploadOutputData")
-        super(UploadOutputData, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = LHCbDIRAC.version
         self.commandTimeOut = 10 * 60
         self.jobID = ""
         self.existingCatalogs = []
@@ -65,7 +63,7 @@ class UploadOutputData(ModuleBase):
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
 
-        super(UploadOutputData, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
         if "outputDataStep" in self.workflow_commons:
             self.outputDataStep = [str(ds) for ds in self.workflow_commons["outputDataStep"].split(";")]
@@ -79,7 +77,7 @@ class UploadOutputData(ModuleBase):
         # Use LHCb utility for local running via jobexec
         if "ProductionOutputData" in self.workflow_commons:
             self.prodOutputLFNs = self.workflow_commons["ProductionOutputData"]
-            if isinstance(self.prodOutputLFNs, six.string_types):
+            if isinstance(self.prodOutputLFNs, str):
                 self.prodOutputLFNs = [i.strip() for i in self.prodOutputLFNs.split(";")]  # pylint: disable=no-member
         else:
             self.log.info("ProductionOutputData parameter not found, creating on the fly")
@@ -116,9 +114,7 @@ class UploadOutputData(ModuleBase):
         """
 
         try:
-
-            super(UploadOutputData, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -167,15 +163,15 @@ class UploadOutputData(ModuleBase):
                 final[fileName] = metadata
                 final[fileName]["resolvedSE"] = resolvedSE
 
-            self.log.info("The following files will be uploaded", ": %s" % ", ".join(final))
+            self.log.info("The following files will be uploaded", f": {', '.join(final)}")
             for fileName, metadata in final.items():
-                self.log.info("--------%s--------" % fileName)
+                self.log.info(f"--------{fileName}--------")
                 for name, val in metadata.items():
-                    self.log.info("%s = %s" % (name, val))
+                    self.log.info(f"{name} = {val}")
 
             if not self._enableModule():
                 # At this point can exit and see exactly what the module would have uploaded
-                self.log.info("Module disabled", "would have attempted to upload the files %s" % ", ".join(final))
+                self.log.info("Module disabled", f"would have attempted to upload the files {', '.join(final)}")
 
             # ## 2. Prior to uploading any files must check (for productions with input data) that no descendant files
             # ##    already exist with replica flag in the BK.
@@ -188,11 +184,11 @@ class UploadOutputData(ModuleBase):
                     if not self._enableModule():
                         self.log.info(
                             "Module disabled",
-                            "would have attempted to check the files %s" % ", ".join(self.inputDataList),
+                            f"would have attempted to check the files {', '.join(self.inputDataList)}",
                         )
                         lfnsWithDescendants = []
                     else:
-                        lfnsWithDescendants = getFileDescendants(
+                        lfnsWithDescendants = getFileDescendents(
                             self.production_id, self.inputDataList, dm=self.dataManager, bkClient=self.bkClient
                         )
                 if not lfnsWithDescendants:
@@ -212,11 +208,11 @@ class UploadOutputData(ModuleBase):
             bkFileExtensions = ["bookkeeping*.xml"]
             bkFiles = []
             for ext in bkFileExtensions:
-                self.log.debug("Looking at BK record wildcard: %s" % ext)
+                self.log.debug(f"Looking at BK record wildcard: {ext}")
                 globList = glob.glob(ext)
                 for check in globList:
                     if os.path.isfile(check):
-                        self.log.verbose("Found locally existing BK file record", ": %s" % check)
+                        self.log.verbose("Found locally existing BK file record", f": {check}")
                         bkFiles.append(check)
 
             # Unfortunately we depend on the file names to order the BK records
@@ -225,19 +221,19 @@ class UploadOutputData(ModuleBase):
                 bkFilesListTuples.append((bk, int(bk.split("_")[-1].split(".")[0])))
             bkFiles = [bk[0] for bk in sorted(bkFilesListTuples, key=itemgetter(1))]
 
-            self.log.info("The following BK records will be sent", ": %s" % (", ".join(bkFiles)))
+            self.log.info("The following BK records will be sent", f": {', '.join(bkFiles)}")
             for bkFile in bkFiles:
-                with open(bkFile, "r") as fd:
+                with open(bkFile) as fd:
                     bkXML = fd.read()
-                self.log.info("Sending BK record", ":\n%s" % (bkXML))
+                self.log.info("Sending BK record", f":\n{bkXML}")
                 if self._enableModule():
                     result = self.bkClient.sendXMLBookkeepingReport(bkXML)
                     self.log.verbose(result)
                     if result["OK"]:
-                        self.log.info("Bookkeeping report sent", "for %s" % bkFile)
+                        self.log.info("Bookkeeping report sent", f"for {bkFile}")
                     else:
-                        self.log.error("Could not send Bookkeeping XML file to server", ": %s" % result["Message"])
-                        self.log.info("Preparing DISET request", "for %s" % bkFile)
+                        self.log.error("Could not send Bookkeeping XML file to server", f": {result['Message']}")
+                        self.log.info("Preparing DISET request", f"for {bkFile}")
                         bkDISETReq = Operation()
                         bkDISETReq.Type = "ForwardDISET"
                         bkDISETReq.Arguments = DEncode.encode(result["rpcStub"])
@@ -264,7 +260,7 @@ class UploadOutputData(ModuleBase):
             for fileName, metadata in final.items():
                 targetSE = metadata["resolvedSE"]
                 self.log.info(
-                    "Attempting to store file to SE", "%s to the following SE(s):\n%s" % (fileName, ", ".join(targetSE))
+                    "Attempting to store file to SE", f"{fileName} to the following SE(s):\n{', '.join(targetSE)}"
                 )
                 fileMetaDict = {
                     "Size": metadata["filedict"]["Size"],
@@ -276,7 +272,7 @@ class UploadOutputData(ModuleBase):
 
                 if not self._enableModule():
                     # At this point can exit and see exactly what the module would have uploaded
-                    self.log.info("Module disabled", "would have attempted to upload file %s" % fileName)
+                    self.log.info("Module disabled", f"would have attempted to upload file {fileName}")
                     continue
 
                 result = self.failoverTransfer.transferAndRegisterFile(
@@ -288,11 +284,11 @@ class UploadOutputData(ModuleBase):
                     masterCatalogOnly=True,
                 )
                 if not result["OK"]:
-                    self.log.error("Could not transfer and register", " %s with metadata:\n %s" % (fileName, metadata))
+                    self.log.error("Could not transfer and register", f" {fileName} with metadata:\n {metadata}")
                     failover[fileName] = metadata
                 else:
                     self.log.info(
-                        "File uploaded, will be registered in BK if all files uploaded for job", "(%s)" % fileName
+                        "File uploaded, will be registered in BK if all files uploaded for job", f"({fileName})"
                     )
 
                     # if the files are uploaded in the SE, independently if the registration in the FC is done,
@@ -316,7 +312,7 @@ class UploadOutputData(ModuleBase):
 
                 if not self._enableModule():
                     # At this point can exit and see exactly what the module would have uploaded
-                    self.log.info("Module disabled", "would have attempted to upload with failover file %s" % fileName)
+                    self.log.info("Module disabled", f"would have attempted to upload with failover file {fileName}")
                     continue
 
                 result = self.failoverTransfer.transferAndRegisterFileFailover(
@@ -330,7 +326,7 @@ class UploadOutputData(ModuleBase):
                 )
                 if not result["OK"]:
                     self.log.error(
-                        "Could not transfer and register", "%s in failover with metadata:\n %s" % (fileName, metadata)
+                        "Could not transfer and register", f"{fileName} in failover with metadata:\n {metadata}"
                     )
                     cleanUp = True
                     break  # no point continuing if one completely fails
@@ -358,14 +354,14 @@ class UploadOutputData(ModuleBase):
                 # performing BK registration
 
                 # Getting what should be registered immediately, and what later
-                lfnsToRegisterInBK = set([metadata["filedict"]["LFN"] for metadata in performBKRegistration])
+                lfnsToRegisterInBK = {metadata["filedict"]["LFN"] for metadata in performBKRegistration}
                 lfnsToRegisterInBKNow = self._getLFNsForBKRegistration(lfnsToRegisterInBK)
                 lfnsToRegisterInBKLater = list(lfnsToRegisterInBK - set(lfnsToRegisterInBKNow))
 
                 # Registering what should be registering immediately, and handling failures
                 if lfnsToRegisterInBKNow:
                     result = FileCatalog(catalogs=["BookkeepingDB"]).addFile(lfnsToRegisterInBKNow)
-                    self.log.verbose("BookkeepingDB.addFile: %s" % result)
+                    self.log.verbose(f"BookkeepingDB.addFile: {result}")
                     if not result["OK"]:
                         self.log.error(result)
                         return S_ERROR("Could Not Perform BK Registration")
@@ -397,7 +393,7 @@ class UploadOutputData(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(UploadOutputData, self).finalize(self.version)
+            super().finalize()
 
     #############################################################################
 
@@ -426,7 +422,7 @@ class UploadOutputData(ModuleBase):
         for _fileName, metadata in final.items():
             lfnList.append(metadata["lfn"])
 
-        self.log.verbose("Cleaning up the request, for LFNs: %s" % ", ".join(lfnList))
+        self.log.verbose(f"Cleaning up the request, for LFNs: {', '.join(lfnList)}")
 
         newRequest = Request()
 
@@ -447,7 +443,7 @@ class UploadOutputData(ModuleBase):
 
         self.request = newRequest
 
-        self.log.verbose("And adding RemoveFile operation for LFNs: %s, just in case" % ", ".join(lfnList))
+        self.log.verbose(f"And adding RemoveFile operation for LFNs: {', '.join(lfnList)}, just in case")
 
         removeFiles = Operation()
         removeFiles.Type = "RemoveFile"
