@@ -19,7 +19,6 @@ from DIRAC.Core.Utilities.File import getGlobbedFiles
 from DIRAC.DataManagementSystem.Client.FailoverTransfer import FailoverTransfer
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
 
-import LHCbDIRAC
 from LHCbDIRAC.Core.Utilities.ProductionData import constructUserLFNs
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Core.Utilities.ResolveSE import getDestinationSEList
@@ -33,9 +32,8 @@ class UserJobFinalization(ModuleBase):
         """Module initialization."""
 
         self.log = gLogger.getSubLogger("UserJobFinalization")
-        super(UserJobFinalization, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
+        super().__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = LHCbDIRAC.version
         self.enable = True
         self.defaultOutputSE = resolveSEGroup(gConfig.getValue("/Resources/StorageElementGroups/Tier1-USER", []))
         self.failoverSEs = resolveSEGroup(gConfig.getValue("/Resources/StorageElementGroups/Tier1-Failover", []))
@@ -53,7 +51,7 @@ class UserJobFinalization(ModuleBase):
     #############################################################################
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
-        super(UserJobFinalization, self)._resolveInputVariables()
+        super()._resolveInputVariables()
 
         # Use LHCb utility for local running via dirac-jobexec
         if "UserOutputData" in self.workflow_commons:
@@ -67,7 +65,7 @@ class UserJobFinalization(ModuleBase):
             if not isinstance(specifiedSE, list):
                 self.userOutputSE = [i.strip() for i in specifiedSE.split(";")]
         else:
-            self.log.verbose("No UserOutputSE specified, using default value: %s" % (", ".join(self.defaultOutputSE)))
+            self.log.verbose(f"No UserOutputSE specified, using default value: {', '.join(self.defaultOutputSE)}")
             self.userOutputSE = []
 
         if "UserOutputPath" in self.workflow_commons:
@@ -97,9 +95,7 @@ class UserJobFinalization(ModuleBase):
         """Main execution function."""
 
         try:
-
-            super(UserJobFinalization, self).execute(
-                self.version,
+            super().execute(
                 production_id,
                 prod_job_id,
                 wms_job_id,
@@ -125,7 +121,7 @@ class UserJobFinalization(ModuleBase):
                 self.log.info("No user output data is specified for this job, nothing to do")
                 return S_OK("No output data to upload")
 
-            self.log.info("User specified output file list is: %s" % (", ".join(self.userOutputData)))
+            self.log.info(f"User specified output file list is: {', '.join(self.userOutputData)}")
 
             globList = []
             for i in self.userOutputData:
@@ -147,10 +143,10 @@ class UserJobFinalization(ModuleBase):
                     self.userOutputData += globbedOutputList
                 else:
                     self.log.info(
-                        "No files were found on the local disk for the following patterns: %s" % (", ".join(globList))
+                        f"No files were found on the local disk for the following patterns: {', '.join(globList)}"
                     )
 
-            self.log.info("Final list of files to upload are: %s" % (", ".join(self.userOutputData)))
+            self.log.info(f"Final list of files to upload are: {', '.join(self.userOutputData)}")
 
             # Determine the final list of possible output files for the workflow
             # and all the parameters needed to upload them.
@@ -160,7 +156,7 @@ class UserJobFinalization(ModuleBase):
 
             userOutputLFNs = []
             if self.userOutputData:
-                self.log.info("Constructing user output LFN(s) for %s" % (", ".join(self.userOutputData)))
+                self.log.info(f"Constructing user output LFN(s) for {', '.join(self.userOutputData)}")
 
                 userOutputLFNs = constructUserLFNs(
                     self.jobID,
@@ -170,9 +166,7 @@ class UserJobFinalization(ModuleBase):
                     self.userPrependString,
                 )
 
-            self.log.verbose(
-                "Calling getCandidateFiles( %s, %s, %s)" % (outputList, userOutputLFNs, self.outputDataFileMask)
-            )
+            self.log.verbose(f"Calling getCandidateFiles( {outputList}, {userOutputLFNs}, {self.outputDataFileMask})")
             try:
                 fileDict = self.getCandidateFiles(outputList, userOutputLFNs, self.outputDataFileMask)
             except os.error as e:
@@ -193,7 +187,7 @@ class UserJobFinalization(ModuleBase):
             if not orderedSEs:
                 orderedSEs = self._getOrderedSEsList()
 
-            self.log.info("Ordered list of output SEs is: %s" % (", ".join(orderedSEs)))
+            self.log.info(f"Ordered list of output SEs is: {', '.join(orderedSEs)}")
             final = {}
             for fileName, metadata in fileMetadata.items():
                 final[fileName] = metadata
@@ -201,11 +195,11 @@ class UserJobFinalization(ModuleBase):
 
             # At this point can exit and see exactly what the module will upload
             if not self._enableModule():
-                self.log.info("Module disabled would have attempted to upload the files %s" % ", ".join(final))
+                self.log.info(f"Module disabled would have attempted to upload the files {', '.join(final)}")
                 for fileName, metadata in final.items():
-                    self.log.info("--------%s--------" % fileName)
+                    self.log.info(f"--------{fileName}--------")
                     for n, v in metadata.items():
-                        self.log.info("%s = %s" % (n, v))
+                        self.log.info(f"{n} = {v}")
 
                 return S_OK("Module is disabled by control flag")
 
@@ -222,7 +216,7 @@ class UserJobFinalization(ModuleBase):
             uploaded = []
             for fileName, metadata in final.items():
                 self.log.info(
-                    "Attempting to store %s to the following SE(s): %s" % (fileName, ", ".join(metadata["resolvedSE"]))
+                    f"Attempting to store {fileName} to the following SE(s): {', '.join(metadata['resolvedSE'])}"
                 )
                 fileMetaDict = {
                     "Size": metadata["filedict"]["Size"],
@@ -240,7 +234,7 @@ class UserJobFinalization(ModuleBase):
                     masterCatalogOnly=True,
                 )
                 if not result["OK"]:
-                    self.log.error("Could not transfer and register %s with metadata:\n %s" % (fileName, metadata))
+                    self.log.error(f"Could not transfer and register {fileName} with metadata:\n {metadata}")
                     failover[fileName] = metadata
                 else:
                     # Only attempt replication after successful upload
@@ -256,7 +250,7 @@ class UserJobFinalization(ModuleBase):
                                 break
 
                     if replicateSE and lfn and self.replicateUserOutputData:
-                        self.log.info("Will attempt to replicate %s to %s" % (lfn, replicateSE))
+                        self.log.info(f"Will attempt to replicate {lfn} to {replicateSE}")
                         replication[lfn] = (uploadedSE, replicateSE, fileMetaDict)
 
             cleanUp = False
@@ -283,7 +277,7 @@ class UserJobFinalization(ModuleBase):
                     masterCatalogOnly=True,
                 )
                 if not result["OK"]:
-                    self.log.error("Could not transfer and register %s with metadata:\n %s" % (fileName, metadata))
+                    self.log.error(f"Could not transfer and register {fileName} with metadata:\n {metadata}")
                     cleanUp = True
                     continue  # for users can continue even if one completely fails
                 else:
@@ -325,7 +319,7 @@ class UserJobFinalization(ModuleBase):
             return S_ERROR(str(e))
 
         finally:
-            super(UserJobFinalization, self).finalize(self.version)
+            super().finalize()
 
     #############################################################################
 
@@ -334,7 +328,7 @@ class UserJobFinalization(ModuleBase):
         # FIXME: remove all banned SEs (not the force ones)
         # First get the local (or assigned) SE to try first for upload and others in random fashion
         localSEs = set(getDestinationSEList("Tier1-USER", self.siteName, outputmode="local"))
-        self.log.verbose("Site Local SE for user outputs is: %s" % (list(localSEs)))
+        self.log.verbose(f"Site Local SE for user outputs is: {list(localSEs)}")
         userSEs = set(self.userOutputSE)
         otherSEs = set(self.defaultOutputSE) - localSEs - userSEs
         # If a user SE is  local set it first
