@@ -9,19 +9,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test class for BookkeepingReport."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=missing-docstring, invalid-name, protected-access
-
-__RCSID__ = "$Id$"
-
 import importlib
 from itertools import product
 
 import pytest
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 # mocks
 from DIRAC.DataManagementSystem.Client.test.mock_DM import dm_mock
