@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit tests for Workflow Modules."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
 
 import unittest
@@ -21,7 +17,7 @@ import copy
 import shutil
 from textwrap import dedent
 
-from mock import MagicMock, patch
+from unittest.mock import MagicMock, patch
 
 from DIRAC import gLogger
 from DIRAC.TransformationSystem.Client.FileReport import FileReport
@@ -52,14 +48,10 @@ from LHCbDIRAC.BookkeepingSystem.Client.test.mock_BookkeepingClient import bkc_m
 from LHCbDIRAC.Workflow.Modules.AnalyseXMLSummary import AnalyseXMLSummary
 
 
-__RCSID__ = "$Id$"
-
-
 class ModulesTestCase(unittest.TestCase):
     """Base class for the Modules test cases."""
 
     def setUp(self):
-
         gLogger.setLevel("DEBUG")
         self.maxDiff = None
 
@@ -138,11 +130,9 @@ class ModulesTestCase(unittest.TestCase):
 
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class AnalyseXMLSummarySuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         axlf = AnalyseXMLSummary(bkClient=bkc_mock, dm=dm_mock)
         axlf.stepInputData = ["some.sdst", "00012345_00006789_1.sdst"]
         axlf.jobType = "merge"
@@ -200,7 +190,6 @@ class AnalyseXMLSummarySuccess(ModulesTestCase):
                 )
 
     def test__basicSuccess(self, _patch):
-
         axlf = AnalyseXMLSummary(bkClient=bkc_mock, dm=dm_mock)
 
         with open("XMLSummaryFile", "w") as f:
