@@ -12,7 +12,7 @@
 # pylint: disable=protected-access, missing-docstring, invalid-name
 import os
 from itertools import product
-from mock import MagicMock
+from unittest.mock import MagicMock
 
 import pytest
 
@@ -40,7 +40,6 @@ def test__enableModule(mocker):
     mocker.patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
     mb = ModuleBase(bkClientIn=bkc_mock, dm=dm_mock)
     mb.execute(
-        version,
         prod_id,
         prod_job_id,
         wms_job_id,
