@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit tests for Workflow Modules."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
 
 import unittest
@@ -22,7 +16,7 @@ import os
 import copy
 import shutil
 
-from mock import MagicMock, patch
+from unittest.mock import MagicMock, patch
 
 from DIRAC.DataManagementSystem.Client.test.mock_DM import dm_mock
 from DIRAC.Resources.Catalog.test.mock_FC import fc_mock
@@ -64,7 +58,6 @@ class ModulesTestCase(unittest.TestCase):
     """Base class for the Modules test cases."""
 
     def setUp(self):
-
         gLogger.setLevel("DEBUG")
         self.maxDiff = None
 
@@ -144,11 +137,9 @@ class ModulesTestCase(unittest.TestCase):
 # FailoverRequest.py
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class FailoverRequestSuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         fr = FailoverRequest(bkClient=bkc_mock, dm=dm_mock)
         fr.jobType = "merge"
         fr.stepInputData = ["foo", "bar"]
@@ -167,11 +158,9 @@ class FailoverRequestSuccess(ModulesTestCase):
 # RemoveInputData.py
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class RemoveInputDataSuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         rid = RemoveInputData(bkClient=bkc_mock, dm=dm_mock)
         # no errors, no input data
         for wf_cs in copy.deepcopy(wf_commons):
@@ -199,11 +188,9 @@ class RemoveInputDataSuccess(ModulesTestCase):
 # StepAccounting.py
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class StepAccountingSuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         sa = StepAccounting(bkClient=bkc_mock, dm=dm_mock)
         sa.jobType = "merge"
         sa.stepInputData = ["foo", "bar"]
@@ -233,7 +220,6 @@ class StepAccountingSuccess(ModulesTestCase):
 class UploadLogFileSuccess(ModulesTestCase):
     @patch("LHCbDIRAC.Workflow.Modules.UploadLogFile.getDestinationSEList", side_effect=getDestinationSEListMockCNAF)
     def test_execute(self, _patch, _patch1):
-
         # no errors, no input data
         #    for wf_commons in copy.deepcopy( wf_commons ):
         #      for step_commons in step_commons:
@@ -342,7 +328,6 @@ class UploadLogFileSuccess(ModulesTestCase):
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class UserJobFinalizationSuccess(ModulesTestCase):
     def test_execute(self, _patch):
-
         ujf = UserJobFinalization(bkClient=bkc_mock, dm=dm_mock)
         ujf.bkClient = bkc_mock
         ujf.failoverTransfer = self.ft_mock
@@ -386,7 +371,6 @@ class UserJobFinalizationSuccess(ModulesTestCase):
 
     @patch("LHCbDIRAC.Workflow.Modules.UserJobFinalization.getDestinationSEList", side_effect=getDestinationSEListMock)
     def test__getOrderedSEsList(self, _patch, _patched):
-
         ujf = UserJobFinalization(bkClient=bkc_mock, dm=dm_mock)
 
         ujf.userOutputSE = ["userSE"]
@@ -401,7 +385,6 @@ class UserJobFinalizationSuccess(ModulesTestCase):
         "LHCbDIRAC.Workflow.Modules.UserJobFinalization.getDestinationSEList", side_effect=getDestinationSEListMockCNAF
     )
     def test__getOrderedSEsListCNAF(self, _patch, _patched):
-
         ujf = UserJobFinalization(bkClient=bkc_mock, dm=dm_mock)
         res = ujf._getOrderedSEsList()
         self.assertEqual(res, ["CNAF"])
@@ -410,11 +393,9 @@ class UserJobFinalizationSuccess(ModulesTestCase):
 # FileUsage.py
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class FileUsageSuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         # no errors, no input files to report
         wfStatus = copy.deepcopy(workflowStatus)
         wfC = copy.deepcopy(wf_commons)
@@ -471,11 +452,9 @@ class FileUsageSuccess(ModulesTestCase):
 # FileUsage.py
 @patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
 class CreateDataFileSuccess(ModulesTestCase):
-
     #################################################
 
     def test_execute(self, _patch):
-
         cdf = CreateDataFile(bkClient=bkc_mock, dm=dm_mock)
         cdf.jobType = "merge"
         cdf.stepInputData = ["foo", "bar"]
