@@ -14,10 +14,10 @@ import os
 import copy
 import json
 
-from mock import MagicMock
+from unittest.mock import MagicMock
 import pytest
 
-from DIRAC import gLogger
+from DIRAC import gConfig, gLogger
 from DIRAC.RequestManagementSystem.Client.Request import Request
 from DIRAC.RequestManagementSystem.Client.Operation import Operation
 from DIRAC.RequestManagementSystem.Client.File import File
@@ -95,10 +95,11 @@ def rmFiles():
             continue
 
 
-def test_execute(mocker, rmFiles):
+def test_execute(mocker, rmFiles, monkeypatch):
     mocker.patch("LHCbDIRAC.Workflow.Modules.ModuleBase.RequestValidator", side_effect=MagicMock())
     mocker.patch("LHCbDIRAC.Workflow.Modules.UploadOutputData.FileCatalog", side_effect=fc_mock)
-    mocker.patch("LHCbDIRAC.Core.Utilities.ResolveSE.gConfig", side_effect=MagicMock())
+
+    monkeypatch.setattr(gConfig, "getOption", lambda x, y: {"OK": True, "Value": "exp1"})
 
     uod = UploadOutputData(bkClient=bkc_mock, dm=dm_mock)
     uod.log = gLogger
@@ -153,13 +154,13 @@ def test_execute(mocker, rmFiles):
                     "/lhcb/MC/2010/DST/00012345/0001/foo.txt",
                     "/lhcb/MC/2010/DST/00012345/0001/bar.txt",
                 ]
-                # bkc_mock.getFileDescendants.return_value = {
+                # bkc_mock.getFileDescendents.return_value = {
                 #     'OK': False,
                 #     'rpcStub': (
                 #         ( 'Bookkeeping/BookkeepingManager',
                 #         {'skipCACheck': False,
                 #         'timeout': 3600} ),
-                #         'getFileDescendants', ( ['foo'], 9, 0, True ) ),
+                #         'getFileDescendents', ( ['foo'], 9, 0, True ) ),
                 #     'Value': {'Successful': {'foo.txt': ['baaar']}, 'Failed': [], 'NotProcessed': []}
                 # }
                 fileDescendants = {"foo.txt": ["baaar"]}
@@ -180,12 +181,12 @@ def test_execute(mocker, rmFiles):
                     is False
                 )
 
-                # bkc_mock.getFileDescendants.return_value = {
+                # bkc_mock.getFileDescendents.return_value = {
                 #     'OK': True,
                 #     'rpcStub': ( (
                 #         'Bookkeeping/BookkeepingManager',
                 #         {'skipCACheck': False, 'timeout': 3600} ),
-                #         'getFileDescendants', ( ['foo'], 9, 0, True ) ),
+                #         'getFileDescendents', ( ['foo'], 9, 0, True ) ),
                 #     'Value': {'Successful': {}, 'Failed': [], 'NotProcessed': []},
                 # }
                 if wf_cs["Request"] == "":
@@ -245,7 +246,7 @@ def test__getLFNsForBKRegistration(mocker):
     uod = UploadOutputData(bkClient=bkc_mock, dm=dm_mock)
     uod.request = r
 
-    lfns = set(["/a/1.txt", "/a/5.txt", "/a/6.txt", "/a/3.txt"])
+    lfns = {"/a/1.txt", "/a/5.txt", "/a/6.txt", "/a/3.txt"}
     lfnsForBkReg = uod._getLFNsForBKRegistration(lfns)
     assert sorted(lfnsForBkReg) == sorted(["/a/5.txt", "/a/6.txt"])
 
