@@ -14,12 +14,6 @@ files if the JDL parameter AncestorDepth is specified.
 The ancestor files are subsequently added to the existing input data
 requirement of the job.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import time
 from DIRAC import S_OK, S_ERROR
 from DIRAC.WorkloadManagementSystem.Agent.OptimizerModule import OptimizerModule
@@ -56,7 +50,7 @@ class AncestorFilesAgent(OptimizerModule):
             inputData = classadJob.getListFromExpression("InputData")
 
         if not classadJob.lookupAttribute("AncestorDepth"):
-            self.log.warn("No AncestorDepth requirement found for job %s" % (job))
+            self.log.warn(f"No AncestorDepth requirement found for job {job}")
             return S_ERROR("AncestorDepth Not Found")
 
         ancestorDepth = classadJob.getAttributeInt("AncestorDepth")
@@ -65,7 +59,7 @@ class AncestorFilesAgent(OptimizerModule):
             return S_OK("Null AncestorDepth specified")
 
         self.log.info(
-            "Job %s has %s input data files and specified ancestor depth of %s" % (job, len(inputData), ancestorDepth)
+            f"Job {job} has {len(inputData)} input data files and specified ancestor depth of {ancestorDepth}"
         )
         result = self.__getInputDataWithAncestors(job, inputData, ancestorDepth)
         if not result["OK"]:
@@ -87,10 +81,10 @@ class AncestorFilesAgent(OptimizerModule):
         try:
             result = self.bk.getFileAncestors(inputData, ancestorDepth, replica=True)
         except Exception as x:
-            self.log.warn("getFileAncestors failed with exception:\n%s" % x)
+            self.log.warn(f"getFileAncestors failed with exception:\n{x}")
             return S_ERROR("getFileAncestors failed with exception")
 
-        self.log.info("BK lookup time %.2f s" % (time.time() - start))
+        self.log.info(f"BK lookup time {time.time() - start:.2f} s")
         self.log.debug(result)
         if not result["OK"]:
             report = self.setJobParam(job, self.am_getModuleParam("optimizerName"), result["Message"])
@@ -101,7 +95,7 @@ class AncestorFilesAgent(OptimizerModule):
 
         ancestors = [anc["FileName"] for ancList in result["Value"]["Successful"].values() for anc in ancList]
         newInputData = ancestors + inputData
-        param = "%d ancestor files retrieved from BK for depth %s" % (len(ancestors), ancestorDepth)
+        param = f"{len(ancestors)} ancestor files retrieved from BK for depth {ancestorDepth}"
 
         report = self.setJobParam(job, self.am_getModuleParam("optimizerName"), param)
         if not report["OK"]:
