@@ -12,6 +12,7 @@
 
 Simply defines what to send.
 """
+
 from DIRAC import S_OK
 from DIRAC.WorkloadManagementSystem.Agent.SiteDirector import SiteDirector as DIRACSiteDirector
 
@@ -32,7 +33,7 @@ class SiteDirector(DIRACSiteDirector):
 
     def _getPilotOptions(self, queue):
         """Adding LHCb specific options."""
-        pilotOptions = super(SiteDirector, self)._getPilotOptions(queue)
+        pilotOptions = super()._getPilotOptions(queue)
 
         if self.lbRunOnly:
             pilotOptions.append("-o lbRunOnly")
