@@ -8,10 +8,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 ############################################################
 
 """LHCbSystem.Agent package.
@@ -19,5 +15,3 @@ from __future__ import print_function
 LHCb specific  agents for any system (e.g. WMS, DMS ...) can be added
 here.
 """
-
-__RCSID__ = "$Id$"
