@@ -14,14 +14,12 @@ import os
 import time
 import errno
 
+from DIRAC import rootPath
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import DMSHelpers
 from DIRAC.tests.Utilities.testJobDefinitions import baseToAllJobs, endOfAllJobs, find_all
 from DIRAC.Core.Utilities.Proxy import executeWithUserProxy
 from LHCbDIRAC.Interfaces.API.LHCbJob import LHCbJob
 from LHCbDIRAC.Interfaces.API.DiracLHCb import DiracLHCb
-from LHCbDIRAC.tests.Workflow import createJob
-
-from LHCbDIRAC import rootPath
 
 # parameters
 
@@ -49,9 +47,8 @@ wdir = os.getcwd()
 
 @executeWithUserProxy
 def helloWorldTestT2s():
-
     job = baseToAllJobs("helloWorldTestT2s", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setBannedSites(tier1s)
     return endOfAllJobs(job)
@@ -59,9 +56,8 @@ def helloWorldTestT2s():
 
 @executeWithUserProxy
 def helloWorldTestCERN():
-
     job = baseToAllJobs("helloWorld-test-CERN", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setDestination("LCG.CERN.cern")
     return endOfAllJobs(job)
@@ -70,7 +66,7 @@ def helloWorldTestCERN():
 @executeWithUserProxy
 def helloWorldTestIN2P3():
     job = baseToAllJobs("helloWorld-test-IN2P3", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setDestination("LCG.IN2P3.fr")
     return endOfAllJobs(job)
@@ -79,7 +75,7 @@ def helloWorldTestIN2P3():
 @executeWithUserProxy
 def helloWorldTestGRIDKA():
     job = baseToAllJobs("helloWorld-test-GRIDKA", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setDestination("LCG.GRIDKA.de")
     return endOfAllJobs(job)
@@ -87,49 +83,26 @@ def helloWorldTestGRIDKA():
 
 @executeWithUserProxy
 def helloWorldTestARC():
-
     job = baseToAllJobs("helloWorld-test-ARC", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setDestination(["LCG.RAL.uk"])
     return endOfAllJobs(job)
 
 
-@executeWithUserProxy
-def helloWorldTestSSH():
-
-    job = baseToAllJobs("helloWorld-test-SSH", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
-    job.setExecutable("exe-script.py", "", "helloWorld.log")
-    job.setDestination(["DIRAC.Zurich.ch"])
-    return endOfAllJobs(job)
-
-
 @executeWithUserProxy
 def helloWorldTestSSHCondor():
-
     job = baseToAllJobs("helloWorld-test-SSHCondor", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
-    job.setDestination(["DIRAC.Syracuse.us"])  # FIXME: not there
-    return endOfAllJobs(job)
-
-
-@executeWithUserProxy
-def helloWorldTestVAC():
-
-    job = baseToAllJobs("helloWorld-test-VAC", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
-    job.setExecutable("exe-script.py", "", "helloWorld.log")
-    job.setDestination(["VAC.Manchester.uk"])  # FIXME: not there
+    job.setDestination(["DIRAC.Sibir.ru"])
     return endOfAllJobs(job)
 
 
 @executeWithUserProxy
 def helloWorldTestCLOUD():
-
     job = baseToAllJobs("helloWorld-test-CLOUD", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setDestination(["CLOUD.CERN.cern"])
     return endOfAllJobs(job)
@@ -137,22 +110,20 @@ def helloWorldTestCLOUD():
 
 @executeWithUserProxy
 def helloWorldTestCentos7():
-
     job = baseToAllJobs("helloWorld-test-CentOS7", jobClass)
-    job.setInputSandbox([find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script.py", rootPath, ".")[0]])
     job.setExecutable("exe-script.py", "", "helloWorld.log")
-    job.setPlatform("x86_64+avx2+fma-centos7-gcc8-opt")
+    job.setPlatform("x86_64-centos7-gcc9-opt")
     return endOfAllJobs(job)
 
 
 @executeWithUserProxy
 def jobWithOutput():
-
     timenow = time.strftime("%s")
     with open(os.path.join(wdir, timenow + "testFileUpload.txt"), "w") as f:
         f.write(timenow)
     inp1 = [find_all(timenow + "testFileUpload.txt", ".")[0]]
-    inp2 = [find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]]
+    inp2 = [find_all("exe-script.py", rootPath, ".")[0]]
     job = baseToAllJobs("jobWithOutput", jobClass)
     job.setInputSandbox(inp1 + inp2)
     job.setExecutable("exe-script.py", "", "helloWorld.log")
@@ -167,13 +138,12 @@ def jobWithOutput():
 
 @executeWithUserProxy
 def jobWithOutputAndPrepend():
-
     timenow = time.strftime("%s")
     with open(os.path.join(wdir, timenow + "testFileUploadNewPath.txt"), "w") as f:
         f.write(timenow)
     job = baseToAllJobs("jobWithOutputAndPrepend", jobClass)
     inp1 = [find_all(timenow + "testFileUploadNewPath.txt", ".")[0]]
-    inp2 = [find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]]
+    inp2 = [find_all("exe-script.py", rootPath, ".")[0]]
     job.setInputSandbox(inp1 + inp2)
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setOutputData([timenow + "testFileUploadNewPath.txt"], filePrepend="testFilePrepend")
@@ -187,13 +157,12 @@ def jobWithOutputAndPrepend():
 
 @executeWithUserProxy
 def jobWithOutputAndPrependWithUnderscore():
-
     timenow = time.strftime("%s")
     with open(os.path.join(wdir, timenow + "testFileUpload_NewPath.txt"), "w") as f:
         f.write(timenow)
     job = baseToAllJobs("jobWithOutputAndPrependWithUnderscore", jobClass)
     inp1 = [find_all(timenow + "testFileUpload_NewPath.txt", ".")[0]]
-    inp2 = [find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]]
+    inp2 = [find_all("exe-script.py", rootPath, ".")[0]]
     job.setInputSandbox(inp1 + inp2)
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     res = job.setOutputData([timenow + "testFileUpload_NewPath.txt"], filePrepend="testFilePrepend")
@@ -209,13 +178,12 @@ def jobWithOutputAndPrependWithUnderscore():
 
 @executeWithUserProxy
 def jobWithOutputAndReplication():
-
     timenow = time.strftime("%s")
     with open(os.path.join(wdir, timenow + "testFileReplication.txt"), "w") as f:
         f.write(timenow)
     job = baseToAllJobs("jobWithOutputAndReplication", jobClass)
     inp1 = [find_all(timenow + "testFileReplication.txt", ".")[0]]
-    inp2 = [find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]]
+    inp2 = [find_all("exe-script.py", rootPath, ".")[0]]
     job.setInputSandbox(inp1 + inp2)
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setOutputData([timenow + "testFileReplication.txt"], replicate="True")
@@ -229,7 +197,6 @@ def jobWithOutputAndReplication():
 
 @executeWithUserProxy
 def jobWith2OutputsToBannedSE():
-
     timenow = time.strftime("%s")
     with open(os.path.join(wdir, timenow + "testFileUploadBanned-1.txt"), "w") as f:
         f.write(timenow)
@@ -238,8 +205,8 @@ def jobWith2OutputsToBannedSE():
     job = baseToAllJobs("jobWith2OutputsToBannedSE", jobClass)
     inp1 = [find_all(timenow + "testFileUploadBanned-1.txt", ".")[0]]
     inp2 = [find_all(timenow + "testFileUploadBanned-2.txt", ".")[0]]
-    inp3 = [find_all("exe-script.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    inp4 = [find_all("partialConfig.cfg", rootPath, "/tests/System/GridTestSubmission")[0]]
+    inp3 = [find_all("exe-script.py", rootPath, ".")[0]]
+    inp4 = [find_all("partialConfig.cfg", "..", ".")[0]]
     job.setInputSandbox(inp1 + inp2 + inp3 + inp4)
     job.setExecutable("exe-script.py", "", "helloWorld.log")
     job.setConfigArgs("partialConfig.cfg")
@@ -261,11 +228,8 @@ def jobWith2OutputsToBannedSE():
 
 @executeWithUserProxy
 def jobWithSingleInputData():
-
     job = baseToAllJobs("jobWithSingleInputData-shouldGoToCERN", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -276,11 +240,8 @@ def jobWithSingleInputData():
 
 @executeWithUserProxy
 def jobWithSingleInputDataCERN():
-
     job = baseToAllJobs("jobWithSingleInputDataCERN-shouldSucceed", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -292,11 +253,8 @@ def jobWithSingleInputDataCERN():
 
 @executeWithUserProxy
 def jobWithSingleInputDataRAL():
-
     job = baseToAllJobs("jobWithSingleInputDataRAL-shouldFailOptimizers", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -308,11 +266,8 @@ def jobWithSingleInputDataRAL():
 
 @executeWithUserProxy
 def jobWithSingleInputDataIN2P3():
-
     job = baseToAllJobs("jobWithSingleInputDataIN2P3-shouldFailOptimizers", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -324,11 +279,8 @@ def jobWithSingleInputDataIN2P3():
 
 @executeWithUserProxy
 def jobWithSingleInputDataRRCKI():
-
     job = baseToAllJobs("jobWithSingleInputDataRRCKI-shouldFailOptimizers", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -340,11 +292,8 @@ def jobWithSingleInputDataRRCKI():
 
 @executeWithUserProxy
 def jobWithSingleInputDataSARA():
-
     job = baseToAllJobs("jobWithSingleInputDataSARA-shouldFailOptimizers", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -356,11 +305,8 @@ def jobWithSingleInputDataSARA():
 
 @executeWithUserProxy
 def jobWithSingleInputDataPIC():
-
     job = baseToAllJobs("jobWithSingleInputDataPIC-shouldFailOptimizers", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-single-location.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-single-location.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-single-location.py", "", "exeWithInput.log")
     # this file should be at CERN-USER only
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFileSingleLocation.txt")
@@ -372,9 +318,8 @@ def jobWithSingleInputDataPIC():
 
 @executeWithUserProxy
 def jobWithSingleInputDataSpreaded():
-
     job = baseToAllJobs("jobWithSingleInputDataSpreaded", jobClass)
-    job.setInputSandbox([find_all("exe-script-with-input.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("exe-script-with-input.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input.py", "", "exeWithInput.log")
     # this file should be at CERN-USER and IN2P3-USER
     job.setInputData("/lhcb/user/f/fstagni/test/testInputFile.txt")
@@ -385,11 +330,8 @@ def jobWithSingleInputDataSpreaded():
 
 @executeWithUserProxy
 def jobWithInputDataAndAncestor():
-
     job = baseToAllJobs("jobWithInputDataAndAncestor", jobClass)
-    job.setInputSandbox(
-        [find_all("exe-script-with-input-and-ancestor.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
+    job.setInputSandbox([find_all("exe-script-with-input-and-ancestor.py", "..", ".")[0]])
     job.setExecutable("exe-script-with-input-and-ancestor.py", "", "exeWithInput.log")
     # WARNING: Collision10!!
     job.setInputData("/lhcb/data/2010/SDST/00008375/0005/00008375_00053941_1.sdst")  # this file should be at SARA-RDST
@@ -400,134 +342,28 @@ def jobWithInputDataAndAncestor():
     return res
 
 
-@executeWithUserProxy
-def gaussJob():
-
-    job = baseToAllJobs("gaussJob", jobClass)
-    job.setInputSandbox(
-        [find_all("prodConf_Gauss_00012345_00067890_1.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
-    job.setOutputSandbox("00012345_00067890_1.sim")
-
-    optGauss = "$APPCONFIGOPTS/Gauss/Sim08-Beam3500GeV-md100-2011-nu2.py;"
-    optDec = "$DECFILESROOT/options/34112104.py;"
-    optPythia = "$LBPYTHIAROOT/options/Pythia.py;"
-    optOpts = "$APPCONFIGOPTS/Gauss/G4PL_FTFP_BERT_EmNoCuts.py;"
-    optCompr = "$APPCONFIGOPTS/Persistency/Compression-ZLIB-1.py;"
-    optPConf = "prodConf_Gauss_00012345_00067890_1.py"
-    options = optGauss + optDec + optPythia + optOpts + optCompr + optPConf
-    job.setApplication(
-        "Gauss",
-        "v45r5",
-        options,  # pylint: disable=no-member
-        extraPackages="AppConfig.v3r179;Gen/DecFiles.v27r14p1;ProdConf.v1r9",
-        systemConfig="x86_64-slc5-gcc43-opt",
-    )
-    job.setDIRACPlatform()  # pylint: disable=no-member
-    job.setCPUTime(172800)
-    res = endOfAllJobs(job)
-    return res
-
-
-@executeWithUserProxy
-def booleJob():
-
-    job = baseToAllJobs("booleJob", jobClass)
-    job.setInputSandbox(
-        [find_all("prodConf_Boole_00012345_00067890_1.py", rootPath, "/tests/System/GridTestSubmission")[0]]
-    )
-    job.setOutputSandbox("00012345_00067890_1.digi")
-
-    opts = "$APPCONFIGOPTS/Boole/Default.py;"
-    optDT = "$APPCONFIGOPTS/Boole/DataType-2011.py;"
-    optTCK = "$APPCONFIGOPTS/Boole/Boole-SiG4EnergyDeposit.py;"
-    optComp = "$APPCONFIGOPTS/Persistency/Compression-ZLIB-1.py;"
-    optPConf = "prodConf_Boole_00012345_00067890_1.py"
-    options = opts + optDT + optTCK + optComp + optPConf
-
-    job.setApplication(
-        "Boole",
-        "v26r3",
-        options,  # pylint: disable=no-member
-        inputData="/lhcb/user/f/fstagni/test/12345/12345678/00012345_00067890_1.sim",
-        extraPackages="AppConfig.v3r171;ProdConf.v1r9",
-        systemConfig="x86_64-slc5-gcc43-opt",
-    )
-
-    job.setDIRACPlatform()  # pylint: disable=no-member
-    job.setCPUTime(172800)
-    res = endOfAllJobs(job)
-    return res
-
-
-@executeWithUserProxy
-def booleJobWithConf():
-
-    job = baseToAllJobs("booleJobWithConf", jobClass)
-    job.setInputSandbox(
-        [
-            find_all("prodConf_Boole_00012345_00067890_1.py", rootPath, "/tests/System/GridTestSubmission")[0],
-            find_all("rootConfig.cfg", rootPath, "/tests/System/GridTestSubmission")[0],
-        ]
-    )
-    job.setOutputSandbox("00012345_00067890_1.digi")
-
-    opts = "$APPCONFIGOPTS/Boole/Default.py;"
-    optDT = "$APPCONFIGOPTS/Boole/DataType-2011.py;"
-    optTCK = "$APPCONFIGOPTS/Boole/Boole-SiG4EnergyDeposit.py;"
-    optComp = "$APPCONFIGOPTS/Persistency/Compression-ZLIB-1.py;"
-    optPConf = "prodConf_Boole_00012345_00067890_1.py"
-    options = opts + optDT + optTCK + optComp + optPConf
-
-    job.setApplication(
-        "Boole",
-        "v26r3",
-        options,  # pylint: disable=no-member
-        inputData="/lhcb/user/f/fstagni/test/12345/12345678/00012345_00067890_1.sim",
-        extraPackages="AppConfig.v3r171;ProdConf.v1r9",
-        systemConfig="x86_64-slc5-gcc43-opt",
-    )
-
-    job.setDIRACPlatform()  # pylint: disable=no-member
-    job.setConfigArgs("rootConfig.cfg")
-    job.setCPUTime(172800)
-    res = endOfAllJobs(job)
-    return res
-
-
-@executeWithUserProxy
-def wrongJob():
-
-    print("\n Submitting gaudiRun job (Gauss only) that will use a configuration file that contains wrong info")
-    print("This will generate a job that should become Completed, use the failover, and only later it will be Done")
-
-    job = createJob(local=False)
-    job.setName("gaudirun-gauss-stays-completed")
-    res = endOfAllJobs(job)
-    return res
-
-
 @executeWithUserProxy
 def gaussMPJob():
+    job = baseToAllJobs("GaussMP_v54r3", jobClass)
 
-    job = baseToAllJobs("GaussMP_v49r14", jobClass)
-
-    job.setInputSandbox([find_all("prodConf_Gauss_MP_test.py", rootPath, "/tests/System/GridTestSubmission")[0]])
+    job.setInputSandbox([find_all("prodConf_Gauss_MP_test.py", "..", ".")[0]])
     job.setOutputSandbox("Gauss_MP_test.sim")
 
-    options = "$APPCONFIGOPTS/Gauss/Beam6500GeV-mu100-2018-nu1.6.py;"
+    options = "$APPCONFIGOPTS/Gauss/Beam7000GeV-mu100-nu7.6-HorExtAngle.py;"
     options += "$APPCONFIGOPTS/Gauss/EnableSpillover-25ns.py;"
-    options += "$APPCONFIGOPTS/Gauss/DataType-2017.py"
-    options += "$APPCONFIGOPTS/Gauss/RICHRandomHits.py"
-    options += "$DECFILESROOT/options/10132060.py"
-    options += "$LBPYTHIA8ROOT/options/Pythia8.py"
-    options += "$APPCONFIGOPTS/Gauss/G4PL_FTFP_BERT_EmNoCuts.py"
+    options += "$DECFILESROOT/options/12143001.py;"
+    options += "$LBPYTHIA8ROOT/options/Pythia8.py;"
+    options += "$APPCONFIGOPTS/Gauss/Gauss-Upgrade-Baseline-20150522.py;"
+    options += "$APPCONFIGOPTS/Gauss/G4PL_FTFP_BERT_EmOpt2.py;"
+    options += "$APPCONFIGOPTS/Gauss/GaussMPpatch20200701.py;"
+    options += "$APPCONFIGOPTS/Persistency/Compression-LZMA-4.py"
+
     job.setApplication(
         "Gauss",
-        "v49r14",
+        "v54r3",
         options,  # pylint: disable=no-member
-        extraPackages="AppConfig.v3r383;Gen/DecFiles.v30r32;ProdConf.v2r8",
-        systemConfig="x86_64-slc6-gcc48-opt",
+        extraPackages="AppConfig.v3r400;Gen/DecFiles.v30r42;ProdConf.v3r0",
+        systemConfig="x86_64-centos7-gcc9-opt",
     )
     job.setDIRACPlatform()  # pylint: disable=no-member
     job.setCPUTime(172800)
